/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/build/cython/src/cython/Cython/Compiler/FlowControl.pxd"
        ],
        "name": "Cython.Compiler.FlowControl",
        "sources": [
            "/build/cython/src/cython/Cython/Compiler/FlowControl.py"
        ]
    },
    "module_name": "Cython.Compiler.FlowControl"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__Cython__Compiler__FlowControl
#define __PYX_HAVE_API__Cython__Compiler__FlowControl
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "Cython/Compiler/FlowControl.py",
  "Cython/Compiler/FlowControl.pxd",
  "(tree fragment)",
  "Cython/Compiler/Visitor.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor;
struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;
struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection;
struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis;
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren;
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children;
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren;
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild;

/* "Visitor.pxd":12
 *     cdef _visitchild(self, child, parent, attrname, idx)
 *     cdef dict _visitchildren(self, parent, attrs, exclude)
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)             # <<<<<<<<<<<<<<
 *     cdef _raise_compiler_error(self, child, e)
 * 
*/
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren {
  int __pyx_n;
  PyObject *attrs;
  PyObject *exclude;
};

/* "Visitor.pxd":16
 * 
 * cdef class VisitorTransform(TreeVisitor):
 *     cdef dict _process_children(self, parent, attrs=*, exclude=*)             # <<<<<<<<<<<<<<
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)
 *     cdef list _flatten_list(self, list orig_list)
*/
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children {
  int __pyx_n;
  PyObject *attrs;
  PyObject *exclude;
};

/* "Visitor.pxd":17
 * cdef class VisitorTransform(TreeVisitor):
 *     cdef dict _process_children(self, parent, attrs=*, exclude=*)
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)             # <<<<<<<<<<<<<<
 *     cdef list _flatten_list(self, list orig_list)
 *     cpdef visitchild(self, parent, str attr, idx=*)
*/
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren {
  int __pyx_n;
  PyObject *attrs;
  PyObject *exclude;
};

/* "Visitor.pxd":19
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)
 *     cdef list _flatten_list(self, list orig_list)
 *     cpdef visitchild(self, parent, str attr, idx=*)             # <<<<<<<<<<<<<<
 * 
 * cdef class CythonTransform(VisitorTransform):
*/
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild {
  int __pyx_n;
  PyObject *idx;
};
struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock;
struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock;
struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment;
struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment;

/* "Cython/Compiler/FlowControl.pxd":62
 *     cdef public Py_ssize_t in_try_block
 * 
 *     cpdef newblock(self, ControlBlock parent=*)             # <<<<<<<<<<<<<<
 *     cpdef nextblock(self, ControlBlock parent=*)
 *     cpdef bint is_tracked(self, entry)
*/
struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock {
  int __pyx_n;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *parent;
};

/* "Cython/Compiler/FlowControl.pxd":63
 * 
 *     cpdef newblock(self, ControlBlock parent=*)
 *     cpdef nextblock(self, ControlBlock parent=*)             # <<<<<<<<<<<<<<
 *     cpdef bint is_tracked(self, entry)
 *     cpdef bint is_statically_assigned(self, entry)
*/
struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock {
  int __pyx_n;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *parent;
};

/* "Cython/Compiler/FlowControl.pxd":67
 *     cpdef bint is_statically_assigned(self, entry)
 *     cpdef mark_position(self, node)
 *     cpdef mark_assignment(self, lhs, rhs, entry, rhs_scope=*)             # <<<<<<<<<<<<<<
 *     cpdef mark_argument(self, lhs, rhs, entry)
 *     cpdef mark_deletion(self, node, entry)
*/
struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment {
  int __pyx_n;
  PyObject *rhs_scope;
};

/* "Cython/Compiler/FlowControl.pxd":96
 *     cdef bint in_inplace_assignment
 * 
 *     cpdef mark_assignment(self, lhs, rhs=*, rhs_scope=*)             # <<<<<<<<<<<<<<
 *     cpdef mark_position(self, node)
*/
struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment {
  int __pyx_n;
  PyObject *rhs;
  PyObject *rhs_scope;
};

/* "Visitor.pxd":3
 * cimport cython
 * 
 * cdef class TreeVisitor:             # <<<<<<<<<<<<<<
 *     cdef public list access_path
 *     cdef dict dispatch_table
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_vtab;
  PyObject *access_path;
  PyObject *dispatch_table;
};


/* "Visitor.pxd":15
 *     cdef _raise_compiler_error(self, child, e)
 * 
 * cdef class VisitorTransform(TreeVisitor):             # <<<<<<<<<<<<<<
 *     cdef dict _process_children(self, parent, attrs=*, exclude=*)
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
};


/* "Visitor.pxd":21
 *     cpdef visitchild(self, parent, str attr, idx=*)
 * 
 * cdef class CythonTransform(VisitorTransform):             # <<<<<<<<<<<<<<
 *     cdef public context
 *     cdef public current_directives
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_base;
  PyObject *context;
  PyObject *current_directives;
};


/* "Visitor.pxd":25
 *     cdef public current_directives
 * 
 * cdef class ScopeTrackingTransform(CythonTransform):             # <<<<<<<<<<<<<<
 *     cdef public scope_type
 *     cdef public scope_node
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
  PyObject *scope_type;
  PyObject *scope_node;
};


/* "Visitor.pxd":30
 *     cdef visit_scope(self, node, scope_type)
 * 
 * cdef class EnvTransform(CythonTransform):             # <<<<<<<<<<<<<<
 *     cdef public list env_stack
 * 
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
  PyObject *env_stack;
};


/* "Visitor.pxd":33
 *     cdef public list env_stack
 * 
 * cdef class MethodDispatcherTransform(EnvTransform):             # <<<<<<<<<<<<<<
 *     @cython.final
 *     cdef _visit_binop_node(self, node)
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform __pyx_base;
};


/* "Visitor.pxd":47
 *                                      node, function, arg_list, kwargs)
 * 
 * cdef class RecursiveNodeReplacer(VisitorTransform):             # <<<<<<<<<<<<<<
 *     cdef public orig_node
 *     cdef public new_node
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_base;
  PyObject *orig_node;
  PyObject *new_node;
};


/* "Visitor.pxd":51
 *     cdef public new_node
 * 
 * cdef class NodeFinder(TreeVisitor):             # <<<<<<<<<<<<<<
 *     cdef node
 *     cdef public bint found
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
  PyObject *node;
  int found;
};


/* "Cython/Compiler/FlowControl.pxd":5
 * from .Visitor cimport CythonTransform, TreeVisitor
 * 
 * cdef class ControlBlock:             # <<<<<<<<<<<<<<
 *     cdef public set children
 *     cdef public set parents
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_vtab;
  PyObject *children;
  PyObject *parents;
  PyObject *positions;
  PyObject *stats;
  PyObject *gen;
  PyObject *bounded;
  PyObject *i_input;
  PyObject *i_output;
  PyObject *i_gen;
  PyObject *i_kill;
  PyObject *i_state;
};


/* "Cython/Compiler/FlowControl.pxd":24
 *     cpdef add_child(self, block)
 * 
 * cdef class ExitBlock(ControlBlock):             # <<<<<<<<<<<<<<
 *     cpdef bint empty(self)
 * 
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock __pyx_base;
};


/* "Cython/Compiler/FlowControl.pxd":27
 *     cpdef bint empty(self)
 * 
 * cdef class NameAssignment:             # <<<<<<<<<<<<<<
 *     cdef public bint is_arg
 *     cdef public bint is_deletion
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment {
  PyObject_HEAD
  int is_arg;
  int is_deletion;
  PyObject *lhs;
  PyObject *rhs;
  PyObject *entry;
  PyObject *pos;
  PyObject *refs;
  PyObject *bit;
  PyObject *inferred_type;
  PyObject *rhs_scope;
};


/* "Cython/Compiler/FlowControl.pxd":39
 *     cdef public object rhs_scope
 * 
 * cdef class AssignmentList:             # <<<<<<<<<<<<<<
 *     cdef public object bit
 *     cdef public object mask
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList {
  PyObject_HEAD
  PyObject *bit;
  PyObject *mask;
  PyObject *stats;
};


/* "Cython/Compiler/FlowControl.pxd":44
 *     cdef public list stats
 * 
 * cdef class AssignmentCollector(TreeVisitor):             # <<<<<<<<<<<<<<
 *     cdef list assignments
 * 
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
  PyObject *assignments;
};


/* "Cython/Compiler/FlowControl.pxd":47
 *     cdef list assignments
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class ControlFlow:
 *     cdef public set blocks
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_vtab;
  PyObject *blocks;
  PyObject *entries;
  PyObject *loops;
  PyObject *exceptions;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *entry_point;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *exit_point;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *block;
  PyObject *assmts;
  Py_ssize_t in_try_block;
};


/* "Cython/Compiler/FlowControl.pxd":76
 *     cdef reaching_definitions(self)
 * 
 * cdef class Uninitialized:             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized {
  PyObject_HEAD
};


/* "Cython/Compiler/FlowControl.pxd":79
 *     pass
 * 
 * cdef class Unknown:             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown {
  PyObject_HEAD
};


/* "Cython/Compiler/FlowControl.pxd":82
 *     pass
 * 
 * cdef class MessageCollection:             # <<<<<<<<<<<<<<
 *     cdef set messages
 * 
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection {
  PyObject_HEAD
  PyObject *messages;
};


/* "Cython/Compiler/FlowControl.pxd":85
 *     cdef set messages
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class ControlFlowAnalysis(CythonTransform):
 *     cdef object gv_ctx
*/
struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
  PyObject *gv_ctx;
  PyObject *constant_folder;
  PyObject *reductions;
  PyObject *stack;
  PyObject *env;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *flow;
  PyObject *object_expr;
  int in_inplace_assignment;
};



/* "Visitor.pxd":3
 * cimport cython
 * 
 * cdef class TreeVisitor:             # <<<<<<<<<<<<<<
 *     cdef public list access_path
 *     cdef dict dispatch_table
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor {
  PyObject *(*visit)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_visit)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *);
  PyObject *(*find_handler)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *);
  PyObject *(*_visitchild)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_visitchildren)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *, PyObject *);
  PyObject *(*visitchildren)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren *__pyx_optional_args);
  PyObject *(*_raise_compiler_error)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor;


/* "Visitor.pxd":15
 *     cdef _raise_compiler_error(self, child, e)
 * 
 * cdef class VisitorTransform(TreeVisitor):             # <<<<<<<<<<<<<<
 *     cdef dict _process_children(self, parent, attrs=*, exclude=*)
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
  PyObject *(*_process_children)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children *__pyx_optional_args);
  PyObject *(*_flatten_list)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *);
  PyObject *(*visitchild)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild *__pyx_optional_args);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform;


/* "Visitor.pxd":21
 *     cpdef visitchild(self, parent, str attr, idx=*)
 * 
 * cdef class CythonTransform(VisitorTransform):             # <<<<<<<<<<<<<<
 *     cdef public context
 *     cdef public current_directives
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform;


/* "Visitor.pxd":25
 *     cdef public current_directives
 * 
 * cdef class ScopeTrackingTransform(CythonTransform):             # <<<<<<<<<<<<<<
 *     cdef public scope_type
 *     cdef public scope_node
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
  PyObject *(*visit_scope)(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;


/* "Visitor.pxd":30
 *     cdef visit_scope(self, node, scope_type)
 * 
 * cdef class EnvTransform(CythonTransform):             # <<<<<<<<<<<<<<
 *     cdef public list env_stack
 * 
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_EnvTransform;


/* "Visitor.pxd":33
 *     cdef public list env_stack
 * 
 * cdef class MethodDispatcherTransform(EnvTransform):             # <<<<<<<<<<<<<<
 *     @cython.final
 *     cdef _visit_binop_node(self, node)
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform __pyx_base;
  PyObject *(*_visit_binop_node)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *);
  PyObject *(*_find_handler)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, int);
  PyObject *(*_delegate_to_assigned_value)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_dispatch_to_handler)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_dispatch_to_method_handler)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;


/* "Visitor.pxd":47
 *                                      node, function, arg_list, kwargs)
 * 
 * cdef class RecursiveNodeReplacer(VisitorTransform):             # <<<<<<<<<<<<<<
 *     cdef public orig_node
 *     cdef public new_node
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_vtabptr_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;


/* "Visitor.pxd":51
 *     cdef public new_node
 * 
 * cdef class NodeFinder(TreeVisitor):             # <<<<<<<<<<<<<<
 *     cdef node
 *     cdef public bint found
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_NodeFinder {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_vtabptr_6Cython_8Compiler_7Visitor_NodeFinder;


/* "Cython/Compiler/FlowControl.py":34
 * 
 * 
 * class ControlBlock:             # <<<<<<<<<<<<<<
 *     """Control flow graph node. Sequence of assignments and name references.
 * 
*/

struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock {
  int (*empty)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *, int __pyx_skip_dispatch);
  PyObject *(*detach)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *, int __pyx_skip_dispatch);
  PyObject *(*add_child)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlBlock;


/* "Cython/Compiler/FlowControl.py":89
 * 
 * 
 * class ExitBlock(ControlBlock):             # <<<<<<<<<<<<<<
 *     """Non-empty exit point block."""
 * 
*/

struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ExitBlock {
  struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_vtabptr_6Cython_8Compiler_11FlowControl_ExitBlock;


/* "Cython/Compiler/FlowControl.py":680
 * 
 * 
 * class AssignmentCollector(TreeVisitor):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         super().__init__()
*/

struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_AssignmentCollector {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_vtabptr_6Cython_8Compiler_11FlowControl_AssignmentCollector;


/* "Cython/Compiler/FlowControl.py":101
 * 
 * 
 * class ControlFlow:             # <<<<<<<<<<<<<<
 *     """Control-flow graph.
 * 
*/

struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlow {
  PyObject *(*newblock)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock *__pyx_optional_args);
  PyObject *(*nextblock)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock *__pyx_optional_args);
  int (*is_tracked)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch);
  int (*is_statically_assigned)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*mark_position)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*mark_assignment)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment *__pyx_optional_args);
  PyObject *(*mark_argument)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*mark_deletion)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*mark_reference)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*normalize)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch);
  PyObject *(*initialize)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch);
  PyObject *(*map_one)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*reaching_definitions)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlow;
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock *__pyx_optional_args);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock *__pyx_optional_args);
static int __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch);
static int __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_statically_assigned(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment *__pyx_optional_args);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_argument(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_deletion(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_reference(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_normalize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_initialize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_map_one(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_reaching_definitions(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *);


/* "Cython/Compiler/FlowControl.py":696
 * 
 * 
 * class ControlFlowAnalysis(CythonTransform):             # <<<<<<<<<<<<<<
 * 
 *     def find_in_stack(self, env):
*/

struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
  PyObject *(*mark_assignment)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment *__pyx_optional_args);
  PyObject *(*mark_position)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis;
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment *__pyx_optional_args);
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *, PyObject *, int __pyx_skip_dispatch);
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* RejectKeywords.export */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* IterFinish.proto (used by set_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* set_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set);
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyObjectVectorCallKwBuilder.proto */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCallNoArg.proto (used by pyfrozenset_new) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* pyfrozenset_new.proto (used by PySetContains) */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* PySetContains.proto */
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* py_set_remove.proto */
static CYTHON_INLINE int __Pyx_PySet_Remove(PyObject *set, PyObject *key);

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_LshiftObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_LshiftObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceLshift(op1, op2) : PyNumber_Lshift(op1, op2))
#endif

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* PyObjectCall2Args.proto (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethod1.proto (used by append) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* py_set_discard.proto */
static CYTHON_INLINE int __Pyx_PySet_Discard(PyObject *set, PyObject *key);

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared)
    #endif
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_OwnStrongReference)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_SharedReference)
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right))

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CallTypeTraverse.proto */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* DelItemOnTypeDict.proto (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k);
#define __Pyx_DelItemOnTypeDict(tp, k) __Pyx__DelItemOnTypeDict((PyTypeObject*)tp, k)

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CyFunctionClassCell.proto */
static int __Pyx_CyFunction_InitClassCell(PyObject *cyfunctions, PyObject *classobj);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CheckUnpickleChecksum.proto */
static CYTHON_INLINE int __Pyx_CheckUnpickleChecksum(long checksum, long checksum1, long checksum2, long checksum3, const char *members);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* UpdateUnpickledDict.proto */
static int __Pyx_UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."

static int __pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_empty(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_detach(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_add_child(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_block, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6Cython_8Compiler_11FlowControl_9ExitBlock_empty(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock *__pyx_optional_args); /* proto*/
static int __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_statically_assigned(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_argument(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_deletion(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_reference(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_normalize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_initialize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_map_one(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_istate, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_reaching_definitions(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_lhs, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "Cython.Compiler.Visitor" */

/* Module declarations from "Cython.Compiler.FlowControl" */
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_PyrexTypes = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_Nodes = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_Builtin = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_Options = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_InternalError = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_error = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_warning = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_fake_rhs_expr = 0;
static PyObject *__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode = 0;
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_check_definitions(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlBlock__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ExitBlock__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_AssignmentList__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlFlow__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_NameAssignment__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_Uninitialized__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_Unknown__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_MessageCollection__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_AssignmentCollector__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlFlowAnalysis__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "Cython.Compiler.FlowControl"
extern int __pyx_module_is_main_Cython__Compiler__FlowControl;
int __pyx_module_is_main_Cython__Compiler__FlowControl = 0;

/* Implementation of "Cython.Compiler.FlowControl" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_super;
static PyObject *__pyx_builtin_min;
static PyObject *__pyx_builtin_max;
static PyObject *__pyx_builtin_reversed;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_enumerate;
/* #### Code section: string_decls ### */
static const char __pyx_k__2[] = "";
static const char __pyx_k_messages[] = "messages";
static const char __pyx_k_bit_mask_stats[] = "bit, mask, stats";
static const char __pyx_k_access_path_assignments_dispatch[] = "access_path, assignments, dispatch_table";
static const char __pyx_k_access_path_constant_folder_cont[] = "access_path, constant_folder, context, current_directives, dispatch_table, env, flow, gv_ctx, in_inplace_assignment, object_expr, reductions, stack";
static const char __pyx_k_assmts_block_blocks_entries_entr[] = "assmts, block, blocks, entries, entry_point, exceptions, exit_point, in_try_block, loops";
static const char __pyx_k_bit_entry_inferred_type_is_arg_i[] = "bit, entry, inferred_type, is_arg, is_deletion, lhs, pos, refs, rhs, rhs_scope";
static const char __pyx_k_bounded_children_gen_i_gen_i_inp[] = "bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13TypedExprNode___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_type, PyObject *__pyx_v_may_be_none, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13TypedExprNode_2may_be_none(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_2empty(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_4detach(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6add_child(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_block); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_10__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_empty(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_2__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_4__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_2__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_2newblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_4nextblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6is_tracked(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_8is_statically_assigned(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry, PyObject *__pyx_v_rhs_scope); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_14mark_argument(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_16mark_deletion(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_18mark_reference(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_20normalize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_22initialize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_24map_one(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_istate, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_26__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_28__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9LoopDescr___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_next_block, PyObject *__pyx_v_loop_block); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14ExceptionDescr___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_entry_point, PyObject *__pyx_v_finally_enter, PyObject *__pyx_v_finally_exit); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry, PyObject *__pyx_v_rhs_scope); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_2__repr__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4infer_type(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6type_dependencies(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4type___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_8__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_10__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment_2infer_type(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment_4type_dependencies(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_8Argument___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12NameDeletion___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12NameDeletion_2infer_type(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13Uninitialized___reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13Uninitialized_2__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_7Unknown___reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_7Unknown_2__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13NameReference___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13NameReference_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16ControlFlowState___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16ControlFlowState_2one(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_2add(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_child); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_4nodeid(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_block); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_6extract_sources(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_block); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_8render(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fp, PyObject *__pyx_v_name, PyObject *__pyx_v_annotate_defs); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_10escape(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_2GV___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_flow); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_2GV_2render(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fp, PyObject *__pyx_v_ctx, PyObject *__pyx_v_annotate_defs); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_2error(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self, PyObject *__pyx_v_pos, PyObject *__pyx_v_message); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_4warning(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self, PyObject *__pyx_v_pos, PyObject *__pyx_v_message); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_6report(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_8__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_10__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_2visit_Node(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_4visit_SingleAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_6visit_CascadedAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_8__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_10__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_find_in_stack(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_env); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_2visit_ModuleNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_4visit_FuncDefNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_6visit_DefNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_8visit_GeneratorBodyDefNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_10visit_CTypeDefNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_12mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_rhs_scope); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_14mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_16visit_FromImportStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_18visit_AssignmentNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_20visit_SingleAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_22visit_CascadedAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_24visit_ParallelAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_26visit_InPlaceAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_28visit_DelStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_30visit_CArgDeclNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_32visit_NameNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_34visit_StatListNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_36visit_Node(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_38visit_SizeofVarNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_40visit_TypeidNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_42visit_IfStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_44visit_AssertStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_46visit_WhileStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_48mark_forloop_target(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_50mark_parallel_forloop_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_52visit_AsyncForStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_54visit_ForInStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_56_delete_privates(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_exclude); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_58visit_ParallelRangeNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_60visit_ParallelWithBlockNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_62visit_ForFromStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_64visit_LoopNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_66visit_WithTargetAssignmentStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_68visit_WithStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_70visit_TryExceptStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_72visit_TryFinallyStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_74visit_RaiseStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_76visit_ReraiseStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_78visit_ReturnStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_80visit_BreakStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_82visit_ContinueStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_84visit_ComprehensionNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_86visit_ScopedExprNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_88visit_PyClassDefNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_90visit_CClassDefNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_92visit_AmpersandNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_94visit_BoolBinopNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_96visit_CondExprNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_98__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_100__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlBlock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_2__pyx_unpickle_ExitBlock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_4__pyx_unpickle_AssignmentList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_6__pyx_unpickle_ControlFlow(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_8__pyx_unpickle_NameAssignment(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_10__pyx_unpickle_Uninitialized(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12__pyx_unpickle_Unknown(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14__pyx_unpickle_MessageCollection(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16__pyx_unpickle_AssignmentCollector(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_18__pyx_unpickle_ControlFlowAnalysis(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlBlock(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_ExitBlock(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_NameAssignment(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_AssignmentList(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_AssignmentCollector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlFlow(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_Uninitialized(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_Unknown(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_MessageCollection(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_Unknown;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection;
  PyObject *__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop;
  PyObject *__pyx_slice[2];
  PyObject *__pyx_tuple[9];
  PyObject *__pyx_codeobj_tab[125];
  PyObject *__pyx_string_tab[647];
  PyObject *__pyx_number_tab[12];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_Cannot_read_reduction_variable_i __pyx_string_tab[1]
#define __pyx_kp_u_Cython_Compiler __pyx_string_tab[2]
#define __pyx_kp_u_Cython_Compiler_Errors __pyx_string_tab[3]
#define __pyx_kp_u_Cython_Compiler_FlowControl_py __pyx_string_tab[4]
#define __pyx_kp_u_Cython_Compiler_Optimize __pyx_string_tab[5]
#define __pyx_kp_u_Cython_Compiler_Visitor __pyx_string_tab[6]
#define __pyx_kp_u_Exception_handling_helper_entry __pyx_string_tab[7]
#define __pyx_kp_u_Generic_loops_are_not_supported __pyx_string_tab[8]
#define __pyx_kp_u_Graphviz_DOT_renderer __pyx_string_tab[9]
#define __pyx_kp_u_Graphviz_subgraph_object __pyx_string_tab[10]
#define __pyx_kp_u_Initialised_at_declaration_time __pyx_string_tab[11]
#define __pyx_kp_u_None __pyx_string_tab[12]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[13]
#define __pyx_kp_u_Unhandled_assignment_node_s __pyx_string_tab[14]
#define __pyx_kp_u_Unused_argument_s __pyx_string_tab[15]
#define __pyx_kp_u_Unused_argument_value_s __pyx_string_tab[16]
#define __pyx_kp_u_Unused_entry_s __pyx_string_tab[17]
#define __pyx_kp_u_Unused_result_in_s __pyx_string_tab[18]
#define __pyx_kp_u__10 __pyx_string_tab[19]
#define __pyx_kp_u__11 __pyx_string_tab[20]
#define __pyx_kp_u__12 __pyx_string_tab[21]
#define __pyx_kp_u__13 __pyx_string_tab[22]
#define __pyx_kp_u__14 __pyx_string_tab[23]
#define __pyx_kp_u__15 __pyx_string_tab[24]
#define __pyx_kp_u__17 __pyx_string_tab[25]
#define __pyx_kp_u__18 __pyx_string_tab[26]
#define __pyx_kp_u__19 __pyx_string_tab[27]
#define __pyx_kp_u__2 __pyx_string_tab[28]
#define __pyx_kp_u__20 __pyx_string_tab[29]
#define __pyx_kp_u__3 __pyx_string_tab[30]
#define __pyx_kp_u__4 __pyx_string_tab[31]
#define __pyx_kp_u__5 __pyx_string_tab[32]
#define __pyx_kp_u__6 __pyx_string_tab[33]
#define __pyx_kp_u__7 __pyx_string_tab[34]
#define __pyx_kp_u__8 __pyx_string_tab[35]
#define __pyx_kp_u__9 __pyx_string_tab[36]
#define __pyx_kp_u_add_note __pyx_string_tab[37]
#define __pyx_kp_u_block_d __pyx_string_tab[38]
#define __pyx_kp_u_can_not_delete_variable_s_refere __pyx_string_tab[39]
#define __pyx_kp_u_control_flow_dot_annotate_defs __pyx_string_tab[40]
#define __pyx_kp_u_control_flow_dot_output __pyx_string_tab[41]
#define __pyx_kp_u_digraph_s __pyx_string_tab[42]
#define __pyx_kp_u_disable __pyx_string_tab[43]
#define __pyx_kp_u_enable __pyx_string_tab[44]
#define __pyx_kp_u_entry_2 __pyx_string_tab[45]
#define __pyx_kp_u_gc __pyx_string_tab[46]
#define __pyx_kp_u_isenabled __pyx_string_tab[47]
#define __pyx_kp_u_label __pyx_string_tab[48]
#define __pyx_kp_u_local_variable_s_might_be_refere __pyx_string_tab[49]
#define __pyx_kp_u_local_variable_s_referenced_befo __pyx_string_tab[50]
#define __pyx_kp_u_maybe_initialized_inside_a_clos __pyx_string_tab[51]
#define __pyx_kp_u_n __pyx_string_tab[52]
#define __pyx_kp_u_node_shape_box __pyx_string_tab[53]
#define __pyx_kp_u_reference __pyx_string_tab[54]
#define __pyx_kp_u_subgraph_s __pyx_string_tab[55]
#define __pyx_kp_u_tree_fragment __pyx_string_tab[56]
#define __pyx_kp_u_warn_maybe_uninitialized __pyx_string_tab[57]
#define __pyx_kp_u_warn_unused __pyx_string_tab[58]
#define __pyx_kp_u_warn_unused_arg __pyx_string_tab[59]
#define __pyx_kp_u_warn_unused_result __pyx_string_tab[60]
#define __pyx_n_u_Argument __pyx_string_tab[61]
#define __pyx_n_u_Argument___init __pyx_string_tab[62]
#define __pyx_n_u_AssignmentCollector __pyx_string_tab[63]
#define __pyx_n_u_AssignmentCollector___reduce_cyt __pyx_string_tab[64]
#define __pyx_n_u_AssignmentCollector___setstate_c __pyx_string_tab[65]
#define __pyx_n_u_AssignmentCollector_visit_Cascad __pyx_string_tab[66]
#define __pyx_n_u_AssignmentCollector_visit_Node __pyx_string_tab[67]
#define __pyx_n_u_AssignmentCollector_visit_Single __pyx_string_tab[68]
#define __pyx_n_u_AssignmentList __pyx_string_tab[69]
#define __pyx_n_u_AssignmentList___reduce_cython __pyx_string_tab[70]
#define __pyx_n_u_AssignmentList___setstate_cython __pyx_string_tab[71]
#define __pyx_n_u_AsyncForStatNode __pyx_string_tab[72]
#define __pyx_n_u_AsyncIteratorNode __pyx_string_tab[73]
#define __pyx_n_u_Builtin __pyx_string_tab[74]
#define __pyx_n_u_ConstantFolding __pyx_string_tab[75]
#define __pyx_n_u_ControlBlock __pyx_string_tab[76]
#define __pyx_n_u_ControlBlock___reduce_cython __pyx_string_tab[77]
#define __pyx_n_u_ControlBlock___setstate_cython __pyx_string_tab[78]
#define __pyx_n_u_ControlBlock_add_child __pyx_string_tab[79]
#define __pyx_n_u_ControlBlock_detach __pyx_string_tab[80]
#define __pyx_n_u_ControlBlock_empty __pyx_string_tab[81]
#define __pyx_n_u_ControlFlow __pyx_string_tab[82]
#define __pyx_n_u_ControlFlowAnalysis __pyx_string_tab[83]
#define __pyx_n_u_ControlFlowAnalysis___reduce_cyt __pyx_string_tab[84]
#define __pyx_n_u_ControlFlowAnalysis___setstate_c __pyx_string_tab[85]
#define __pyx_n_u_ControlFlowAnalysis__delete_priv __pyx_string_tab[86]
#define __pyx_n_u_ControlFlowAnalysis_find_in_stac __pyx_string_tab[87]
#define __pyx_n_u_ControlFlowAnalysis_mark_assignm __pyx_string_tab[88]
#define __pyx_n_u_ControlFlowAnalysis_mark_forloop __pyx_string_tab[89]
#define __pyx_n_u_ControlFlowAnalysis_mark_paralle __pyx_string_tab[90]
#define __pyx_n_u_ControlFlowAnalysis_mark_positio __pyx_string_tab[91]
#define __pyx_n_u_ControlFlowAnalysis_visit_Ampers __pyx_string_tab[92]
#define __pyx_n_u_ControlFlowAnalysis_visit_Assert __pyx_string_tab[93]
#define __pyx_n_u_ControlFlowAnalysis_visit_Assign __pyx_string_tab[94]
#define __pyx_n_u_ControlFlowAnalysis_visit_AsyncF __pyx_string_tab[95]
#define __pyx_n_u_ControlFlowAnalysis_visit_BoolBi __pyx_string_tab[96]
#define __pyx_n_u_ControlFlowAnalysis_visit_BreakS __pyx_string_tab[97]
#define __pyx_n_u_ControlFlowAnalysis_visit_CArgDe __pyx_string_tab[98]
#define __pyx_n_u_ControlFlowAnalysis_visit_CClass __pyx_string_tab[99]
#define __pyx_n_u_ControlFlowAnalysis_visit_CTypeD __pyx_string_tab[100]
#define __pyx_n_u_ControlFlowAnalysis_visit_Cascad __pyx_string_tab[101]
#define __pyx_n_u_ControlFlowAnalysis_visit_Compre __pyx_string_tab[102]
#define __pyx_n_u_ControlFlowAnalysis_visit_CondEx __pyx_string_tab[103]
#define __pyx_n_u_ControlFlowAnalysis_visit_Contin __pyx_string_tab[104]
#define __pyx_n_u_ControlFlowAnalysis_visit_DefNod __pyx_string_tab[105]
#define __pyx_n_u_ControlFlowAnalysis_visit_DelSta __pyx_string_tab[106]
#define __pyx_n_u_ControlFlowAnalysis_visit_ForFro __pyx_string_tab[107]
#define __pyx_n_u_ControlFlowAnalysis_visit_ForInS __pyx_string_tab[108]
#define __pyx_n_u_ControlFlowAnalysis_visit_FromIm __pyx_string_tab[109]
#define __pyx_n_u_ControlFlowAnalysis_visit_FuncDe __pyx_string_tab[110]
#define __pyx_n_u_ControlFlowAnalysis_visit_Genera __pyx_string_tab[111]
#define __pyx_n_u_ControlFlowAnalysis_visit_IfStat __pyx_string_tab[112]
#define __pyx_n_u_ControlFlowAnalysis_visit_InPlac __pyx_string_tab[113]
#define __pyx_n_u_ControlFlowAnalysis_visit_LoopNo __pyx_string_tab[114]
#define __pyx_n_u_ControlFlowAnalysis_visit_Module __pyx_string_tab[115]
#define __pyx_n_u_ControlFlowAnalysis_visit_NameNo __pyx_string_tab[116]
#define __pyx_n_u_ControlFlowAnalysis_visit_Node __pyx_string_tab[117]
#define __pyx_n_u_ControlFlowAnalysis_visit_Parall __pyx_string_tab[118]
#define __pyx_n_u_ControlFlowAnalysis_visit_Parall_2 __pyx_string_tab[119]
#define __pyx_n_u_ControlFlowAnalysis_visit_Parall_3 __pyx_string_tab[120]
#define __pyx_n_u_ControlFlowAnalysis_visit_PyClas __pyx_string_tab[121]
#define __pyx_n_u_ControlFlowAnalysis_visit_RaiseS __pyx_string_tab[122]
#define __pyx_n_u_ControlFlowAnalysis_visit_Rerais __pyx_string_tab[123]
#define __pyx_n_u_ControlFlowAnalysis_visit_Return __pyx_string_tab[124]
#define __pyx_n_u_ControlFlowAnalysis_visit_Scoped __pyx_string_tab[125]
#define __pyx_n_u_ControlFlowAnalysis_visit_Single __pyx_string_tab[126]
#define __pyx_n_u_ControlFlowAnalysis_visit_Sizeof __pyx_string_tab[127]
#define __pyx_n_u_ControlFlowAnalysis_visit_StatLi __pyx_string_tab[128]
#define __pyx_n_u_ControlFlowAnalysis_visit_TryExc __pyx_string_tab[129]
#define __pyx_n_u_ControlFlowAnalysis_visit_TryFin __pyx_string_tab[130]
#define __pyx_n_u_ControlFlowAnalysis_visit_Typeid __pyx_string_tab[131]
#define __pyx_n_u_ControlFlowAnalysis_visit_WhileS __pyx_string_tab[132]
#define __pyx_n_u_ControlFlowAnalysis_visit_WithSt __pyx_string_tab[133]
#define __pyx_n_u_ControlFlowAnalysis_visit_WithTa __pyx_string_tab[134]
#define __pyx_n_u_ControlFlowState __pyx_string_tab[135]
#define __pyx_n_u_ControlFlowState___init __pyx_string_tab[136]
#define __pyx_n_u_ControlFlowState_one __pyx_string_tab[137]
#define __pyx_n_u_ControlFlow___reduce_cython __pyx_string_tab[138]
#define __pyx_n_u_ControlFlow___setstate_cython __pyx_string_tab[139]
#define __pyx_n_u_ControlFlow_initialize __pyx_string_tab[140]
#define __pyx_n_u_ControlFlow_is_statically_assign __pyx_string_tab[141]
#define __pyx_n_u_ControlFlow_is_tracked __pyx_string_tab[142]
#define __pyx_n_u_ControlFlow_map_one __pyx_string_tab[143]
#define __pyx_n_u_ControlFlow_mark_argument __pyx_string_tab[144]
#define __pyx_n_u_ControlFlow_mark_assignment __pyx_string_tab[145]
#define __pyx_n_u_ControlFlow_mark_deletion __pyx_string_tab[146]
#define __pyx_n_u_ControlFlow_mark_position __pyx_string_tab[147]
#define __pyx_n_u_ControlFlow_mark_reference __pyx_string_tab[148]
#define __pyx_n_u_ControlFlow_newblock __pyx_string_tab[149]
#define __pyx_n_u_ControlFlow_nextblock __pyx_string_tab[150]
#define __pyx_n_u_ControlFlow_normalize __pyx_string_tab[151]
#define __pyx_n_u_CythonTransform __pyx_string_tab[152]
#define __pyx_n_u_Cython_Compiler_FlowControl __pyx_string_tab[153]
#define __pyx_n_u_Errors __pyx_string_tab[154]
#define __pyx_n_u_ExceptionDescr __pyx_string_tab[155]
#define __pyx_n_u_ExceptionDescr___init __pyx_string_tab[156]
#define __pyx_n_u_ExitBlock __pyx_string_tab[157]
#define __pyx_n_u_ExitBlock___reduce_cython __pyx_string_tab[158]
#define __pyx_n_u_ExitBlock___setstate_cython __pyx_string_tab[159]
#define __pyx_n_u_ExitBlock_empty __pyx_string_tab[160]
#define __pyx_n_u_ExprNode __pyx_string_tab[161]
#define __pyx_n_u_ExprNodes __pyx_string_tab[162]
#define __pyx_n_u_ForInStatNode __pyx_string_tab[163]
#define __pyx_n_u_GV __pyx_string_tab[164]
#define __pyx_n_u_GVContext __pyx_string_tab[165]
#define __pyx_n_u_GVContext___init __pyx_string_tab[166]
#define __pyx_n_u_GVContext_add __pyx_string_tab[167]
#define __pyx_n_u_GVContext_escape __pyx_string_tab[168]
#define __pyx_n_u_GVContext_extract_sources __pyx_string_tab[169]
#define __pyx_n_u_GVContext_nodeid __pyx_string_tab[170]
#define __pyx_n_u_GVContext_render __pyx_string_tab[171]
#define __pyx_n_u_GV___init __pyx_string_tab[172]
#define __pyx_n_u_GV_render __pyx_string_tab[173]
#define __pyx_n_u_IntNode __pyx_string_tab[174]
#define __pyx_n_u_InternalError __pyx_string_tab[175]
#define __pyx_n_u_IteratorNode __pyx_string_tab[176]
#define __pyx_n_u_LoopDescr __pyx_string_tab[177]
#define __pyx_n_u_LoopDescr___init __pyx_string_tab[178]
#define __pyx_n_u_MessageCollection __pyx_string_tab[179]
#define __pyx_n_u_MessageCollection___reduce_cytho __pyx_string_tab[180]
#define __pyx_n_u_MessageCollection___setstate_cyt __pyx_string_tab[181]
#define __pyx_n_u_MessageCollection_error __pyx_string_tab[182]
#define __pyx_n_u_MessageCollection_report __pyx_string_tab[183]
#define __pyx_n_u_MessageCollection_warning __pyx_string_tab[184]
#define __pyx_n_u_NameAssignment __pyx_string_tab[185]
#define __pyx_n_u_NameAssignment___reduce_cython __pyx_string_tab[186]
#define __pyx_n_u_NameAssignment___setstate_cython __pyx_string_tab[187]
#define __pyx_n_u_NameAssignment_infer_type __pyx_string_tab[188]
#define __pyx_n_u_NameAssignment_type_dependencies __pyx_string_tab[189]
#define __pyx_n_u_NameDeletion __pyx_string_tab[190]
#define __pyx_n_u_NameDeletion___init __pyx_string_tab[191]
#define __pyx_n_u_NameDeletion_infer_type __pyx_string_tab[192]
#define __pyx_n_u_NameReference __pyx_string_tab[193]
#define __pyx_n_u_NameReference___init __pyx_string_tab[194]
#define __pyx_n_u_NameReference___repr __pyx_string_tab[195]
#define __pyx_n_u_Nodes __pyx_string_tab[196]
#define __pyx_n_u_Optimize __pyx_string_tab[197]
#define __pyx_n_u_Options __pyx_string_tab[198]
#define __pyx_n_u_PY_SSIZE_T_MAX __pyx_string_tab[199]
#define __pyx_n_u_ParallelRangeNode __pyx_string_tab[200]
#define __pyx_n_u_PyrexTypes __pyx_string_tab[201]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[202]
#define __pyx_n_u_SimpleCallNode __pyx_string_tab[203]
#define __pyx_n_u_StaticAssignment __pyx_string_tab[204]
#define __pyx_n_u_StaticAssignment___init __pyx_string_tab[205]
#define __pyx_n_u_StaticAssignment_infer_type __pyx_string_tab[206]
#define __pyx_n_u_StaticAssignment_type_dependenci __pyx_string_tab[207]
#define __pyx_n_u_TreeVisitor __pyx_string_tab[208]
#define __pyx_n_u_TypedExprNode __pyx_string_tab[209]
#define __pyx_n_u_TypedExprNode___init __pyx_string_tab[210]
#define __pyx_n_u_TypedExprNode_may_be_none __pyx_string_tab[211]
#define __pyx_n_u_Uninitialized __pyx_string_tab[212]
#define __pyx_n_u_Uninitialized___reduce_cython __pyx_string_tab[213]
#define __pyx_n_u_Uninitialized___setstate_cython __pyx_string_tab[214]
#define __pyx_n_u_Unknown __pyx_string_tab[215]
#define __pyx_n_u_Unknown___reduce_cython __pyx_string_tab[216]
#define __pyx_n_u_Unknown___setstate_cython __pyx_string_tab[217]
#define __pyx_n_u_Visitor __pyx_string_tab[218]
#define __pyx_n_u__16 __pyx_string_tab[219]
#define __pyx_n_u__2 __pyx_string_tab[220]
#define __pyx_n_u_add __pyx_string_tab[221]
#define __pyx_n_u_add_child __pyx_string_tab[222]
#define __pyx_n_u_allow_null __pyx_string_tab[223]
#define __pyx_n_u_annotate_defs __pyx_string_tab[224]
#define __pyx_n_u_append __pyx_string_tab[225]
#define __pyx_n_u_arg __pyx_string_tab[226]
#define __pyx_n_u_args __pyx_string_tab[227]
#define __pyx_n_u_assigned_nodes __pyx_string_tab[228]
#define __pyx_n_u_assignments __pyx_string_tab[229]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[230]
#define __pyx_n_u_bases __pyx_string_tab[231]
#define __pyx_n_u_binop_node __pyx_string_tab[232]
#define __pyx_n_u_bit __pyx_string_tab[233]
#define __pyx_n_u_block __pyx_string_tab[234]
#define __pyx_n_u_blockids __pyx_string_tab[235]
#define __pyx_n_u_blocks __pyx_string_tab[236]
#define __pyx_n_u_body __pyx_string_tab[237]
#define __pyx_n_u_body_block __pyx_string_tab[238]
#define __pyx_n_u_bound1 __pyx_string_tab[239]
#define __pyx_n_u_bound2 __pyx_string_tab[240]
#define __pyx_n_u_c_py_ssize_t_type __pyx_string_tab[241]
#define __pyx_n_u_can_coerce_to_pyobject __pyx_string_tab[242]
#define __pyx_n_u_cf_assignments __pyx_string_tab[243]
#define __pyx_n_u_cf_is_null __pyx_string_tab[244]
#define __pyx_n_u_cf_maybe_null __pyx_string_tab[245]
#define __pyx_n_u_cf_references __pyx_string_tab[246]
#define __pyx_n_u_cf_state __pyx_string_tab[247]
#define __pyx_n_u_cf_used __pyx_string_tab[248]
#define __pyx_n_u_child __pyx_string_tab[249]
#define __pyx_n_u_children __pyx_string_tab[250]
#define __pyx_n_u_class __pyx_string_tab[251]
#define __pyx_n_u_class_getitem __pyx_string_tab[252]
#define __pyx_n_u_class_result __pyx_string_tab[253]
#define __pyx_n_u_classobj __pyx_string_tab[254]
#define __pyx_n_u_clause __pyx_string_tab[255]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[256]
#define __pyx_n_u_collector __pyx_string_tab[257]
#define __pyx_n_u_condition __pyx_string_tab[258]
#define __pyx_n_u_condition_block __pyx_string_tab[259]
#define __pyx_n_u_create_binop_node __pyx_string_tab[260]
#define __pyx_n_u_ctx __pyx_string_tab[261]
#define __pyx_n_u_decorators __pyx_string_tab[262]
#define __pyx_n_u_default __pyx_string_tab[263]
#define __pyx_n_u_definition __pyx_string_tab[264]
#define __pyx_n_u_delete_privates __pyx_string_tab[265]
#define __pyx_n_u_deletion __pyx_string_tab[266]
#define __pyx_n_u_descr __pyx_string_tab[267]
#define __pyx_n_u_detach __pyx_string_tab[268]
#define __pyx_n_u_dict __pyx_string_tab[269]
#define __pyx_n_u_dict_2 __pyx_string_tab[270]
#define __pyx_n_u_dict_3 __pyx_string_tab[271]
#define __pyx_n_u_dict_type __pyx_string_tab[272]
#define __pyx_n_u_discard __pyx_string_tab[273]
#define __pyx_n_u_doc __pyx_string_tab[274]
#define __pyx_n_u_doc_node __pyx_string_tab[275]
#define __pyx_n_u_dot_output __pyx_string_tab[276]
#define __pyx_n_u_e __pyx_string_tab[277]
#define __pyx_n_u_else_clause __pyx_string_tab[278]
#define __pyx_n_u_empty __pyx_string_tab[279]
#define __pyx_n_u_enter __pyx_string_tab[280]
#define __pyx_n_u_enter_call __pyx_string_tab[281]
#define __pyx_n_u_entries __pyx_string_tab[282]
#define __pyx_n_u_entry __pyx_string_tab[283]
#define __pyx_n_u_entry_point __pyx_string_tab[284]
#define __pyx_n_u_enumerate __pyx_string_tab[285]
#define __pyx_n_u_env __pyx_string_tab[286]
#define __pyx_n_u_error __pyx_string_tab[287]
#define __pyx_n_u_error_on_uninitialized __pyx_string_tab[288]
#define __pyx_n_u_escape __pyx_string_tab[289]
#define __pyx_n_u_exc_value __pyx_string_tab[290]
#define __pyx_n_u_except_clauses __pyx_string_tab[291]
#define __pyx_n_u_exception __pyx_string_tab[292]
#define __pyx_n_u_exceptions __pyx_string_tab[293]
#define __pyx_n_u_exclude __pyx_string_tab[294]
#define __pyx_n_u_exit __pyx_string_tab[295]
#define __pyx_n_u_exit_point __pyx_string_tab[296]
#define __pyx_n_u_expr_scope __pyx_string_tab[297]
#define __pyx_n_u_extract_sources __pyx_string_tab[298]
#define __pyx_n_u_false_val __pyx_string_tab[299]
#define __pyx_n_u_finally_clause __pyx_string_tab[300]
#define __pyx_n_u_finally_enter __pyx_string_tab[301]
#define __pyx_n_u_finally_except_clause __pyx_string_tab[302]
#define __pyx_n_u_finally_exit __pyx_string_tab[303]
#define __pyx_n_u_find_in_stack __pyx_string_tab[304]
#define __pyx_n_u_flow __pyx_string_tab[305]
#define __pyx_n_u_fp __pyx_string_tab[306]
#define __pyx_n_u_from_closure __pyx_string_tab[307]
#define __pyx_n_u_func __pyx_string_tab[308]
#define __pyx_n_u_function __pyx_string_tab[309]
#define __pyx_n_u_gbody __pyx_string_tab[310]
#define __pyx_n_u_get_lines __pyx_string_tab[311]
#define __pyx_n_u_getstate __pyx_string_tab[312]
#define __pyx_n_u_handler __pyx_string_tab[313]
#define __pyx_n_u_i __pyx_string_tab[314]
#define __pyx_n_u_if_clauses __pyx_string_tab[315]
#define __pyx_n_u_ignore_nonexisting __pyx_string_tab[316]
#define __pyx_n_u_in_closure __pyx_string_tab[317]
#define __pyx_n_u_in_try_block __pyx_string_tab[318]
#define __pyx_n_u_infer_type __pyx_string_tab[319]
#define __pyx_n_u_inferable_item_node __pyx_string_tab[320]
#define __pyx_n_u_inferred_type __pyx_string_tab[321]
#define __pyx_n_u_init __pyx_string_tab[322]
#define __pyx_n_u_initialize __pyx_string_tab[323]
#define __pyx_n_u_is_anonymous __pyx_string_tab[324]
#define __pyx_n_u_is_arg __pyx_string_tab[325]
#define __pyx_n_u_is_array __pyx_string_tab[326]
#define __pyx_n_u_is_builtin __pyx_string_tab[327]
#define __pyx_n_u_is_builtin_type __pyx_string_tab[328]
#define __pyx_n_u_is_complex __pyx_string_tab[329]
#define __pyx_n_u_is_coroutine __pyx_string_tab[330]
#define __pyx_n_u_is_cpp_class __pyx_string_tab[331]
#define __pyx_n_u_is_cpp_optional __pyx_string_tab[332]
#define __pyx_n_u_is_cython_lock_type __pyx_string_tab[333]
#define __pyx_n_u_is_deletion __pyx_string_tab[334]
#define __pyx_n_u_is_error __pyx_string_tab[335]
#define __pyx_n_u_is_generator __pyx_string_tab[336]
#define __pyx_n_u_is_local __pyx_string_tab[337]
#define __pyx_n_u_is_name __pyx_string_tab[338]
#define __pyx_n_u_is_pyclass_attr __pyx_string_tab[339]
#define __pyx_n_u_is_pyobject __pyx_string_tab[340]
#define __pyx_n_u_is_sequence_constructor __pyx_string_tab[341]
#define __pyx_n_u_is_single __pyx_string_tab[342]
#define __pyx_n_u_is_special __pyx_string_tab[343]
#define __pyx_n_u_is_starred __pyx_string_tab[344]
#define __pyx_n_u_is_statically_assigned __pyx_string_tab[345]
#define __pyx_n_u_is_struct_or_union __pyx_string_tab[346]
#define __pyx_n_u_is_terminator __pyx_string_tab[347]
#define __pyx_n_u_is_tracked __pyx_string_tab[348]
#define __pyx_n_u_is_type __pyx_string_tab[349]
#define __pyx_n_u_is_unspecified __pyx_string_tab[350]
#define __pyx_n_u_is_variable __pyx_string_tab[351]
#define __pyx_n_u_istate __pyx_string_tab[352]
#define __pyx_n_u_item __pyx_string_tab[353]
#define __pyx_n_u_items __pyx_string_tab[354]
#define __pyx_n_u_iterator __pyx_string_tab[355]
#define __pyx_n_u_iterator_type __pyx_string_tab[356]
#define __pyx_n_u_l __pyx_string_tab[357]
#define __pyx_n_u_label_2 __pyx_string_tab[358]
#define __pyx_n_u_lhs __pyx_string_tab[359]
#define __pyx_n_u_lhs_list __pyx_string_tab[360]
#define __pyx_n_u_lines __pyx_string_tab[361]
#define __pyx_n_u_list_type __pyx_string_tab[362]
#define __pyx_n_u_local_scope __pyx_string_tab[363]
#define __pyx_n_u_lookup __pyx_string_tab[364]
#define __pyx_n_u_loop __pyx_string_tab[365]
#define __pyx_n_u_loop_block __pyx_string_tab[366]
#define __pyx_n_u_main __pyx_string_tab[367]
#define __pyx_n_u_manager __pyx_string_tab[368]
#define __pyx_n_u_map_one __pyx_string_tab[369]
#define __pyx_n_u_mark_argument __pyx_string_tab[370]
#define __pyx_n_u_mark_assignment __pyx_string_tab[371]
#define __pyx_n_u_mark_deletion __pyx_string_tab[372]
#define __pyx_n_u_mark_forloop_target __pyx_string_tab[373]
#define __pyx_n_u_mark_parallel_forloop_assignment __pyx_string_tab[374]
#define __pyx_n_u_mark_position __pyx_string_tab[375]
#define __pyx_n_u_mark_reference __pyx_string_tab[376]
#define __pyx_n_u_mask __pyx_string_tab[377]
#define __pyx_n_u_max __pyx_string_tab[378]
#define __pyx_n_u_may_be_none __pyx_string_tab[379]
#define __pyx_n_u_may_be_none_2 __pyx_string_tab[380]
#define __pyx_n_u_message __pyx_string_tab[381]
#define __pyx_n_u_metaclass __pyx_string_tab[382]
#define __pyx_n_u_metaclass_2 __pyx_string_tab[383]
#define __pyx_n_u_min __pyx_string_tab[384]
#define __pyx_n_u_mkw __pyx_string_tab[385]
#define __pyx_n_u_module __pyx_string_tab[386]
#define __pyx_n_u_module_2 __pyx_string_tab[387]
#define __pyx_n_u_mro_entries __pyx_string_tab[388]
#define __pyx_n_u_name __pyx_string_tab[389]
#define __pyx_n_u_name_2 __pyx_string_tab[390]
#define __pyx_n_u_new __pyx_string_tab[391]
#define __pyx_n_u_newblock __pyx_string_tab[392]
#define __pyx_n_u_next_block __pyx_string_tab[393]
#define __pyx_n_u_next_handler __pyx_string_tab[394]
#define __pyx_n_u_nextblock __pyx_string_tab[395]
#define __pyx_n_u_nextid __pyx_string_tab[396]
#define __pyx_n_u_node __pyx_string_tab[397]
#define __pyx_n_u_nodeid __pyx_string_tab[398]
#define __pyx_n_u_normalize __pyx_string_tab[399]
#define __pyx_n_u_not_none __pyx_string_tab[400]
#define __pyx_n_u_one __pyx_string_tab[401]
#define __pyx_n_u_open __pyx_string_tab[402]
#define __pyx_n_u_operand __pyx_string_tab[403]
#define __pyx_n_u_operand1 __pyx_string_tab[404]
#define __pyx_n_u_operand2 __pyx_string_tab[405]
#define __pyx_n_u_outer_exception_handlers __pyx_string_tab[406]
#define __pyx_n_u_parent __pyx_string_tab[407]
#define __pyx_n_u_parents __pyx_string_tab[408]
#define __pyx_n_u_pattern __pyx_string_tab[409]
#define __pyx_n_u_pid __pyx_string_tab[410]
#define __pyx_n_u_pop __pyx_string_tab[411]
#define __pyx_n_u_pos __pyx_string_tab[412]
#define __pyx_n_u_positions __pyx_string_tab[413]
#define __pyx_n_u_prepare __pyx_string_tab[414]
#define __pyx_n_u_private_node __pyx_string_tab[415]
#define __pyx_n_u_py_object_type __pyx_string_tab[416]
#define __pyx_n_u_pyx_checksum __pyx_string_tab[417]
#define __pyx_n_u_pyx_result __pyx_string_tab[418]
#define __pyx_n_u_pyx_state __pyx_string_tab[419]
#define __pyx_n_u_pyx_type __pyx_string_tab[420]
#define __pyx_n_u_pyx_unpickle_AssignmentCollect __pyx_string_tab[421]
#define __pyx_n_u_pyx_unpickle_AssignmentList __pyx_string_tab[422]
#define __pyx_n_u_pyx_unpickle_ControlBlock __pyx_string_tab[423]
#define __pyx_n_u_pyx_unpickle_ControlFlow __pyx_string_tab[424]
#define __pyx_n_u_pyx_unpickle_ControlFlowAnalys __pyx_string_tab[425]
#define __pyx_n_u_pyx_unpickle_ExitBlock __pyx_string_tab[426]
#define __pyx_n_u_pyx_unpickle_MessageCollection __pyx_string_tab[427]
#define __pyx_n_u_pyx_unpickle_NameAssignment __pyx_string_tab[428]
#define __pyx_n_u_pyx_unpickle_Uninitialized __pyx_string_tab[429]
#define __pyx_n_u_pyx_unpickle_Unknown __pyx_string_tab[430]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[431]
#define __pyx_n_u_qualname __pyx_string_tab[432]
#define __pyx_n_u_range __pyx_string_tab[433]
#define __pyx_n_u_range_type __pyx_string_tab[434]
#define __pyx_n_u_reduce __pyx_string_tab[435]
#define __pyx_n_u_reduce_cython __pyx_string_tab[436]
#define __pyx_n_u_reduce_ex __pyx_string_tab[437]
#define __pyx_n_u_reduction __pyx_string_tab[438]
#define __pyx_n_u_reductions __pyx_string_tab[439]
#define __pyx_n_u_remove __pyx_string_tab[440]
#define __pyx_n_u_render __pyx_string_tab[441]
#define __pyx_n_u_replace __pyx_string_tab[442]
#define __pyx_n_u_report __pyx_string_tab[443]
#define __pyx_n_u_repr __pyx_string_tab[444]
#define __pyx_n_u_reversed __pyx_string_tab[445]
#define __pyx_n_u_rhs __pyx_string_tab[446]
#define __pyx_n_u_rhs_scope __pyx_string_tab[447]
#define __pyx_n_u_scope __pyx_string_tab[448]
#define __pyx_n_u_scope_predefined_names __pyx_string_tab[449]
#define __pyx_n_u_self __pyx_string_tab[450]
#define __pyx_n_u_sequence __pyx_string_tab[451]
#define __pyx_n_u_set_name __pyx_string_tab[452]
#define __pyx_n_u_setdefault __pyx_string_tab[453]
#define __pyx_n_u_setstate __pyx_string_tab[454]
#define __pyx_n_u_setstate_cython __pyx_string_tab[455]
#define __pyx_n_u_sources __pyx_string_tab[456]
#define __pyx_n_u_srcdescr __pyx_string_tab[457]
#define __pyx_n_u_star_arg __pyx_string_tab[458]
#define __pyx_n_u_starstar_arg __pyx_string_tab[459]
#define __pyx_n_u_start __pyx_string_tab[460]
#define __pyx_n_u_startswith __pyx_string_tab[461]
#define __pyx_n_u_stat __pyx_string_tab[462]
#define __pyx_n_u_state __pyx_string_tab[463]
#define __pyx_n_u_stats __pyx_string_tab[464]
#define __pyx_n_u_step __pyx_string_tab[465]
#define __pyx_n_u_stop __pyx_string_tab[466]
#define __pyx_n_u_strip __pyx_string_tab[467]
#define __pyx_n_u_subexprs __pyx_string_tab[468]
#define __pyx_n_u_super __pyx_string_tab[469]
#define __pyx_n_u_target __pyx_string_tab[470]
#define __pyx_n_u_test __pyx_string_tab[471]
#define __pyx_n_u_text __pyx_string_tab[472]
#define __pyx_n_u_true_val __pyx_string_tab[473]
#define __pyx_n_u_tuple_type __pyx_string_tab[474]
#define __pyx_n_u_type __pyx_string_tab[475]
#define __pyx_n_u_type_dependencies __pyx_string_tab[476]
#define __pyx_n_u_unspecified_type __pyx_string_tab[477]
#define __pyx_n_u_unused __pyx_string_tab[478]
#define __pyx_n_u_update __pyx_string_tab[479]
#define __pyx_n_u_use_setstate __pyx_string_tab[480]
#define __pyx_n_u_used __pyx_string_tab[481]
#define __pyx_n_u_value __pyx_string_tab[482]
#define __pyx_n_u_values __pyx_string_tab[483]
#define __pyx_n_u_visit_AmpersandNode __pyx_string_tab[484]
#define __pyx_n_u_visit_AssertStatNode __pyx_string_tab[485]
#define __pyx_n_u_visit_AssignmentNode __pyx_string_tab[486]
#define __pyx_n_u_visit_AsyncForStatNode __pyx_string_tab[487]
#define __pyx_n_u_visit_BoolBinopNode __pyx_string_tab[488]
#define __pyx_n_u_visit_BreakStatNode __pyx_string_tab[489]
#define __pyx_n_u_visit_CArgDeclNode __pyx_string_tab[490]
#define __pyx_n_u_visit_CClassDefNode __pyx_string_tab[491]
#define __pyx_n_u_visit_CTypeDefNode __pyx_string_tab[492]
#define __pyx_n_u_visit_CascadedAssignmentNode __pyx_string_tab[493]
#define __pyx_n_u_visit_ComprehensionNode __pyx_string_tab[494]
#define __pyx_n_u_visit_CondExprNode __pyx_string_tab[495]
#define __pyx_n_u_visit_ContinueStatNode __pyx_string_tab[496]
#define __pyx_n_u_visit_DefNode __pyx_string_tab[497]
#define __pyx_n_u_visit_DelStatNode __pyx_string_tab[498]
#define __pyx_n_u_visit_ForFromStatNode __pyx_string_tab[499]
#define __pyx_n_u_visit_ForInStatNode __pyx_string_tab[500]
#define __pyx_n_u_visit_FromImportStatNode __pyx_string_tab[501]
#define __pyx_n_u_visit_FuncDefNode __pyx_string_tab[502]
#define __pyx_n_u_visit_GeneratorBodyDefNode __pyx_string_tab[503]
#define __pyx_n_u_visit_IfStatNode __pyx_string_tab[504]
#define __pyx_n_u_visit_InPlaceAssignmentNode __pyx_string_tab[505]
#define __pyx_n_u_visit_LoopNode __pyx_string_tab[506]
#define __pyx_n_u_visit_ModuleNode __pyx_string_tab[507]
#define __pyx_n_u_visit_NameNode __pyx_string_tab[508]
#define __pyx_n_u_visit_Node __pyx_string_tab[509]
#define __pyx_n_u_visit_ParallelAssignmentNode __pyx_string_tab[510]
#define __pyx_n_u_visit_ParallelRangeNode __pyx_string_tab[511]
#define __pyx_n_u_visit_ParallelWithBlockNode __pyx_string_tab[512]
#define __pyx_n_u_visit_PyClassDefNode __pyx_string_tab[513]
#define __pyx_n_u_visit_RaiseStatNode __pyx_string_tab[514]
#define __pyx_n_u_visit_ReraiseStatNode __pyx_string_tab[515]
#define __pyx_n_u_visit_ReturnStatNode __pyx_string_tab[516]
#define __pyx_n_u_visit_ScopedExprNode __pyx_string_tab[517]
#define __pyx_n_u_visit_SingleAssignmentNode __pyx_string_tab[518]
#define __pyx_n_u_visit_SizeofVarNode __pyx_string_tab[519]
#define __pyx_n_u_visit_StatListNode __pyx_string_tab[520]
#define __pyx_n_u_visit_TryExceptStatNode __pyx_string_tab[521]
#define __pyx_n_u_visit_TryFinallyStatNode __pyx_string_tab[522]
#define __pyx_n_u_visit_TypeidNode __pyx_string_tab[523]
#define __pyx_n_u_visit_WhileStatNode __pyx_string_tab[524]
#define __pyx_n_u_visit_WithStatNode __pyx_string_tab[525]
#define __pyx_n_u_visit_WithTargetAssignmentStatNo __pyx_string_tab[526]
#define __pyx_n_u_w __pyx_string_tab[527]
#define __pyx_n_u_warning __pyx_string_tab[528]
#define __pyx_n_u_with_node __pyx_string_tab[529]
#define __pyx_n_u_write __pyx_string_tab[530]
#define __pyx_n_u_xrange __pyx_string_tab[531]
#define __pyx_kp_b_iso88591_1 __pyx_string_tab[532]
#define __pyx_kp_b_iso88591_1F __pyx_string_tab[533]
#define __pyx_kp_b_iso88591_6 __pyx_string_tab[534]
#define __pyx_kp_b_iso88591_7q_4t5_4uA_E_Ba_V_Qiq_Zq_4q_a_3 __pyx_string_tab[535]
#define __pyx_kp_b_iso88591_8_O1_Q_A __pyx_string_tab[536]
#define __pyx_kp_b_iso88591_9_4wd_k_q_U_1_fG1A_d_9A_AQ __pyx_string_tab[537]
#define __pyx_kp_b_iso88591_AV1 __pyx_string_tab[538]
#define __pyx_kp_b_iso88591_A_4_1_1A __pyx_string_tab[539]
#define __pyx_kp_b_iso88591_A_4q_gRt6_Q_t1_G1D_4q_d_fD_q __pyx_string_tab[540]
#define __pyx_kp_b_iso88591_A_4q_j_AT_Rq __pyx_string_tab[541]
#define __pyx_kp_b_iso88591_A_4s_a_4q_Cxxq_A_r_A_q_q __pyx_string_tab[542]
#define __pyx_kp_b_iso88591_A_4t5_1_t5_b_N_1_M_A_y_E_z_1_9A __pyx_string_tab[543]
#define __pyx_kp_b_iso88591_A_4uA_1_1E_s_5_5_9G4q_T_A_HAQ_uE __pyx_string_tab[544]
#define __pyx_kp_b_iso88591_A_4uA_A_G1A_4t5_q __pyx_string_tab[545]
#define __pyx_kp_b_iso88591_A_4uA_D_s_d_a_q_E_q_6_D_D_D_a_q __pyx_string_tab[546]
#define __pyx_kp_b_iso88591_A_4uE_m1_M_U_Ry_e1 __pyx_string_tab[547]
#define __pyx_kp_b_iso88591_A_4wd_k_QfA_fG1A_d_9A_AQ __pyx_string_tab[548]
#define __pyx_kp_b_iso88591_A_4wd_k_fG1M_AQ __pyx_string_tab[549]
#define __pyx_kp_b_iso88591_A_4wd_k_uA_fG1A_d_9A_AQ __pyx_string_tab[550]
#define __pyx_kp_b_iso88591_A_4xq_Zq_N_1_q __pyx_string_tab[551]
#define __pyx_kp_b_iso88591_A_4z_A_q_HA_IQ_G4q __pyx_string_tab[552]
#define __pyx_kp_b_iso88591_A_5_1_Zs_8_5_3e_q_Q __pyx_string_tab[553]
#define __pyx_kp_b_iso88591_A_6_A_Rt1_1_t9AQ __pyx_string_tab[554]
#define __pyx_kp_b_iso88591_A_AT_t_Q_q __pyx_string_tab[555]
#define __pyx_kp_b_iso88591_A_A_t1_N_S_s_7_Q_M_Ry_Rt5_c_wa __pyx_string_tab[556]
#define __pyx_kp_b_iso88591_A_D_1D_a_D_Q_M_8_V1_Q_Q_q __pyx_string_tab[557]
#define __pyx_kp_b_iso88591_A_D_8_N_1_Qa_q __pyx_string_tab[558]
#define __pyx_kp_b_iso88591_A_D_q_A_1_d_1_m1E_a_q __pyx_string_tab[559]
#define __pyx_kp_b_iso88591_A_D_t4t1 __pyx_string_tab[560]
#define __pyx_kp_b_iso88591_A_E_4uM_e_q_e_q_e_Q_e_0_uN_d_q_1 __pyx_string_tab[561]
#define __pyx_kp_b_iso88591_A_E_fAT_q_Qe1_q_Ya __pyx_string_tab[562]
#define __pyx_kp_b_iso88591_A_F_4xt1_N_1_F_a_q __pyx_string_tab[563]
#define __pyx_kp_b_iso88591_A_F_D_uCq_AQ_N_1_q __pyx_string_tab[564]
#define __pyx_kp_b_iso88591_A_G1D_AT_t1_q __pyx_string_tab[565]
#define __pyx_kp_b_iso88591_A_G1D_G1D_G1D_q __pyx_string_tab[566]
#define __pyx_kp_b_iso88591_A_G1D_G4q_d_q __pyx_string_tab[567]
#define __pyx_kp_b_iso88591_A_G1F_a_vWE_Q_q_q_q_AWKwa_AWKq __pyx_string_tab[568]
#define __pyx_kp_b_iso88591_A_G1F_a_vWE_Q_q_q_q_d_7_WA_d_7 __pyx_string_tab[569]
#define __pyx_kp_b_iso88591_A_G4q_G2U_a __pyx_string_tab[570]
#define __pyx_kp_b_iso88591_A_G4q_s_7_T_WAS_5_CuA_Q_79_a_4t1 __pyx_string_tab[571]
#define __pyx_kp_b_iso88591_A_G4q_s_N_1_N_7_F_4vT_G4q_HKq_IT __pyx_string_tab[572]
#define __pyx_kp_b_iso88591_A_HA_HA __pyx_string_tab[573]
#define __pyx_kp_b_iso88591_A_HA_t_Qa __pyx_string_tab[574]
#define __pyx_kp_b_iso88591_A_IT_5_a __pyx_string_tab[575]
#define __pyx_kp_b_iso88591_A_IT_5_q __pyx_string_tab[576]
#define __pyx_kp_b_iso88591_A_IT_Jd_7_1_HF_IV1 __pyx_string_tab[577]
#define __pyx_kp_b_iso88591_A_IT_XT __pyx_string_tab[578]
#define __pyx_kp_b_iso88591_A_IWAQ __pyx_string_tab[579]
#define __pyx_kp_b_iso88591_A_Ja_1_IT_1_q_q_A_IT_Q_QfA_q_T_Q __pyx_string_tab[580]
#define __pyx_kp_b_iso88591_A_L_Ja_L_Kq __pyx_string_tab[581]
#define __pyx_kp_b_iso88591_A_L_r_V4q __pyx_string_tab[582]
#define __pyx_kp_b_iso88591_A_N_1_4uA_V_Qd_Ba_E_q __pyx_string_tab[583]
#define __pyx_kp_b_iso88591_A_N_1_N_1_4q_E_D_Kq_wa_E_z_7_U_q __pyx_string_tab[584]
#define __pyx_kp_b_iso88591_A_N_1_N_1_4uA_V_Qd_Ba_E_4uA_q __pyx_string_tab[585]
#define __pyx_kp_b_iso88591_A_N_1_N_1_q __pyx_string_tab[586]
#define __pyx_kp_b_iso88591_A_N_1_T_iq_U_U_AQ_G1D_E_1_G1D_4u __pyx_string_tab[587]
#define __pyx_kp_b_iso88591_A_N_7_E_it1_d_gQ_F_4vT_G4q_E_1_4 __pyx_string_tab[588]
#define __pyx_kp_b_iso88591_A_N_N_N __pyx_string_tab[589]
#define __pyx_kp_b_iso88591_A_O1F __pyx_string_tab[590]
#define __pyx_kp_b_iso88591_A_Q_4y_Q_d_s_a_Qj_xq_xvS_T_7_81 __pyx_string_tab[591]
#define __pyx_kp_b_iso88591_A_Q_G4uBa_3at7_A_Q_AT_E_E_4t1 __pyx_string_tab[592]
#define __pyx_kp_b_iso88591_A_Q_N_1_Q_AT_t_1D_RRS_q __pyx_string_tab[593]
#define __pyx_kp_b_iso88591_A_Q_Q_a_5_A_4q_Q_6_Qa_4xr_IQ_wat __pyx_string_tab[594]
#define __pyx_kp_b_iso88591_A_T_4vQ_t1 __pyx_string_tab[595]
#define __pyx_kp_b_iso88591_A_T_7_4y_c_A_F_A_a_1_4q_A_4_1A_N __pyx_string_tab[596]
#define __pyx_kp_b_iso88591_A_T_AQ_Jiv_5Q_a_a_Q_Q_G4q_HKq_IQ __pyx_string_tab[597]
#define __pyx_kp_b_iso88591_A_T_iq_E_d_y_E_G1N_1_E_1_E_z_E_1 __pyx_string_tab[598]
#define __pyx_kp_b_iso88591_A_T_iq_U_Jd_T_j_q_a_Zq_q_a_t5_E __pyx_string_tab[599]
#define __pyx_kp_b_iso88591_A_T_j_d_y_E_G1D_4uG4t5_V_Qd_Ba_E __pyx_string_tab[600]
#define __pyx_kp_b_iso88591_A_WAQ_7_F_t_1_4q_a_4q_4q_IV1_wb __pyx_string_tab[601]
#define __pyx_kp_b_iso88591_A_Z_a __pyx_string_tab[602]
#define __pyx_kp_b_iso88591_A_e_Q_T_iq_E_way_Q_4q_q_A_E_1_G1 __pyx_string_tab[603]
#define __pyx_kp_b_iso88591_A_e_Q_T_iq_E_way_Q_G1D_E_1_QfE_A __pyx_string_tab[604]
#define __pyx_kp_b_iso88591_A_e_Q_T_iq_E_way_Q_G1D_G1D_4vWA __pyx_string_tab[605]
#define __pyx_kp_b_iso88591_A_iq_e5_Ja __pyx_string_tab[606]
#define __pyx_kp_b_iso88591_A_iq_e5_O1 __pyx_string_tab[607]
#define __pyx_kp_b_iso88591_A_m1A __pyx_string_tab[608]
#define __pyx_kp_b_iso88591_A_m1_2T __pyx_string_tab[609]
#define __pyx_kp_b_iso88591_A_q __pyx_string_tab[610]
#define __pyx_kp_b_iso88591_A_q_q_E_q_E_a_q __pyx_string_tab[611]
#define __pyx_kp_b_iso88591_A_s_4_Q_G1D_U_T_iq_E_1_G1D_4uA_V __pyx_string_tab[612]
#define __pyx_kp_b_iso88591_A_s_4_Q_T_iq_U_G1D_E_1_G1D_4uA_V __pyx_string_tab[613]
#define __pyx_kp_b_iso88591_A_t1A __pyx_string_tab[614]
#define __pyx_kp_b_iso88591_A_t4_k_D_a __pyx_string_tab[615]
#define __pyx_kp_b_iso88591_A_t6 __pyx_string_tab[616]
#define __pyx_kp_b_iso88591_A_t81E_xq_a __pyx_string_tab[617]
#define __pyx_kp_b_iso88591_A_t_A __pyx_string_tab[618]
#define __pyx_kp_b_iso88591_A_t_q __pyx_string_tab[619]
#define __pyx_kp_b_iso88591_A_z_BXXY_4q_gRt6_Q_N_4q_t1_N_1_4 __pyx_string_tab[620]
#define __pyx_kp_b_iso88591_Q_D_t83l_E_q_l __pyx_string_tab[621]
#define __pyx_kp_b_iso88591_QfA __pyx_string_tab[622]
#define __pyx_kp_b_iso88591_T_4_fD_JdR___jjnnxx_G_G_K_K_W_W __pyx_string_tab[623]
#define __pyx_kp_b_iso88591_T_4_fD_JdR___jjnnxx_G_G_K_K_W_W_2 __pyx_string_tab[624]
#define __pyx_kp_b_iso88591_T_G1F_a_vWE_Q_q_t_WA_q_2_awk_PQ __pyx_string_tab[625]
#define __pyx_kp_b_iso88591_T_hd_4z_SWWddhhuuy_z_I_I_M_M_N __pyx_string_tab[626]
#define __pyx_kp_b_iso88591_T_t7_a_G1F_a_vWE_Q_q_t5_uCt6_S __pyx_string_tab[627]
#define __pyx_kp_b_iso88591_T_t84_7t9D_VZZ_ddjjnnuuyy_D_D_E __pyx_string_tab[628]
#define __pyx_kp_b_iso88591_T_t_5T_4G_qquu_G_G_K_K_T_T_X_X __pyx_string_tab[629]
#define __pyx_kp_b_iso88591_T_t_Q_G1F_a_vWE_Q_q_t_uCt_uTWW __pyx_string_tab[630]
#define __pyx_kp_b_iso88591__21 __pyx_string_tab[631]
#define __pyx_kp_b_iso88591_a_A_G4q_1_AQ_q __pyx_string_tab[632]
#define __pyx_kp_b_iso88591_a_Bd_IT_a_C_q_q_HE_z_g_4_QQ__cc __pyx_string_tab[633]
#define __pyx_kp_b_iso88591_q_0_kQR_7_0_1B_PQ_1 __pyx_string_tab[634]
#define __pyx_kp_b_iso88591_q_0_kQR_7_1_7_N_1 __pyx_string_tab[635]
#define __pyx_kp_b_iso88591_q_0_kQR_7_q0_a_1 __pyx_string_tab[636]
#define __pyx_kp_b_iso88591_q_0_kQR_9HAQ_7_1L_a_1 __pyx_string_tab[637]
#define __pyx_kp_b_iso88591_q_0_kQR_HAQ_7_314H_VW_1 __pyx_string_tab[638]
#define __pyx_kp_b_iso88591_q_0_kQR_haq_7_5Q6LNZ_1 __pyx_string_tab[639]
#define __pyx_kp_b_iso88591_q_0_kQR_haq_7_QnN_1 __pyx_string_tab[640]
#define __pyx_kp_b_iso88591_q_0_kQR_xq_7_a_nA_1 __pyx_string_tab[641]
#define __pyx_kp_b_iso88591_q_A_G4q_1_AQ_j_IQ_t1 __pyx_string_tab[642]
#define __pyx_kp_b_iso88591_q_A_IT_V1 __pyx_string_tab[643]
#define __pyx_kp_b_iso88591_q_Ry_HA_A __pyx_string_tab[644]
#define __pyx_kp_b_iso88591_q_a __pyx_string_tab[645]
#define __pyx_kp_b_iso88591_q_a_2 __pyx_string_tab[646]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_neg_1 __pyx_number_tab[1]
#define __pyx_int_1 __pyx_number_tab[2]
#define __pyx_int_2 __pyx_number_tab[3]
#define __pyx_int_9995728 __pyx_number_tab[4]
#define __pyx_int_48084501 __pyx_number_tab[5]
#define __pyx_int_105766659 __pyx_number_tab[6]
#define __pyx_int_161667023 __pyx_number_tab[7]
#define __pyx_int_211101602 __pyx_number_tab[8]
#define __pyx_int_238750788 __pyx_number_tab[9]
#define __pyx_int_243737303 __pyx_number_tab[10]
#define __pyx_int_257740027 __pyx_number_tab[11]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_Unknown);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis);
  for (int i=0; i<2; ++i) { Py_CLEAR(clear_module_state->__pyx_slice[i]); }
  for (int i=0; i<9; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<125; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<647; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<12; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_Unknown);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis);
  for (int i=0; i<2; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_slice[i]); }
  for (int i=0; i<9; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<125; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<647; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<12; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "Cython/Compiler/FlowControl.py":22
 * class TypedExprNode(ExprNodes.ExprNode):
 *     # Used for declaring assignments of a specified type without a known entry.
 *     def __init__(self, type, may_be_none=None, pos=None):             # <<<<<<<<<<<<<<
 *         super().__init__(pos)
 *         self.type = type
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13TypedExprNode_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_13TypedExprNode_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_13TypedExprNode_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13TypedExprNode_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_type = 0;
  PyObject *__pyx_v_may_be_none = 0;
  PyObject *__pyx_v_pos = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_type,&__pyx_mstate_global->__pyx_n_u_may_be_none,&__pyx_mstate_global->__pyx_n_u_pos,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 22, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 22, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 22, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 22, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 22, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 22, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, i); __PYX_ERR(0, 22, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 22, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 22, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 22, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 22, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_type = values[1];
    __pyx_v_may_be_none = values[2];
    __pyx_v_pos = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 22, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.TypedExprNode.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_13TypedExprNode___init__(__pyx_self, __pyx_v_self, __pyx_v_type, __pyx_v_may_be_none, __pyx_v_pos);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13TypedExprNode___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_type, PyObject *__pyx_v_may_be_none, PyObject *__pyx_v_pos) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":23
 *     # Used for declaring assignments of a specified type without a known entry.
 *     def __init__(self, type, may_be_none=None, pos=None):
 *         super().__init__(pos)             # <<<<<<<<<<<<<<
 *         self.type = type
 *         self._may_be_none = may_be_none
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = __Pyx_CyFunction_GetClassObj(__pyx_self);
  if (!__pyx_t_5) { PyErr_SetString(PyExc_RuntimeError, "super(): empty __class__ cell"); __PYX_ERR(0, 23, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_5, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 23, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":24
 *     def __init__(self, type, may_be_none=None, pos=None):
 *         super().__init__(pos)
 *         self.type = type             # <<<<<<<<<<<<<<
 *         self._may_be_none = may_be_none
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_type, __pyx_v_type) < (0)) __PYX_ERR(0, 24, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":25
 *         super().__init__(pos)
 *         self.type = type
 *         self._may_be_none = may_be_none             # <<<<<<<<<<<<<<
 * 
 *     def may_be_none(self):
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_may_be_none_2, __pyx_v_may_be_none) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":22
 * class TypedExprNode(ExprNodes.ExprNode):
 *     # Used for declaring assignments of a specified type without a known entry.
 *     def __init__(self, type, may_be_none=None, pos=None):             # <<<<<<<<<<<<<<
 *         super().__init__(pos)
 *         self.type = type
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.TypedExprNode.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":27
 *         self._may_be_none = may_be_none
 * 
 *     def may_be_none(self):             # <<<<<<<<<<<<<<
 *         return self._may_be_none != False
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13TypedExprNode_3may_be_none(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_13TypedExprNode_3may_be_none = {"may_be_none", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_13TypedExprNode_3may_be_none, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13TypedExprNode_3may_be_none(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("may_be_none (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_13TypedExprNode_2may_be_none(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13TypedExprNode_2may_be_none(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("may_be_none", 0);

  /* "Cython/Compiler/FlowControl.py":28
 * 
 *     def may_be_none(self):
 *         return self._may_be_none != False             # <<<<<<<<<<<<<<
 * 
 * # Fake rhs to silence "unused variable" warning
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_may_be_none_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":27
 *         self._may_be_none = may_be_none
 * 
 *     def may_be_none(self):             # <<<<<<<<<<<<<<
 *         return self._may_be_none != False
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.TypedExprNode.may_be_none", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":57
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.children = set()
 *         self.parents = set()
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock___init__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":58
 * 
 *     def __init__(self):
 *         self.children = set()             # <<<<<<<<<<<<<<
 *         self.parents = set()
 *         self.positions = set()
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->children);
  __Pyx_DECREF(__pyx_v_self->children);
  __pyx_v_self->children = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":59
 *     def __init__(self):
 *         self.children = set()
 *         self.parents = set()             # <<<<<<<<<<<<<<
 *         self.positions = set()
 * 
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->parents);
  __Pyx_DECREF(__pyx_v_self->parents);
  __pyx_v_self->parents = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":60
 *         self.children = set()
 *         self.parents = set()
 *         self.positions = set()             # <<<<<<<<<<<<<<
 * 
 *         self.stats = []
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->positions);
  __Pyx_DECREF(__pyx_v_self->positions);
  __pyx_v_self->positions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":62
 *         self.positions = set()
 * 
 *         self.stats = []             # <<<<<<<<<<<<<<
 *         self.gen = {}
 *         self.bounded = set()
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->stats);
  __Pyx_DECREF(__pyx_v_self->stats);
  __pyx_v_self->stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":63
 * 
 *         self.stats = []
 *         self.gen = {}             # <<<<<<<<<<<<<<
 *         self.bounded = set()
 * 
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->gen);
  __Pyx_DECREF(__pyx_v_self->gen);
  __pyx_v_self->gen = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":64
 *         self.stats = []
 *         self.gen = {}
 *         self.bounded = set()             # <<<<<<<<<<<<<<
 * 
 *         self.i_input = 0
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->bounded);
  __Pyx_DECREF(__pyx_v_self->bounded);
  __pyx_v_self->bounded = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":66
 *         self.bounded = set()
 * 
 *         self.i_input = 0             # <<<<<<<<<<<<<<
 *         self.i_output = 0
 *         self.i_gen = 0
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GOTREF(__pyx_v_self->i_input);
  __Pyx_DECREF(__pyx_v_self->i_input);
  __pyx_v_self->i_input = __pyx_mstate_global->__pyx_int_0;

  /* "Cython/Compiler/FlowControl.py":67
 * 
 *         self.i_input = 0
 *         self.i_output = 0             # <<<<<<<<<<<<<<
 *         self.i_gen = 0
 *         self.i_kill = 0
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GOTREF(__pyx_v_self->i_output);
  __Pyx_DECREF(__pyx_v_self->i_output);
  __pyx_v_self->i_output = __pyx_mstate_global->__pyx_int_0;

  /* "Cython/Compiler/FlowControl.py":68
 *         self.i_input = 0
 *         self.i_output = 0
 *         self.i_gen = 0             # <<<<<<<<<<<<<<
 *         self.i_kill = 0
 *         self.i_state = 0
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GOTREF(__pyx_v_self->i_gen);
  __Pyx_DECREF(__pyx_v_self->i_gen);
  __pyx_v_self->i_gen = __pyx_mstate_global->__pyx_int_0;

  /* "Cython/Compiler/FlowControl.py":69
 *         self.i_output = 0
 *         self.i_gen = 0
 *         self.i_kill = 0             # <<<<<<<<<<<<<<
 *         self.i_state = 0
 * 
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GOTREF(__pyx_v_self->i_kill);
  __Pyx_DECREF(__pyx_v_self->i_kill);
  __pyx_v_self->i_kill = __pyx_mstate_global->__pyx_int_0;

  /* "Cython/Compiler/FlowControl.py":70
 *         self.i_gen = 0
 *         self.i_kill = 0
 *         self.i_state = 0             # <<<<<<<<<<<<<<
 * 
 *     def empty(self):
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GOTREF(__pyx_v_self->i_state);
  __Pyx_DECREF(__pyx_v_self->i_state);
  __pyx_v_self->i_state = __pyx_mstate_global->__pyx_int_0;

  /* "Cython/Compiler/FlowControl.py":57
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.children = set()
 *         self.parents = set()
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":72
 *         self.i_state = 0
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         return (not self.stats and not self.positions)
 * 
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3empty(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_empty(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_empty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3empty)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 72, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Cython/Compiler/FlowControl.py":73
 * 
 *     def empty(self):
 *         return (not self.stats and not self.positions)             # <<<<<<<<<<<<<<
 * 
 *     def detach(self):
*/
  if (__pyx_v_self->stats == Py_None) __pyx_t_7 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->stats);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 73, __pyx_L1_error)
    __pyx_t_7 = (__pyx_temp != 0);
  }

  __pyx_t_8 = (!__pyx_t_7);
  if (__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L3_bool_binop_done;
  }
  if (__pyx_v_self->positions == Py_None) __pyx_t_8 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PySet_GET_SIZE(__pyx_v_self->positions);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 73, __pyx_L1_error)
    __pyx_t_8 = (__pyx_temp != 0);
  }

  __pyx_t_7 = (!__pyx_t_8);
  __pyx_t_6 = __pyx_t_7;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":72
 *         self.i_state = 0
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         return (not self.stats and not self.positions)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3empty(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_3empty = {"empty", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3empty, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3empty(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("empty (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_2empty(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_2empty(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_empty(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 72, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":75
 *         return (not self.stats and not self.positions)
 * 
 *     def detach(self):             # <<<<<<<<<<<<<<
 *         """Detach block from parents and children."""
 *         for child in self.children:
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_detach(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_child = NULL;
  PyObject *__pyx_v_parent = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("detach", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_detach); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5detach)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 75, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Cython/Compiler/FlowControl.py":77
 *     def detach(self):
 *         """Detach block from parents and children."""
 *         for child in self.children:             # <<<<<<<<<<<<<<
 *             child.parents.remove(self)
 *         for parent in self.parents:
*/
  __pyx_t_6 = 0;
  __pyx_t_2 = __Pyx_set_iterator(__pyx_v_self->children, 1, (&__pyx_t_7), (&__pyx_t_8)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_7, &__pyx_t_6, &__pyx_t_2, __pyx_t_8);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_child, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":78
 *         """Detach block from parents and children."""
 *         for child in self.children:
 *             child.parents.remove(self)             # <<<<<<<<<<<<<<
 *         for parent in self.parents:
 *             parent.children.remove(self)
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_child, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __pyx_t_3;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_self)};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_remove, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 78, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":79
 *         for child in self.children:
 *             child.parents.remove(self)
 *         for parent in self.parents:             # <<<<<<<<<<<<<<
 *             parent.children.remove(self)
 *         self.parents.clear()
*/
  __pyx_t_7 = 0;
  __pyx_t_2 = __Pyx_set_iterator(__pyx_v_self->parents, 1, (&__pyx_t_6), (&__pyx_t_8)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_6, &__pyx_t_7, &__pyx_t_2, __pyx_t_8);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_parent, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":80
 *             child.parents.remove(self)
 *         for parent in self.parents:
 *             parent.children.remove(self)             # <<<<<<<<<<<<<<
 *         self.parents.clear()
 *         self.children.clear()
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent, __pyx_mstate_global->__pyx_n_u_children); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_self)};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_remove, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 80, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":81
 *         for parent in self.parents:
 *             parent.children.remove(self)
 *         self.parents.clear()             # <<<<<<<<<<<<<<
 *         self.children.clear()
 * 
*/
  if (unlikely(__pyx_v_self->parents == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
    __PYX_ERR(0, 81, __pyx_L1_error)
  }
  __pyx_t_10 = PySet_Clear(__pyx_v_self->parents); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 81, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":82
 *             parent.children.remove(self)
 *         self.parents.clear()
 *         self.children.clear()             # <<<<<<<<<<<<<<
 * 
 *     def add_child(self, block):
*/
  if (unlikely(__pyx_v_self->children == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
    __PYX_ERR(0, 82, __pyx_L1_error)
  }
  __pyx_t_10 = PySet_Clear(__pyx_v_self->children); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 82, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":75
 *         return (not self.stats and not self.positions)
 * 
 *     def detach(self):             # <<<<<<<<<<<<<<
 *         """Detach block from parents and children."""
 *         for child in self.children:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.detach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_parent);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_12ControlBlock_4detach, "Detach block from parents and children.");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_5detach = {"detach", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5detach, METH_NOARGS, __pyx_doc_6Cython_8Compiler_11FlowControl_12ControlBlock_4detach};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("detach (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_4detach(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_4detach(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("detach", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_detach(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.detach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":84
 *         self.children.clear()
 * 
 *     def add_child(self, block):             # <<<<<<<<<<<<<<
 *         self.children.add(block)
 *         block.parents.add(self)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7add_child(PyObject *__pyx_v_self, PyObject *__pyx_v_block); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_add_child(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_block, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_child", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_add_child); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 84, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7add_child)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_block};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 84, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Cython/Compiler/FlowControl.py":85
 * 
 *     def add_child(self, block):
 *         self.children.add(block)             # <<<<<<<<<<<<<<
 *         block.parents.add(self)
 * 
*/
  if (unlikely(__pyx_v_self->children == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(0, 85, __pyx_L1_error)
  }
  __pyx_t_6 = PySet_Add(__pyx_v_self->children, __pyx_v_block); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 85, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":86
 *     def add_child(self, block):
 *         self.children.add(block)
 *         block.parents.add(self)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __pyx_t_4;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_self)};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":84
 *         self.children.clear()
 * 
 *     def add_child(self, block):             # <<<<<<<<<<<<<<
 *         self.children.add(block)
 *         block.parents.add(self)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.add_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7add_child(PyObject *__pyx_v_self, PyObject *__pyx_v_block); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_7add_child = {"add_child", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7add_child, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7add_child(PyObject *__pyx_v_self, PyObject *__pyx_v_block) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_child (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6add_child(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_block));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6add_child(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_block) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_child", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_add_child(__pyx_v_self, __pyx_v_block, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.add_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":6
 * 
 * cdef class ControlBlock:
 *     cdef public set children             # <<<<<<<<<<<<<<
 *     cdef public set parents
 *     cdef public set positions
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->children);
  __pyx_r = __pyx_v_self->children;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->children);
  __Pyx_DECREF(__pyx_v_self->children);
  __pyx_v_self->children = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.children.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->children);
  __Pyx_DECREF(__pyx_v_self->children);
  __pyx_v_self->children = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":7
 * cdef class ControlBlock:
 *     cdef public set children
 *     cdef public set parents             # <<<<<<<<<<<<<<
 *     cdef public set positions
 *     cdef public list stats
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->parents);
  __pyx_r = __pyx_v_self->parents;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->parents);
  __Pyx_DECREF(__pyx_v_self->parents);
  __pyx_v_self->parents = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.parents.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->parents);
  __Pyx_DECREF(__pyx_v_self->parents);
  __pyx_v_self->parents = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":8
 *     cdef public set children
 *     cdef public set parents
 *     cdef public set positions             # <<<<<<<<<<<<<<
 *     cdef public list stats
 *     cdef public dict gen
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->positions);
  __pyx_r = __pyx_v_self->positions;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(1, 8, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->positions);
  __Pyx_DECREF(__pyx_v_self->positions);
  __pyx_v_self->positions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.positions.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->positions);
  __Pyx_DECREF(__pyx_v_self->positions);
  __pyx_v_self->positions = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":9
 *     cdef public set parents
 *     cdef public set positions
 *     cdef public list stats             # <<<<<<<<<<<<<<
 *     cdef public dict gen
 *     cdef public set bounded
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->stats);
  __pyx_r = __pyx_v_self->stats;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 9, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->stats);
  __Pyx_DECREF(__pyx_v_self->stats);
  __pyx_v_self->stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.stats.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->stats);
  __Pyx_DECREF(__pyx_v_self->stats);
  __pyx_v_self->stats = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":10
 *     cdef public set positions
 *     cdef public list stats
 *     cdef public dict gen             # <<<<<<<<<<<<<<
 *     cdef public set bounded
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->gen);
  __pyx_r = __pyx_v_self->gen;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(1, 10, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->gen);
  __Pyx_DECREF(__pyx_v_self->gen);
  __pyx_v_self->gen = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.gen.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->gen);
  __Pyx_DECREF(__pyx_v_self->gen);
  __pyx_v_self->gen = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":11
 *     cdef public list stats
 *     cdef public dict gen
 *     cdef public set bounded             # <<<<<<<<<<<<<<
 * 
 *     # Big integer bitsets
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->bounded);
  __pyx_r = __pyx_v_self->bounded;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(1, 11, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->bounded);
  __Pyx_DECREF(__pyx_v_self->bounded);
  __pyx_v_self->bounded = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.bounded.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->bounded);
  __Pyx_DECREF(__pyx_v_self->bounded);
  __pyx_v_self->bounded = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":14
 * 
 *     # Big integer bitsets
 *     cdef public object i_input             # <<<<<<<<<<<<<<
 *     cdef public object i_output
 *     cdef public object i_gen
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->i_input);
  __pyx_r = __pyx_v_self->i_input;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->i_input);
  __Pyx_DECREF(__pyx_v_self->i_input);
  __pyx_v_self->i_input = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->i_input);
  __Pyx_DECREF(__pyx_v_self->i_input);
  __pyx_v_self->i_input = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":15
 *     # Big integer bitsets
 *     cdef public object i_input
 *     cdef public object i_output             # <<<<<<<<<<<<<<
 *     cdef public object i_gen
 *     cdef public object i_kill
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->i_output);
  __pyx_r = __pyx_v_self->i_output;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->i_output);
  __Pyx_DECREF(__pyx_v_self->i_output);
  __pyx_v_self->i_output = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->i_output);
  __Pyx_DECREF(__pyx_v_self->i_output);
  __pyx_v_self->i_output = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":16
 *     cdef public object i_input
 *     cdef public object i_output
 *     cdef public object i_gen             # <<<<<<<<<<<<<<
 *     cdef public object i_kill
 *     cdef public object i_state
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->i_gen);
  __pyx_r = __pyx_v_self->i_gen;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->i_gen);
  __Pyx_DECREF(__pyx_v_self->i_gen);
  __pyx_v_self->i_gen = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->i_gen);
  __Pyx_DECREF(__pyx_v_self->i_gen);
  __pyx_v_self->i_gen = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":17
 *     cdef public object i_output
 *     cdef public object i_gen
 *     cdef public object i_kill             # <<<<<<<<<<<<<<
 *     cdef public object i_state
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->i_kill);
  __pyx_r = __pyx_v_self->i_kill;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->i_kill);
  __Pyx_DECREF(__pyx_v_self->i_kill);
  __pyx_v_self->i_kill = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->i_kill);
  __Pyx_DECREF(__pyx_v_self->i_kill);
  __pyx_v_self->i_kill = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":18
 *     cdef public object i_gen
 *     cdef public object i_kill
 *     cdef public object i_state             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint empty(self)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->i_state);
  __pyx_r = __pyx_v_self->i_state;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->i_state);
  __Pyx_DECREF(__pyx_v_self->i_state);
  __pyx_v_self->i_state = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->i_state);
  __Pyx_DECREF(__pyx_v_self->i_state);
  __pyx_v_self->i_state = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8__reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_8__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.bounded, self.children, self.gen, self.i_gen, self.i_input, self.i_kill, self.i_output, self.i_state, self.parents, self.positions, self.stats)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = PyTuple_New(11); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->bounded);
  __Pyx_GIVEREF(__pyx_v_self->bounded);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->bounded) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->children);
  __Pyx_GIVEREF(__pyx_v_self->children);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->children) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->gen);
  __Pyx_GIVEREF(__pyx_v_self->gen);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->gen) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->i_gen);
  __Pyx_GIVEREF(__pyx_v_self->i_gen);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_self->i_gen) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->i_input);
  __Pyx_GIVEREF(__pyx_v_self->i_input);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_v_self->i_input) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->i_kill);
  __Pyx_GIVEREF(__pyx_v_self->i_kill);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_v_self->i_kill) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->i_output);
  __Pyx_GIVEREF(__pyx_v_self->i_output);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 6, __pyx_v_self->i_output) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->i_state);
  __Pyx_GIVEREF(__pyx_v_self->i_state);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 7, __pyx_v_self->i_state) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->parents);
  __Pyx_GIVEREF(__pyx_v_self->parents);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 8, __pyx_v_self->parents) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->positions);
  __Pyx_GIVEREF(__pyx_v_self->positions);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 9, __pyx_v_self->positions) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->stats);
  __Pyx_GIVEREF(__pyx_v_self->stats);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 10, __pyx_v_self->stats) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.bounded, self.children, self.gen, self.i_gen, self.i_input, self.i_kill, self.i_output, self.i_state, self.parents, self.positions, self.stats)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.bounded, self.children, self.gen, self.i_gen, self.i_input, self.i_kill, self.i_output, self.i_state, self.parents, self.positions, self.stats)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.bounded, self.children, self.gen, self.i_gen, self.i_input, self.i_kill, self.i_output, self.i_state, self.parents, self.positions, self.stats)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, None), state
*/
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->bounded != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->children != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->gen != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->i_gen != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->i_input != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->i_kill != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->i_output != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->i_state != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->parents != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->positions != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->stats != ((PyObject*)Py_None));
    __pyx_t_2 = __pyx_t_3;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlBlock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_105766659);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_105766659);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_105766659) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, None), state
 *     else:
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ControlBlock__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlBlock); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_105766659);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_105766659);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_105766659) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlBlock__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_11__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_10__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12ControlBlock_10__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ControlBlock__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlBlock__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlBlock__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlBlock.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":92
 *     """Non-empty exit point block."""
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         return False
 * 
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_1empty(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6Cython_8Compiler_11FlowControl_9ExitBlock_empty(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_empty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_1empty)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 92, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Cython/Compiler/FlowControl.py":93
 * 
 *     def empty(self):
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":92
 *     """Non-empty exit point block."""
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         return False
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ExitBlock.empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_1empty(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9ExitBlock_1empty = {"empty", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_1empty, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_1empty(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("empty (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_empty(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_empty(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_9ExitBlock_empty(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 92, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ExitBlock.empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9ExitBlock_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_2__reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_2__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.bounded, self.children, self.gen, self.i_gen, self.i_input, self.i_kill, self.i_output, self.i_state, self.parents, self.positions, self.stats)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = PyTuple_New(11); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.bounded);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.bounded);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->__pyx_base.bounded) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.children);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.children);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->__pyx_base.children) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.gen);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.gen);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->__pyx_base.gen) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.i_gen);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.i_gen);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_self->__pyx_base.i_gen) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.i_input);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.i_input);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_v_self->__pyx_base.i_input) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.i_kill);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.i_kill);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_v_self->__pyx_base.i_kill) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.i_output);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.i_output);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 6, __pyx_v_self->__pyx_base.i_output) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.i_state);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.i_state);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 7, __pyx_v_self->__pyx_base.i_state) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.parents);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.parents);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 8, __pyx_v_self->__pyx_base.parents) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.positions);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.positions);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 9, __pyx_v_self->__pyx_base.positions) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.stats);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.stats);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 10, __pyx_v_self->__pyx_base.stats) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.bounded, self.children, self.gen, self.i_gen, self.i_input, self.i_kill, self.i_output, self.i_state, self.parents, self.positions, self.stats)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.bounded, self.children, self.gen, self.i_gen, self.i_input, self.i_kill, self.i_output, self.i_state, self.parents, self.positions, self.stats)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.bounded, self.children, self.gen, self.i_gen, self.i_input, self.i_kill, self.i_output, self.i_state, self.parents, self.positions, self.stats)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, None), state
*/
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->__pyx_base.bounded != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.children != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.gen != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.i_gen != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.i_input != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.i_kill != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.i_output != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.i_state != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.parents != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.positions != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.stats != ((PyObject*)Py_None));
    __pyx_t_2 = __pyx_t_3;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ExitBlock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_105766659);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_105766659);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_105766659) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bounded is not None or self.children is not None or self.gen is not None or self.i_gen is not None or self.i_input is not None or self.i_kill is not None or self.i_output is not None or self.i_state is not None or self.parents is not None or self.positions is not None or self.stats is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, None), state
 *     else:
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ExitBlock__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ExitBlock); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_105766659);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_105766659);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_105766659) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ExitBlock.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ExitBlock__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9ExitBlock_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_4__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9ExitBlock_4__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ExitBlock__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ExitBlock__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ExitBlock__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ExitBlock.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":97
 * 
 * class AssignmentList:
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.stats = []
 * 
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList___init__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":98
 * class AssignmentList:
 *     def __init__(self):
 *         self.stats = []             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->stats);
  __Pyx_DECREF(__pyx_v_self->stats);
  __pyx_v_self->stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":97
 * 
 * class AssignmentList:
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.stats = []
 * 
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentList.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":40
 * 
 * cdef class AssignmentList:
 *     cdef public object bit             # <<<<<<<<<<<<<<
 *     cdef public object mask
 *     cdef public list stats
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->bit);
  __pyx_r = __pyx_v_self->bit;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->bit);
  __Pyx_DECREF(__pyx_v_self->bit);
  __pyx_v_self->bit = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->bit);
  __Pyx_DECREF(__pyx_v_self->bit);
  __pyx_v_self->bit = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":41
 * cdef class AssignmentList:
 *     cdef public object bit
 *     cdef public object mask             # <<<<<<<<<<<<<<
 *     cdef public list stats
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->mask);
  __pyx_r = __pyx_v_self->mask;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->mask);
  __Pyx_DECREF(__pyx_v_self->mask);
  __pyx_v_self->mask = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->mask);
  __Pyx_DECREF(__pyx_v_self->mask);
  __pyx_v_self->mask = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":42
 *     cdef public object bit
 *     cdef public object mask
 *     cdef public list stats             # <<<<<<<<<<<<<<
 * 
 * cdef class AssignmentCollector(TreeVisitor):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->stats);
  __pyx_r = __pyx_v_self->stats;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->stats);
  __Pyx_DECREF(__pyx_v_self->stats);
  __pyx_v_self->stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentList.stats.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->stats);
  __Pyx_DECREF(__pyx_v_self->stats);
  __pyx_v_self->stats = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_14AssignmentList_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_2__reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_2__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.bit, self.mask, self.stats)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->bit);
  __Pyx_GIVEREF(__pyx_v_self->bit);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->bit) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->mask);
  __Pyx_GIVEREF(__pyx_v_self->mask);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->mask) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->stats);
  __Pyx_GIVEREF(__pyx_v_self->stats);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->stats) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.bit, self.mask, self.stats)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.bit, self.mask, self.stats)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.bit is not None or self.mask is not None or self.stats is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.bit, self.mask, self.stats)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.bit is not None or self.mask is not None or self.stats is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, None), state
*/
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->bit != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->mask != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->stats != ((PyObject*)Py_None));
    __pyx_t_2 = __pyx_t_3;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bit is not None or self.mask is not None or self.stats is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.bit is not None or self.mask is not None or self.stats is not None
 *     if use_setstate:
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_AssignmentList); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_161667023);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_161667023);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_161667023) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bit is not None or self.mask is not None or self.stats is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, None), state
 *     else:
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_AssignmentList__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_AssignmentList); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_161667023);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_161667023);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_161667023) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentList.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_AssignmentList__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_14AssignmentList_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14AssignmentList_4__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_AssignmentList__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_AssignmentList__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_AssignmentList__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentList.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":114
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.blocks = set()
 *         self.entries = set()
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow___init__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":115
 * 
 *     def __init__(self):
 *         self.blocks = set()             # <<<<<<<<<<<<<<
 *         self.entries = set()
 *         self.loops = []
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->blocks);
  __Pyx_DECREF(__pyx_v_self->blocks);
  __pyx_v_self->blocks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":116
 *     def __init__(self):
 *         self.blocks = set()
 *         self.entries = set()             # <<<<<<<<<<<<<<
 *         self.loops = []
 *         self.exceptions = []
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(__pyx_v_self->entries);
  __pyx_v_self->entries = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":117
 *         self.blocks = set()
 *         self.entries = set()
 *         self.loops = []             # <<<<<<<<<<<<<<
 *         self.exceptions = []
 * 
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->loops);
  __Pyx_DECREF(__pyx_v_self->loops);
  __pyx_v_self->loops = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":118
 *         self.entries = set()
 *         self.loops = []
 *         self.exceptions = []             # <<<<<<<<<<<<<<
 * 
 *         self.entry_point = ControlBlock()
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->exceptions);
  __Pyx_DECREF(__pyx_v_self->exceptions);
  __pyx_v_self->exceptions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":120
 *         self.exceptions = []
 * 
 *         self.entry_point = ControlBlock()             # <<<<<<<<<<<<<<
 *         self.exit_point = ExitBlock()
 *         self.blocks.add(self.exit_point)
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __Pyx_GIVEREF((PyObject *)__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->entry_point);
  __Pyx_DECREF((PyObject *)__pyx_v_self->entry_point);
  __pyx_v_self->entry_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":121
 * 
 *         self.entry_point = ControlBlock()
 *         self.exit_point = ExitBlock()             # <<<<<<<<<<<<<<
 *         self.blocks.add(self.exit_point)
 *         self.block = self.entry_point
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __Pyx_GIVEREF((PyObject *)__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->exit_point);
  __Pyx_DECREF((PyObject *)__pyx_v_self->exit_point);
  __pyx_v_self->exit_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":122
 *         self.entry_point = ControlBlock()
 *         self.exit_point = ExitBlock()
 *         self.blocks.add(self.exit_point)             # <<<<<<<<<<<<<<
 *         self.block = self.entry_point
 *         self.in_try_block = 0
*/
  if (unlikely(__pyx_v_self->blocks == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(0, 122, __pyx_L1_error)
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_self->exit_point);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = PySet_Add(__pyx_v_self->blocks, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":123
 *         self.exit_point = ExitBlock()
 *         self.blocks.add(self.exit_point)
 *         self.block = self.entry_point             # <<<<<<<<<<<<<<
 *         self.in_try_block = 0
 * 
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->entry_point);
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->block);
  __pyx_v_self->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":124
 *         self.blocks.add(self.exit_point)
 *         self.block = self.entry_point
 *         self.in_try_block = 0             # <<<<<<<<<<<<<<
 * 
 *     def newblock(self, parent=None):
*/
  __pyx_v_self->in_try_block = 0;

  /* "Cython/Compiler/FlowControl.py":114
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.blocks = set()
 *         self.entries = set()
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":126
 *         self.in_try_block = 0
 * 
 *     def newblock(self, parent=None):             # <<<<<<<<<<<<<<
 *         """Create floating block linked to `parent` if given.
 * 
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_3newblock(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock *__pyx_optional_args) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_block = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("newblock", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_parent = __pyx_optional_args->parent;
    }
  }

  /* "Cython/Compiler/FlowControl.py":131
 *            NOTE: Block is NOT added to self.blocks
 *         """
 *         block = ControlBlock()             # <<<<<<<<<<<<<<
 *         self.blocks.add(block)
 *         if parent:
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":132
 *         """
 *         block = ControlBlock()
 *         self.blocks.add(block)             # <<<<<<<<<<<<<<
 *         if parent:
 *             parent.add_child(block)
*/
  if (unlikely(__pyx_v_self->blocks == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(0, 132, __pyx_L1_error)
  }
  __pyx_t_4 = PySet_Add(__pyx_v_self->blocks, ((PyObject *)__pyx_v_block)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 132, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":133
 *         block = ControlBlock()
 *         self.blocks.add(block)
 *         if parent:             # <<<<<<<<<<<<<<
 *             parent.add_child(block)
 *         return block
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_parent)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 133, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":134
 *         self.blocks.add(block)
 *         if parent:
 *             parent.add_child(block)             # <<<<<<<<<<<<<<
 *         return block
 * 
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_parent->__pyx_vtab)->add_child(__pyx_v_parent, ((PyObject *)__pyx_v_block), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":133
 *         block = ControlBlock()
 *         self.blocks.add(block)
 *         if parent:             # <<<<<<<<<<<<<<
 *             parent.add_child(block)
 *         return block
*/
  }

  /* "Cython/Compiler/FlowControl.py":135
 *         if parent:
 *             parent.add_child(block)
 *         return block             # <<<<<<<<<<<<<<
 * 
 *     def nextblock(self, parent=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_block);
  __pyx_r = ((PyObject *)__pyx_v_block);
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":126
 *         self.in_try_block = 0
 * 
 *     def newblock(self, parent=None):             # <<<<<<<<<<<<<<
 *         """Create floating block linked to `parent` if given.
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.newblock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_block);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_3newblock(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_2newblock, "Create floating block linked to `parent` if given.\n\n           NOTE: Block is NOT added to self.blocks\n        ");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_3newblock = {"newblock", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_3newblock, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_2newblock};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_3newblock(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("newblock (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_parent,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 126, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 126, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "newblock", 0) < (0)) __PYX_ERR(0, 126, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef((PyObject *)((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 126, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef((PyObject *)((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None));
    }
    __pyx_v_parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("newblock", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 126, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.newblock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_parent), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, 1, "parent", 0))) __PYX_ERR(0, 126, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_2newblock(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), __pyx_v_parent);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_2newblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("newblock", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.parent = __pyx_v_parent;
  __pyx_t_1 = __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlow->newblock(__pyx_v_self, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.newblock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":137
 *         return block
 * 
 *     def nextblock(self, parent=None):             # <<<<<<<<<<<<<<
 *         """Create block children block linked to current or `parent` if given.
 * 
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5nextblock(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock *__pyx_optional_args) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_block = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nextblock", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_parent = __pyx_optional_args->parent;
    }
  }

  /* "Cython/Compiler/FlowControl.py":142
 *            NOTE: Block is added to self.blocks
 *         """
 *         block = ControlBlock()             # <<<<<<<<<<<<<<
 *         self.blocks.add(block)
 *         if parent:
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 142, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":143
 *         """
 *         block = ControlBlock()
 *         self.blocks.add(block)             # <<<<<<<<<<<<<<
 *         if parent:
 *             parent.add_child(block)
*/
  if (unlikely(__pyx_v_self->blocks == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(0, 143, __pyx_L1_error)
  }
  __pyx_t_4 = PySet_Add(__pyx_v_self->blocks, ((PyObject *)__pyx_v_block)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 143, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":144
 *         block = ControlBlock()
 *         self.blocks.add(block)
 *         if parent:             # <<<<<<<<<<<<<<
 *             parent.add_child(block)
 *         elif self.block:
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_parent)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 144, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":145
 *         self.blocks.add(block)
 *         if parent:
 *             parent.add_child(block)             # <<<<<<<<<<<<<<
 *         elif self.block:
 *             self.block.add_child(block)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_parent->__pyx_vtab)->add_child(__pyx_v_parent, ((PyObject *)__pyx_v_block), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 145, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":144
 *         block = ControlBlock()
 *         self.blocks.add(block)
 *         if parent:             # <<<<<<<<<<<<<<
 *             parent.add_child(block)
 *         elif self.block:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/FlowControl.py":146
 *         if parent:
 *             parent.add_child(block)
 *         elif self.block:             # <<<<<<<<<<<<<<
 *             self.block.add_child(block)
 *         self.block = block
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->block)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 146, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":147
 *             parent.add_child(block)
 *         elif self.block:
 *             self.block.add_child(block)             # <<<<<<<<<<<<<<
 *         self.block = block
 *         return self.block
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->block->__pyx_vtab)->add_child(__pyx_v_self->block, ((PyObject *)__pyx_v_block), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":146
 *         if parent:
 *             parent.add_child(block)
 *         elif self.block:             # <<<<<<<<<<<<<<
 *             self.block.add_child(block)
 *         self.block = block
*/
  }
  __pyx_L3:;

  /* "Cython/Compiler/FlowControl.py":148
 *         elif self.block:
 *             self.block.add_child(block)
 *         self.block = block             # <<<<<<<<<<<<<<
 *         return self.block
 * 
*/
  __Pyx_INCREF((PyObject *)__pyx_v_block);
  __Pyx_GIVEREF((PyObject *)__pyx_v_block);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->block);
  __pyx_v_self->block = __pyx_v_block;

  /* "Cython/Compiler/FlowControl.py":149
 *             self.block.add_child(block)
 *         self.block = block
 *         return self.block             # <<<<<<<<<<<<<<
 * 
 *     def is_tracked(self, entry):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->block);
  __pyx_r = ((PyObject *)__pyx_v_self->block);
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":137
 *         return block
 * 
 *     def nextblock(self, parent=None):             # <<<<<<<<<<<<<<
 *         """Create block children block linked to current or `parent` if given.
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.nextblock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_block);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5nextblock(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_4nextblock, "Create block children block linked to current or `parent` if given.\n\n           NOTE: Block is added to self.blocks\n        ");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_5nextblock = {"nextblock", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5nextblock, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_4nextblock};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5nextblock(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nextblock (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_parent,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 137, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 137, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "nextblock", 0) < (0)) __PYX_ERR(0, 137, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef((PyObject *)((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 137, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef((PyObject *)((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None));
    }
    __pyx_v_parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nextblock", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 137, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.nextblock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_parent), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, 1, "parent", 0))) __PYX_ERR(0, 137, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_4nextblock(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), __pyx_v_parent);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_4nextblock(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nextblock", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.parent = __pyx_v_parent;
  __pyx_t_1 = __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlow->nextblock(__pyx_v_self, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.nextblock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":151
 *         return self.block
 * 
 *     def is_tracked(self, entry):             # <<<<<<<<<<<<<<
 *         if entry.is_anonymous:
 *             return False
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7is_tracked(PyObject *__pyx_v_self, PyObject *__pyx_v_entry); /*proto*/
static int __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_tracked", 0);

  /* "Cython/Compiler/FlowControl.py":152
 * 
 *     def is_tracked(self, entry):
 *         if entry.is_anonymous:             # <<<<<<<<<<<<<<
 *             return False
 *         return (entry.is_local or entry.is_pyclass_attr or entry.is_arg or
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_anonymous); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":153
 *     def is_tracked(self, entry):
 *         if entry.is_anonymous:
 *             return False             # <<<<<<<<<<<<<<
 *         return (entry.is_local or entry.is_pyclass_attr or entry.is_arg or
 *                 entry.from_closure or entry.in_closure or
*/
    __pyx_r = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":152
 * 
 *     def is_tracked(self, entry):
 *         if entry.is_anonymous:             # <<<<<<<<<<<<<<
 *             return False
 *         return (entry.is_local or entry.is_pyclass_attr or entry.is_arg or
*/
  }

  /* "Cython/Compiler/FlowControl.py":154
 *         if entry.is_anonymous:
 *             return False
 *         return (entry.is_local or entry.is_pyclass_attr or entry.is_arg or             # <<<<<<<<<<<<<<
 *                 entry.from_closure or entry.in_closure or
 *                 entry.error_on_uninitialized)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_local); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_pyclass_attr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/FlowControl.py":155
 *             return False
 *         return (entry.is_local or entry.is_pyclass_attr or entry.is_arg or
 *                 entry.from_closure or entry.in_closure or             # <<<<<<<<<<<<<<
 *                 entry.error_on_uninitialized)
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_from_closure); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_in_closure); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/FlowControl.py":156
 *         return (entry.is_local or entry.is_pyclass_attr or entry.is_arg or
 *                 entry.from_closure or entry.in_closure or
 *                 entry.error_on_uninitialized)             # <<<<<<<<<<<<<<
 * 
 *     def is_statically_assigned(self, entry):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_error_on_uninitialized); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":151
 *         return self.block
 * 
 *     def is_tracked(self, entry):             # <<<<<<<<<<<<<<
 *         if entry.is_anonymous:
 *             return False
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.is_tracked", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7is_tracked(PyObject *__pyx_v_self, PyObject *__pyx_v_entry); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_7is_tracked = {"is_tracked", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7is_tracked, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7is_tracked(PyObject *__pyx_v_self, PyObject *__pyx_v_entry) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_tracked (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6is_tracked(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_entry));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6is_tracked(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_tracked", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(__pyx_v_self, __pyx_v_entry, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 151, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.is_tracked", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":158
 *                 entry.error_on_uninitialized)
 * 
 *     def is_statically_assigned(self, entry):             # <<<<<<<<<<<<<<
 *         if (entry.is_local and entry.is_variable and
 *                 (entry.type.is_struct_or_union or
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_9is_statically_assigned(PyObject *__pyx_v_self, PyObject *__pyx_v_entry); /*proto*/
static int __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_statically_assigned(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_statically_assigned", 0);

  /* "Cython/Compiler/FlowControl.py":159
 * 
 *     def is_statically_assigned(self, entry):
 *         if (entry.is_local and entry.is_variable and             # <<<<<<<<<<<<<<
 *                 (entry.type.is_struct_or_union or
 *                  entry.type.is_complex or
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_local); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_variable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/FlowControl.py":160
 *     def is_statically_assigned(self, entry):
 *         if (entry.is_local and entry.is_variable and
 *                 (entry.type.is_struct_or_union or             # <<<<<<<<<<<<<<
 *                  entry.type.is_complex or
 *                  entry.type.is_array or
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_is_struct_or_union); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/FlowControl.py":161
 *         if (entry.is_local and entry.is_variable and
 *                 (entry.type.is_struct_or_union or
 *                  entry.type.is_complex or             # <<<<<<<<<<<<<<
 *                  entry.type.is_array or
 *                  entry.type.is_cython_lock_type or
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_is_complex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/FlowControl.py":162
 *                 (entry.type.is_struct_or_union or
 *                  entry.type.is_complex or
 *                  entry.type.is_array or             # <<<<<<<<<<<<<<
 *                  entry.type.is_cython_lock_type or
 *                  (entry.type.is_cpp_class and not entry.is_cpp_optional))):
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_is_array); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/FlowControl.py":163
 *                  entry.type.is_complex or
 *                  entry.type.is_array or
 *                  entry.type.is_cython_lock_type or             # <<<<<<<<<<<<<<
 *                  (entry.type.is_cpp_class and not entry.is_cpp_optional))):
 *             # stack allocated structured variable => never uninitialised
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_is_cython_lock_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/FlowControl.py":164
 *                  entry.type.is_array or
 *                  entry.type.is_cython_lock_type or
 *                  (entry.type.is_cpp_class and not entry.is_cpp_optional))):             # <<<<<<<<<<<<<<
 *             # stack allocated structured variable => never uninitialised
 *             return True
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_is_cpp_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_cpp_optional); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = (!__pyx_t_3);
  __pyx_t_1 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;

  /* "Cython/Compiler/FlowControl.py":159
 * 
 *     def is_statically_assigned(self, entry):
 *         if (entry.is_local and entry.is_variable and             # <<<<<<<<<<<<<<
 *                 (entry.type.is_struct_or_union or
 *                  entry.type.is_complex or
*/
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":166
 *                  (entry.type.is_cpp_class and not entry.is_cpp_optional))):
 *             # stack allocated structured variable => never uninitialised
 *             return True             # <<<<<<<<<<<<<<
 *         return False
 * 
*/
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":159
 * 
 *     def is_statically_assigned(self, entry):
 *         if (entry.is_local and entry.is_variable and             # <<<<<<<<<<<<<<
 *                 (entry.type.is_struct_or_union or
 *                  entry.type.is_complex or
*/
  }

  /* "Cython/Compiler/FlowControl.py":167
 *             # stack allocated structured variable => never uninitialised
 *             return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def mark_position(self, node):
*/
  __pyx_r = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":158
 *                 entry.error_on_uninitialized)
 * 
 *     def is_statically_assigned(self, entry):             # <<<<<<<<<<<<<<
 *         if (entry.is_local and entry.is_variable and
 *                 (entry.type.is_struct_or_union or
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.is_statically_assigned", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_9is_statically_assigned(PyObject *__pyx_v_self, PyObject *__pyx_v_entry); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_9is_statically_assigned = {"is_statically_assigned", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_9is_statically_assigned, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_9is_statically_assigned(PyObject *__pyx_v_self, PyObject *__pyx_v_entry) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_statically_assigned (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_8is_statically_assigned(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_entry));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_8is_statically_assigned(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_statically_assigned", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_statically_assigned(__pyx_v_self, __pyx_v_entry, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 158, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.is_statically_assigned", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":169
 *         return False
 * 
 *     def mark_position(self, node):             # <<<<<<<<<<<<<<
 *         """Mark position, will be used to draw graph nodes."""
 *         if self.block:
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11mark_position(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_position", 0);

  /* "Cython/Compiler/FlowControl.py":171
 *     def mark_position(self, node):
 *         """Mark position, will be used to draw graph nodes."""
 *         if self.block:             # <<<<<<<<<<<<<<
 *             self.block.positions.add(node.pos[:2])
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->block)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 171, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":172
 *         """Mark position, will be used to draw graph nodes."""
 *         if self.block:
 *             self.block.positions.add(node.pos[:2])             # <<<<<<<<<<<<<<
 * 
 *     def mark_assignment(self, lhs, rhs, entry, rhs_scope=None):
*/
    if (unlikely(__pyx_v_self->block->positions == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
      __PYX_ERR(0, 172, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, 2, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = PySet_Add(__pyx_v_self->block->positions, __pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 172, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":171
 *     def mark_position(self, node):
 *         """Mark position, will be used to draw graph nodes."""
 *         if self.block:             # <<<<<<<<<<<<<<
 *             self.block.positions.add(node.pos[:2])
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":169
 *         return False
 * 
 *     def mark_position(self, node):             # <<<<<<<<<<<<<<
 *         """Mark position, will be used to draw graph nodes."""
 *         if self.block:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11mark_position(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_10mark_position, "Mark position, will be used to draw graph nodes.");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_11mark_position = {"mark_position", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11mark_position, METH_O, __pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_10mark_position};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11mark_position(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_position (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10mark_position(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_position", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_position(__pyx_v_self, __pyx_v_node, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":174
 *             self.block.positions.add(node.pos[:2])
 * 
 *     def mark_assignment(self, lhs, rhs, entry, rhs_scope=None):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameAssignment(lhs, rhs, entry, rhs_scope=rhs_scope)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_13mark_assignment(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment *__pyx_optional_args) {
  PyObject *__pyx_v_rhs_scope = ((PyObject *)Py_None);
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_assignment = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_assignment", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_rhs_scope = __pyx_optional_args->rhs_scope;
    }
  }

  /* "Cython/Compiler/FlowControl.py":175
 * 
 *     def mark_assignment(self, lhs, rhs, entry, rhs_scope=None):
 *         if self.block and self.is_tracked(entry):             # <<<<<<<<<<<<<<
 *             assignment = NameAssignment(lhs, rhs, entry, rhs_scope=rhs_scope)
 *             self.block.stats.append(assignment)
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->block)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 175, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(__pyx_v_self, __pyx_v_entry, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 175, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":176
 *     def mark_assignment(self, lhs, rhs, entry, rhs_scope=None):
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameAssignment(lhs, rhs, entry, rhs_scope=rhs_scope)             # <<<<<<<<<<<<<<
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = assignment
*/
    __pyx_t_4 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[4 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_rhs_scope, __pyx_v_rhs_scope, __pyx_t_6, __pyx_callargs+4, 0) < (0)) __PYX_ERR(0, 176, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 176, __pyx_L1_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_3);
    }
    __pyx_v_assignment = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":177
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameAssignment(lhs, rhs, entry, rhs_scope=rhs_scope)
 *             self.block.stats.append(assignment)             # <<<<<<<<<<<<<<
 *             self.block.gen[entry] = assignment
 *             self.entries.add(entry)
*/
    if (unlikely(__pyx_v_self->block->stats == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 177, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->block->stats, ((PyObject *)__pyx_v_assignment)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 177, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":178
 *             assignment = NameAssignment(lhs, rhs, entry, rhs_scope=rhs_scope)
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = assignment             # <<<<<<<<<<<<<<
 *             self.entries.add(entry)
 * 
*/
    if (unlikely(__pyx_v_self->block->gen == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 178, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_self->block->gen, __pyx_v_entry, ((PyObject *)__pyx_v_assignment)) < 0))) __PYX_ERR(0, 178, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":179
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = assignment
 *             self.entries.add(entry)             # <<<<<<<<<<<<<<
 * 
 *     def mark_argument(self, lhs, rhs, entry):
*/
    if (unlikely(__pyx_v_self->entries == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
      __PYX_ERR(0, 179, __pyx_L1_error)
    }
    __pyx_t_7 = PySet_Add(__pyx_v_self->entries, __pyx_v_entry); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 179, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":175
 * 
 *     def mark_assignment(self, lhs, rhs, entry, rhs_scope=None):
 *         if self.block and self.is_tracked(entry):             # <<<<<<<<<<<<<<
 *             assignment = NameAssignment(lhs, rhs, entry, rhs_scope=rhs_scope)
 *             self.block.stats.append(assignment)
*/
  }

  /* "Cython/Compiler/FlowControl.py":174
 *             self.block.positions.add(node.pos[:2])
 * 
 *     def mark_assignment(self, lhs, rhs, entry, rhs_scope=None):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameAssignment(lhs, rhs, entry, rhs_scope=rhs_scope)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_assignment);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_13mark_assignment(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_13mark_assignment = {"mark_assignment", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_13mark_assignment, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_13mark_assignment(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_lhs = 0;
  PyObject *__pyx_v_rhs = 0;
  PyObject *__pyx_v_entry = 0;
  PyObject *__pyx_v_rhs_scope = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_assignment (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_lhs,&__pyx_mstate_global->__pyx_n_u_rhs,&__pyx_mstate_global->__pyx_n_u_entry,&__pyx_mstate_global->__pyx_n_u_rhs_scope,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 174, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 174, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 174, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 174, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 174, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "mark_assignment", 0) < (0)) __PYX_ERR(0, 174, __pyx_L3_error)
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("mark_assignment", 0, 3, 4, i); __PYX_ERR(0, 174, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 174, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 174, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 174, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 174, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_lhs = values[0];
    __pyx_v_rhs = values[1];
    __pyx_v_entry = values[2];
    __pyx_v_rhs_scope = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mark_assignment", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 174, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12mark_assignment(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry, __pyx_v_rhs_scope);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry, PyObject *__pyx_v_rhs_scope) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_assignment", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.rhs_scope = __pyx_v_rhs_scope;
  __pyx_t_1 = __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlow->mark_assignment(__pyx_v_self, __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":181
 *             self.entries.add(entry)
 * 
 *     def mark_argument(self, lhs, rhs, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = Argument(lhs, rhs, entry)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_15mark_argument(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_argument(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_assignment = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_argument", 0);

  /* "Cython/Compiler/FlowControl.py":182
 * 
 *     def mark_argument(self, lhs, rhs, entry):
 *         if self.block and self.is_tracked(entry):             # <<<<<<<<<<<<<<
 *             assignment = Argument(lhs, rhs, entry)
 *             self.block.stats.append(assignment)
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->block)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 182, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(__pyx_v_self, __pyx_v_entry, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 182, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":183
 *     def mark_argument(self, lhs, rhs, entry):
 *         if self.block and self.is_tracked(entry):
 *             assignment = Argument(lhs, rhs, entry)             # <<<<<<<<<<<<<<
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = assignment
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Argument); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_v_assignment = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":184
 *         if self.block and self.is_tracked(entry):
 *             assignment = Argument(lhs, rhs, entry)
 *             self.block.stats.append(assignment)             # <<<<<<<<<<<<<<
 *             self.block.gen[entry] = assignment
 *             self.entries.add(entry)
*/
    if (unlikely(__pyx_v_self->block->stats == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 184, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->block->stats, __pyx_v_assignment); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 184, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":185
 *             assignment = Argument(lhs, rhs, entry)
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = assignment             # <<<<<<<<<<<<<<
 *             self.entries.add(entry)
 * 
*/
    if (unlikely(__pyx_v_self->block->gen == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 185, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_self->block->gen, __pyx_v_entry, __pyx_v_assignment) < 0))) __PYX_ERR(0, 185, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":186
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = assignment
 *             self.entries.add(entry)             # <<<<<<<<<<<<<<
 * 
 *     def mark_deletion(self, node, entry):
*/
    if (unlikely(__pyx_v_self->entries == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
      __PYX_ERR(0, 186, __pyx_L1_error)
    }
    __pyx_t_7 = PySet_Add(__pyx_v_self->entries, __pyx_v_entry); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 186, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":182
 * 
 *     def mark_argument(self, lhs, rhs, entry):
 *         if self.block and self.is_tracked(entry):             # <<<<<<<<<<<<<<
 *             assignment = Argument(lhs, rhs, entry)
 *             self.block.stats.append(assignment)
*/
  }

  /* "Cython/Compiler/FlowControl.py":181
 *             self.entries.add(entry)
 * 
 *     def mark_argument(self, lhs, rhs, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = Argument(lhs, rhs, entry)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_argument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_assignment);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_15mark_argument(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_15mark_argument = {"mark_argument", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_15mark_argument, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_15mark_argument(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_lhs = 0;
  PyObject *__pyx_v_rhs = 0;
  PyObject *__pyx_v_entry = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_argument (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_lhs,&__pyx_mstate_global->__pyx_n_u_rhs,&__pyx_mstate_global->__pyx_n_u_entry,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 181, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 181, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 181, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 181, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "mark_argument", 0) < (0)) __PYX_ERR(0, 181, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("mark_argument", 1, 3, 3, i); __PYX_ERR(0, 181, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 181, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 181, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 181, __pyx_L3_error)
    }
    __pyx_v_lhs = values[0];
    __pyx_v_rhs = values[1];
    __pyx_v_entry = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mark_argument", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 181, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_argument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_14mark_argument(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_14mark_argument(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_argument", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_argument(__pyx_v_self, __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_argument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":188
 *             self.entries.add(entry)
 * 
 *     def mark_deletion(self, node, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameDeletion(node, entry)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_17mark_deletion(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_deletion(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_assignment = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_deletion", 0);

  /* "Cython/Compiler/FlowControl.py":189
 * 
 *     def mark_deletion(self, node, entry):
 *         if self.block and self.is_tracked(entry):             # <<<<<<<<<<<<<<
 *             assignment = NameDeletion(node, entry)
 *             self.block.stats.append(assignment)
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->block)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 189, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(__pyx_v_self, __pyx_v_entry, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 189, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":190
 *     def mark_deletion(self, node, entry):
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameDeletion(node, entry)             # <<<<<<<<<<<<<<
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = Uninitialized
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NameDeletion); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_node, __pyx_v_entry};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_v_assignment = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":191
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameDeletion(node, entry)
 *             self.block.stats.append(assignment)             # <<<<<<<<<<<<<<
 *             self.block.gen[entry] = Uninitialized
 *             self.entries.add(entry)
*/
    if (unlikely(__pyx_v_self->block->stats == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 191, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->block->stats, __pyx_v_assignment); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 191, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":192
 *             assignment = NameDeletion(node, entry)
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = Uninitialized             # <<<<<<<<<<<<<<
 *             self.entries.add(entry)
 * 
*/
    if (unlikely(__pyx_v_self->block->gen == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 192, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_self->block->gen, __pyx_v_entry, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized)) < 0))) __PYX_ERR(0, 192, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":193
 *             self.block.stats.append(assignment)
 *             self.block.gen[entry] = Uninitialized
 *             self.entries.add(entry)             # <<<<<<<<<<<<<<
 * 
 *     def mark_reference(self, node, entry):
*/
    if (unlikely(__pyx_v_self->entries == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
      __PYX_ERR(0, 193, __pyx_L1_error)
    }
    __pyx_t_7 = PySet_Add(__pyx_v_self->entries, __pyx_v_entry); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 193, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":189
 * 
 *     def mark_deletion(self, node, entry):
 *         if self.block and self.is_tracked(entry):             # <<<<<<<<<<<<<<
 *             assignment = NameDeletion(node, entry)
 *             self.block.stats.append(assignment)
*/
  }

  /* "Cython/Compiler/FlowControl.py":188
 *             self.entries.add(entry)
 * 
 *     def mark_deletion(self, node, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameDeletion(node, entry)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_deletion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_assignment);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_17mark_deletion(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_17mark_deletion = {"mark_deletion", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_17mark_deletion, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_17mark_deletion(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_node = 0;
  PyObject *__pyx_v_entry = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_deletion (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_entry,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 188, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 188, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 188, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "mark_deletion", 0) < (0)) __PYX_ERR(0, 188, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("mark_deletion", 1, 2, 2, i); __PYX_ERR(0, 188, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 188, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 188, __pyx_L3_error)
    }
    __pyx_v_node = values[0];
    __pyx_v_entry = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mark_deletion", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 188, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_deletion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_16mark_deletion(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), __pyx_v_node, __pyx_v_entry);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_16mark_deletion(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_deletion", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_deletion(__pyx_v_self, __pyx_v_node, __pyx_v_entry, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_deletion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":195
 *             self.entries.add(entry)
 * 
 *     def mark_reference(self, node, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             self.block.stats.append(NameReference(node, entry))
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_19mark_reference(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_reference(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_reference", 0);

  /* "Cython/Compiler/FlowControl.py":196
 * 
 *     def mark_reference(self, node, entry):
 *         if self.block and self.is_tracked(entry):             # <<<<<<<<<<<<<<
 *             self.block.stats.append(NameReference(node, entry))
 *             ## XXX: We don't track expression evaluation order so we can't use
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->block)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 196, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(__pyx_v_self, __pyx_v_entry, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 196, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":197
 *     def mark_reference(self, node, entry):
 *         if self.block and self.is_tracked(entry):
 *             self.block.stats.append(NameReference(node, entry))             # <<<<<<<<<<<<<<
 *             ## XXX: We don't track expression evaluation order so we can't use
 *             ## XXX: successful reference as initialization sign.
*/
    if (unlikely(__pyx_v_self->block->stats == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 197, __pyx_L1_error)
    }
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NameReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_node, __pyx_v_entry};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->block->stats, __pyx_t_3); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":203
 *             ## if not node.allow_null:
 *             ##     self.block.bounded.add(entry)
 *             self.entries.add(entry)             # <<<<<<<<<<<<<<
 * 
 *     def normalize(self):
*/
    if (unlikely(__pyx_v_self->entries == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
      __PYX_ERR(0, 203, __pyx_L1_error)
    }
    __pyx_t_7 = PySet_Add(__pyx_v_self->entries, __pyx_v_entry); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 203, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":196
 * 
 *     def mark_reference(self, node, entry):
 *         if self.block and self.is_tracked(entry):             # <<<<<<<<<<<<<<
 *             self.block.stats.append(NameReference(node, entry))
 *             ## XXX: We don't track expression evaluation order so we can't use
*/
  }

  /* "Cython/Compiler/FlowControl.py":195
 *             self.entries.add(entry)
 * 
 *     def mark_reference(self, node, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             self.block.stats.append(NameReference(node, entry))
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_reference", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_19mark_reference(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_19mark_reference = {"mark_reference", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_19mark_reference, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_19mark_reference(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_node = 0;
  PyObject *__pyx_v_entry = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_reference (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_entry,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 195, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 195, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 195, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "mark_reference", 0) < (0)) __PYX_ERR(0, 195, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("mark_reference", 1, 2, 2, i); __PYX_ERR(0, 195, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 195, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 195, __pyx_L3_error)
    }
    __pyx_v_node = values[0];
    __pyx_v_entry = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mark_reference", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 195, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_reference", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_18mark_reference(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), __pyx_v_node, __pyx_v_entry);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_18mark_reference(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_reference", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_reference(__pyx_v_self, __pyx_v_node, __pyx_v_entry, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.mark_reference", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":205
 *             self.entries.add(entry)
 * 
 *     def normalize(self):             # <<<<<<<<<<<<<<
 *         """Delete unreachable and orphan blocks."""
 *         queue = {self.entry_point}
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_21normalize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_normalize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_queue = NULL;
  PyObject *__pyx_v_visited = NULL;
  PyObject *__pyx_v_root = NULL;
  PyObject *__pyx_v_child = NULL;
  PyObject *__pyx_v_unreachable = 0;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_block = 0;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normalize", 0);

  /* "Cython/Compiler/FlowControl.py":207
 *     def normalize(self):
 *         """Delete unreachable and orphan blocks."""
 *         queue = {self.entry_point}             # <<<<<<<<<<<<<<
 *         visited = set()
 *         while queue:
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PySet_Add(__pyx_t_1, ((PyObject *)__pyx_v_self->entry_point)) < (0)) __PYX_ERR(0, 207, __pyx_L1_error)
  __pyx_v_queue = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":208
 *         """Delete unreachable and orphan blocks."""
 *         queue = {self.entry_point}
 *         visited = set()             # <<<<<<<<<<<<<<
 *         while queue:
 *             root = queue.pop()
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_visited = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":209
 *         queue = {self.entry_point}
 *         visited = set()
 *         while queue:             # <<<<<<<<<<<<<<
 *             root = queue.pop()
 *             visited.add(root)
*/
  while (1) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PySet_GET_SIZE(__pyx_v_queue);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 209, __pyx_L1_error)
      __pyx_t_2 = (__pyx_temp != 0);
    }

    if (!__pyx_t_2) break;

    /* "Cython/Compiler/FlowControl.py":210
 *         visited = set()
 *         while queue:
 *             root = queue.pop()             # <<<<<<<<<<<<<<
 *             visited.add(root)
 *             for child in root.children:
*/
    __pyx_t_1 = PySet_Pop(__pyx_v_queue); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_root, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":211
 *         while queue:
 *             root = queue.pop()
 *             visited.add(root)             # <<<<<<<<<<<<<<
 *             for child in root.children:
 *                 if child not in visited:
*/
    __pyx_t_3 = PySet_Add(__pyx_v_visited, __pyx_v_root); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 211, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":212
 *             root = queue.pop()
 *             visited.add(root)
 *             for child in root.children:             # <<<<<<<<<<<<<<
 *                 if child not in visited:
 *                     queue.add(child)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_root, __pyx_mstate_global->__pyx_n_u_children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 212, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 212, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_5;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 212, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5));
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5);
          #endif
          ++__pyx_t_5;
        }
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 212, __pyx_L1_error)
      } else {
        __pyx_t_1 = __pyx_t_6(__pyx_t_4);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 212, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_child, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":213
 *             visited.add(root)
 *             for child in root.children:
 *                 if child not in visited:             # <<<<<<<<<<<<<<
 *                     queue.add(child)
 * 
*/
      __pyx_t_2 = (__Pyx_PySet_ContainsTF(__pyx_v_child, __pyx_v_visited, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 213, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/FlowControl.py":214
 *             for child in root.children:
 *                 if child not in visited:
 *                     queue.add(child)             # <<<<<<<<<<<<<<
 * 
 *         unreachable: set = self.blocks - visited
*/
        __pyx_t_3 = PySet_Add(__pyx_v_queue, __pyx_v_child); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 214, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":213
 *             visited.add(root)
 *             for child in root.children:
 *                 if child not in visited:             # <<<<<<<<<<<<<<
 *                     queue.add(child)
 * 
*/
      }

      /* "Cython/Compiler/FlowControl.py":212
 *             root = queue.pop()
 *             visited.add(root)
 *             for child in root.children:             # <<<<<<<<<<<<<<
 *                 if child not in visited:
 *                     queue.add(child)
*/
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }

  /* "Cython/Compiler/FlowControl.py":216
 *                     queue.add(child)
 * 
 *         unreachable: set = self.blocks - visited             # <<<<<<<<<<<<<<
 *         block: ControlBlock
 *         for block in unreachable:
*/
  __pyx_t_4 = PyNumber_Subtract(__pyx_v_self->blocks, __pyx_v_visited); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(PySet_CheckExact(__pyx_t_4)) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_4))) __PYX_ERR(0, 216, __pyx_L1_error)
  __pyx_v_unreachable = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":218
 *         unreachable: set = self.blocks - visited
 *         block: ControlBlock
 *         for block in unreachable:             # <<<<<<<<<<<<<<
 *             block.detach()
 * 
*/
  __pyx_t_5 = 0;
  __pyx_t_1 = __Pyx_set_iterator(__pyx_v_unreachable, 1, (&__pyx_t_7), (&__pyx_t_8)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __pyx_t_4 = __pyx_t_1;
  __pyx_t_1 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_set_iter_next(__pyx_t_4, __pyx_t_7, &__pyx_t_5, &__pyx_t_1, __pyx_t_8);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_block, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":219
 *         block: ControlBlock
 *         for block in unreachable:
 *             block.detach()             # <<<<<<<<<<<<<<
 * 
 *         visited.remove(self.entry_point)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_block->__pyx_vtab)->detach(__pyx_v_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":221
 *             block.detach()
 * 
 *         visited.remove(self.entry_point)             # <<<<<<<<<<<<<<
 * 
 *         parent: ControlBlock
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_self->entry_point);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PySet_Remove(__pyx_v_visited, __pyx_t_4); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":224
 * 
 *         parent: ControlBlock
 *         for block in visited:             # <<<<<<<<<<<<<<
 *             if block.empty():
 *                 for parent in block.parents:  # Re-parent
*/
  __pyx_t_7 = 0;
  __pyx_t_1 = __Pyx_set_iterator(__pyx_v_visited, 1, (&__pyx_t_5), (&__pyx_t_8)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __pyx_t_4 = __pyx_t_1;
  __pyx_t_1 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_set_iter_next(__pyx_t_4, __pyx_t_5, &__pyx_t_7, &__pyx_t_1, __pyx_t_8);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_block, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":225
 *         parent: ControlBlock
 *         for block in visited:
 *             if block.empty():             # <<<<<<<<<<<<<<
 *                 for parent in block.parents:  # Re-parent
 *                     for child in block.children:
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_block->__pyx_vtab)->empty(__pyx_v_block, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 225, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/FlowControl.py":226
 *         for block in visited:
 *             if block.empty():
 *                 for parent in block.parents:  # Re-parent             # <<<<<<<<<<<<<<
 *                     for child in block.children:
 *                         parent.add_child(child)
*/
      __pyx_t_10 = 0;
      __pyx_t_12 = __Pyx_set_iterator(__pyx_v_block->parents, 1, (&__pyx_t_11), (&__pyx_t_9)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_1);
      __pyx_t_1 = __pyx_t_12;
      __pyx_t_12 = 0;
      while (1) {
        __pyx_t_13 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_11, &__pyx_t_10, &__pyx_t_12, __pyx_t_9);
        if (unlikely(__pyx_t_13 == 0)) break;
        if (unlikely(__pyx_t_13 == -1)) __PYX_ERR(0, 226, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (!(likely(((__pyx_t_12) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_12, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 226, __pyx_L1_error)
        __Pyx_XDECREF_SET(__pyx_v_parent, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_12));
        __pyx_t_12 = 0;

        /* "Cython/Compiler/FlowControl.py":227
 *             if block.empty():
 *                 for parent in block.parents:  # Re-parent
 *                     for child in block.children:             # <<<<<<<<<<<<<<
 *                         parent.add_child(child)
 *                 block.detach()
*/
        __pyx_t_14 = 0;
        __pyx_t_16 = __Pyx_set_iterator(__pyx_v_block->children, 1, (&__pyx_t_15), (&__pyx_t_13)); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 227, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_XDECREF(__pyx_t_12);
        __pyx_t_12 = __pyx_t_16;
        __pyx_t_16 = 0;
        while (1) {
          __pyx_t_17 = __Pyx_set_iter_next(__pyx_t_12, __pyx_t_15, &__pyx_t_14, &__pyx_t_16, __pyx_t_13);
          if (unlikely(__pyx_t_17 == 0)) break;
          if (unlikely(__pyx_t_17 == -1)) __PYX_ERR(0, 227, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_XDECREF_SET(__pyx_v_child, __pyx_t_16);
          __pyx_t_16 = 0;

          /* "Cython/Compiler/FlowControl.py":228
 *                 for parent in block.parents:  # Re-parent
 *                     for child in block.children:
 *                         parent.add_child(child)             # <<<<<<<<<<<<<<
 *                 block.detach()
 *                 unreachable.add(block)
*/
          __pyx_t_16 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_parent->__pyx_vtab)->add_child(__pyx_v_parent, __pyx_v_child, 0); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 228, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":229
 *                     for child in block.children:
 *                         parent.add_child(child)
 *                 block.detach()             # <<<<<<<<<<<<<<
 *                 unreachable.add(block)
 *         self.blocks -= unreachable
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_block->__pyx_vtab)->detach(__pyx_v_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":230
 *                         parent.add_child(child)
 *                 block.detach()
 *                 unreachable.add(block)             # <<<<<<<<<<<<<<
 *         self.blocks -= unreachable
 * 
*/
      __pyx_t_3 = PySet_Add(__pyx_v_unreachable, ((PyObject *)__pyx_v_block)); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 230, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":225
 *         parent: ControlBlock
 *         for block in visited:
 *             if block.empty():             # <<<<<<<<<<<<<<
 *                 for parent in block.parents:  # Re-parent
 *                     for child in block.children:
*/
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":231
 *                 block.detach()
 *                 unreachable.add(block)
 *         self.blocks -= unreachable             # <<<<<<<<<<<<<<
 * 
 *     def initialize(self):
*/
  __pyx_t_4 = PyNumber_InPlaceSubtract(__pyx_v_self->blocks, __pyx_v_unreachable); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(PySet_CheckExact(__pyx_t_4)) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_4))) __PYX_ERR(0, 231, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->blocks);
  __Pyx_DECREF(__pyx_v_self->blocks);
  __pyx_v_self->blocks = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":205
 *             self.entries.add(entry)
 * 
 *     def normalize(self):             # <<<<<<<<<<<<<<
 *         """Delete unreachable and orphan blocks."""
 *         queue = {self.entry_point}
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.normalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_queue);
  __Pyx_XDECREF(__pyx_v_visited);
  __Pyx_XDECREF(__pyx_v_root);
  __Pyx_XDECREF(__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_unreachable);
  __Pyx_XDECREF((PyObject *)__pyx_v_block);
  __Pyx_XDECREF((PyObject *)__pyx_v_parent);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_21normalize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_20normalize, "Delete unreachable and orphan blocks.");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_21normalize = {"normalize", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_21normalize, METH_NOARGS, __pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_20normalize};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_21normalize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normalize (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_20normalize(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_20normalize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normalize", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_normalize(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.normalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":233
 *         self.blocks -= unreachable
 * 
 *     def initialize(self):             # <<<<<<<<<<<<<<
 *         """Set initial state, map assignments to bits."""
 *         self.assmts = {}
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_23initialize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_initialize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_assmts = 0;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_block = 0;
  PyObject *__pyx_v_bit = 0;
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_v_stat = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("initialize", 0);

  /* "Cython/Compiler/FlowControl.py":235
 *     def initialize(self):
 *         """Set initial state, map assignments to bits."""
 *         self.assmts = {}             # <<<<<<<<<<<<<<
 *         assmts: AssignmentList
 *         block: ControlBlock
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->assmts);
  __Pyx_DECREF(__pyx_v_self->assmts);
  __pyx_v_self->assmts = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":239
 *         block: ControlBlock
 * 
 *         bit: int = 1             # <<<<<<<<<<<<<<
 *         for entry in self.entries:
 *             assmts = AssignmentList()
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_1);
  __pyx_v_bit = __pyx_mstate_global->__pyx_int_1;

  /* "Cython/Compiler/FlowControl.py":240
 * 
 *         bit: int = 1
 *         for entry in self.entries:             # <<<<<<<<<<<<<<
 *             assmts = AssignmentList()
 *             assmts.mask = assmts.bit = bit
*/
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_set_iterator(__pyx_v_self->entries, 1, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":241
 *         bit: int = 1
 *         for entry in self.entries:
 *             assmts = AssignmentList()             # <<<<<<<<<<<<<<
 *             assmts.mask = assmts.bit = bit
 *             self.assmts[entry] = assmts
*/
    __pyx_t_7 = NULL;
    __pyx_t_8 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList, __pyx_callargs+__pyx_t_8, (1-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 241, __pyx_L1_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_assmts, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":242
 *         for entry in self.entries:
 *             assmts = AssignmentList()
 *             assmts.mask = assmts.bit = bit             # <<<<<<<<<<<<<<
 *             self.assmts[entry] = assmts
 *             bit <<= 1
*/
    __Pyx_INCREF(__pyx_v_bit);
    __Pyx_GIVEREF(__pyx_v_bit);
    __Pyx_GOTREF(__pyx_v_assmts->mask);
    __Pyx_DECREF(__pyx_v_assmts->mask);
    __pyx_v_assmts->mask = __pyx_v_bit;
    __Pyx_INCREF(__pyx_v_bit);
    __Pyx_GIVEREF(__pyx_v_bit);
    __Pyx_GOTREF(__pyx_v_assmts->bit);
    __Pyx_DECREF(__pyx_v_assmts->bit);
    __pyx_v_assmts->bit = __pyx_v_bit;

    /* "Cython/Compiler/FlowControl.py":243
 *             assmts = AssignmentList()
 *             assmts.mask = assmts.bit = bit
 *             self.assmts[entry] = assmts             # <<<<<<<<<<<<<<
 *             bit <<= 1
 * 
*/
    if (unlikely(__pyx_v_self->assmts == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 243, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_self->assmts, __pyx_v_entry, ((PyObject *)__pyx_v_assmts)) < 0))) __PYX_ERR(0, 243, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":244
 *             assmts.mask = assmts.bit = bit
 *             self.assmts[entry] = assmts
 *             bit <<= 1             # <<<<<<<<<<<<<<
 * 
 *         for block in self.blocks:
*/
    __pyx_t_5 = __Pyx_PyLong_LshiftObjC(__pyx_v_bit, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_bit, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":246
 *             bit <<= 1
 * 
 *         for block in self.blocks:             # <<<<<<<<<<<<<<
 *             for stat in block.stats:
 *                 if isinstance(stat, NameAssignment):
*/
  __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_set_iterator(__pyx_v_self->blocks, 1, (&__pyx_t_2), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_2, &__pyx_t_3, &__pyx_t_5, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 246, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_block, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":247
 * 
 *         for block in self.blocks:
 *             for stat in block.stats:             # <<<<<<<<<<<<<<
 *                 if isinstance(stat, NameAssignment):
 *                     stat.bit = bit
*/
    if (unlikely(__pyx_v_block->stats == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 247, __pyx_L1_error)
    }
    __pyx_t_5 = __pyx_v_block->stats; __Pyx_INCREF(__pyx_t_5);
    __pyx_t_9 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 247, __pyx_L1_error)
        #endif
        if (__pyx_t_9 >= __pyx_temp) break;
      }
      __pyx_t_7 = __Pyx_PyList_GetItemRefFast(__pyx_t_5, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_9;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_stat, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "Cython/Compiler/FlowControl.py":248
 *         for block in self.blocks:
 *             for stat in block.stats:
 *                 if isinstance(stat, NameAssignment):             # <<<<<<<<<<<<<<
 *                     stat.bit = bit
 *                     assmts = self.assmts[stat.entry]
*/
      __pyx_t_10 = __Pyx_TypeCheck(__pyx_v_stat, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment); 
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":249
 *             for stat in block.stats:
 *                 if isinstance(stat, NameAssignment):
 *                     stat.bit = bit             # <<<<<<<<<<<<<<
 *                     assmts = self.assmts[stat.entry]
 *                     assmts.stats.append(stat)
*/
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_bit, __pyx_v_bit) < (0)) __PYX_ERR(0, 249, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":250
 *                 if isinstance(stat, NameAssignment):
 *                     stat.bit = bit
 *                     assmts = self.assmts[stat.entry]             # <<<<<<<<<<<<<<
 *                     assmts.stats.append(stat)
 *                     assmts.mask |= bit
*/
        if (unlikely(__pyx_v_self->assmts == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 250, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 250, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_11 = __Pyx_PyDict_GetItem(__pyx_v_self->assmts, __pyx_t_7); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 250, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (!(likely(((__pyx_t_11) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_11, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList))))) __PYX_ERR(0, 250, __pyx_L1_error)
        __Pyx_XDECREF_SET(__pyx_v_assmts, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_t_11));
        __pyx_t_11 = 0;

        /* "Cython/Compiler/FlowControl.py":251
 *                     stat.bit = bit
 *                     assmts = self.assmts[stat.entry]
 *                     assmts.stats.append(stat)             # <<<<<<<<<<<<<<
 *                     assmts.mask |= bit
 *                     bit <<= 1
*/
        if (unlikely(__pyx_v_assmts->stats == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 251, __pyx_L1_error)
        }
        __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_assmts->stats, __pyx_v_stat); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 251, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":252
 *                     assmts = self.assmts[stat.entry]
 *                     assmts.stats.append(stat)
 *                     assmts.mask |= bit             # <<<<<<<<<<<<<<
 *                     bit <<= 1
 * 
*/
        __pyx_t_11 = PyNumber_InPlaceOr(__pyx_v_assmts->mask, __pyx_v_bit); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 252, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_11);
        __Pyx_GOTREF(__pyx_v_assmts->mask);
        __Pyx_DECREF(__pyx_v_assmts->mask);
        __pyx_v_assmts->mask = __pyx_t_11;
        __pyx_t_11 = 0;

        /* "Cython/Compiler/FlowControl.py":253
 *                     assmts.stats.append(stat)
 *                     assmts.mask |= bit
 *                     bit <<= 1             # <<<<<<<<<<<<<<
 * 
 *         for block in self.blocks:
*/
        __pyx_t_11 = __Pyx_PyLong_LshiftObjC(__pyx_v_bit, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 253, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF_SET(__pyx_v_bit, ((PyObject*)__pyx_t_11));
        __pyx_t_11 = 0;

        /* "Cython/Compiler/FlowControl.py":248
 *         for block in self.blocks:
 *             for stat in block.stats:
 *                 if isinstance(stat, NameAssignment):             # <<<<<<<<<<<<<<
 *                     stat.bit = bit
 *                     assmts = self.assmts[stat.entry]
*/
      }

      /* "Cython/Compiler/FlowControl.py":247
 * 
 *         for block in self.blocks:
 *             for stat in block.stats:             # <<<<<<<<<<<<<<
 *                 if isinstance(stat, NameAssignment):
 *                     stat.bit = bit
*/
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":255
 *                     bit <<= 1
 * 
 *         for block in self.blocks:             # <<<<<<<<<<<<<<
 *             for entry, stat in block.gen.items():
 *                 assmts = self.assmts[entry]
*/
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_set_iterator(__pyx_v_self->blocks, 1, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_block, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":256
 * 
 *         for block in self.blocks:
 *             for entry, stat in block.gen.items():             # <<<<<<<<<<<<<<
 *                 assmts = self.assmts[entry]
 *                 if stat is Uninitialized:
*/
    __pyx_t_9 = 0;
    if (unlikely(__pyx_v_block->gen == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
      __PYX_ERR(0, 256, __pyx_L1_error)
    }
    __pyx_t_11 = __Pyx_dict_iterator(__pyx_v_block->gen, 1, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_13), (&__pyx_t_6)); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_5);
    __pyx_t_5 = __pyx_t_11;
    __pyx_t_11 = 0;
    while (1) {
      __pyx_t_14 = __Pyx_dict_iter_next(__pyx_t_5, __pyx_t_13, &__pyx_t_9, &__pyx_t_11, &__pyx_t_7, NULL, __pyx_t_6);
      if (unlikely(__pyx_t_14 == 0)) break;
      if (unlikely(__pyx_t_14 == -1)) __PYX_ERR(0, 256, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_11);
      __pyx_t_11 = 0;
      __Pyx_XDECREF_SET(__pyx_v_stat, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "Cython/Compiler/FlowControl.py":257
 *         for block in self.blocks:
 *             for entry, stat in block.gen.items():
 *                 assmts = self.assmts[entry]             # <<<<<<<<<<<<<<
 *                 if stat is Uninitialized:
 *                     block.i_gen |= assmts.bit
*/
      if (unlikely(__pyx_v_self->assmts == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 257, __pyx_L1_error)
      }
      __pyx_t_7 = __Pyx_PyDict_GetItem(__pyx_v_self->assmts, __pyx_v_entry); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 257, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList))))) __PYX_ERR(0, 257, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_assmts, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_t_7));
      __pyx_t_7 = 0;

      /* "Cython/Compiler/FlowControl.py":258
 *             for entry, stat in block.gen.items():
 *                 assmts = self.assmts[entry]
 *                 if stat is Uninitialized:             # <<<<<<<<<<<<<<
 *                     block.i_gen |= assmts.bit
 *                 else:
*/
      __pyx_t_10 = (__pyx_v_stat == ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized));
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":259
 *                 assmts = self.assmts[entry]
 *                 if stat is Uninitialized:
 *                     block.i_gen |= assmts.bit             # <<<<<<<<<<<<<<
 *                 else:
 *                     block.i_gen |= stat.bit
*/
        __pyx_t_7 = PyNumber_InPlaceOr(__pyx_v_block->i_gen, __pyx_v_assmts->bit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 259, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_v_block->i_gen);
        __Pyx_DECREF(__pyx_v_block->i_gen);
        __pyx_v_block->i_gen = __pyx_t_7;
        __pyx_t_7 = 0;

        /* "Cython/Compiler/FlowControl.py":258
 *             for entry, stat in block.gen.items():
 *                 assmts = self.assmts[entry]
 *                 if stat is Uninitialized:             # <<<<<<<<<<<<<<
 *                     block.i_gen |= assmts.bit
 *                 else:
*/
        goto __pyx_L15;
      }

      /* "Cython/Compiler/FlowControl.py":261
 *                     block.i_gen |= assmts.bit
 *                 else:
 *                     block.i_gen |= stat.bit             # <<<<<<<<<<<<<<
 *                 block.i_kill |= assmts.mask
 *             block.i_output = block.i_gen
*/
      /*else*/ {
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_bit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 261, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_11 = PyNumber_InPlaceOr(__pyx_v_block->i_gen, __pyx_t_7); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 261, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GIVEREF(__pyx_t_11);
        __Pyx_GOTREF(__pyx_v_block->i_gen);
        __Pyx_DECREF(__pyx_v_block->i_gen);
        __pyx_v_block->i_gen = __pyx_t_11;
        __pyx_t_11 = 0;
      }
      __pyx_L15:;

      /* "Cython/Compiler/FlowControl.py":262
 *                 else:
 *                     block.i_gen |= stat.bit
 *                 block.i_kill |= assmts.mask             # <<<<<<<<<<<<<<
 *             block.i_output = block.i_gen
 *             for entry in block.bounded:
*/
      __pyx_t_11 = PyNumber_InPlaceOr(__pyx_v_block->i_kill, __pyx_v_assmts->mask); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 262, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_11);
      __Pyx_GOTREF(__pyx_v_block->i_kill);
      __Pyx_DECREF(__pyx_v_block->i_kill);
      __pyx_v_block->i_kill = __pyx_t_11;
      __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":263
 *                     block.i_gen |= stat.bit
 *                 block.i_kill |= assmts.mask
 *             block.i_output = block.i_gen             # <<<<<<<<<<<<<<
 *             for entry in block.bounded:
 *                 block.i_kill |= self.assmts[entry].bit
*/
    __pyx_t_5 = __pyx_v_block->i_gen;
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_v_block->i_output);
    __Pyx_DECREF(__pyx_v_block->i_output);
    __pyx_v_block->i_output = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":264
 *                 block.i_kill |= assmts.mask
 *             block.i_output = block.i_gen
 *             for entry in block.bounded:             # <<<<<<<<<<<<<<
 *                 block.i_kill |= self.assmts[entry].bit
 * 
*/
    __pyx_t_13 = 0;
    __pyx_t_11 = __Pyx_set_iterator(__pyx_v_block->bounded, 1, (&__pyx_t_9), (&__pyx_t_6)); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_5);
    __pyx_t_5 = __pyx_t_11;
    __pyx_t_11 = 0;
    while (1) {
      __pyx_t_14 = __Pyx_set_iter_next(__pyx_t_5, __pyx_t_9, &__pyx_t_13, &__pyx_t_11, __pyx_t_6);
      if (unlikely(__pyx_t_14 == 0)) break;
      if (unlikely(__pyx_t_14 == -1)) __PYX_ERR(0, 264, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "Cython/Compiler/FlowControl.py":265
 *             block.i_output = block.i_gen
 *             for entry in block.bounded:
 *                 block.i_kill |= self.assmts[entry].bit             # <<<<<<<<<<<<<<
 * 
 *         for assmts in self.assmts.values():
*/
      if (unlikely(__pyx_v_self->assmts == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 265, __pyx_L1_error)
      }
      __pyx_t_11 = __Pyx_PyDict_GetItem(__pyx_v_self->assmts, __pyx_v_entry); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 265, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_bit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 265, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = PyNumber_InPlaceOr(__pyx_v_block->i_kill, __pyx_t_7); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 265, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GIVEREF(__pyx_t_11);
      __Pyx_GOTREF(__pyx_v_block->i_kill);
      __Pyx_DECREF(__pyx_v_block->i_kill);
      __pyx_v_block->i_kill = __pyx_t_11;
      __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":267
 *                 block.i_kill |= self.assmts[entry].bit
 * 
 *         for assmts in self.assmts.values():             # <<<<<<<<<<<<<<
 *             self.entry_point.i_gen |= assmts.bit
 *         self.entry_point.i_output = self.entry_point.i_gen
*/
  __pyx_t_3 = 0;
  if (unlikely(__pyx_v_self->assmts == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
    __PYX_ERR(0, 267, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_self->assmts, 1, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_2), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_2, &__pyx_t_3, NULL, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList))))) __PYX_ERR(0, 267, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_assmts, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":268
 * 
 *         for assmts in self.assmts.values():
 *             self.entry_point.i_gen |= assmts.bit             # <<<<<<<<<<<<<<
 *         self.entry_point.i_output = self.entry_point.i_gen
 * 
*/
    __pyx_t_5 = PyNumber_InPlaceOr(__pyx_v_self->entry_point->i_gen, __pyx_v_assmts->bit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_v_self->entry_point->i_gen);
    __Pyx_DECREF(__pyx_v_self->entry_point->i_gen);
    __pyx_v_self->entry_point->i_gen = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":269
 *         for assmts in self.assmts.values():
 *             self.entry_point.i_gen |= assmts.bit
 *         self.entry_point.i_output = self.entry_point.i_gen             # <<<<<<<<<<<<<<
 * 
 *     def map_one(self, istate, entry):
*/
  __pyx_t_1 = __pyx_v_self->entry_point->i_gen;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->entry_point->i_output);
  __Pyx_DECREF(__pyx_v_self->entry_point->i_output);
  __pyx_v_self->entry_point->i_output = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":233
 *         self.blocks -= unreachable
 * 
 *     def initialize(self):             # <<<<<<<<<<<<<<
 *         """Set initial state, map assignments to bits."""
 *         self.assmts = {}
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.initialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_assmts);
  __Pyx_XDECREF((PyObject *)__pyx_v_block);
  __Pyx_XDECREF(__pyx_v_bit);
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XDECREF(__pyx_v_stat);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_23initialize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_22initialize, "Set initial state, map assignments to bits.");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_23initialize = {"initialize", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_23initialize, METH_NOARGS, __pyx_doc_6Cython_8Compiler_11FlowControl_11ControlFlow_22initialize};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_23initialize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("initialize (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_22initialize(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_22initialize(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("initialize", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_initialize(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.initialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":271
 *         self.entry_point.i_output = self.entry_point.i_gen
 * 
 *     def map_one(self, istate, entry):             # <<<<<<<<<<<<<<
 *         ret = set()
 *         assmts: AssignmentList = self.assmts[entry]
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_25map_one(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_map_one(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_istate, PyObject *__pyx_v_entry, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_ret = NULL;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v_assmts = 0;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_assmt = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_one", 0);

  /* "Cython/Compiler/FlowControl.py":272
 * 
 *     def map_one(self, istate, entry):
 *         ret = set()             # <<<<<<<<<<<<<<
 *         assmts: AssignmentList = self.assmts[entry]
 *         if istate & assmts.bit:
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ret = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":273
 *     def map_one(self, istate, entry):
 *         ret = set()
 *         assmts: AssignmentList = self.assmts[entry]             # <<<<<<<<<<<<<<
 *         if istate & assmts.bit:
 *             if self.is_statically_assigned(entry):
*/
  if (unlikely(__pyx_v_self->assmts == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 273, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->assmts, __pyx_v_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList))))) __PYX_ERR(0, 273, __pyx_L1_error)
  __pyx_v_assmts = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":274
 *         ret = set()
 *         assmts: AssignmentList = self.assmts[entry]
 *         if istate & assmts.bit:             # <<<<<<<<<<<<<<
 *             if self.is_statically_assigned(entry):
 *                 ret.add(StaticAssignment(entry))
*/
  __pyx_t_1 = PyNumber_And(__pyx_v_istate, __pyx_v_assmts->bit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":275
 *         assmts: AssignmentList = self.assmts[entry]
 *         if istate & assmts.bit:
 *             if self.is_statically_assigned(entry):             # <<<<<<<<<<<<<<
 *                 ret.add(StaticAssignment(entry))
 *             elif entry.from_closure:
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_statically_assigned(__pyx_v_self, __pyx_v_entry, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 275, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/FlowControl.py":276
 *         if istate & assmts.bit:
 *             if self.is_statically_assigned(entry):
 *                 ret.add(StaticAssignment(entry))             # <<<<<<<<<<<<<<
 *             elif entry.from_closure:
 *                 ret.add(Unknown)
*/
      __pyx_t_3 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_StaticAssignment); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_entry};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 276, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_6 = PySet_Add(__pyx_v_ret, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":275
 *         assmts: AssignmentList = self.assmts[entry]
 *         if istate & assmts.bit:
 *             if self.is_statically_assigned(entry):             # <<<<<<<<<<<<<<
 *                 ret.add(StaticAssignment(entry))
 *             elif entry.from_closure:
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/FlowControl.py":277
 *             if self.is_statically_assigned(entry):
 *                 ret.add(StaticAssignment(entry))
 *             elif entry.from_closure:             # <<<<<<<<<<<<<<
 *                 ret.add(Unknown)
 *             else:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_from_closure); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 277, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/FlowControl.py":278
 *                 ret.add(StaticAssignment(entry))
 *             elif entry.from_closure:
 *                 ret.add(Unknown)             # <<<<<<<<<<<<<<
 *             else:
 *                 ret.add(Uninitialized)
*/
      __pyx_t_6 = PySet_Add(__pyx_v_ret, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown)); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 278, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":277
 *             if self.is_statically_assigned(entry):
 *                 ret.add(StaticAssignment(entry))
 *             elif entry.from_closure:             # <<<<<<<<<<<<<<
 *                 ret.add(Unknown)
 *             else:
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/FlowControl.py":280
 *                 ret.add(Unknown)
 *             else:
 *                 ret.add(Uninitialized)             # <<<<<<<<<<<<<<
 * 
 *         assmt: NameAssignment
*/
    /*else*/ {
      __pyx_t_6 = PySet_Add(__pyx_v_ret, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized)); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 280, __pyx_L1_error)
    }
    __pyx_L4:;

    /* "Cython/Compiler/FlowControl.py":274
 *         ret = set()
 *         assmts: AssignmentList = self.assmts[entry]
 *         if istate & assmts.bit:             # <<<<<<<<<<<<<<
 *             if self.is_statically_assigned(entry):
 *                 ret.add(StaticAssignment(entry))
*/
  }

  /* "Cython/Compiler/FlowControl.py":283
 * 
 *         assmt: NameAssignment
 *         for assmt in assmts.stats:             # <<<<<<<<<<<<<<
 *             if istate & assmt.bit:
 *                 ret.add(assmt)
*/
  if (unlikely(__pyx_v_assmts->stats == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 283, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_assmts->stats; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_7 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 283, __pyx_L1_error)
      #endif
      if (__pyx_t_7 >= __pyx_temp) break;
    }
    __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_7;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment))))) __PYX_ERR(0, 283, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_assmt, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":284
 *         assmt: NameAssignment
 *         for assmt in assmts.stats:
 *             if istate & assmt.bit:             # <<<<<<<<<<<<<<
 *                 ret.add(assmt)
 *         return ret
*/
    __pyx_t_4 = PyNumber_And(__pyx_v_istate, __pyx_v_assmt->bit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 284, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/FlowControl.py":285
 *         for assmt in assmts.stats:
 *             if istate & assmt.bit:
 *                 ret.add(assmt)             # <<<<<<<<<<<<<<
 *         return ret
 * 
*/
      __pyx_t_6 = PySet_Add(__pyx_v_ret, ((PyObject *)__pyx_v_assmt)); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 285, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":284
 *         assmt: NameAssignment
 *         for assmt in assmts.stats:
 *             if istate & assmt.bit:             # <<<<<<<<<<<<<<
 *                 ret.add(assmt)
 *         return ret
*/
    }

    /* "Cython/Compiler/FlowControl.py":283
 * 
 *         assmt: NameAssignment
 *         for assmt in assmts.stats:             # <<<<<<<<<<<<<<
 *             if istate & assmt.bit:
 *                 ret.add(assmt)
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":286
 *             if istate & assmt.bit:
 *                 ret.add(assmt)
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def reaching_definitions(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":271
 *         self.entry_point.i_output = self.entry_point.i_gen
 * 
 *     def map_one(self, istate, entry):             # <<<<<<<<<<<<<<
 *         ret = set()
 *         assmts: AssignmentList = self.assmts[entry]
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.map_one", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF((PyObject *)__pyx_v_assmts);
  __Pyx_XDECREF((PyObject *)__pyx_v_assmt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_25map_one(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_25map_one = {"map_one", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_25map_one, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_25map_one(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_istate = 0;
  PyObject *__pyx_v_entry = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_one (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_istate,&__pyx_mstate_global->__pyx_n_u_entry,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 271, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 271, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 271, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "map_one", 0) < (0)) __PYX_ERR(0, 271, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("map_one", 1, 2, 2, i); __PYX_ERR(0, 271, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 271, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 271, __pyx_L3_error)
    }
    __pyx_v_istate = values[0];
    __pyx_v_entry = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_one", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 271, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.map_one", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_24map_one(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), __pyx_v_istate, __pyx_v_entry);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_24map_one(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_istate, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_one", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_map_one(__pyx_v_self, __pyx_v_istate, __pyx_v_entry, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.map_one", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":288
 *         return ret
 * 
 *     def reaching_definitions(self):             # <<<<<<<<<<<<<<
 *         """Per-block reaching definitions analysis."""
 *         block: ControlBlock
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_reaching_definitions(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_block = 0;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent = 0;
  int __pyx_v_dirty;
  PyObject *__pyx_v_i_input = NULL;
  PyObject *__pyx_v_i_output = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reaching_definitions", 0);

  /* "Cython/Compiler/FlowControl.py":293
 *         parent: ControlBlock
 * 
 *         dirty = True             # <<<<<<<<<<<<<<
 *         while dirty:
 *             dirty = False
*/
  __pyx_v_dirty = 1;

  /* "Cython/Compiler/FlowControl.py":294
 * 
 *         dirty = True
 *         while dirty:             # <<<<<<<<<<<<<<
 *             dirty = False
 *             for block in self.blocks:
*/
  while (1) {
    if (!__pyx_v_dirty) break;

    /* "Cython/Compiler/FlowControl.py":295
 *         dirty = True
 *         while dirty:
 *             dirty = False             # <<<<<<<<<<<<<<
 *             for block in self.blocks:
 *                 i_input = 0
*/
    __pyx_v_dirty = 0;

    /* "Cython/Compiler/FlowControl.py":296
 *         while dirty:
 *             dirty = False
 *             for block in self.blocks:             # <<<<<<<<<<<<<<
 *                 i_input = 0
 *                 for parent in block.parents:
*/
    __pyx_t_2 = 0;
    __pyx_t_5 = __Pyx_set_iterator(__pyx_v_self->blocks, 1, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 296, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_5;
    __pyx_t_5 = 0;
    while (1) {
      __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, __pyx_t_4);
      if (unlikely(__pyx_t_6 == 0)) break;
      if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 296, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_block, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_5));
      __pyx_t_5 = 0;

      /* "Cython/Compiler/FlowControl.py":297
 *             dirty = False
 *             for block in self.blocks:
 *                 i_input = 0             # <<<<<<<<<<<<<<
 *                 for parent in block.parents:
 *                     i_input |= parent.i_output
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
      __Pyx_XDECREF_SET(__pyx_v_i_input, __pyx_mstate_global->__pyx_int_0);

      /* "Cython/Compiler/FlowControl.py":298
 *             for block in self.blocks:
 *                 i_input = 0
 *                 for parent in block.parents:             # <<<<<<<<<<<<<<
 *                     i_input |= parent.i_output
 *                 i_output = (i_input & ~block.i_kill) | block.i_gen
*/
      __pyx_t_7 = 0;
      __pyx_t_9 = __Pyx_set_iterator(__pyx_v_block->parents, 1, (&__pyx_t_8), (&__pyx_t_6)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5);
      __pyx_t_5 = __pyx_t_9;
      __pyx_t_9 = 0;
      while (1) {
        __pyx_t_10 = __Pyx_set_iter_next(__pyx_t_5, __pyx_t_8, &__pyx_t_7, &__pyx_t_9, __pyx_t_6);
        if (unlikely(__pyx_t_10 == 0)) break;
        if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 298, __pyx_L1_error)
        __Pyx_XDECREF_SET(__pyx_v_parent, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_9));
        __pyx_t_9 = 0;

        /* "Cython/Compiler/FlowControl.py":299
 *                 i_input = 0
 *                 for parent in block.parents:
 *                     i_input |= parent.i_output             # <<<<<<<<<<<<<<
 *                 i_output = (i_input & ~block.i_kill) | block.i_gen
 *                 if i_output != block.i_output:
*/
        __pyx_t_9 = PyNumber_InPlaceOr(__pyx_v_i_input, __pyx_v_parent->i_output); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF_SET(__pyx_v_i_input, __pyx_t_9);
        __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "Cython/Compiler/FlowControl.py":300
 *                 for parent in block.parents:
 *                     i_input |= parent.i_output
 *                 i_output = (i_input & ~block.i_kill) | block.i_gen             # <<<<<<<<<<<<<<
 *                 if i_output != block.i_output:
 *                     dirty = True
*/
      __pyx_t_5 = PyNumber_Invert(__pyx_v_block->i_kill); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = PyNumber_And(__pyx_v_i_input, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Or(__pyx_t_9, __pyx_v_block->i_gen); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF_SET(__pyx_v_i_output, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Compiler/FlowControl.py":301
 *                     i_input |= parent.i_output
 *                 i_output = (i_input & ~block.i_kill) | block.i_gen
 *                 if i_output != block.i_output:             # <<<<<<<<<<<<<<
 *                     dirty = True
 *                 block.i_input = i_input
*/
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_i_output, __pyx_v_block->i_output, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 301, __pyx_L1_error)
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 301, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_11) {

        /* "Cython/Compiler/FlowControl.py":302
 *                 i_output = (i_input & ~block.i_kill) | block.i_gen
 *                 if i_output != block.i_output:
 *                     dirty = True             # <<<<<<<<<<<<<<
 *                 block.i_input = i_input
 *                 block.i_output = i_output
*/
        __pyx_v_dirty = 1;

        /* "Cython/Compiler/FlowControl.py":301
 *                     i_input |= parent.i_output
 *                 i_output = (i_input & ~block.i_kill) | block.i_gen
 *                 if i_output != block.i_output:             # <<<<<<<<<<<<<<
 *                     dirty = True
 *                 block.i_input = i_input
*/
      }

      /* "Cython/Compiler/FlowControl.py":303
 *                 if i_output != block.i_output:
 *                     dirty = True
 *                 block.i_input = i_input             # <<<<<<<<<<<<<<
 *                 block.i_output = i_output
 * 
*/
      __Pyx_INCREF(__pyx_v_i_input);
      __Pyx_GIVEREF(__pyx_v_i_input);
      __Pyx_GOTREF(__pyx_v_block->i_input);
      __Pyx_DECREF(__pyx_v_block->i_input);
      __pyx_v_block->i_input = __pyx_v_i_input;

      /* "Cython/Compiler/FlowControl.py":304
 *                     dirty = True
 *                 block.i_input = i_input
 *                 block.i_output = i_output             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_INCREF(__pyx_v_i_output);
      __Pyx_GIVEREF(__pyx_v_i_output);
      __Pyx_GOTREF(__pyx_v_block->i_output);
      __Pyx_DECREF(__pyx_v_block->i_output);
      __pyx_v_block->i_output = __pyx_v_i_output;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/FlowControl.py":288
 *         return ret
 * 
 *     def reaching_definitions(self):             # <<<<<<<<<<<<<<
 *         """Per-block reaching definitions analysis."""
 *         block: ControlBlock
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.reaching_definitions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_block);
  __Pyx_XDECREF((PyObject *)__pyx_v_parent);
  __Pyx_XDECREF(__pyx_v_i_input);
  __Pyx_XDECREF(__pyx_v_i_output);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":49
 * @cython.final
 * cdef class ControlFlow:
 *     cdef public set blocks             # <<<<<<<<<<<<<<
 *     cdef public set entries
 *     cdef public list loops
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->blocks);
  __pyx_r = __pyx_v_self->blocks;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(1, 49, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->blocks);
  __Pyx_DECREF(__pyx_v_self->blocks);
  __pyx_v_self->blocks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.blocks.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->blocks);
  __Pyx_DECREF(__pyx_v_self->blocks);
  __pyx_v_self->blocks = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":50
 * cdef class ControlFlow:
 *     cdef public set blocks
 *     cdef public set entries             # <<<<<<<<<<<<<<
 *     cdef public list loops
 *     cdef public list exceptions
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->entries);
  __pyx_r = __pyx_v_self->entries;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(1, 50, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(__pyx_v_self->entries);
  __pyx_v_self->entries = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.entries.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(__pyx_v_self->entries);
  __pyx_v_self->entries = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":51
 *     cdef public set blocks
 *     cdef public set entries
 *     cdef public list loops             # <<<<<<<<<<<<<<
 *     cdef public list exceptions
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->loops);
  __pyx_r = __pyx_v_self->loops;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 51, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->loops);
  __Pyx_DECREF(__pyx_v_self->loops);
  __pyx_v_self->loops = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.loops.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->loops);
  __Pyx_DECREF(__pyx_v_self->loops);
  __pyx_v_self->loops = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":52
 *     cdef public set entries
 *     cdef public list loops
 *     cdef public list exceptions             # <<<<<<<<<<<<<<
 * 
 *     cdef public ControlBlock entry_point
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->exceptions);
  __pyx_r = __pyx_v_self->exceptions;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 52, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->exceptions);
  __Pyx_DECREF(__pyx_v_self->exceptions);
  __pyx_v_self->exceptions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.exceptions.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->exceptions);
  __Pyx_DECREF(__pyx_v_self->exceptions);
  __pyx_v_self->exceptions = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":54
 *     cdef public list exceptions
 * 
 *     cdef public ControlBlock entry_point             # <<<<<<<<<<<<<<
 *     cdef public ExitBlock exit_point
 *     cdef public ControlBlock block
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->entry_point);
  __pyx_r = ((PyObject *)__pyx_v_self->entry_point);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(1, 54, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->entry_point);
  __Pyx_DECREF((PyObject *)__pyx_v_self->entry_point);
  __pyx_v_self->entry_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.entry_point.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->entry_point);
  __Pyx_DECREF((PyObject *)__pyx_v_self->entry_point);
  __pyx_v_self->entry_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":55
 * 
 *     cdef public ControlBlock entry_point
 *     cdef public ExitBlock exit_point             # <<<<<<<<<<<<<<
 *     cdef public ControlBlock block
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->exit_point);
  __pyx_r = ((PyObject *)__pyx_v_self->exit_point);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock))))) __PYX_ERR(1, 55, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->exit_point);
  __Pyx_DECREF((PyObject *)__pyx_v_self->exit_point);
  __pyx_v_self->exit_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.exit_point.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->exit_point);
  __Pyx_DECREF((PyObject *)__pyx_v_self->exit_point);
  __pyx_v_self->exit_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":56
 *     cdef public ControlBlock entry_point
 *     cdef public ExitBlock exit_point
 *     cdef public ControlBlock block             # <<<<<<<<<<<<<<
 * 
 *     cdef public dict assmts
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->block);
  __pyx_r = ((PyObject *)__pyx_v_self->block);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(1, 56, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->block);
  __pyx_v_self->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.block.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->block);
  __pyx_v_self->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":58
 *     cdef public ControlBlock block
 * 
 *     cdef public dict assmts             # <<<<<<<<<<<<<<
 * 
 *     cdef public Py_ssize_t in_try_block
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->assmts);
  __pyx_r = __pyx_v_self->assmts;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(1, 58, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->assmts);
  __Pyx_DECREF(__pyx_v_self->assmts);
  __pyx_v_self->assmts = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.assmts.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->assmts);
  __Pyx_DECREF(__pyx_v_self->assmts);
  __pyx_v_self->assmts = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":60
 *     cdef public dict assmts
 * 
 *     cdef public Py_ssize_t in_try_block             # <<<<<<<<<<<<<<
 * 
 *     cpdef newblock(self, ControlBlock parent=*)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyLong_FromSsize_t(__pyx_v_self->in_try_block); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.in_try_block.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyIndex_AsSsize_t(__pyx_v_value); if (unlikely((__pyx_t_1 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 60, __pyx_L1_error)
  __pyx_v_self->in_try_block = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.in_try_block.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_27__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_27__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_27__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_27__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_26__reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_26__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.assmts, self.block, self.blocks, self.entries, self.entry_point, self.exceptions, self.exit_point, self.in_try_block, self.loops)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = PyLong_FromSsize_t(__pyx_v_self->in_try_block); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(9); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->assmts);
  __Pyx_GIVEREF(__pyx_v_self->assmts);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->assmts) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->block);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->block);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self->block)) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->blocks);
  __Pyx_GIVEREF(__pyx_v_self->blocks);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_self->blocks) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->entries);
  __Pyx_GIVEREF(__pyx_v_self->entries);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_self->entries) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->entry_point);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->entry_point);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 4, ((PyObject *)__pyx_v_self->entry_point)) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->exceptions);
  __Pyx_GIVEREF(__pyx_v_self->exceptions);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 5, __pyx_v_self->exceptions) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->exit_point);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->exit_point);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 6, ((PyObject *)__pyx_v_self->exit_point)) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 7, __pyx_t_1) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->loops);
  __Pyx_GIVEREF(__pyx_v_self->loops);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 8, __pyx_v_self->loops) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.assmts, self.block, self.blocks, self.entries, self.entry_point, self.exceptions, self.exit_point, self.in_try_block, self.loops)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v__dict = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":7
 *     state = (self.assmts, self.block, self.blocks, self.entries, self.entry_point, self.exceptions, self.exit_point, self.in_try_block, self.loops)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_4 = (__pyx_v__dict != Py_None);
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.assmts is not None or self.block is not None or self.blocks is not None or self.entries is not None or self.entry_point is not None or self.exceptions is not None or self.exit_point is not None or self.loops is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.assmts, self.block, self.blocks, self.entries, self.entry_point, self.exceptions, self.exit_point, self.in_try_block, self.loops)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.assmts is not None or self.block is not None or self.blocks is not None or self.entries is not None or self.entry_point is not None or self.exceptions is not None or self.exit_point is not None or self.loops is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, None), state
*/
  /*else*/ {
    __pyx_t_4 = (__pyx_v_self->assmts != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (((PyObject *)__pyx_v_self->block) != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->blocks != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->entries != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (((PyObject *)__pyx_v_self->entry_point) != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->exceptions != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (((PyObject *)__pyx_v_self->exit_point) != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->loops != ((PyObject*)Py_None));
    __pyx_t_3 = __pyx_t_4;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.assmts is not None or self.block is not None or self.blocks is not None or self.entries is not None or self.entry_point is not None or self.exceptions is not None or self.exit_point is not None or self.loops is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.assmts is not None or self.block is not None or self.blocks is not None or self.entries is not None or self.entry_point is not None or self.exceptions is not None or self.exit_point is not None or self.loops is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlFlow); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_211101602);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_211101602);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_mstate_global->__pyx_int_211101602) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.assmts is not None or self.block is not None or self.blocks is not None or self.entries is not None or self.entry_point is not None or self.exceptions is not None or self.exit_point is not None or self.loops is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, None), state
 *     else:
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ControlFlow__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlFlow); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_211101602);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_211101602);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_mstate_global->__pyx_int_211101602) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlFlow__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_29__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_29__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_29__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_29__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_28__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_11ControlFlow_28__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ControlFlow__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlFlow__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlFlow__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlow.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":308
 * 
 * class LoopDescr:
 *     def __init__(self, next_block, loop_block):             # <<<<<<<<<<<<<<
 *         self.next_block = next_block
 *         self.loop_block = loop_block
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9LoopDescr_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9LoopDescr_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_9LoopDescr_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9LoopDescr_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_next_block = 0;
  PyObject *__pyx_v_loop_block = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_next_block,&__pyx_mstate_global->__pyx_n_u_loop_block,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 308, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 308, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, i); __PYX_ERR(0, 308, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 308, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 308, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 308, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_next_block = values[1];
    __pyx_v_loop_block = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 308, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.LoopDescr.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9LoopDescr___init__(__pyx_self, __pyx_v_self, __pyx_v_next_block, __pyx_v_loop_block);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9LoopDescr___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_next_block, PyObject *__pyx_v_loop_block) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":309
 * class LoopDescr:
 *     def __init__(self, next_block, loop_block):
 *         self.next_block = next_block             # <<<<<<<<<<<<<<
 *         self.loop_block = loop_block
 *         self.exceptions = []
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_next_block, __pyx_v_next_block) < (0)) __PYX_ERR(0, 309, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":310
 *     def __init__(self, next_block, loop_block):
 *         self.next_block = next_block
 *         self.loop_block = loop_block             # <<<<<<<<<<<<<<
 *         self.exceptions = []
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_loop_block, __pyx_v_loop_block) < (0)) __PYX_ERR(0, 310, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":311
 *         self.next_block = next_block
 *         self.loop_block = loop_block
 *         self.exceptions = []             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_exceptions, __pyx_t_1) < (0)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":308
 * 
 * class LoopDescr:
 *     def __init__(self, next_block, loop_block):             # <<<<<<<<<<<<<<
 *         self.next_block = next_block
 *         self.loop_block = loop_block
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.LoopDescr.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":322
 *     """
 * 
 *     def __init__(self, entry_point, finally_enter=None, finally_exit=None):             # <<<<<<<<<<<<<<
 *         self.entry_point = entry_point
 *         self.finally_enter = finally_enter
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14ExceptionDescr_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_14ExceptionDescr_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_14ExceptionDescr_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14ExceptionDescr_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_entry_point = 0;
  PyObject *__pyx_v_finally_enter = 0;
  PyObject *__pyx_v_finally_exit = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_entry_point,&__pyx_mstate_global->__pyx_n_u_finally_enter,&__pyx_mstate_global->__pyx_n_u_finally_exit,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 322, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 322, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 322, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 322, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 322, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 322, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, i); __PYX_ERR(0, 322, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 322, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 322, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 322, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 322, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_entry_point = values[1];
    __pyx_v_finally_enter = values[2];
    __pyx_v_finally_exit = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 322, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ExceptionDescr.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14ExceptionDescr___init__(__pyx_self, __pyx_v_self, __pyx_v_entry_point, __pyx_v_finally_enter, __pyx_v_finally_exit);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14ExceptionDescr___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_entry_point, PyObject *__pyx_v_finally_enter, PyObject *__pyx_v_finally_exit) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":323
 * 
 *     def __init__(self, entry_point, finally_enter=None, finally_exit=None):
 *         self.entry_point = entry_point             # <<<<<<<<<<<<<<
 *         self.finally_enter = finally_enter
 *         self.finally_exit = finally_exit
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_entry_point, __pyx_v_entry_point) < (0)) __PYX_ERR(0, 323, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":324
 *     def __init__(self, entry_point, finally_enter=None, finally_exit=None):
 *         self.entry_point = entry_point
 *         self.finally_enter = finally_enter             # <<<<<<<<<<<<<<
 *         self.finally_exit = finally_exit
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_finally_enter, __pyx_v_finally_enter) < (0)) __PYX_ERR(0, 324, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":325
 *         self.entry_point = entry_point
 *         self.finally_enter = finally_enter
 *         self.finally_exit = finally_exit             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_finally_exit, __pyx_v_finally_exit) < (0)) __PYX_ERR(0, 325, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":322
 *     """
 * 
 *     def __init__(self, entry_point, finally_enter=None, finally_exit=None):             # <<<<<<<<<<<<<<
 *         self.entry_point = entry_point
 *         self.finally_enter = finally_enter
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ExceptionDescr.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":329
 * 
 * class NameAssignment:
 *     def __init__(self, lhs, rhs, entry, rhs_scope=None):             # <<<<<<<<<<<<<<
 *         if lhs.cf_state is None:
 *             lhs.cf_state = set()
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_lhs = 0;
  PyObject *__pyx_v_rhs = 0;
  PyObject *__pyx_v_entry = 0;
  PyObject *__pyx_v_rhs_scope = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_lhs,&__pyx_mstate_global->__pyx_n_u_rhs,&__pyx_mstate_global->__pyx_n_u_entry,&__pyx_mstate_global->__pyx_n_u_rhs_scope,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 329, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 329, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 329, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 329, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 329, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 329, __pyx_L3_error)
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 4, i); __PYX_ERR(0, 329, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 329, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 329, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 329, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 329, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_lhs = values[0];
    __pyx_v_rhs = values[1];
    __pyx_v_entry = values[2];
    __pyx_v_rhs_scope = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 329, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment___init__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry, __pyx_v_rhs_scope);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry, PyObject *__pyx_v_rhs_scope) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":330
 * class NameAssignment:
 *     def __init__(self, lhs, rhs, entry, rhs_scope=None):
 *         if lhs.cf_state is None:             # <<<<<<<<<<<<<<
 *             lhs.cf_state = set()
 *         self.lhs = lhs
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":331
 *     def __init__(self, lhs, rhs, entry, rhs_scope=None):
 *         if lhs.cf_state is None:
 *             lhs.cf_state = set()             # <<<<<<<<<<<<<<
 *         self.lhs = lhs
 *         self.rhs = rhs
*/
    __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_cf_state, __pyx_t_1) < (0)) __PYX_ERR(0, 331, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":330
 * class NameAssignment:
 *     def __init__(self, lhs, rhs, entry, rhs_scope=None):
 *         if lhs.cf_state is None:             # <<<<<<<<<<<<<<
 *             lhs.cf_state = set()
 *         self.lhs = lhs
*/
  }

  /* "Cython/Compiler/FlowControl.py":332
 *         if lhs.cf_state is None:
 *             lhs.cf_state = set()
 *         self.lhs = lhs             # <<<<<<<<<<<<<<
 *         self.rhs = rhs
 *         self.entry = entry
*/
  __Pyx_INCREF(__pyx_v_lhs);
  __Pyx_GIVEREF(__pyx_v_lhs);
  __Pyx_GOTREF(__pyx_v_self->lhs);
  __Pyx_DECREF(__pyx_v_self->lhs);
  __pyx_v_self->lhs = __pyx_v_lhs;

  /* "Cython/Compiler/FlowControl.py":333
 *             lhs.cf_state = set()
 *         self.lhs = lhs
 *         self.rhs = rhs             # <<<<<<<<<<<<<<
 *         self.entry = entry
 *         self.pos = lhs.pos
*/
  __Pyx_INCREF(__pyx_v_rhs);
  __Pyx_GIVEREF(__pyx_v_rhs);
  __Pyx_GOTREF(__pyx_v_self->rhs);
  __Pyx_DECREF(__pyx_v_self->rhs);
  __pyx_v_self->rhs = __pyx_v_rhs;

  /* "Cython/Compiler/FlowControl.py":334
 *         self.lhs = lhs
 *         self.rhs = rhs
 *         self.entry = entry             # <<<<<<<<<<<<<<
 *         self.pos = lhs.pos
 *         self.refs = set()
*/
  __Pyx_INCREF(__pyx_v_entry);
  __Pyx_GIVEREF(__pyx_v_entry);
  __Pyx_GOTREF(__pyx_v_self->entry);
  __Pyx_DECREF(__pyx_v_self->entry);
  __pyx_v_self->entry = __pyx_v_entry;

  /* "Cython/Compiler/FlowControl.py":335
 *         self.rhs = rhs
 *         self.entry = entry
 *         self.pos = lhs.pos             # <<<<<<<<<<<<<<
 *         self.refs = set()
 *         self.is_arg = False
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->pos);
  __Pyx_DECREF(__pyx_v_self->pos);
  __pyx_v_self->pos = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":336
 *         self.entry = entry
 *         self.pos = lhs.pos
 *         self.refs = set()             # <<<<<<<<<<<<<<
 *         self.is_arg = False
 *         self.is_deletion = False
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->refs);
  __Pyx_DECREF(__pyx_v_self->refs);
  __pyx_v_self->refs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":337
 *         self.pos = lhs.pos
 *         self.refs = set()
 *         self.is_arg = False             # <<<<<<<<<<<<<<
 *         self.is_deletion = False
 *         self.inferred_type = None
*/
  __pyx_v_self->is_arg = 0;

  /* "Cython/Compiler/FlowControl.py":338
 *         self.refs = set()
 *         self.is_arg = False
 *         self.is_deletion = False             # <<<<<<<<<<<<<<
 *         self.inferred_type = None
 *         # For generator expression targets in comprehensions (and possibly other things),
*/
  __pyx_v_self->is_deletion = 0;

  /* "Cython/Compiler/FlowControl.py":339
 *         self.is_arg = False
 *         self.is_deletion = False
 *         self.inferred_type = None             # <<<<<<<<<<<<<<
 *         # For generator expression targets in comprehensions (and possibly other things),
 *         # the rhs can have a different scope than the lhs.
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->inferred_type);
  __Pyx_DECREF(__pyx_v_self->inferred_type);
  __pyx_v_self->inferred_type = Py_None;

  /* "Cython/Compiler/FlowControl.py":342
 *         # For generator expression targets in comprehensions (and possibly other things),
 *         # the rhs can have a different scope than the lhs.
 *         self.rhs_scope = rhs_scope             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_INCREF(__pyx_v_rhs_scope);
  __Pyx_GIVEREF(__pyx_v_rhs_scope);
  __Pyx_GOTREF(__pyx_v_self->rhs_scope);
  __Pyx_DECREF(__pyx_v_self->rhs_scope);
  __pyx_v_self->rhs_scope = __pyx_v_rhs_scope;

  /* "Cython/Compiler/FlowControl.py":329
 * 
 * class NameAssignment:
 *     def __init__(self, lhs, rhs, entry, rhs_scope=None):             # <<<<<<<<<<<<<<
 *         if lhs.cf_state is None:
 *             lhs.cf_state = set()
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":344
 *         self.rhs_scope = rhs_scope
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_2__repr__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_2__repr__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3[4];
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Compiler/FlowControl.py":345
 * 
 *     def __repr__(self):
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)             # <<<<<<<<<<<<<<
 * 
 *     def infer_type(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_self->entry), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3[0] = __pyx_t_1;
  __pyx_t_3[1] = __pyx_mstate_global->__pyx_kp_u_entry_2;
  __pyx_t_3[2] = __pyx_t_2;
  __pyx_t_3[3] = __pyx_mstate_global->__pyx_kp_u_;
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_3, 4, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2));
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":344
 *         self.rhs_scope = rhs_scope
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":347
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         self.inferred_type = self.rhs.infer_type(self.rhs_scope or self.entry.scope)
 *         return self.inferred_type
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5infer_type(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_14NameAssignment_5infer_type = {"infer_type", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5infer_type, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5infer_type(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("infer_type (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4infer_type(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4infer_type(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("infer_type", 0);

  /* "Cython/Compiler/FlowControl.py":348
 * 
 *     def infer_type(self):
 *         self.inferred_type = self.rhs.infer_type(self.rhs_scope or self.entry.scope)             # <<<<<<<<<<<<<<
 *         return self.inferred_type
 * 
*/
  __pyx_t_2 = __pyx_v_self->rhs;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_self->rhs_scope); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 348, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __Pyx_INCREF(__pyx_v_self->rhs_scope);
    __pyx_t_3 = __pyx_v_self->rhs_scope;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->entry, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = __pyx_t_5;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_infer_type, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->inferred_type);
  __Pyx_DECREF(__pyx_v_self->inferred_type);
  __pyx_v_self->inferred_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":349
 *     def infer_type(self):
 *         self.inferred_type = self.rhs.infer_type(self.rhs_scope or self.entry.scope)
 *         return self.inferred_type             # <<<<<<<<<<<<<<
 * 
 *     def type_dependencies(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->inferred_type);
  __pyx_r = __pyx_v_self->inferred_type;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":347
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         self.inferred_type = self.rhs.infer_type(self.rhs_scope or self.entry.scope)
 *         return self.inferred_type
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.infer_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":351
 *         return self.inferred_type
 * 
 *     def type_dependencies(self):             # <<<<<<<<<<<<<<
 *         return self.rhs.type_dependencies(self.rhs_scope or self.entry.scope)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_7type_dependencies(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_14NameAssignment_7type_dependencies = {"type_dependencies", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_7type_dependencies, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_7type_dependencies(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("type_dependencies (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6type_dependencies(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6type_dependencies(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("type_dependencies", 0);

  /* "Cython/Compiler/FlowControl.py":352
 * 
 *     def type_dependencies(self):
 *         return self.rhs.type_dependencies(self.rhs_scope or self.entry.scope)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_self->rhs;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_self->rhs_scope); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 352, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __Pyx_INCREF(__pyx_v_self->rhs_scope);
    __pyx_t_3 = __pyx_v_self->rhs_scope;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->entry, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = __pyx_t_5;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_type_dependencies, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":351
 *         return self.inferred_type
 * 
 *     def type_dependencies(self):             # <<<<<<<<<<<<<<
 *         return self.rhs.type_dependencies(self.rhs_scope or self.entry.scope)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.type_dependencies", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":354
 *         return self.rhs.type_dependencies(self.rhs_scope or self.entry.scope)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def type(self):
 *         if not self.entry.type.is_unspecified:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4type_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4type___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4type___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "Cython/Compiler/FlowControl.py":356
 *     @property
 *     def type(self):
 *         if not self.entry.type.is_unspecified:             # <<<<<<<<<<<<<<
 *             return self.entry.type
 *         return self.inferred_type
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_unspecified); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "Cython/Compiler/FlowControl.py":357
 *     def type(self):
 *         if not self.entry.type.is_unspecified:
 *             return self.entry.type             # <<<<<<<<<<<<<<
 *         return self.inferred_type
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":356
 *     @property
 *     def type(self):
 *         if not self.entry.type.is_unspecified:             # <<<<<<<<<<<<<<
 *             return self.entry.type
 *         return self.inferred_type
*/
  }

  /* "Cython/Compiler/FlowControl.py":358
 *         if not self.entry.type.is_unspecified:
 *             return self.entry.type
 *         return self.inferred_type             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->inferred_type);
  __pyx_r = __pyx_v_self->inferred_type;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":354
 *         return self.rhs.type_dependencies(self.rhs_scope or self.entry.scope)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def type(self):
 *         if not self.entry.type.is_unspecified:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.type.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":28
 * 
 * cdef class NameAssignment:
 *     cdef public bint is_arg             # <<<<<<<<<<<<<<
 *     cdef public bint is_deletion
 *     cdef public object lhs
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->is_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.is_arg.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 28, __pyx_L1_error)
  __pyx_v_self->is_arg = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.is_arg.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":29
 * cdef class NameAssignment:
 *     cdef public bint is_arg
 *     cdef public bint is_deletion             # <<<<<<<<<<<<<<
 *     cdef public object lhs
 *     cdef public object rhs
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->is_deletion); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.is_deletion.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 29, __pyx_L1_error)
  __pyx_v_self->is_deletion = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.is_deletion.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":30
 *     cdef public bint is_arg
 *     cdef public bint is_deletion
 *     cdef public object lhs             # <<<<<<<<<<<<<<
 *     cdef public object rhs
 *     cdef public object entry
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->lhs);
  __pyx_r = __pyx_v_self->lhs;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->lhs);
  __Pyx_DECREF(__pyx_v_self->lhs);
  __pyx_v_self->lhs = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->lhs);
  __Pyx_DECREF(__pyx_v_self->lhs);
  __pyx_v_self->lhs = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":31
 *     cdef public bint is_deletion
 *     cdef public object lhs
 *     cdef public object rhs             # <<<<<<<<<<<<<<
 *     cdef public object entry
 *     cdef public object pos
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->rhs);
  __pyx_r = __pyx_v_self->rhs;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->rhs);
  __Pyx_DECREF(__pyx_v_self->rhs);
  __pyx_v_self->rhs = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->rhs);
  __Pyx_DECREF(__pyx_v_self->rhs);
  __pyx_v_self->rhs = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":32
 *     cdef public object lhs
 *     cdef public object rhs
 *     cdef public object entry             # <<<<<<<<<<<<<<
 *     cdef public object pos
 *     cdef public set refs
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->entry);
  __pyx_r = __pyx_v_self->entry;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->entry);
  __Pyx_DECREF(__pyx_v_self->entry);
  __pyx_v_self->entry = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->entry);
  __Pyx_DECREF(__pyx_v_self->entry);
  __pyx_v_self->entry = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":33
 *     cdef public object rhs
 *     cdef public object entry
 *     cdef public object pos             # <<<<<<<<<<<<<<
 *     cdef public set refs
 *     cdef public object bit
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->pos);
  __pyx_r = __pyx_v_self->pos;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->pos);
  __Pyx_DECREF(__pyx_v_self->pos);
  __pyx_v_self->pos = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->pos);
  __Pyx_DECREF(__pyx_v_self->pos);
  __pyx_v_self->pos = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":34
 *     cdef public object entry
 *     cdef public object pos
 *     cdef public set refs             # <<<<<<<<<<<<<<
 *     cdef public object bit
 *     cdef public object inferred_type
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->refs);
  __pyx_r = __pyx_v_self->refs;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(1, 34, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->refs);
  __Pyx_DECREF(__pyx_v_self->refs);
  __pyx_v_self->refs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.refs.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->refs);
  __Pyx_DECREF(__pyx_v_self->refs);
  __pyx_v_self->refs = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":35
 *     cdef public object pos
 *     cdef public set refs
 *     cdef public object bit             # <<<<<<<<<<<<<<
 *     cdef public object inferred_type
 *     cdef public object rhs_scope
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->bit);
  __pyx_r = __pyx_v_self->bit;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->bit);
  __Pyx_DECREF(__pyx_v_self->bit);
  __pyx_v_self->bit = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->bit);
  __Pyx_DECREF(__pyx_v_self->bit);
  __pyx_v_self->bit = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":36
 *     cdef public set refs
 *     cdef public object bit
 *     cdef public object inferred_type             # <<<<<<<<<<<<<<
 *     cdef public object rhs_scope
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->inferred_type);
  __pyx_r = __pyx_v_self->inferred_type;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->inferred_type);
  __Pyx_DECREF(__pyx_v_self->inferred_type);
  __pyx_v_self->inferred_type = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->inferred_type);
  __Pyx_DECREF(__pyx_v_self->inferred_type);
  __pyx_v_self->inferred_type = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.pxd":37
 *     cdef public object bit
 *     cdef public object inferred_type
 *     cdef public object rhs_scope             # <<<<<<<<<<<<<<
 * 
 * cdef class AssignmentList:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope___get__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope___get__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->rhs_scope);
  __pyx_r = __pyx_v_self->rhs_scope;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_2__set__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_2__set__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->rhs_scope);
  __Pyx_DECREF(__pyx_v_self->rhs_scope);
  __pyx_v_self->rhs_scope = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_4__del__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_4__del__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->rhs_scope);
  __Pyx_DECREF(__pyx_v_self->rhs_scope);
  __pyx_v_self->rhs_scope = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_14NameAssignment_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_8__reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_8__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.bit, self.entry, self.inferred_type, self.is_arg, self.is_deletion, self.lhs, self.pos, self.refs, self.rhs, self.rhs_scope)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->is_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->is_deletion); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(10); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->bit);
  __Pyx_GIVEREF(__pyx_v_self->bit);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->bit) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->entry);
  __Pyx_GIVEREF(__pyx_v_self->entry);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self->entry) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->inferred_type);
  __Pyx_GIVEREF(__pyx_v_self->inferred_type);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_self->inferred_type) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_1) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_2) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->lhs);
  __Pyx_GIVEREF(__pyx_v_self->lhs);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_v_self->lhs) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->pos);
  __Pyx_GIVEREF(__pyx_v_self->pos);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 6, __pyx_v_self->pos) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->refs);
  __Pyx_GIVEREF(__pyx_v_self->refs);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 7, __pyx_v_self->refs) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->rhs);
  __Pyx_GIVEREF(__pyx_v_self->rhs);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 8, __pyx_v_self->rhs) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->rhs_scope);
  __Pyx_GIVEREF(__pyx_v_self->rhs_scope);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 9, __pyx_v_self->rhs_scope) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.bit, self.entry, self.inferred_type, self.is_arg, self.is_deletion, self.lhs, self.pos, self.refs, self.rhs, self.rhs_scope)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_3 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__dict = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":7
 *     state = (self.bit, self.entry, self.inferred_type, self.is_arg, self.is_deletion, self.lhs, self.pos, self.refs, self.rhs, self.rhs_scope)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_5 = (__pyx_v__dict != Py_None);
  if (__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.bit is not None or self.entry is not None or self.inferred_type is not None or self.lhs is not None or self.pos is not None or self.refs is not None or self.rhs is not None or self.rhs_scope is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.bit, self.entry, self.inferred_type, self.is_arg, self.is_deletion, self.lhs, self.pos, self.refs, self.rhs, self.rhs_scope)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.bit is not None or self.entry is not None or self.inferred_type is not None or self.lhs is not None or self.pos is not None or self.refs is not None or self.rhs is not None or self.rhs_scope is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, None), state
*/
  /*else*/ {
    __pyx_t_5 = (__pyx_v_self->bit != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->entry != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->inferred_type != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->lhs != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->pos != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->refs != ((PyObject*)Py_None));
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->rhs != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->rhs_scope != Py_None);
    __pyx_t_4 = __pyx_t_5;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_4;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bit is not None or self.entry is not None or self.inferred_type is not None or self.lhs is not None or self.pos is not None or self.refs is not None or self.rhs is not None or self.rhs_scope is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.bit is not None or self.entry is not None or self.inferred_type is not None or self.lhs is not None or self.pos is not None or self.refs is not None or self.rhs is not None or self.rhs_scope is not None
 *     if use_setstate:
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_NameAssignment); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_9995728);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_9995728);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_mstate_global->__pyx_int_9995728) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bit is not None or self.entry is not None or self.inferred_type is not None or self.lhs is not None or self.pos is not None or self.refs is not None or self.rhs is not None or self.rhs_scope is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, None), state
 *     else:
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_NameAssignment__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_NameAssignment); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_9995728);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_9995728);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_mstate_global->__pyx_int_9995728) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_NameAssignment__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_14NameAssignment_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_10__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14NameAssignment_10__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_NameAssignment__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_NameAssignment__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_NameAssignment__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameAssignment.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":363
 * class StaticAssignment(NameAssignment):
 *     """Initialised at declaration time, e.g. stack allocation."""
 *     def __init__(self, entry):             # <<<<<<<<<<<<<<
 *         if not entry.type.is_pyobject:
 *             may_be_none = False
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_16StaticAssignment_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_entry = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_entry,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 363, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 363, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 363, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 363, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 363, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 363, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 363, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_entry = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 363, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.StaticAssignment.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment___init__(__pyx_self, __pyx_v_self, __pyx_v_entry);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_entry) {
  PyObject *__pyx_v_may_be_none = NULL;
  PyObject *__pyx_v_lhs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":364
 *     """Initialised at declaration time, e.g. stack allocation."""
 *     def __init__(self, entry):
 *         if not entry.type.is_pyobject:             # <<<<<<<<<<<<<<
 *             may_be_none = False
 *         else:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_pyobject); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "Cython/Compiler/FlowControl.py":365
 *     def __init__(self, entry):
 *         if not entry.type.is_pyobject:
 *             may_be_none = False             # <<<<<<<<<<<<<<
 *         else:
 *             may_be_none = None  # unknown
*/
    __Pyx_INCREF(Py_False);
    __pyx_v_may_be_none = Py_False;

    /* "Cython/Compiler/FlowControl.py":364
 *     """Initialised at declaration time, e.g. stack allocation."""
 *     def __init__(self, entry):
 *         if not entry.type.is_pyobject:             # <<<<<<<<<<<<<<
 *             may_be_none = False
 *         else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/FlowControl.py":367
 *             may_be_none = False
 *         else:
 *             may_be_none = None  # unknown             # <<<<<<<<<<<<<<
 *         lhs = TypedExprNode(
 *             entry.type, may_be_none=may_be_none, pos=entry.pos)
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_may_be_none = Py_None;
  }
  __pyx_L3:;

  /* "Cython/Compiler/FlowControl.py":368
 *         else:
 *             may_be_none = None  # unknown
 *         lhs = TypedExprNode(             # <<<<<<<<<<<<<<
 *             entry.type, may_be_none=may_be_none, pos=entry.pos)
 *         super().__init__(lhs, lhs, entry)
*/
  __pyx_t_1 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode);
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode; 

  /* "Cython/Compiler/FlowControl.py":369
 *             may_be_none = None  # unknown
 *         lhs = TypedExprNode(
 *             entry.type, may_be_none=may_be_none, pos=entry.pos)             # <<<<<<<<<<<<<<
 *         super().__init__(lhs, lhs, entry)
 * 
*/
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_8 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_t_6};
    __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_may_be_none, __pyx_v_may_be_none, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_7, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v_lhs = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":370
 *         lhs = TypedExprNode(
 *             entry.type, may_be_none=may_be_none, pos=entry.pos)
 *         super().__init__(lhs, lhs, entry)             # <<<<<<<<<<<<<<
 * 
 *     def infer_type(self):
*/
  __pyx_t_7 = NULL;
  __pyx_t_6 = __Pyx_CyFunction_GetClassObj(__pyx_self);
  if (!__pyx_t_6) { PyErr_SetString(PyExc_RuntimeError, "super(): empty __class__ cell"); __PYX_ERR(0, 370, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_8 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_6, __pyx_v_self};
    __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
  }
  __pyx_t_5 = __pyx_t_9;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_8 = 0;
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_lhs, __pyx_v_lhs, __pyx_v_entry};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_8, (4-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":363
 * class StaticAssignment(NameAssignment):
 *     """Initialised at declaration time, e.g. stack allocation."""
 *     def __init__(self, entry):             # <<<<<<<<<<<<<<
 *         if not entry.type.is_pyobject:
 *             may_be_none = False
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.StaticAssignment.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_may_be_none);
  __Pyx_XDECREF(__pyx_v_lhs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":372
 *         super().__init__(lhs, lhs, entry)
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         return self.entry.type
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_3infer_type(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_16StaticAssignment_3infer_type = {"infer_type", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_3infer_type, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_3infer_type(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("infer_type (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment_2infer_type(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment_2infer_type(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("infer_type", 0);

  /* "Cython/Compiler/FlowControl.py":373
 * 
 *     def infer_type(self):
 *         return self.entry.type             # <<<<<<<<<<<<<<
 * 
 *     def type_dependencies(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":372
 *         super().__init__(lhs, lhs, entry)
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         return self.entry.type
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.StaticAssignment.infer_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":375
 *         return self.entry.type
 * 
 *     def type_dependencies(self):             # <<<<<<<<<<<<<<
 *         return ()
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_5type_dependencies(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_16StaticAssignment_5type_dependencies = {"type_dependencies", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_5type_dependencies, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16StaticAssignment_5type_dependencies(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("type_dependencies (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment_4type_dependencies(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16StaticAssignment_4type_dependencies(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("type_dependencies", 0);

  /* "Cython/Compiler/FlowControl.py":376
 * 
 *     def type_dependencies(self):
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_empty_tuple);
  __pyx_r = __pyx_mstate_global->__pyx_empty_tuple;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":375
 *         return self.entry.type
 * 
 *     def type_dependencies(self):             # <<<<<<<<<<<<<<
 *         return ()
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":380
 * 
 * class Argument(NameAssignment):
 *     def __init__(self, lhs, rhs, entry):             # <<<<<<<<<<<<<<
 *         NameAssignment.__init__(self, lhs, rhs, entry)
 *         self.is_arg = True
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_8Argument_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_8Argument_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_8Argument_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_8Argument_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_lhs = 0;
  PyObject *__pyx_v_rhs = 0;
  PyObject *__pyx_v_entry = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_lhs,&__pyx_mstate_global->__pyx_n_u_rhs,&__pyx_mstate_global->__pyx_n_u_entry,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 380, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 380, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 380, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 380, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 380, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 380, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, i); __PYX_ERR(0, 380, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 380, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 380, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 380, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 380, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_lhs = values[1];
    __pyx_v_rhs = values[2];
    __pyx_v_entry = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 380, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.Argument.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_8Argument___init__(__pyx_self, __pyx_v_self, __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_8Argument___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":381
 * class Argument(NameAssignment):
 *     def __init__(self, lhs, rhs, entry):
 *         NameAssignment.__init__(self, lhs, rhs, entry)             # <<<<<<<<<<<<<<
 *         self.is_arg = True
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_2, __pyx_v_self, __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_3, (5-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":382
 *     def __init__(self, lhs, rhs, entry):
 *         NameAssignment.__init__(self, lhs, rhs, entry)
 *         self.is_arg = True             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_is_arg, Py_True) < (0)) __PYX_ERR(0, 382, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":380
 * 
 * class Argument(NameAssignment):
 *     def __init__(self, lhs, rhs, entry):             # <<<<<<<<<<<<<<
 *         NameAssignment.__init__(self, lhs, rhs, entry)
 *         self.is_arg = True
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.Argument.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":386
 * 
 * class NameDeletion(NameAssignment):
 *     def __init__(self, lhs, entry):             # <<<<<<<<<<<<<<
 *         NameAssignment.__init__(self, lhs, lhs, entry)
 *         self.is_deletion = True
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12NameDeletion_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_12NameDeletion_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_12NameDeletion_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12NameDeletion_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_lhs = 0;
  PyObject *__pyx_v_entry = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_lhs,&__pyx_mstate_global->__pyx_n_u_entry,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 386, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 386, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 386, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 386, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 386, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, i); __PYX_ERR(0, 386, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 386, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 386, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 386, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_lhs = values[1];
    __pyx_v_entry = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 386, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameDeletion.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12NameDeletion___init__(__pyx_self, __pyx_v_self, __pyx_v_lhs, __pyx_v_entry);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12NameDeletion___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":387
 * class NameDeletion(NameAssignment):
 *     def __init__(self, lhs, entry):
 *         NameAssignment.__init__(self, lhs, lhs, entry)             # <<<<<<<<<<<<<<
 *         self.is_deletion = True
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_2, __pyx_v_self, __pyx_v_lhs, __pyx_v_lhs, __pyx_v_entry};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_3, (5-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":388
 *     def __init__(self, lhs, entry):
 *         NameAssignment.__init__(self, lhs, lhs, entry)
 *         self.is_deletion = True             # <<<<<<<<<<<<<<
 * 
 *     def infer_type(self):
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_is_deletion, Py_True) < (0)) __PYX_ERR(0, 388, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":386
 * 
 * class NameDeletion(NameAssignment):
 *     def __init__(self, lhs, entry):             # <<<<<<<<<<<<<<
 *         NameAssignment.__init__(self, lhs, lhs, entry)
 *         self.is_deletion = True
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameDeletion.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":390
 *         self.is_deletion = True
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         inferred_type = self.rhs.infer_type(self.entry.scope)
 *         if (not inferred_type.is_pyobject
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12NameDeletion_3infer_type(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_12NameDeletion_3infer_type = {"infer_type", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_12NameDeletion_3infer_type, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_12NameDeletion_3infer_type(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("infer_type (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12NameDeletion_2infer_type(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12NameDeletion_2infer_type(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_inferred_type = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("infer_type", 0);

  /* "Cython/Compiler/FlowControl.py":391
 * 
 *     def infer_type(self):
 *         inferred_type = self.rhs.infer_type(self.entry.scope)             # <<<<<<<<<<<<<<
 *         if (not inferred_type.is_pyobject
 *                 and inferred_type.can_coerce_to_pyobject(self.entry.scope)):
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_infer_type, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_inferred_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":392
 *     def infer_type(self):
 *         inferred_type = self.rhs.infer_type(self.entry.scope)
 *         if (not inferred_type.is_pyobject             # <<<<<<<<<<<<<<
 *                 and inferred_type.can_coerce_to_pyobject(self.entry.scope)):
 *             return PyrexTypes.py_object_type
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_inferred_type, __pyx_mstate_global->__pyx_n_u_is_pyobject); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_9 = (!__pyx_t_8);
  if (__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/FlowControl.py":393
 *         inferred_type = self.rhs.infer_type(self.entry.scope)
 *         if (not inferred_type.is_pyobject
 *                 and inferred_type.can_coerce_to_pyobject(self.entry.scope)):             # <<<<<<<<<<<<<<
 *             return PyrexTypes.py_object_type
 *         self.inferred_type = inferred_type
*/
  __pyx_t_3 = __pyx_v_inferred_type;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_can_coerce_to_pyobject, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;

  /* "Cython/Compiler/FlowControl.py":392
 *     def infer_type(self):
 *         inferred_type = self.rhs.infer_type(self.entry.scope)
 *         if (not inferred_type.is_pyobject             # <<<<<<<<<<<<<<
 *                 and inferred_type.can_coerce_to_pyobject(self.entry.scope)):
 *             return PyrexTypes.py_object_type
*/
  if (__pyx_t_7) {

    /* "Cython/Compiler/FlowControl.py":394
 *         if (not inferred_type.is_pyobject
 *                 and inferred_type.can_coerce_to_pyobject(self.entry.scope)):
 *             return PyrexTypes.py_object_type             # <<<<<<<<<<<<<<
 *         self.inferred_type = inferred_type
 *         return inferred_type
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_PyrexTypes, __pyx_mstate_global->__pyx_n_u_py_object_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":392
 *     def infer_type(self):
 *         inferred_type = self.rhs.infer_type(self.entry.scope)
 *         if (not inferred_type.is_pyobject             # <<<<<<<<<<<<<<
 *                 and inferred_type.can_coerce_to_pyobject(self.entry.scope)):
 *             return PyrexTypes.py_object_type
*/
  }

  /* "Cython/Compiler/FlowControl.py":395
 *                 and inferred_type.can_coerce_to_pyobject(self.entry.scope)):
 *             return PyrexTypes.py_object_type
 *         self.inferred_type = inferred_type             # <<<<<<<<<<<<<<
 *         return inferred_type
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_inferred_type, __pyx_v_inferred_type) < (0)) __PYX_ERR(0, 395, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":396
 *             return PyrexTypes.py_object_type
 *         self.inferred_type = inferred_type
 *         return inferred_type             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_inferred_type);
  __pyx_r = __pyx_v_inferred_type;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":390
 *         self.is_deletion = True
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         inferred_type = self.rhs.infer_type(self.entry.scope)
 *         if (not inferred_type.is_pyobject
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameDeletion.infer_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_inferred_type);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13Uninitialized_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_13Uninitialized_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_13Uninitialized_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13Uninitialized_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_13Uninitialized___reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13Uninitialized___reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_empty_tuple);
  __pyx_v_state = __pyx_mstate_global->__pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, None), state
*/
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Uninitialized); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_238750788) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, None), state
 *     else:
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Uninitialized__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Uninitialized); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_238750788) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.Uninitialized.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Uninitialized__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13Uninitialized_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_13Uninitialized_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_13Uninitialized_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13Uninitialized_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_13Uninitialized_2__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13Uninitialized_2__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Uninitialized__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_Uninitialized__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Uninitialized__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.Uninitialized.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_7Unknown_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_7Unknown_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_7Unknown_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_7Unknown_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_7Unknown___reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_7Unknown___reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_empty_tuple);
  __pyx_v_state = __pyx_mstate_global->__pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, None), state
*/
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Unknown); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_238750788) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, None), state
 *     else:
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Unknown__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Unknown); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_238750788) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.Unknown.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Unknown__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_7Unknown_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_7Unknown_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_7Unknown_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_7Unknown_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_7Unknown_2__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_7Unknown_2__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Unknown__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_Unknown__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Unknown__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.Unknown.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":408
 * 
 * class NameReference:
 *     def __init__(self, node, entry):             # <<<<<<<<<<<<<<
 *         if node.cf_state is None:
 *             node.cf_state = set()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13NameReference_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_13NameReference_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_13NameReference_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13NameReference_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_node = 0;
  PyObject *__pyx_v_entry = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_entry,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 408, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 408, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 408, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 408, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 408, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, i); __PYX_ERR(0, 408, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 408, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 408, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 408, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_node = values[1];
    __pyx_v_entry = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 408, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameReference.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_13NameReference___init__(__pyx_self, __pyx_v_self, __pyx_v_node, __pyx_v_entry);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13NameReference___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_entry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":409
 * class NameReference:
 *     def __init__(self, node, entry):
 *         if node.cf_state is None:             # <<<<<<<<<<<<<<
 *             node.cf_state = set()
 *         self.node = node
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":410
 *     def __init__(self, node, entry):
 *         if node.cf_state is None:
 *             node.cf_state = set()             # <<<<<<<<<<<<<<
 *         self.node = node
 *         self.entry = entry
*/
    __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state, __pyx_t_1) < (0)) __PYX_ERR(0, 410, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":409
 * class NameReference:
 *     def __init__(self, node, entry):
 *         if node.cf_state is None:             # <<<<<<<<<<<<<<
 *             node.cf_state = set()
 *         self.node = node
*/
  }

  /* "Cython/Compiler/FlowControl.py":411
 *         if node.cf_state is None:
 *             node.cf_state = set()
 *         self.node = node             # <<<<<<<<<<<<<<
 *         self.entry = entry
 *         self.pos = node.pos
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_node, __pyx_v_node) < (0)) __PYX_ERR(0, 411, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":412
 *             node.cf_state = set()
 *         self.node = node
 *         self.entry = entry             # <<<<<<<<<<<<<<
 *         self.pos = node.pos
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_entry, __pyx_v_entry) < (0)) __PYX_ERR(0, 412, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":413
 *         self.node = node
 *         self.entry = entry
 *         self.pos = node.pos             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_pos, __pyx_t_1) < (0)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":408
 * 
 * class NameReference:
 *     def __init__(self, node, entry):             # <<<<<<<<<<<<<<
 *         if node.cf_state is None:
 *             node.cf_state = set()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameReference.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":415
 *         self.pos = node.pos
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13NameReference_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_13NameReference_3__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_13NameReference_3__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13NameReference_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_13NameReference_2__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_13NameReference_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4[4];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Compiler/FlowControl.py":416
 * 
 *     def __repr__(self):
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4[0] = __pyx_t_1;
  __pyx_t_4[1] = __pyx_mstate_global->__pyx_kp_u_entry_2;
  __pyx_t_4[2] = __pyx_t_3;
  __pyx_t_4[3] = __pyx_mstate_global->__pyx_kp_u_;
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":415
 *         self.pos = node.pos
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.NameReference.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":430
 *     is_single = False
 * 
 *     def __init__(self, state):             # <<<<<<<<<<<<<<
 *         if Uninitialized in state:
 *             state.discard(Uninitialized)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16ControlFlowState_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_16ControlFlowState_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_16ControlFlowState_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16ControlFlowState_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 430, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 430, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 430, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 430, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 430, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 430, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 430, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_state = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 430, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowState.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_16ControlFlowState___init__(__pyx_self, __pyx_v_self, __pyx_v_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16ControlFlowState___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_7genexpr__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":431
 * 
 *     def __init__(self, state):
 *         if Uninitialized in state:             # <<<<<<<<<<<<<<
 *             state.discard(Uninitialized)
 *             self.cf_maybe_null = True
*/
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized), __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 431, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":432
 *     def __init__(self, state):
 *         if Uninitialized in state:
 *             state.discard(Uninitialized)             # <<<<<<<<<<<<<<
 *             self.cf_maybe_null = True
 *             if not state:
*/
    __pyx_t_3 = __pyx_v_state;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized)};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_discard, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":433
 *         if Uninitialized in state:
 *             state.discard(Uninitialized)
 *             self.cf_maybe_null = True             # <<<<<<<<<<<<<<
 *             if not state:
 *                 self.cf_is_null = True
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_True) < (0)) __PYX_ERR(0, 433, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":434
 *             state.discard(Uninitialized)
 *             self.cf_maybe_null = True
 *             if not state:             # <<<<<<<<<<<<<<
 *                 self.cf_is_null = True
 *         elif Unknown in state:
*/
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_state); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 434, __pyx_L1_error)
    __pyx_t_5 = (!__pyx_t_1);
    if (__pyx_t_5) {

      /* "Cython/Compiler/FlowControl.py":435
 *             self.cf_maybe_null = True
 *             if not state:
 *                 self.cf_is_null = True             # <<<<<<<<<<<<<<
 *         elif Unknown in state:
 *             state.discard(Unknown)
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cf_is_null, Py_True) < (0)) __PYX_ERR(0, 435, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":434
 *             state.discard(Uninitialized)
 *             self.cf_maybe_null = True
 *             if not state:             # <<<<<<<<<<<<<<
 *                 self.cf_is_null = True
 *         elif Unknown in state:
*/
    }

    /* "Cython/Compiler/FlowControl.py":431
 * 
 *     def __init__(self, state):
 *         if Uninitialized in state:             # <<<<<<<<<<<<<<
 *             state.discard(Uninitialized)
 *             self.cf_maybe_null = True
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/FlowControl.py":436
 *             if not state:
 *                 self.cf_is_null = True
 *         elif Unknown in state:             # <<<<<<<<<<<<<<
 *             state.discard(Unknown)
 *             self.cf_maybe_null = True
*/
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown), __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 436, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":437
 *                 self.cf_is_null = True
 *         elif Unknown in state:
 *             state.discard(Unknown)             # <<<<<<<<<<<<<<
 *             self.cf_maybe_null = True
 *         else:
*/
    __pyx_t_3 = __pyx_v_state;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown)};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_discard, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":438
 *         elif Unknown in state:
 *             state.discard(Unknown)
 *             self.cf_maybe_null = True             # <<<<<<<<<<<<<<
 *         else:
 *             if len(state) == 1:
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_True) < (0)) __PYX_ERR(0, 438, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":436
 *             if not state:
 *                 self.cf_is_null = True
 *         elif Unknown in state:             # <<<<<<<<<<<<<<
 *             state.discard(Unknown)
 *             self.cf_maybe_null = True
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/FlowControl.py":440
 *             self.cf_maybe_null = True
 *         else:
 *             if len(state) == 1:             # <<<<<<<<<<<<<<
 *                 self.is_single = True
 *         # XXX: Remove fake_rhs_expr
*/
  /*else*/ {
    __pyx_t_6 = PyObject_Length(__pyx_v_state); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 440, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_6 == 1);
    if (__pyx_t_5) {

      /* "Cython/Compiler/FlowControl.py":441
 *         else:
 *             if len(state) == 1:
 *                 self.is_single = True             # <<<<<<<<<<<<<<
 *         # XXX: Remove fake_rhs_expr
 *         super().__init__(
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_is_single, Py_True) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":440
 *             self.cf_maybe_null = True
 *         else:
 *             if len(state) == 1:             # <<<<<<<<<<<<<<
 *                 self.is_single = True
 *         # XXX: Remove fake_rhs_expr
*/
    }
  }
  __pyx_L3:;

  /* "Cython/Compiler/FlowControl.py":443
 *                 self.is_single = True
 *         # XXX: Remove fake_rhs_expr
 *         super().__init__(             # <<<<<<<<<<<<<<
 *             [i for i in state if i.rhs is not fake_rhs_expr])
 * 
*/
  __pyx_t_8 = NULL;
  __pyx_t_9 = __Pyx_CyFunction_GetClassObj(__pyx_self);
  if (!__pyx_t_9) { PyErr_SetString(PyExc_RuntimeError, "super(): empty __class__ cell"); __PYX_ERR(0, 443, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_t_9);
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_9, __pyx_v_self};
    __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
  }
  __pyx_t_3 = __pyx_t_7;
  __Pyx_INCREF(__pyx_t_3);
  { /* enter inner scope */

    /* "Cython/Compiler/FlowControl.py":444
 *         # XXX: Remove fake_rhs_expr
 *         super().__init__(
 *             [i for i in state if i.rhs is not fake_rhs_expr])             # <<<<<<<<<<<<<<
 * 
 *     def one(self):
*/
    __pyx_t_9 = PyList_New(0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 444, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (likely(PyList_CheckExact(__pyx_v_state)) || PyTuple_CheckExact(__pyx_v_state)) {
      __pyx_t_8 = __pyx_v_state; __Pyx_INCREF(__pyx_t_8);
      __pyx_t_6 = 0;
      __pyx_t_10 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_v_state); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 444, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 444, __pyx_L8_error)
    }
    for (;;) {
      if (likely(!__pyx_t_10)) {
        if (likely(PyList_CheckExact(__pyx_t_8))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_8);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 444, __pyx_L8_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          __pyx_t_11 = __Pyx_PyList_GetItemRefFast(__pyx_t_8, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_6;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_8);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 444, __pyx_L8_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_11 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_6));
          #else
          __pyx_t_11 = __Pyx_PySequence_ITEM(__pyx_t_8, __pyx_t_6);
          #endif
          ++__pyx_t_6;
        }
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 444, __pyx_L8_error)
      } else {
        __pyx_t_11 = __pyx_t_10(__pyx_t_8);
        if (unlikely(!__pyx_t_11)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 444, __pyx_L8_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_i, __pyx_t_11);
      __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_i, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 444, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_5 = (__pyx_t_11 != __pyx_v_6Cython_8Compiler_11FlowControl_fake_rhs_expr);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (__pyx_t_5) {
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_9, (PyObject*)__pyx_7genexpr__pyx_v_i))) __PYX_ERR(0, 444, __pyx_L8_error)
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_i); __pyx_7genexpr__pyx_v_i = 0;
    goto __pyx_L13_exit_scope;
    __pyx_L8_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_i); __pyx_7genexpr__pyx_v_i = 0;
    goto __pyx_L1_error;
    __pyx_L13_exit_scope:;
  } /* exit inner scope */
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_9};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":430
 *     is_single = False
 * 
 *     def __init__(self, state):             # <<<<<<<<<<<<<<
 *         if Uninitialized in state:
 *             state.discard(Uninitialized)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowState.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":446
 *             [i for i in state if i.rhs is not fake_rhs_expr])
 * 
 *     def one(self):             # <<<<<<<<<<<<<<
 *         return self[0]
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16ControlFlowState_3one(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_16ControlFlowState_3one = {"one", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_16ControlFlowState_3one, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_16ControlFlowState_3one(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("one (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_16ControlFlowState_2one(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16ControlFlowState_2one(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("one", 0);

  /* "Cython/Compiler/FlowControl.py":447
 * 
 *     def one(self):
 *         return self[0]             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_self, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":446
 *             [i for i in state if i.rhs is not fake_rhs_expr])
 * 
 *     def one(self):             # <<<<<<<<<<<<<<
 *         return self[0]
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowState.one", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":453
 *     """Graphviz subgraph object."""
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.blockids = {}
 *         self.nextid = 0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_1__init__ = {"__init__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_1__init__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":454
 * 
 *     def __init__(self):
 *         self.blockids = {}             # <<<<<<<<<<<<<<
 *         self.nextid = 0
 *         self.children = []
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_blockids, __pyx_t_1) < (0)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":455
 *     def __init__(self):
 *         self.blockids = {}
 *         self.nextid = 0             # <<<<<<<<<<<<<<
 *         self.children = []
 *         self.sources = {}
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_nextid, __pyx_mstate_global->__pyx_int_0) < (0)) __PYX_ERR(0, 455, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":456
 *         self.blockids = {}
 *         self.nextid = 0
 *         self.children = []             # <<<<<<<<<<<<<<
 *         self.sources = {}
 * 
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_children, __pyx_t_1) < (0)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":457
 *         self.nextid = 0
 *         self.children = []
 *         self.sources = {}             # <<<<<<<<<<<<<<
 * 
 *     def add(self, child):
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_sources, __pyx_t_1) < (0)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":453
 *     """Graphviz subgraph object."""
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.blockids = {}
 *         self.nextid = 0
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":459
 *         self.sources = {}
 * 
 *     def add(self, child):             # <<<<<<<<<<<<<<
 *         self.children.append(child)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_3add(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_3add = {"add", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_3add, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_3add(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_child = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_child,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 459, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 459, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 459, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "add", 0) < (0)) __PYX_ERR(0, 459, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("add", 1, 2, 2, i); __PYX_ERR(0, 459, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 459, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 459, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_child = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 459, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_2add(__pyx_self, __pyx_v_self, __pyx_v_child);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_2add(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_child) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);

  /* "Cython/Compiler/FlowControl.py":460
 * 
 *     def add(self, child):
 *         self.children.append(child)             # <<<<<<<<<<<<<<
 * 
 *     def nodeid(self, block):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_child); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":459
 *         self.sources = {}
 * 
 *     def add(self, child):             # <<<<<<<<<<<<<<
 *         self.children.append(child)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":462
 *         self.children.append(child)
 * 
 *     def nodeid(self, block):             # <<<<<<<<<<<<<<
 *         if block not in self.blockids:
 *             self.blockids[block] = 'block%d' % self.nextid
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_5nodeid(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_5nodeid = {"nodeid", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_5nodeid, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_5nodeid(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_block = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nodeid (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_block,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 462, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 462, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 462, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "nodeid", 0) < (0)) __PYX_ERR(0, 462, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("nodeid", 1, 2, 2, i); __PYX_ERR(0, 462, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 462, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 462, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_block = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nodeid", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 462, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.nodeid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_4nodeid(__pyx_self, __pyx_v_self, __pyx_v_block);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_4nodeid(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_block) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nodeid", 0);

  /* "Cython/Compiler/FlowControl.py":463
 * 
 *     def nodeid(self, block):
 *         if block not in self.blockids:             # <<<<<<<<<<<<<<
 *             self.blockids[block] = 'block%d' % self.nextid
 *             self.nextid += 1
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_blockids); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_block, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":464
 *     def nodeid(self, block):
 *         if block not in self.blockids:
 *             self.blockids[block] = 'block%d' % self.nextid             # <<<<<<<<<<<<<<
 *             self.nextid += 1
 *         return self.blockids[block]
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_nextid); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_block_d, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_blockids); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_block, __pyx_t_3) < 0))) __PYX_ERR(0, 464, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":465
 *         if block not in self.blockids:
 *             self.blockids[block] = 'block%d' % self.nextid
 *             self.nextid += 1             # <<<<<<<<<<<<<<
 *         return self.blockids[block]
 * 
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_nextid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 465, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyLong_AddObjC(__pyx_t_3, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_nextid, __pyx_t_1) < (0)) __PYX_ERR(0, 465, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":463
 * 
 *     def nodeid(self, block):
 *         if block not in self.blockids:             # <<<<<<<<<<<<<<
 *             self.blockids[block] = 'block%d' % self.nextid
 *             self.nextid += 1
*/
  }

  /* "Cython/Compiler/FlowControl.py":466
 *             self.blockids[block] = 'block%d' % self.nextid
 *             self.nextid += 1
 *         return self.blockids[block]             # <<<<<<<<<<<<<<
 * 
 *     def extract_sources(self, block):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_blockids); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_block); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":462
 *         self.children.append(child)
 * 
 *     def nodeid(self, block):             # <<<<<<<<<<<<<<
 *         if block not in self.blockids:
 *             self.blockids[block] = 'block%d' % self.nextid
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.nodeid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":468
 *         return self.blockids[block]
 * 
 *     def extract_sources(self, block):             # <<<<<<<<<<<<<<
 *         if not block.positions:
 *             return ''
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_7extract_sources(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_7extract_sources = {"extract_sources", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_7extract_sources, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_7extract_sources(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_block = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extract_sources (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_block,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 468, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 468, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 468, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "extract_sources", 0) < (0)) __PYX_ERR(0, 468, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("extract_sources", 1, 2, 2, i); __PYX_ERR(0, 468, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 468, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 468, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_block = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extract_sources", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 468, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.extract_sources", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_6extract_sources(__pyx_self, __pyx_v_self, __pyx_v_block);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_6extract_sources(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_block) {
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_stop = NULL;
  PyObject *__pyx_v_srcdescr = NULL;
  PyObject *__pyx_v_lines = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extract_sources", 0);

  /* "Cython/Compiler/FlowControl.py":469
 * 
 *     def extract_sources(self, block):
 *         if not block.positions:             # <<<<<<<<<<<<<<
 *             return ''
 *         start = min(block.positions)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_block, __pyx_mstate_global->__pyx_n_u_positions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":470
 *     def extract_sources(self, block):
 *         if not block.positions:
 *             return ''             # <<<<<<<<<<<<<<
 *         start = min(block.positions)
 *         stop = max(block.positions)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__2);
    __pyx_r = __pyx_mstate_global->__pyx_kp_u__2;
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":469
 * 
 *     def extract_sources(self, block):
 *         if not block.positions:             # <<<<<<<<<<<<<<
 *             return ''
 *         start = min(block.positions)
*/
  }

  /* "Cython/Compiler/FlowControl.py":471
 *         if not block.positions:
 *             return ''
 *         start = min(block.positions)             # <<<<<<<<<<<<<<
 *         stop = max(block.positions)
 *         srcdescr = start[0]
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_block, __pyx_mstate_global->__pyx_n_u_positions); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_min, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_start = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":472
 *             return ''
 *         start = min(block.positions)
 *         stop = max(block.positions)             # <<<<<<<<<<<<<<
 *         srcdescr = start[0]
 *         if srcdescr not in self.sources:
*/
  __pyx_t_5 = NULL;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_block, __pyx_mstate_global->__pyx_n_u_positions); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_max, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_stop = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":473
 *         start = min(block.positions)
 *         stop = max(block.positions)
 *         srcdescr = start[0]             # <<<<<<<<<<<<<<
 *         if srcdescr not in self.sources:
 *             self.sources[srcdescr] = list(srcdescr.get_lines())
*/
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_start, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_srcdescr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":474
 *         stop = max(block.positions)
 *         srcdescr = start[0]
 *         if srcdescr not in self.sources:             # <<<<<<<<<<<<<<
 *             self.sources[srcdescr] = list(srcdescr.get_lines())
 *         lines = self.sources[srcdescr]
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_sources); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_srcdescr, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":475
 *         srcdescr = start[0]
 *         if srcdescr not in self.sources:
 *             self.sources[srcdescr] = list(srcdescr.get_lines())             # <<<<<<<<<<<<<<
 *         lines = self.sources[srcdescr]
 *         return '\\n'.join([l.strip() for l in lines[start[1] - 1:stop[1]]])
*/
    __pyx_t_4 = __pyx_v_srcdescr;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_lines, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_4 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_sources); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_srcdescr, __pyx_t_4) < 0))) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":474
 *         stop = max(block.positions)
 *         srcdescr = start[0]
 *         if srcdescr not in self.sources:             # <<<<<<<<<<<<<<
 *             self.sources[srcdescr] = list(srcdescr.get_lines())
 *         lines = self.sources[srcdescr]
*/
  }

  /* "Cython/Compiler/FlowControl.py":476
 *         if srcdescr not in self.sources:
 *             self.sources[srcdescr] = list(srcdescr.get_lines())
 *         lines = self.sources[srcdescr]             # <<<<<<<<<<<<<<
 *         return '\\n'.join([l.strip() for l in lines[start[1] - 1:stop[1]]])
 * 
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_sources); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_srcdescr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_lines = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":477
 *             self.sources[srcdescr] = list(srcdescr.get_lines())
 *         lines = self.sources[srcdescr]
 *         return '\\n'.join([l.strip() for l in lines[start[1] - 1:stop[1]]])             # <<<<<<<<<<<<<<
 * 
 *     def render(self, fp, name, annotate_defs=False):
*/
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L7_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_start, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 477, __pyx_L7_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyLong_SubtractObjC(__pyx_t_4, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 477, __pyx_L7_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_stop, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 477, __pyx_L7_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_v_lines, 0, 0, &__pyx_t_5, &__pyx_t_4, NULL, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 477, __pyx_L7_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
      __pyx_t_4 = __pyx_t_7; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 477, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 477, __pyx_L7_error)
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 477, __pyx_L7_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          __pyx_t_7 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_8;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 477, __pyx_L7_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_8));
          #else
          __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_8);
          #endif
          ++__pyx_t_8;
        }
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 477, __pyx_L7_error)
      } else {
        __pyx_t_7 = __pyx_t_9(__pyx_t_4);
        if (unlikely(!__pyx_t_7)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 477, __pyx_L7_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_l, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_5 = __pyx_8genexpr1__pyx_v_l;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 477, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_7))) __PYX_ERR(0, 477, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_l); __pyx_8genexpr1__pyx_v_l = 0;
    goto __pyx_L11_exit_scope;
    __pyx_L7_error:;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_l); __pyx_8genexpr1__pyx_v_l = 0;
    goto __pyx_L1_error;
    __pyx_L11_exit_scope:;
  } /* exit inner scope */
  __pyx_t_4 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u_n, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":468
 *         return self.blockids[block]
 * 
 *     def extract_sources(self, block):             # <<<<<<<<<<<<<<
 *         if not block.positions:
 *             return ''
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.extract_sources", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_stop);
  __Pyx_XDECREF(__pyx_v_srcdescr);
  __Pyx_XDECREF(__pyx_v_lines);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":479
 *         return '\\n'.join([l.strip() for l in lines[start[1] - 1:stop[1]]])
 * 
 *     def render(self, fp, name, annotate_defs=False):             # <<<<<<<<<<<<<<
 *         """Render graphviz dot graph"""
 *         fp.write('digraph %s {\n' % name)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_9render(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_9GVContext_8render, "Render graphviz dot graph");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_9render = {"render", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_9render, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_8Compiler_11FlowControl_9GVContext_8render};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_9render(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fp = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_annotate_defs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("render (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_fp,&__pyx_mstate_global->__pyx_n_u_name_2,&__pyx_mstate_global->__pyx_n_u_annotate_defs,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 479, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 479, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 479, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 479, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 479, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "render", 0) < (0)) __PYX_ERR(0, 479, __pyx_L3_error)
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_False)));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("render", 0, 3, 4, i); __PYX_ERR(0, 479, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 479, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 479, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 479, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 479, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_False)));
    }
    __pyx_v_self = values[0];
    __pyx_v_fp = values[1];
    __pyx_v_name = values[2];
    __pyx_v_annotate_defs = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("render", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 479, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.render", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_8render(__pyx_self, __pyx_v_self, __pyx_v_fp, __pyx_v_name, __pyx_v_annotate_defs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_8render(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fp, PyObject *__pyx_v_name, PyObject *__pyx_v_annotate_defs) {
  PyObject *__pyx_v_child = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("render", 0);

  /* "Cython/Compiler/FlowControl.py":481
 *     def render(self, fp, name, annotate_defs=False):
 *         """Render graphviz dot graph"""
 *         fp.write('digraph %s {\n' % name)             # <<<<<<<<<<<<<<
 *         fp.write(' node [shape=box];\n')
 *         for child in self.children:
*/
  __pyx_t_2 = __pyx_v_fp;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_digraph_s, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 481, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":482
 *         """Render graphviz dot graph"""
 *         fp.write('digraph %s {\n' % name)
 *         fp.write(' node [shape=box];\n')             # <<<<<<<<<<<<<<
 *         for child in self.children:
 *             child.render(fp, self, annotate_defs)
*/
  __pyx_t_3 = __pyx_v_fp;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_node_shape_box};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":483
 *         fp.write('digraph %s {\n' % name)
 *         fp.write(' node [shape=box];\n')
 *         for child in self.children:             # <<<<<<<<<<<<<<
 *             child.render(fp, self, annotate_defs)
 *         fp.write('}\n')
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 483, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 483, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_5;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 483, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5);
        #endif
        ++__pyx_t_5;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 483, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_6(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 483, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_child, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":484
 *         fp.write(' node [shape=box];\n')
 *         for child in self.children:
 *             child.render(fp, self, annotate_defs)             # <<<<<<<<<<<<<<
 *         fp.write('}\n')
 * 
*/
    __pyx_t_2 = __pyx_v_child;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_fp, __pyx_v_self, __pyx_v_annotate_defs};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_render, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":483
 *         fp.write('digraph %s {\n' % name)
 *         fp.write(' node [shape=box];\n')
 *         for child in self.children:             # <<<<<<<<<<<<<<
 *             child.render(fp, self, annotate_defs)
 *         fp.write('}\n')
*/
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":485
 *         for child in self.children:
 *             child.render(fp, self, annotate_defs)
 *         fp.write('}\n')             # <<<<<<<<<<<<<<
 * 
 *     def escape(self, text):
*/
  __pyx_t_1 = __pyx_v_fp;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__3};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":479
 *         return '\\n'.join([l.strip() for l in lines[start[1] - 1:stop[1]]])
 * 
 *     def render(self, fp, name, annotate_defs=False):             # <<<<<<<<<<<<<<
 *         """Render graphviz dot graph"""
 *         fp.write('digraph %s {\n' % name)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.render", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_child);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":487
 *         fp.write('}\n')
 * 
 *     def escape(self, text):             # <<<<<<<<<<<<<<
 *         return text.replace('"', '\\"').replace('\n', '\\n')
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_11escape(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_11escape = {"escape", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_11escape, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9GVContext_11escape(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_text = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("escape (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_text,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 487, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 487, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 487, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "escape", 0) < (0)) __PYX_ERR(0, 487, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("escape", 1, 2, 2, i); __PYX_ERR(0, 487, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 487, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 487, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_text = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("escape", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 487, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.escape", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_10escape(__pyx_self, __pyx_v_self, __pyx_v_text);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_9GVContext_10escape(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("escape", 0);

  /* "Cython/Compiler/FlowControl.py":488
 * 
 *     def escape(self, text):
 *         return text.replace('"', '\\"').replace('\n', '\\n')             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_text, __pyx_mstate_global->__pyx_n_u_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[0], NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[1], NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":487
 *         fp.write('}\n')
 * 
 *     def escape(self, text):             # <<<<<<<<<<<<<<
 *         return text.replace('"', '\\"').replace('\n', '\\n')
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GVContext.escape", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":494
 *     """Graphviz DOT renderer."""
 * 
 *     def __init__(self, name, flow):             # <<<<<<<<<<<<<<
 *         self.name = name
 *         self.flow = flow
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_2GV_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_2GV_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_2GV_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_2GV_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_flow = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_name_2,&__pyx_mstate_global->__pyx_n_u_flow,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 494, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 494, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 494, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 494, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 494, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, i); __PYX_ERR(0, 494, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 494, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 494, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 494, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_flow = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 494, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GV.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_2GV___init__(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_flow);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_2GV___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_flow) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":495
 * 
 *     def __init__(self, name, flow):
 *         self.name = name             # <<<<<<<<<<<<<<
 *         self.flow = flow
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_v_name) < (0)) __PYX_ERR(0, 495, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":496
 *     def __init__(self, name, flow):
 *         self.name = name
 *         self.flow = flow             # <<<<<<<<<<<<<<
 * 
 *     def render(self, fp, ctx, annotate_defs=False):
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_flow, __pyx_v_flow) < (0)) __PYX_ERR(0, 496, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":494
 *     """Graphviz DOT renderer."""
 * 
 *     def __init__(self, name, flow):             # <<<<<<<<<<<<<<
 *         self.name = name
 *         self.flow = flow
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GV.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":498
 *         self.flow = flow
 * 
 *     def render(self, fp, ctx, annotate_defs=False):             # <<<<<<<<<<<<<<
 *         fp.write(' subgraph %s {\n' % self.name)
 *         for block in self.flow.blocks:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_2GV_3render(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_2GV_3render = {"render", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_2GV_3render, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_2GV_3render(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fp = 0;
  PyObject *__pyx_v_ctx = 0;
  PyObject *__pyx_v_annotate_defs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("render (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_fp,&__pyx_mstate_global->__pyx_n_u_ctx,&__pyx_mstate_global->__pyx_n_u_annotate_defs,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 498, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 498, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 498, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 498, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 498, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "render", 0) < (0)) __PYX_ERR(0, 498, __pyx_L3_error)
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_False)));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("render", 0, 3, 4, i); __PYX_ERR(0, 498, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 498, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 498, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 498, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 498, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_False)));
    }
    __pyx_v_self = values[0];
    __pyx_v_fp = values[1];
    __pyx_v_ctx = values[2];
    __pyx_v_annotate_defs = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("render", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 498, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GV.render", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_2GV_2render(__pyx_self, __pyx_v_self, __pyx_v_fp, __pyx_v_ctx, __pyx_v_annotate_defs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_2GV_2render(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fp, PyObject *__pyx_v_ctx, PyObject *__pyx_v_annotate_defs) {
  PyObject *__pyx_v_block = NULL;
  PyObject *__pyx_v_label = NULL;
  PyObject *__pyx_v_stat = NULL;
  PyObject *__pyx_v_pid = NULL;
  PyObject *__pyx_v_child = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13[7];
  PyObject *__pyx_t_14[5];
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("render", 0);

  /* "Cython/Compiler/FlowControl.py":499
 * 
 *     def render(self, fp, ctx, annotate_defs=False):
 *         fp.write(' subgraph %s {\n' % self.name)             # <<<<<<<<<<<<<<
 *         for block in self.flow.blocks:
 *             label = ctx.extract_sources(block)
*/
  __pyx_t_2 = __pyx_v_fp;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_subgraph_s, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":500
 *     def render(self, fp, ctx, annotate_defs=False):
 *         fp.write(' subgraph %s {\n' % self.name)
 *         for block in self.flow.blocks:             # <<<<<<<<<<<<<<
 *             label = ctx.extract_sources(block)
 *             if annotate_defs:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_flow); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_blocks); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 500, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 500, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_6;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 500, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6);
        #endif
        ++__pyx_t_6;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 500, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_7(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 500, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_block, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":501
 *         fp.write(' subgraph %s {\n' % self.name)
 *         for block in self.flow.blocks:
 *             label = ctx.extract_sources(block)             # <<<<<<<<<<<<<<
 *             if annotate_defs:
 *                 for stat in block.stats:
*/
    __pyx_t_2 = __pyx_v_ctx;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_block};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_extract_sources, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_label, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":502
 *         for block in self.flow.blocks:
 *             label = ctx.extract_sources(block)
 *             if annotate_defs:             # <<<<<<<<<<<<<<
 *                 for stat in block.stats:
 *                     if isinstance(stat, NameAssignment):
*/
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_annotate_defs); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 502, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "Cython/Compiler/FlowControl.py":503
 *             label = ctx.extract_sources(block)
 *             if annotate_defs:
 *                 for stat in block.stats:             # <<<<<<<<<<<<<<
 *                     if isinstance(stat, NameAssignment):
 *                         label += '\n %s [%s %s]' % (
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_block, __pyx_mstate_global->__pyx_n_u_stats); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 503, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_2 = __pyx_t_4; __Pyx_INCREF(__pyx_t_2);
        __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
      } else {
        __pyx_t_9 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_10 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 503, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_10)) {
          if (likely(PyList_CheckExact(__pyx_t_2))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 503, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_9;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 503, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_9));
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_9);
            #endif
            ++__pyx_t_9;
          }
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 503, __pyx_L1_error)
        } else {
          __pyx_t_4 = __pyx_t_10(__pyx_t_2);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 503, __pyx_L1_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_stat, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Compiler/FlowControl.py":504
 *             if annotate_defs:
 *                 for stat in block.stats:
 *                     if isinstance(stat, NameAssignment):             # <<<<<<<<<<<<<<
 *                         label += '\n %s [%s %s]' % (
 *                             stat.entry.name, 'deletion' if stat.is_deletion else 'definition', stat.pos[1])
*/
        __pyx_t_8 = __Pyx_TypeCheck(__pyx_v_stat, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment); 
        if (__pyx_t_8) {

          /* "Cython/Compiler/FlowControl.py":506
 *                     if isinstance(stat, NameAssignment):
 *                         label += '\n %s [%s %s]' % (
 *                             stat.entry.name, 'deletion' if stat.is_deletion else 'definition', stat.pos[1])             # <<<<<<<<<<<<<<
 *                     elif isinstance(stat, NameReference):
 *                         if stat.entry:
*/
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_is_deletion); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (__pyx_t_8) {
            __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_deletion);
            __pyx_t_3 = __pyx_mstate_global->__pyx_n_u_deletion;
          } else {
            __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_definition);
            __pyx_t_3 = __pyx_mstate_global->__pyx_n_u_definition;
          }
          __pyx_t_11 = __Pyx_PyUnicode_Unicode(__pyx_t_3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_12), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_13[0] = __pyx_mstate_global->__pyx_kp_u__7;
          __pyx_t_13[1] = __pyx_t_4;
          __pyx_t_13[2] = __pyx_mstate_global->__pyx_kp_u__8;
          __pyx_t_13[3] = __pyx_t_11;
          __pyx_t_13[4] = __pyx_mstate_global->__pyx_kp_u__9;
          __pyx_t_13[5] = __pyx_t_3;
          __pyx_t_13[6] = __pyx_mstate_global->__pyx_kp_u__10;

          /* "Cython/Compiler/FlowControl.py":505
 *                 for stat in block.stats:
 *                     if isinstance(stat, NameAssignment):
 *                         label += '\n %s [%s %s]' % (             # <<<<<<<<<<<<<<
 *                             stat.entry.name, 'deletion' if stat.is_deletion else 'definition', stat.pos[1])
 *                     elif isinstance(stat, NameReference):
*/
          __pyx_t_12 = __Pyx_PyUnicode_Join(__pyx_t_13, 7, 2 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 505, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_label, __pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 505, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_label, __pyx_t_3);
          __pyx_t_3 = 0;

          /* "Cython/Compiler/FlowControl.py":504
 *             if annotate_defs:
 *                 for stat in block.stats:
 *                     if isinstance(stat, NameAssignment):             # <<<<<<<<<<<<<<
 *                         label += '\n %s [%s %s]' % (
 *                             stat.entry.name, 'deletion' if stat.is_deletion else 'definition', stat.pos[1])
*/
          goto __pyx_L8;
        }

        /* "Cython/Compiler/FlowControl.py":507
 *                         label += '\n %s [%s %s]' % (
 *                             stat.entry.name, 'deletion' if stat.is_deletion else 'definition', stat.pos[1])
 *                     elif isinstance(stat, NameReference):             # <<<<<<<<<<<<<<
 *                         if stat.entry:
 *                             label += '\n %s [reference %s]' % (stat.entry.name, stat.pos[1])
*/
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_NameReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 507, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = PyObject_IsInstance(__pyx_v_stat, __pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 507, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_8) {

          /* "Cython/Compiler/FlowControl.py":508
 *                             stat.entry.name, 'deletion' if stat.is_deletion else 'definition', stat.pos[1])
 *                     elif isinstance(stat, NameReference):
 *                         if stat.entry:             # <<<<<<<<<<<<<<
 *                             label += '\n %s [reference %s]' % (stat.entry.name, stat.pos[1])
 *             if not label:
*/
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 508, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 508, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (__pyx_t_8) {

            /* "Cython/Compiler/FlowControl.py":509
 *                     elif isinstance(stat, NameReference):
 *                         if stat.entry:
 *                             label += '\n %s [reference %s]' % (stat.entry.name, stat.pos[1])             # <<<<<<<<<<<<<<
 *             if not label:
 *                 label = 'empty'
*/
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 509, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 509, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_12), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 509, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 509, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_11 = __Pyx_GetItemInt(__pyx_t_12, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 509, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_11), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 509, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __pyx_t_14[0] = __pyx_mstate_global->__pyx_kp_u__7;
            __pyx_t_14[1] = __pyx_t_3;
            __pyx_t_14[2] = __pyx_mstate_global->__pyx_kp_u_reference;
            __pyx_t_14[3] = __pyx_t_12;
            __pyx_t_14[4] = __pyx_mstate_global->__pyx_kp_u__10;
            __pyx_t_11 = __Pyx_PyUnicode_Join(__pyx_t_14, 5, 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 12 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_12) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_12));
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 509, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = PyNumber_InPlaceAdd(__pyx_v_label, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 509, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF_SET(__pyx_v_label, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "Cython/Compiler/FlowControl.py":508
 *                             stat.entry.name, 'deletion' if stat.is_deletion else 'definition', stat.pos[1])
 *                     elif isinstance(stat, NameReference):
 *                         if stat.entry:             # <<<<<<<<<<<<<<
 *                             label += '\n %s [reference %s]' % (stat.entry.name, stat.pos[1])
 *             if not label:
*/
          }

          /* "Cython/Compiler/FlowControl.py":507
 *                         label += '\n %s [%s %s]' % (
 *                             stat.entry.name, 'deletion' if stat.is_deletion else 'definition', stat.pos[1])
 *                     elif isinstance(stat, NameReference):             # <<<<<<<<<<<<<<
 *                         if stat.entry:
 *                             label += '\n %s [reference %s]' % (stat.entry.name, stat.pos[1])
*/
        }
        __pyx_L8:;

        /* "Cython/Compiler/FlowControl.py":503
 *             label = ctx.extract_sources(block)
 *             if annotate_defs:
 *                 for stat in block.stats:             # <<<<<<<<<<<<<<
 *                     if isinstance(stat, NameAssignment):
 *                         label += '\n %s [%s %s]' % (
*/
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":502
 *         for block in self.flow.blocks:
 *             label = ctx.extract_sources(block)
 *             if annotate_defs:             # <<<<<<<<<<<<<<
 *                 for stat in block.stats:
 *                     if isinstance(stat, NameAssignment):
*/
    }

    /* "Cython/Compiler/FlowControl.py":510
 *                         if stat.entry:
 *                             label += '\n %s [reference %s]' % (stat.entry.name, stat.pos[1])
 *             if not label:             # <<<<<<<<<<<<<<
 *                 label = 'empty'
 *             pid = ctx.nodeid(block)
*/
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_label); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 510, __pyx_L1_error)
    __pyx_t_15 = (!__pyx_t_8);
    if (__pyx_t_15) {

      /* "Cython/Compiler/FlowControl.py":511
 *                             label += '\n %s [reference %s]' % (stat.entry.name, stat.pos[1])
 *             if not label:
 *                 label = 'empty'             # <<<<<<<<<<<<<<
 *             pid = ctx.nodeid(block)
 *             fp.write('  %s [label="%s"];\n' % (pid, ctx.escape(label)))
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_empty);
      __Pyx_DECREF_SET(__pyx_v_label, __pyx_mstate_global->__pyx_n_u_empty);

      /* "Cython/Compiler/FlowControl.py":510
 *                         if stat.entry:
 *                             label += '\n %s [reference %s]' % (stat.entry.name, stat.pos[1])
 *             if not label:             # <<<<<<<<<<<<<<
 *                 label = 'empty'
 *             pid = ctx.nodeid(block)
*/
    }

    /* "Cython/Compiler/FlowControl.py":512
 *             if not label:
 *                 label = 'empty'
 *             pid = ctx.nodeid(block)             # <<<<<<<<<<<<<<
 *             fp.write('  %s [label="%s"];\n' % (pid, ctx.escape(label)))
 *         for block in self.flow.blocks:
*/
    __pyx_t_12 = __pyx_v_ctx;
    __Pyx_INCREF(__pyx_t_12);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_block};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_nodeid, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_pid, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":513
 *                 label = 'empty'
 *             pid = ctx.nodeid(block)
 *             fp.write('  %s [label="%s"];\n' % (pid, ctx.escape(label)))             # <<<<<<<<<<<<<<
 *         for block in self.flow.blocks:
 *             pid = ctx.nodeid(block)
*/
    __pyx_t_12 = __pyx_v_fp;
    __Pyx_INCREF(__pyx_t_12);
    __pyx_t_11 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_pid), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_escape); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_label); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_4), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_14[0] = __pyx_mstate_global->__pyx_kp_u__11;
    __pyx_t_14[1] = __pyx_t_11;
    __pyx_t_14[2] = __pyx_mstate_global->__pyx_kp_u_label;
    __pyx_t_14[3] = __pyx_t_3;
    __pyx_t_14[4] = __pyx_mstate_global->__pyx_kp_u__12;
    __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_14, 5, 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11) + 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 4, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":500
 *     def render(self, fp, ctx, annotate_defs=False):
 *         fp.write(' subgraph %s {\n' % self.name)
 *         for block in self.flow.blocks:             # <<<<<<<<<<<<<<
 *             label = ctx.extract_sources(block)
 *             if annotate_defs:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":514
 *             pid = ctx.nodeid(block)
 *             fp.write('  %s [label="%s"];\n' % (pid, ctx.escape(label)))
 *         for block in self.flow.blocks:             # <<<<<<<<<<<<<<
 *             pid = ctx.nodeid(block)
 *             for child in block.children:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_flow); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_blocks); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 514, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 514, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_6;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 514, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6));
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6);
        #endif
        ++__pyx_t_6;
      }
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
    } else {
      __pyx_t_2 = __pyx_t_7(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 514, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_block, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":515
 *             fp.write('  %s [label="%s"];\n' % (pid, ctx.escape(label)))
 *         for block in self.flow.blocks:
 *             pid = ctx.nodeid(block)             # <<<<<<<<<<<<<<
 *             for child in block.children:
 *                 fp.write('  %s -> %s;\n' % (pid, ctx.nodeid(child)))
*/
    __pyx_t_4 = __pyx_v_ctx;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_block};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_nodeid, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_pid, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":516
 *         for block in self.flow.blocks:
 *             pid = ctx.nodeid(block)
 *             for child in block.children:             # <<<<<<<<<<<<<<
 *                 fp.write('  %s -> %s;\n' % (pid, ctx.nodeid(child)))
 *         fp.write(' }\n')
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_block, __pyx_mstate_global->__pyx_n_u_children); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_4 = __pyx_t_2; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_9 = 0;
      __pyx_t_10 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 516, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_10)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 516, __pyx_L1_error)
            #endif
            if (__pyx_t_9 >= __pyx_temp) break;
          }
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_9;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 516, __pyx_L1_error)
            #endif
            if (__pyx_t_9 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_9));
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_9);
          #endif
          ++__pyx_t_9;
        }
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 516, __pyx_L1_error)
      } else {
        __pyx_t_2 = __pyx_t_10(__pyx_t_4);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 516, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_child, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":517
 *             pid = ctx.nodeid(block)
 *             for child in block.children:
 *                 fp.write('  %s -> %s;\n' % (pid, ctx.nodeid(child)))             # <<<<<<<<<<<<<<
 *         fp.write(' }\n')
 * 
*/
      __pyx_t_12 = __pyx_v_fp;
      __Pyx_INCREF(__pyx_t_12);
      __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_pid), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_nodeid); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_16 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_child); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_16), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_14[0] = __pyx_mstate_global->__pyx_kp_u__11;
      __pyx_t_14[1] = __pyx_t_3;
      __pyx_t_14[2] = __pyx_mstate_global->__pyx_kp_u__13;
      __pyx_t_14[3] = __pyx_t_11;
      __pyx_t_14[4] = __pyx_mstate_global->__pyx_kp_u__14;
      __pyx_t_16 = __Pyx_PyUnicode_Join(__pyx_t_14, 5, 2 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 4 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11));
      if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_16};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 517, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":516
 *         for block in self.flow.blocks:
 *             pid = ctx.nodeid(block)
 *             for child in block.children:             # <<<<<<<<<<<<<<
 *                 fp.write('  %s -> %s;\n' % (pid, ctx.nodeid(child)))
 *         fp.write(' }\n')
*/
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":514
 *             pid = ctx.nodeid(block)
 *             fp.write('  %s [label="%s"];\n' % (pid, ctx.escape(label)))
 *         for block in self.flow.blocks:             # <<<<<<<<<<<<<<
 *             pid = ctx.nodeid(block)
 *             for child in block.children:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":518
 *             for child in block.children:
 *                 fp.write('  %s -> %s;\n' % (pid, ctx.nodeid(child)))
 *         fp.write(' }\n')             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_4 = __pyx_v_fp;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__15};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":498
 *         self.flow = flow
 * 
 *     def render(self, fp, ctx, annotate_defs=False):             # <<<<<<<<<<<<<<
 *         fp.write(' subgraph %s {\n' % self.name)
 *         for block in self.flow.blocks:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.GV.render", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_block);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_XDECREF(__pyx_v_stat);
  __Pyx_XDECREF(__pyx_v_pid);
  __Pyx_XDECREF(__pyx_v_child);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":523
 * class MessageCollection:
 *     """Collect error/warnings messages first then sort"""
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.messages = set()
 * 
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection___init__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":524
 *     """Collect error/warnings messages first then sort"""
 *     def __init__(self):
 *         self.messages = set()             # <<<<<<<<<<<<<<
 * 
 *     def error(self, pos, message):
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->messages);
  __Pyx_DECREF(__pyx_v_self->messages);
  __pyx_v_self->messages = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":523
 * class MessageCollection:
 *     """Collect error/warnings messages first then sort"""
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.messages = set()
 * 
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.MessageCollection.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":526
 *         self.messages = set()
 * 
 *     def error(self, pos, message):             # <<<<<<<<<<<<<<
 *         self.messages.add((pos, True, message))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_3error(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_3error = {"error", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_3error, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_3error(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_pos = 0;
  PyObject *__pyx_v_message = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("error (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pos,&__pyx_mstate_global->__pyx_n_u_message,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 526, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 526, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 526, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "error", 0) < (0)) __PYX_ERR(0, 526, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("error", 1, 2, 2, i); __PYX_ERR(0, 526, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 526, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 526, __pyx_L3_error)
    }
    __pyx_v_pos = values[0];
    __pyx_v_message = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("error", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 526, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.MessageCollection.error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_2error(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)__pyx_v_self), __pyx_v_pos, __pyx_v_message);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_2error(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self, PyObject *__pyx_v_pos, PyObject *__pyx_v_message) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("error", 0);

  /* "Cython/Compiler/FlowControl.py":527
 * 
 *     def error(self, pos, message):
 *         self.messages.add((pos, True, message))             # <<<<<<<<<<<<<<
 * 
 *     def warning(self, pos, message):
*/
  if (unlikely(__pyx_v_self->messages == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(0, 527, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_pos);
  __Pyx_GIVEREF(__pyx_v_pos);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_pos) != (0)) __PYX_ERR(0, 527, __pyx_L1_error);
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_True) != (0)) __PYX_ERR(0, 527, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_message);
  __Pyx_GIVEREF(__pyx_v_message);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_message) != (0)) __PYX_ERR(0, 527, __pyx_L1_error);
  __pyx_t_2 = PySet_Add(__pyx_v_self->messages, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":526
 *         self.messages = set()
 * 
 *     def error(self, pos, message):             # <<<<<<<<<<<<<<
 *         self.messages.add((pos, True, message))
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.MessageCollection.error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":529
 *         self.messages.add((pos, True, message))
 * 
 *     def warning(self, pos, message):             # <<<<<<<<<<<<<<
 *         self.messages.add((pos, False, message))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_5warning(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_5warning = {"warning", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_5warning, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_5warning(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_pos = 0;
  PyObject *__pyx_v_message = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("warning (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pos,&__pyx_mstate_global->__pyx_n_u_message,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 529, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 529, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 529, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "warning", 0) < (0)) __PYX_ERR(0, 529, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("warning", 1, 2, 2, i); __PYX_ERR(0, 529, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 529, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 529, __pyx_L3_error)
    }
    __pyx_v_pos = values[0];
    __pyx_v_message = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("warning", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 529, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.MessageCollection.warning", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_4warning(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)__pyx_v_self), __pyx_v_pos, __pyx_v_message);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_4warning(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self, PyObject *__pyx_v_pos, PyObject *__pyx_v_message) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("warning", 0);

  /* "Cython/Compiler/FlowControl.py":530
 * 
 *     def warning(self, pos, message):
 *         self.messages.add((pos, False, message))             # <<<<<<<<<<<<<<
 * 
 *     def report(self):
*/
  if (unlikely(__pyx_v_self->messages == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(0, 530, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_pos);
  __Pyx_GIVEREF(__pyx_v_pos);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_pos) != (0)) __PYX_ERR(0, 530, __pyx_L1_error);
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_False) != (0)) __PYX_ERR(0, 530, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_message);
  __Pyx_GIVEREF(__pyx_v_message);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_message) != (0)) __PYX_ERR(0, 530, __pyx_L1_error);
  __pyx_t_2 = PySet_Add(__pyx_v_self->messages, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":529
 *         self.messages.add((pos, True, message))
 * 
 *     def warning(self, pos, message):             # <<<<<<<<<<<<<<
 *         self.messages.add((pos, False, message))
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.MessageCollection.warning", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":532
 *         self.messages.add((pos, False, message))
 * 
 *     def report(self):             # <<<<<<<<<<<<<<
 *         for pos, is_error, message in sorted(self.messages):
 *             if is_error:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_7report(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_7report = {"report", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_7report, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_7report(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("report (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_6report(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_6report(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_is_error = NULL;
  PyObject *__pyx_v_message = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("report", 0);

  /* "Cython/Compiler/FlowControl.py":533
 * 
 *     def report(self):
 *         for pos, is_error, message in sorted(self.messages):             # <<<<<<<<<<<<<<
 *             if is_error:
 *                 error(pos, message)
*/
  __pyx_t_1 = __pyx_v_self->messages;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyList_Sort(__pyx_t_2) < 0))) __PYX_ERR(0, 533, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 533, __pyx_L1_error)
      #endif
      if (__pyx_t_3 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_3;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 533, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2);
        __Pyx_INCREF(__pyx_t_6);
      } else {
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 533, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 533, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 533, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
      }
      #else
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 533, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 533, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 533, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 533, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 2; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 3) < (0)) __PYX_ERR(0, 533, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 533, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_pos, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_is_error, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_message, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/FlowControl.py":534
 *     def report(self):
 *         for pos, is_error, message in sorted(self.messages):
 *             if is_error:             # <<<<<<<<<<<<<<
 *                 error(pos, message)
 *             else:
*/
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_is_error); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 534, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "Cython/Compiler/FlowControl.py":535
 *         for pos, is_error, message in sorted(self.messages):
 *             if is_error:
 *                 error(pos, message)             # <<<<<<<<<<<<<<
 *             else:
 *                 warning(pos, message, 2)
*/
      __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_error);
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_11FlowControl_error; 
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_pos, __pyx_v_message};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_10, (3-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":534
 *     def report(self):
 *         for pos, is_error, message in sorted(self.messages):
 *             if is_error:             # <<<<<<<<<<<<<<
 *                 error(pos, message)
 *             else:
*/
      goto __pyx_L7;
    }

    /* "Cython/Compiler/FlowControl.py":537
 *                 error(pos, message)
 *             else:
 *                 warning(pos, message, 2)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    /*else*/ {
      __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_warning);
      __pyx_t_6 = __pyx_v_6Cython_8Compiler_11FlowControl_warning; 
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_pos, __pyx_v_message, __pyx_mstate_global->__pyx_int_2};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_10, (4-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 537, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L7:;

    /* "Cython/Compiler/FlowControl.py":533
 * 
 *     def report(self):
 *         for pos, is_error, message in sorted(self.messages):             # <<<<<<<<<<<<<<
 *             if is_error:
 *                 error(pos, message)
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":532
 *         self.messages.add((pos, False, message))
 * 
 *     def report(self):             # <<<<<<<<<<<<<<
 *         for pos, is_error, message in sorted(self.messages):
 *             if is_error:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.MessageCollection.report", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_is_error);
  __Pyx_XDECREF(__pyx_v_message);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_9__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_8__reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_8__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.messages,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->messages);
  __Pyx_GIVEREF(__pyx_v_self->messages);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->messages) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.messages,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.messages,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.messages is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.messages,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.messages is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, None), state
*/
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->messages != ((PyObject*)Py_None));
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.messages is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.messages is not None
 *     if use_setstate:
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_MessageCollection); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_257740027);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_257740027);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_257740027) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.messages is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, None), state
 *     else:
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_MessageCollection__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_MessageCollection); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_257740027);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_257740027);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_257740027) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.MessageCollection.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_MessageCollection__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_11__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_10__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_17MessageCollection_10__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_MessageCollection__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_MessageCollection__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_MessageCollection__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.MessageCollection.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":540
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def check_definitions(flow: ControlFlow, compiler_directives: dict):
 *     flow.initialize()
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_check_definitions(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v_flow, PyObject *__pyx_v_compiler_directives) {
  PyObject *__pyx_v_assignments = NULL;
  PyObject *__pyx_v_references = NULL;
  PyObject *__pyx_v_assmt_nodes = NULL;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_block = 0;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v_assmt = 0;
  PyObject *__pyx_v_i_state = NULL;
  PyObject *__pyx_v_stat = NULL;
  PyObject *__pyx_v_i_assmts = NULL;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v_warn_maybe_uninitialized = NULL;
  PyObject *__pyx_v_warn_unused_result = NULL;
  PyObject *__pyx_v_warn_unused = NULL;
  PyObject *__pyx_v_warn_unused_arg = NULL;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v_messages = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  size_t __pyx_t_13;
  int __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_definitions", 0);

  /* "Cython/Compiler/FlowControl.py":542
 * @cython.cfunc
 * def check_definitions(flow: ControlFlow, compiler_directives: dict):
 *     flow.initialize()             # <<<<<<<<<<<<<<
 *     flow.reaching_definitions()
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_initialize(__pyx_v_flow, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":543
 * def check_definitions(flow: ControlFlow, compiler_directives: dict):
 *     flow.initialize()
 *     flow.reaching_definitions()             # <<<<<<<<<<<<<<
 * 
 *     # Track down state
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_reaching_definitions(__pyx_v_flow); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":546
 * 
 *     # Track down state
 *     assignments = set()             # <<<<<<<<<<<<<<
 *     # Node to entry map
 *     references = {}
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_assignments = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":548
 *     assignments = set()
 *     # Node to entry map
 *     references = {}             # <<<<<<<<<<<<<<
 *     assmt_nodes = set()
 * 
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_references = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":549
 *     # Node to entry map
 *     references = {}
 *     assmt_nodes = set()             # <<<<<<<<<<<<<<
 * 
 *     block: ControlBlock
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_assmt_nodes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":553
 *     block: ControlBlock
 *     assmt: NameAssignment
 *     for block in flow.blocks:             # <<<<<<<<<<<<<<
 *         i_state = block.i_input
 *         for stat in block.stats:
*/
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_set_iterator(__pyx_v_flow->blocks, 1, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_block, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":554
 *     assmt: NameAssignment
 *     for block in flow.blocks:
 *         i_state = block.i_input             # <<<<<<<<<<<<<<
 *         for stat in block.stats:
 *             i_assmts = flow.assmts[stat.entry]
*/
    __pyx_t_5 = __pyx_v_block->i_input;
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_i_state, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":555
 *     for block in flow.blocks:
 *         i_state = block.i_input
 *         for stat in block.stats:             # <<<<<<<<<<<<<<
 *             i_assmts = flow.assmts[stat.entry]
 *             state = flow.map_one(i_state, stat.entry)
*/
    if (unlikely(__pyx_v_block->stats == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 555, __pyx_L1_error)
    }
    __pyx_t_5 = __pyx_v_block->stats; __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 555, __pyx_L1_error)
        #endif
        if (__pyx_t_7 >= __pyx_temp) break;
      }
      __pyx_t_8 = __Pyx_PyList_GetItemRefFast(__pyx_t_5, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_7;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 555, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_stat, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "Cython/Compiler/FlowControl.py":556
 *         i_state = block.i_input
 *         for stat in block.stats:
 *             i_assmts = flow.assmts[stat.entry]             # <<<<<<<<<<<<<<
 *             state = flow.map_one(i_state, stat.entry)
 *             if isinstance(stat, NameAssignment):
*/
      if (unlikely(__pyx_v_flow->assmts == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 556, __pyx_L1_error)
      }
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyDict_GetItem(__pyx_v_flow->assmts, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF_SET(__pyx_v_i_assmts, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "Cython/Compiler/FlowControl.py":557
 *         for stat in block.stats:
 *             i_assmts = flow.assmts[stat.entry]
 *             state = flow.map_one(i_state, stat.entry)             # <<<<<<<<<<<<<<
 *             if isinstance(stat, NameAssignment):
 *                 stat.lhs.cf_state.update(state)
*/
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_map_one(__pyx_v_flow, __pyx_v_i_state, __pyx_t_9, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_8));
      __pyx_t_8 = 0;

      /* "Cython/Compiler/FlowControl.py":558
 *             i_assmts = flow.assmts[stat.entry]
 *             state = flow.map_one(i_state, stat.entry)
 *             if isinstance(stat, NameAssignment):             # <<<<<<<<<<<<<<
 *                 stat.lhs.cf_state.update(state)
 *                 assmt_nodes.add(stat.lhs)
*/
      __pyx_t_10 = __Pyx_TypeCheck(__pyx_v_stat, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment); 
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":559
 *             state = flow.map_one(i_state, stat.entry)
 *             if isinstance(stat, NameAssignment):
 *                 stat.lhs.cf_state.update(state)             # <<<<<<<<<<<<<<
 *                 assmt_nodes.add(stat.lhs)
 *                 i_state = i_state & ~i_assmts.mask
*/
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_lhs); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 559, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 559, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_9 = __pyx_t_12;
        __Pyx_INCREF(__pyx_t_9);
        __pyx_t_13 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_state};
          __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 559, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "Cython/Compiler/FlowControl.py":560
 *             if isinstance(stat, NameAssignment):
 *                 stat.lhs.cf_state.update(state)
 *                 assmt_nodes.add(stat.lhs)             # <<<<<<<<<<<<<<
 *                 i_state = i_state & ~i_assmts.mask
 *                 if stat.is_deletion:
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_lhs); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 560, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_14 = PySet_Add(__pyx_v_assmt_nodes, __pyx_t_8); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 560, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "Cython/Compiler/FlowControl.py":561
 *                 stat.lhs.cf_state.update(state)
 *                 assmt_nodes.add(stat.lhs)
 *                 i_state = i_state & ~i_assmts.mask             # <<<<<<<<<<<<<<
 *                 if stat.is_deletion:
 *                     i_state |= i_assmts.bit
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_i_assmts, __pyx_mstate_global->__pyx_n_u_mask); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 561, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_12 = PyNumber_Invert(__pyx_t_8); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 561, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyNumber_And(__pyx_v_i_state, __pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 561, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF_SET(__pyx_v_i_state, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "Cython/Compiler/FlowControl.py":562
 *                 assmt_nodes.add(stat.lhs)
 *                 i_state = i_state & ~i_assmts.mask
 *                 if stat.is_deletion:             # <<<<<<<<<<<<<<
 *                     i_state |= i_assmts.bit
 *                 else:
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_is_deletion); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 562, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 562, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_10) {

          /* "Cython/Compiler/FlowControl.py":563
 *                 i_state = i_state & ~i_assmts.mask
 *                 if stat.is_deletion:
 *                     i_state |= i_assmts.bit             # <<<<<<<<<<<<<<
 *                 else:
 *                     i_state |= stat.bit
*/
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_i_assmts, __pyx_mstate_global->__pyx_n_u_bit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 563, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_12 = PyNumber_InPlaceOr(__pyx_v_i_state, __pyx_t_8); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 563, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF_SET(__pyx_v_i_state, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "Cython/Compiler/FlowControl.py":562
 *                 assmt_nodes.add(stat.lhs)
 *                 i_state = i_state & ~i_assmts.mask
 *                 if stat.is_deletion:             # <<<<<<<<<<<<<<
 *                     i_state |= i_assmts.bit
 *                 else:
*/
          goto __pyx_L8;
        }

        /* "Cython/Compiler/FlowControl.py":565
 *                     i_state |= i_assmts.bit
 *                 else:
 *                     i_state |= stat.bit             # <<<<<<<<<<<<<<
 *                 assignments.add(stat)
 *                 if stat.rhs is not fake_rhs_expr:
*/
        /*else*/ {
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_bit); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 565, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_8 = PyNumber_InPlaceOr(__pyx_v_i_state, __pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 565, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_i_state, __pyx_t_8);
          __pyx_t_8 = 0;
        }
        __pyx_L8:;

        /* "Cython/Compiler/FlowControl.py":566
 *                 else:
 *                     i_state |= stat.bit
 *                 assignments.add(stat)             # <<<<<<<<<<<<<<
 *                 if stat.rhs is not fake_rhs_expr:
 *                     stat.entry.cf_assignments.append(stat)
*/
        __pyx_t_14 = PySet_Add(__pyx_v_assignments, __pyx_v_stat); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 566, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":567
 *                     i_state |= stat.bit
 *                 assignments.add(stat)
 *                 if stat.rhs is not fake_rhs_expr:             # <<<<<<<<<<<<<<
 *                     stat.entry.cf_assignments.append(stat)
 *             elif isinstance(stat, NameReference):
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 567, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = (__pyx_t_8 != __pyx_v_6Cython_8Compiler_11FlowControl_fake_rhs_expr);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_10) {

          /* "Cython/Compiler/FlowControl.py":568
 *                 assignments.add(stat)
 *                 if stat.rhs is not fake_rhs_expr:
 *                     stat.entry.cf_assignments.append(stat)             # <<<<<<<<<<<<<<
 *             elif isinstance(stat, NameReference):
 *                 references[stat.node] = stat.entry
*/
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_cf_assignments); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_12, __pyx_v_stat); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "Cython/Compiler/FlowControl.py":567
 *                     i_state |= stat.bit
 *                 assignments.add(stat)
 *                 if stat.rhs is not fake_rhs_expr:             # <<<<<<<<<<<<<<
 *                     stat.entry.cf_assignments.append(stat)
 *             elif isinstance(stat, NameReference):
*/
        }

        /* "Cython/Compiler/FlowControl.py":558
 *             i_assmts = flow.assmts[stat.entry]
 *             state = flow.map_one(i_state, stat.entry)
 *             if isinstance(stat, NameAssignment):             # <<<<<<<<<<<<<<
 *                 stat.lhs.cf_state.update(state)
 *                 assmt_nodes.add(stat.lhs)
*/
        goto __pyx_L7;
      }

      /* "Cython/Compiler/FlowControl.py":569
 *                 if stat.rhs is not fake_rhs_expr:
 *                     stat.entry.cf_assignments.append(stat)
 *             elif isinstance(stat, NameReference):             # <<<<<<<<<<<<<<
 *                 references[stat.node] = stat.entry
 *                 stat.entry.cf_references.append(stat)
*/
      __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_NameReference); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_10 = PyObject_IsInstance(__pyx_v_stat, __pyx_t_12); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":570
 *                     stat.entry.cf_assignments.append(stat)
 *             elif isinstance(stat, NameReference):
 *                 references[stat.node] = stat.entry             # <<<<<<<<<<<<<<
 *                 stat.entry.cf_references.append(stat)
 *                 stat.node.cf_state.update(state)
*/
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 570, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_node); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 570, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely((PyDict_SetItem(__pyx_v_references, __pyx_t_8, __pyx_t_12) < 0))) __PYX_ERR(0, 570, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "Cython/Compiler/FlowControl.py":571
 *             elif isinstance(stat, NameReference):
 *                 references[stat.node] = stat.entry
 *                 stat.entry.cf_references.append(stat)             # <<<<<<<<<<<<<<
 *                 stat.node.cf_state.update(state)
 *                 ## if not stat.node.allow_null:
*/
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 571, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_cf_references); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 571, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_v_stat); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 571, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "Cython/Compiler/FlowControl.py":572
 *                 references[stat.node] = stat.entry
 *                 stat.entry.cf_references.append(stat)
 *                 stat.node.cf_state.update(state)             # <<<<<<<<<<<<<<
 *                 ## if not stat.node.allow_null:
 *                 ##     i_state &= ~i_assmts.bit
*/
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_node); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 572, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 572, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_12 = __pyx_t_11;
        __Pyx_INCREF(__pyx_t_12);
        __pyx_t_13 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_state};
          __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 572, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "Cython/Compiler/FlowControl.py":576
 *                 ##     i_state &= ~i_assmts.bit
 *                 ## # after successful read, the state is known to be initialised
 *                 state.discard(Uninitialized)             # <<<<<<<<<<<<<<
 *                 state.discard(Unknown)
 *                 for assmt in state:
*/
        if (unlikely(__pyx_v_state == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "discard");
          __PYX_ERR(0, 576, __pyx_L1_error)
        }
        __pyx_t_14 = __Pyx_PySet_Discard(__pyx_v_state, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized)); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 576, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":577
 *                 ## # after successful read, the state is known to be initialised
 *                 state.discard(Uninitialized)
 *                 state.discard(Unknown)             # <<<<<<<<<<<<<<
 *                 for assmt in state:
 *                     assmt.refs.add(stat)
*/
        if (unlikely(__pyx_v_state == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "discard");
          __PYX_ERR(0, 577, __pyx_L1_error)
        }
        __pyx_t_14 = __Pyx_PySet_Discard(__pyx_v_state, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown)); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 577, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":578
 *                 state.discard(Uninitialized)
 *                 state.discard(Unknown)
 *                 for assmt in state:             # <<<<<<<<<<<<<<
 *                     assmt.refs.add(stat)
 * 
*/
        __pyx_t_15 = 0;
        __pyx_t_11 = __Pyx_set_iterator(__pyx_v_state, 1, (&__pyx_t_16), (&__pyx_t_6)); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 578, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_XDECREF(__pyx_t_8);
        __pyx_t_8 = __pyx_t_11;
        __pyx_t_11 = 0;
        while (1) {
          __pyx_t_17 = __Pyx_set_iter_next(__pyx_t_8, __pyx_t_16, &__pyx_t_15, &__pyx_t_11, __pyx_t_6);
          if (unlikely(__pyx_t_17 == 0)) break;
          if (unlikely(__pyx_t_17 == -1)) __PYX_ERR(0, 578, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          if (!(likely(((__pyx_t_11) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_11, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment))))) __PYX_ERR(0, 578, __pyx_L1_error)
          __Pyx_XDECREF_SET(__pyx_v_assmt, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_t_11));
          __pyx_t_11 = 0;

          /* "Cython/Compiler/FlowControl.py":579
 *                 state.discard(Unknown)
 *                 for assmt in state:
 *                     assmt.refs.add(stat)             # <<<<<<<<<<<<<<
 * 
 *     # Check variable usage
*/
          if (unlikely(__pyx_v_assmt->refs == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
            __PYX_ERR(0, 579, __pyx_L1_error)
          }
          __pyx_t_14 = PySet_Add(__pyx_v_assmt->refs, __pyx_v_stat); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 579, __pyx_L1_error)
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "Cython/Compiler/FlowControl.py":569
 *                 if stat.rhs is not fake_rhs_expr:
 *                     stat.entry.cf_assignments.append(stat)
 *             elif isinstance(stat, NameReference):             # <<<<<<<<<<<<<<
 *                 references[stat.node] = stat.entry
 *                 stat.entry.cf_references.append(stat)
*/
      }
      __pyx_L7:;

      /* "Cython/Compiler/FlowControl.py":555
 *     for block in flow.blocks:
 *         i_state = block.i_input
 *         for stat in block.stats:             # <<<<<<<<<<<<<<
 *             i_assmts = flow.assmts[stat.entry]
 *             state = flow.map_one(i_state, stat.entry)
*/
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":582
 * 
 *     # Check variable usage
 *     warn_maybe_uninitialized = compiler_directives['warn.maybe_uninitialized']             # <<<<<<<<<<<<<<
 *     warn_unused_result = compiler_directives['warn.unused_result']
 *     warn_unused = compiler_directives['warn.unused']
*/
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_compiler_directives, __pyx_mstate_global->__pyx_kp_u_warn_maybe_uninitialized); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_warn_maybe_uninitialized = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":583
 *     # Check variable usage
 *     warn_maybe_uninitialized = compiler_directives['warn.maybe_uninitialized']
 *     warn_unused_result = compiler_directives['warn.unused_result']             # <<<<<<<<<<<<<<
 *     warn_unused = compiler_directives['warn.unused']
 *     warn_unused_arg = compiler_directives['warn.unused_arg']
*/
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_compiler_directives, __pyx_mstate_global->__pyx_kp_u_warn_unused_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_warn_unused_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":584
 *     warn_maybe_uninitialized = compiler_directives['warn.maybe_uninitialized']
 *     warn_unused_result = compiler_directives['warn.unused_result']
 *     warn_unused = compiler_directives['warn.unused']             # <<<<<<<<<<<<<<
 *     warn_unused_arg = compiler_directives['warn.unused_arg']
 * 
*/
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_compiler_directives, __pyx_mstate_global->__pyx_kp_u_warn_unused); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_warn_unused = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":585
 *     warn_unused_result = compiler_directives['warn.unused_result']
 *     warn_unused = compiler_directives['warn.unused']
 *     warn_unused_arg = compiler_directives['warn.unused_arg']             # <<<<<<<<<<<<<<
 * 
 *     messages = MessageCollection()
*/
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_compiler_directives, __pyx_mstate_global->__pyx_kp_u_warn_unused_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_warn_unused_arg = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":587
 *     warn_unused_arg = compiler_directives['warn.unused_arg']
 * 
 *     messages = MessageCollection()             # <<<<<<<<<<<<<<
 * 
 *     # assignment hints
*/
  __pyx_t_5 = NULL;
  __pyx_t_13 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection, __pyx_callargs+__pyx_t_13, (1-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_messages = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":590
 * 
 *     # assignment hints
 *     for node in assmt_nodes:             # <<<<<<<<<<<<<<
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True
*/
  __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_set_iterator(__pyx_v_assmt_nodes, 1, (&__pyx_t_2), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_2, &__pyx_t_3, &__pyx_t_5, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":591
 *     # assignment hints
 *     for node in assmt_nodes:
 *         if Uninitialized in node.cf_state:             # <<<<<<<<<<<<<<
 *             node.cf_maybe_null = True
 *             if len(node.cf_state) == 1:
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized), __pyx_t_5, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 591, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_10) {

      /* "Cython/Compiler/FlowControl.py":592
 *     for node in assmt_nodes:
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True             # <<<<<<<<<<<<<<
 *             if len(node.cf_state) == 1:
 *                 node.cf_is_null = True
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_True) < (0)) __PYX_ERR(0, 592, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":593
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True
 *             if len(node.cf_state) == 1:             # <<<<<<<<<<<<<<
 *                 node.cf_is_null = True
 *             else:
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 593, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_10 = (__pyx_t_7 == 1);
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":594
 *             node.cf_maybe_null = True
 *             if len(node.cf_state) == 1:
 *                 node.cf_is_null = True             # <<<<<<<<<<<<<<
 *             else:
 *                 node.cf_is_null = False
*/
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_is_null, Py_True) < (0)) __PYX_ERR(0, 594, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":593
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True
 *             if len(node.cf_state) == 1:             # <<<<<<<<<<<<<<
 *                 node.cf_is_null = True
 *             else:
*/
        goto __pyx_L16;
      }

      /* "Cython/Compiler/FlowControl.py":596
 *                 node.cf_is_null = True
 *             else:
 *                 node.cf_is_null = False             # <<<<<<<<<<<<<<
 *         elif Unknown in node.cf_state:
 *             node.cf_maybe_null = True
*/
      /*else*/ {
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_is_null, Py_False) < (0)) __PYX_ERR(0, 596, __pyx_L1_error)
      }
      __pyx_L16:;

      /* "Cython/Compiler/FlowControl.py":591
 *     # assignment hints
 *     for node in assmt_nodes:
 *         if Uninitialized in node.cf_state:             # <<<<<<<<<<<<<<
 *             node.cf_maybe_null = True
 *             if len(node.cf_state) == 1:
*/
      goto __pyx_L15;
    }

    /* "Cython/Compiler/FlowControl.py":597
 *             else:
 *                 node.cf_is_null = False
 *         elif Unknown in node.cf_state:             # <<<<<<<<<<<<<<
 *             node.cf_maybe_null = True
 *         else:
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown), __pyx_t_5, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_10) {

      /* "Cython/Compiler/FlowControl.py":598
 *                 node.cf_is_null = False
 *         elif Unknown in node.cf_state:
 *             node.cf_maybe_null = True             # <<<<<<<<<<<<<<
 *         else:
 *             node.cf_is_null = False
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_True) < (0)) __PYX_ERR(0, 598, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":597
 *             else:
 *                 node.cf_is_null = False
 *         elif Unknown in node.cf_state:             # <<<<<<<<<<<<<<
 *             node.cf_maybe_null = True
 *         else:
*/
      goto __pyx_L15;
    }

    /* "Cython/Compiler/FlowControl.py":600
 *             node.cf_maybe_null = True
 *         else:
 *             node.cf_is_null = False             # <<<<<<<<<<<<<<
 *             node.cf_maybe_null = False
 * 
*/
    /*else*/ {
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_is_null, Py_False) < (0)) __PYX_ERR(0, 600, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":601
 *         else:
 *             node.cf_is_null = False
 *             node.cf_maybe_null = False             # <<<<<<<<<<<<<<
 * 
 *     # Find uninitialized references and cf-hints
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_False) < (0)) __PYX_ERR(0, 601, __pyx_L1_error)
    }
    __pyx_L15:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":604
 * 
 *     # Find uninitialized references and cf-hints
 *     for node, entry in references.items():             # <<<<<<<<<<<<<<
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True
*/
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_references, 1, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_8, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "Cython/Compiler/FlowControl.py":605
 *     # Find uninitialized references and cf-hints
 *     for node, entry in references.items():
 *         if Uninitialized in node.cf_state:             # <<<<<<<<<<<<<<
 *             node.cf_maybe_null = True
 *             if (not entry.from_closure and len(node.cf_state) == 1
*/
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized), __pyx_t_8, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 605, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_10) {

      /* "Cython/Compiler/FlowControl.py":606
 *     for node, entry in references.items():
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True             # <<<<<<<<<<<<<<
 *             if (not entry.from_closure and len(node.cf_state) == 1
 *                     and entry.name not in entry.scope.scope_predefined_names):
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_True) < (0)) __PYX_ERR(0, 606, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":607
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True
 *             if (not entry.from_closure and len(node.cf_state) == 1             # <<<<<<<<<<<<<<
 *                     and entry.name not in entry.scope.scope_predefined_names):
 *                 node.cf_is_null = True
*/
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_from_closure); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 607, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_19 = (!__pyx_t_18);
      if (__pyx_t_19) {
      } else {
        __pyx_t_10 = __pyx_t_19;
        goto __pyx_L21_bool_binop_done;
      }

      /* "Cython/Compiler/FlowControl.py":608
 *             node.cf_maybe_null = True
 *             if (not entry.from_closure and len(node.cf_state) == 1
 *                     and entry.name not in entry.scope.scope_predefined_names):             # <<<<<<<<<<<<<<
 *                 node.cf_is_null = True
 *             if (node.allow_null or entry.from_closure
*/
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);

      /* "Cython/Compiler/FlowControl.py":607
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True
 *             if (not entry.from_closure and len(node.cf_state) == 1             # <<<<<<<<<<<<<<
 *                     and entry.name not in entry.scope.scope_predefined_names):
 *                 node.cf_is_null = True
*/
      __pyx_t_7 = PyObject_Length(__pyx_t_8); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 607, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_19 = (__pyx_t_7 == 1);
      if (__pyx_t_19) {
      } else {
        __pyx_t_10 = __pyx_t_19;
        goto __pyx_L21_bool_binop_done;
      }

      /* "Cython/Compiler/FlowControl.py":608
 *             node.cf_maybe_null = True
 *             if (not entry.from_closure and len(node.cf_state) == 1
 *                     and entry.name not in entry.scope.scope_predefined_names):             # <<<<<<<<<<<<<<
 *                 node.cf_is_null = True
 *             if (node.allow_null or entry.from_closure
*/
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 608, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 608, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_scope_predefined_names); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 608, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_19 = (__Pyx_PySequence_ContainsTF(__pyx_t_8, __pyx_t_11, Py_NE)); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 608, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_10 = __pyx_t_19;
      __pyx_L21_bool_binop_done:;

      /* "Cython/Compiler/FlowControl.py":607
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True
 *             if (not entry.from_closure and len(node.cf_state) == 1             # <<<<<<<<<<<<<<
 *                     and entry.name not in entry.scope.scope_predefined_names):
 *                 node.cf_is_null = True
*/
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":609
 *             if (not entry.from_closure and len(node.cf_state) == 1
 *                     and entry.name not in entry.scope.scope_predefined_names):
 *                 node.cf_is_null = True             # <<<<<<<<<<<<<<
 *             if (node.allow_null or entry.from_closure
 *                     or entry.is_pyclass_attr or entry.type.is_error):
*/
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_is_null, Py_True) < (0)) __PYX_ERR(0, 609, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":607
 *         if Uninitialized in node.cf_state:
 *             node.cf_maybe_null = True
 *             if (not entry.from_closure and len(node.cf_state) == 1             # <<<<<<<<<<<<<<
 *                     and entry.name not in entry.scope.scope_predefined_names):
 *                 node.cf_is_null = True
*/
      }

      /* "Cython/Compiler/FlowControl.py":610
 *                     and entry.name not in entry.scope.scope_predefined_names):
 *                 node.cf_is_null = True
 *             if (node.allow_null or entry.from_closure             # <<<<<<<<<<<<<<
 *                     or entry.is_pyclass_attr or entry.type.is_error):
 *                 pass  # Can be uninitialized here
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_allow_null); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 610, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (!__pyx_t_19) {
      } else {
        __pyx_t_10 = __pyx_t_19;
        goto __pyx_L25_bool_binop_done;
      }

      /* "Cython/Compiler/FlowControl.py":611
 *                 node.cf_is_null = True
 *             if (node.allow_null or entry.from_closure
 *                     or entry.is_pyclass_attr or entry.type.is_error):             # <<<<<<<<<<<<<<
 *                 pass  # Can be uninitialized here
 *             elif node.cf_is_null and not entry.in_closure:
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_from_closure); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);

      /* "Cython/Compiler/FlowControl.py":610
 *                     and entry.name not in entry.scope.scope_predefined_names):
 *                 node.cf_is_null = True
 *             if (node.allow_null or entry.from_closure             # <<<<<<<<<<<<<<
 *                     or entry.is_pyclass_attr or entry.type.is_error):
 *                 pass  # Can be uninitialized here
*/
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 610, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (!__pyx_t_19) {
      } else {
        __pyx_t_10 = __pyx_t_19;
        goto __pyx_L25_bool_binop_done;
      }

      /* "Cython/Compiler/FlowControl.py":611
 *                 node.cf_is_null = True
 *             if (node.allow_null or entry.from_closure
 *                     or entry.is_pyclass_attr or entry.type.is_error):             # <<<<<<<<<<<<<<
 *                 pass  # Can be uninitialized here
 *             elif node.cf_is_null and not entry.in_closure:
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_pyclass_attr); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 611, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 611, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (!__pyx_t_19) {
      } else {
        __pyx_t_10 = __pyx_t_19;
        goto __pyx_L25_bool_binop_done;
      }
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 611, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_is_error); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 611, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 611, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_10 = __pyx_t_19;
      __pyx_L25_bool_binop_done:;

      /* "Cython/Compiler/FlowControl.py":610
 *                     and entry.name not in entry.scope.scope_predefined_names):
 *                 node.cf_is_null = True
 *             if (node.allow_null or entry.from_closure             # <<<<<<<<<<<<<<
 *                     or entry.is_pyclass_attr or entry.type.is_error):
 *                 pass  # Can be uninitialized here
*/
      if (__pyx_t_10) {
        goto __pyx_L24;
      }

      /* "Cython/Compiler/FlowControl.py":613
 *                     or entry.is_pyclass_attr or entry.type.is_error):
 *                 pass  # Can be uninitialized here
 *             elif node.cf_is_null and not entry.in_closure:             # <<<<<<<<<<<<<<
 *                 if entry.error_on_uninitialized or (
 *                         Options.error_on_uninitialized and (
*/
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_is_null); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 613, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 613, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (__pyx_t_19) {
      } else {
        __pyx_t_10 = __pyx_t_19;
        goto __pyx_L29_bool_binop_done;
      }
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_in_closure); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 613, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 613, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_18 = (!__pyx_t_19);
      __pyx_t_10 = __pyx_t_18;
      __pyx_L29_bool_binop_done:;
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":614
 *                 pass  # Can be uninitialized here
 *             elif node.cf_is_null and not entry.in_closure:
 *                 if entry.error_on_uninitialized or (             # <<<<<<<<<<<<<<
 *                         Options.error_on_uninitialized and (
 *                         entry.type.is_pyobject or entry.type.is_unspecified)):
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_error_on_uninitialized); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 614, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 614, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (!__pyx_t_18) {
        } else {
          __pyx_t_10 = __pyx_t_18;
          goto __pyx_L32_bool_binop_done;
        }

        /* "Cython/Compiler/FlowControl.py":615
 *             elif node.cf_is_null and not entry.in_closure:
 *                 if entry.error_on_uninitialized or (
 *                         Options.error_on_uninitialized and (             # <<<<<<<<<<<<<<
 *                         entry.type.is_pyobject or entry.type.is_unspecified)):
 *                     messages.error(
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_Options, __pyx_mstate_global->__pyx_n_u_error_on_uninitialized); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 615, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 615, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_18) {
        } else {
          __pyx_t_10 = __pyx_t_18;
          goto __pyx_L32_bool_binop_done;
        }

        /* "Cython/Compiler/FlowControl.py":616
 *                 if entry.error_on_uninitialized or (
 *                         Options.error_on_uninitialized and (
 *                         entry.type.is_pyobject or entry.type.is_unspecified)):             # <<<<<<<<<<<<<<
 *                     messages.error(
 *                         node.pos,
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 616, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_is_pyobject); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 616, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 616, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (!__pyx_t_18) {
        } else {
          __pyx_t_10 = __pyx_t_18;
          goto __pyx_L32_bool_binop_done;
        }
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 616, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_is_unspecified); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 616, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 616, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_10 = __pyx_t_18;
        __pyx_L32_bool_binop_done:;

        /* "Cython/Compiler/FlowControl.py":614
 *                 pass  # Can be uninitialized here
 *             elif node.cf_is_null and not entry.in_closure:
 *                 if entry.error_on_uninitialized or (             # <<<<<<<<<<<<<<
 *                         Options.error_on_uninitialized and (
 *                         entry.type.is_pyobject or entry.type.is_unspecified)):
*/
        if (__pyx_t_10) {

          /* "Cython/Compiler/FlowControl.py":617
 *                         Options.error_on_uninitialized and (
 *                         entry.type.is_pyobject or entry.type.is_unspecified)):
 *                     messages.error(             # <<<<<<<<<<<<<<
 *                         node.pos,
 *                         "local variable '%s' referenced before assignment"
*/
          __pyx_t_11 = ((PyObject *)__pyx_v_messages);
          __Pyx_INCREF(__pyx_t_11);

          /* "Cython/Compiler/FlowControl.py":618
 *                         entry.type.is_pyobject or entry.type.is_unspecified)):
 *                     messages.error(
 *                         node.pos,             # <<<<<<<<<<<<<<
 *                         "local variable '%s' referenced before assignment"
 *                         % entry.name)
*/
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);

          /* "Cython/Compiler/FlowControl.py":620
 *                         node.pos,
 *                         "local variable '%s' referenced before assignment"
 *                         % entry.name)             # <<<<<<<<<<<<<<
 *                 else:
 *                     messages.warning(
*/
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 620, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_9 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_local_variable_s_referenced_befo, __pyx_t_12); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 620, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_13 = 0;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_5, __pyx_t_9};
            __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 617, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "Cython/Compiler/FlowControl.py":614
 *                 pass  # Can be uninitialized here
 *             elif node.cf_is_null and not entry.in_closure:
 *                 if entry.error_on_uninitialized or (             # <<<<<<<<<<<<<<
 *                         Options.error_on_uninitialized and (
 *                         entry.type.is_pyobject or entry.type.is_unspecified)):
*/
          goto __pyx_L31;
        }

        /* "Cython/Compiler/FlowControl.py":622
 *                         % entry.name)
 *                 else:
 *                     messages.warning(             # <<<<<<<<<<<<<<
 *                         node.pos,
 *                         "local variable '%s' referenced before assignment"
*/
        /*else*/ {
          __pyx_t_9 = ((PyObject *)__pyx_v_messages);
          __Pyx_INCREF(__pyx_t_9);

          /* "Cython/Compiler/FlowControl.py":623
 *                 else:
 *                     messages.warning(
 *                         node.pos,             # <<<<<<<<<<<<<<
 *                         "local variable '%s' referenced before assignment"
 *                         % entry.name)
*/
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);

          /* "Cython/Compiler/FlowControl.py":625
 *                         node.pos,
 *                         "local variable '%s' referenced before assignment"
 *                         % entry.name)             # <<<<<<<<<<<<<<
 *             elif warn_maybe_uninitialized:
 *                 msg = "local variable '%s' might be referenced before assignment" % entry.name
*/
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_local_variable_s_referenced_befo, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_13 = 0;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_t_5, __pyx_t_12};
            __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_warning, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 622, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_L31:;

        /* "Cython/Compiler/FlowControl.py":613
 *                     or entry.is_pyclass_attr or entry.type.is_error):
 *                 pass  # Can be uninitialized here
 *             elif node.cf_is_null and not entry.in_closure:             # <<<<<<<<<<<<<<
 *                 if entry.error_on_uninitialized or (
 *                         Options.error_on_uninitialized and (
*/
        goto __pyx_L24;
      }

      /* "Cython/Compiler/FlowControl.py":626
 *                         "local variable '%s' referenced before assignment"
 *                         % entry.name)
 *             elif warn_maybe_uninitialized:             # <<<<<<<<<<<<<<
 *                 msg = "local variable '%s' might be referenced before assignment" % entry.name
 *                 if entry.in_closure:
*/
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_warn_maybe_uninitialized); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 626, __pyx_L1_error)
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":627
 *                         % entry.name)
 *             elif warn_maybe_uninitialized:
 *                 msg = "local variable '%s' might be referenced before assignment" % entry.name             # <<<<<<<<<<<<<<
 *                 if entry.in_closure:
 *                     msg += " (maybe initialized inside a closure)"
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 627, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_12 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_local_variable_s_might_be_refere, __pyx_t_8); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 627, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_msg, ((PyObject*)__pyx_t_12));
        __pyx_t_12 = 0;

        /* "Cython/Compiler/FlowControl.py":628
 *             elif warn_maybe_uninitialized:
 *                 msg = "local variable '%s' might be referenced before assignment" % entry.name
 *                 if entry.in_closure:             # <<<<<<<<<<<<<<
 *                     msg += " (maybe initialized inside a closure)"
 *                 messages.warning(
*/
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_in_closure); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 628, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 628, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (__pyx_t_10) {

          /* "Cython/Compiler/FlowControl.py":629
 *                 msg = "local variable '%s' might be referenced before assignment" % entry.name
 *                 if entry.in_closure:
 *                     msg += " (maybe initialized inside a closure)"             # <<<<<<<<<<<<<<
 *                 messages.warning(
 *                     node.pos,
*/
          __pyx_t_12 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_v_msg, __pyx_mstate_global->__pyx_kp_u_maybe_initialized_inside_a_clos); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF_SET(__pyx_v_msg, ((PyObject*)__pyx_t_12));
          __pyx_t_12 = 0;

          /* "Cython/Compiler/FlowControl.py":628
 *             elif warn_maybe_uninitialized:
 *                 msg = "local variable '%s' might be referenced before assignment" % entry.name
 *                 if entry.in_closure:             # <<<<<<<<<<<<<<
 *                     msg += " (maybe initialized inside a closure)"
 *                 messages.warning(
*/
        }

        /* "Cython/Compiler/FlowControl.py":630
 *                 if entry.in_closure:
 *                     msg += " (maybe initialized inside a closure)"
 *                 messages.warning(             # <<<<<<<<<<<<<<
 *                     node.pos,
 *                     msg)
*/
        __pyx_t_8 = ((PyObject *)__pyx_v_messages);
        __Pyx_INCREF(__pyx_t_8);

        /* "Cython/Compiler/FlowControl.py":631
 *                     msg += " (maybe initialized inside a closure)"
 *                 messages.warning(
 *                     node.pos,             # <<<<<<<<<<<<<<
 *                     msg)
 *         elif Unknown in node.cf_state:
*/
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 631, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);

        /* "Cython/Compiler/FlowControl.py":632
 *                 messages.warning(
 *                     node.pos,
 *                     msg)             # <<<<<<<<<<<<<<
 *         elif Unknown in node.cf_state:
 *             # TODO: better cross-closure analysis to know when inner functions
*/
        __pyx_t_13 = 0;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_5, __pyx_v_msg};
          __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_warning, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 630, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "Cython/Compiler/FlowControl.py":626
 *                         "local variable '%s' referenced before assignment"
 *                         % entry.name)
 *             elif warn_maybe_uninitialized:             # <<<<<<<<<<<<<<
 *                 msg = "local variable '%s' might be referenced before assignment" % entry.name
 *                 if entry.in_closure:
*/
      }
      __pyx_L24:;

      /* "Cython/Compiler/FlowControl.py":605
 *     # Find uninitialized references and cf-hints
 *     for node, entry in references.items():
 *         if Uninitialized in node.cf_state:             # <<<<<<<<<<<<<<
 *             node.cf_maybe_null = True
 *             if (not entry.from_closure and len(node.cf_state) == 1
*/
      goto __pyx_L19;
    }

    /* "Cython/Compiler/FlowControl.py":633
 *                     node.pos,
 *                     msg)
 *         elif Unknown in node.cf_state:             # <<<<<<<<<<<<<<
 *             # TODO: better cross-closure analysis to know when inner functions
 *             #       are being called before a variable is being set, and when
*/
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown), __pyx_t_12, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (__pyx_t_10) {

      /* "Cython/Compiler/FlowControl.py":638
 *             #       a variable is known to be set before even defining the
 *             #       inner function, etc.
 *             node.cf_maybe_null = True             # <<<<<<<<<<<<<<
 *         else:
 *             node.cf_is_null = False
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_True) < (0)) __PYX_ERR(0, 638, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":633
 *                     node.pos,
 *                     msg)
 *         elif Unknown in node.cf_state:             # <<<<<<<<<<<<<<
 *             # TODO: better cross-closure analysis to know when inner functions
 *             #       are being called before a variable is being set, and when
*/
      goto __pyx_L19;
    }

    /* "Cython/Compiler/FlowControl.py":640
 *             node.cf_maybe_null = True
 *         else:
 *             node.cf_is_null = False             # <<<<<<<<<<<<<<
 *             node.cf_maybe_null = False
 * 
*/
    /*else*/ {
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_is_null, Py_False) < (0)) __PYX_ERR(0, 640, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":641
 *         else:
 *             node.cf_is_null = False
 *             node.cf_maybe_null = False             # <<<<<<<<<<<<<<
 * 
 *     # Unused result
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_False) < (0)) __PYX_ERR(0, 641, __pyx_L1_error)
    }
    __pyx_L19:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":644
 * 
 *     # Unused result
 *     for assmt in assignments:             # <<<<<<<<<<<<<<
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr
 *                 and not assmt.entry.in_closure):
*/
  __pyx_t_3 = 0;
  __pyx_t_12 = __Pyx_set_iterator(__pyx_v_assignments, 1, (&__pyx_t_2), (&__pyx_t_4)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_12;
  __pyx_t_12 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_2, &__pyx_t_3, &__pyx_t_12, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    if (!(likely(((__pyx_t_12) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_12, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment))))) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_assmt, ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_t_12));
    __pyx_t_12 = 0;

    /* "Cython/Compiler/FlowControl.py":645
 *     # Unused result
 *     for assmt in assignments:
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr             # <<<<<<<<<<<<<<
 *                 and not assmt.entry.in_closure):
 *             if assmt.entry.cf_references and warn_unused_result:
*/
    if (__pyx_v_assmt->refs == Py_None) __pyx_t_18 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PySet_GET_SIZE(__pyx_v_assmt->refs);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 645, __pyx_L1_error)
      __pyx_t_18 = (__pyx_temp != 0);
    }

    __pyx_t_19 = (!__pyx_t_18);
    if (__pyx_t_19) {
    } else {
      __pyx_t_10 = __pyx_t_19;
      goto __pyx_L40_bool_binop_done;
    }

    /* "Cython/Compiler/FlowControl.py":646
 *     for assmt in assignments:
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr
 *                 and not assmt.entry.in_closure):             # <<<<<<<<<<<<<<
 *             if assmt.entry.cf_references and warn_unused_result:
 *                 if assmt.is_arg:
*/
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_assmt->entry, __pyx_mstate_global->__pyx_n_u_is_pyclass_attr); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 645, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);

    /* "Cython/Compiler/FlowControl.py":645
 *     # Unused result
 *     for assmt in assignments:
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr             # <<<<<<<<<<<<<<
 *                 and not assmt.entry.in_closure):
 *             if assmt.entry.cf_references and warn_unused_result:
*/
    __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 645, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_18 = (!__pyx_t_19);
    if (__pyx_t_18) {
    } else {
      __pyx_t_10 = __pyx_t_18;
      goto __pyx_L40_bool_binop_done;
    }

    /* "Cython/Compiler/FlowControl.py":646
 *     for assmt in assignments:
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr
 *                 and not assmt.entry.in_closure):             # <<<<<<<<<<<<<<
 *             if assmt.entry.cf_references and warn_unused_result:
 *                 if assmt.is_arg:
*/
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_assmt->entry, __pyx_mstate_global->__pyx_n_u_in_closure); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_19 = (!__pyx_t_18);
    __pyx_t_10 = __pyx_t_19;
    __pyx_L40_bool_binop_done:;

    /* "Cython/Compiler/FlowControl.py":645
 *     # Unused result
 *     for assmt in assignments:
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr             # <<<<<<<<<<<<<<
 *                 and not assmt.entry.in_closure):
 *             if assmt.entry.cf_references and warn_unused_result:
*/
    if (__pyx_t_10) {

      /* "Cython/Compiler/FlowControl.py":647
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr
 *                 and not assmt.entry.in_closure):
 *             if assmt.entry.cf_references and warn_unused_result:             # <<<<<<<<<<<<<<
 *                 if assmt.is_arg:
 *                     messages.warning(assmt.pos, "Unused argument value '%s'" %
*/
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_assmt->entry, __pyx_mstate_global->__pyx_n_u_cf_references); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 647, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (__pyx_t_19) {
      } else {
        __pyx_t_10 = __pyx_t_19;
        goto __pyx_L44_bool_binop_done;
      }
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_v_warn_unused_result); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 647, __pyx_L1_error)
      __pyx_t_10 = __pyx_t_19;
      __pyx_L44_bool_binop_done:;
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":648
 *                 and not assmt.entry.in_closure):
 *             if assmt.entry.cf_references and warn_unused_result:
 *                 if assmt.is_arg:             # <<<<<<<<<<<<<<
 *                     messages.warning(assmt.pos, "Unused argument value '%s'" %
 *                                      assmt.entry.name)
*/
        if (__pyx_v_assmt->is_arg) {

          /* "Cython/Compiler/FlowControl.py":649
 *             if assmt.entry.cf_references and warn_unused_result:
 *                 if assmt.is_arg:
 *                     messages.warning(assmt.pos, "Unused argument value '%s'" %             # <<<<<<<<<<<<<<
 *                                      assmt.entry.name)
 *                 else:
*/
          __pyx_t_5 = ((PyObject *)__pyx_v_messages);
          __Pyx_INCREF(__pyx_t_5);

          /* "Cython/Compiler/FlowControl.py":650
 *                 if assmt.is_arg:
 *                     messages.warning(assmt.pos, "Unused argument value '%s'" %
 *                                      assmt.entry.name)             # <<<<<<<<<<<<<<
 *                 else:
 *                     messages.warning(assmt.pos, "Unused result in '%s'" %
*/
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_assmt->entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 650, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);

          /* "Cython/Compiler/FlowControl.py":649
 *             if assmt.entry.cf_references and warn_unused_result:
 *                 if assmt.is_arg:
 *                     messages.warning(assmt.pos, "Unused argument value '%s'" %             # <<<<<<<<<<<<<<
 *                                      assmt.entry.name)
 *                 else:
*/
          __pyx_t_9 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Unused_argument_value_s, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 649, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_13 = 0;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_assmt->pos, __pyx_t_9};
            __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_warning, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 649, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "Cython/Compiler/FlowControl.py":648
 *                 and not assmt.entry.in_closure):
 *             if assmt.entry.cf_references and warn_unused_result:
 *                 if assmt.is_arg:             # <<<<<<<<<<<<<<
 *                     messages.warning(assmt.pos, "Unused argument value '%s'" %
 *                                      assmt.entry.name)
*/
          goto __pyx_L46;
        }

        /* "Cython/Compiler/FlowControl.py":652
 *                                      assmt.entry.name)
 *                 else:
 *                     messages.warning(assmt.pos, "Unused result in '%s'" %             # <<<<<<<<<<<<<<
 *                                      assmt.entry.name)
 *             assmt.lhs.cf_used = False
*/
        /*else*/ {
          __pyx_t_9 = ((PyObject *)__pyx_v_messages);
          __Pyx_INCREF(__pyx_t_9);

          /* "Cython/Compiler/FlowControl.py":653
 *                 else:
 *                     messages.warning(assmt.pos, "Unused result in '%s'" %
 *                                      assmt.entry.name)             # <<<<<<<<<<<<<<
 *             assmt.lhs.cf_used = False
 * 
*/
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_assmt->entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 653, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);

          /* "Cython/Compiler/FlowControl.py":652
 *                                      assmt.entry.name)
 *                 else:
 *                     messages.warning(assmt.pos, "Unused result in '%s'" %             # <<<<<<<<<<<<<<
 *                                      assmt.entry.name)
 *             assmt.lhs.cf_used = False
*/
          __pyx_t_8 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Unused_result_in_s, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 652, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_13 = 0;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_v_assmt->pos, __pyx_t_8};
            __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_warning, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 652, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
        __pyx_L46:;

        /* "Cython/Compiler/FlowControl.py":647
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr
 *                 and not assmt.entry.in_closure):
 *             if assmt.entry.cf_references and warn_unused_result:             # <<<<<<<<<<<<<<
 *                 if assmt.is_arg:
 *                     messages.warning(assmt.pos, "Unused argument value '%s'" %
*/
      }

      /* "Cython/Compiler/FlowControl.py":654
 *                     messages.warning(assmt.pos, "Unused result in '%s'" %
 *                                      assmt.entry.name)
 *             assmt.lhs.cf_used = False             # <<<<<<<<<<<<<<
 * 
 *     # Unused entries
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_assmt->lhs, __pyx_mstate_global->__pyx_n_u_cf_used, Py_False) < (0)) __PYX_ERR(0, 654, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":645
 *     # Unused result
 *     for assmt in assignments:
 *         if (not assmt.refs and not assmt.entry.is_pyclass_attr             # <<<<<<<<<<<<<<
 *                 and not assmt.entry.in_closure):
 *             if assmt.entry.cf_references and warn_unused_result:
*/
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":657
 * 
 *     # Unused entries
 *     for entry in flow.entries:             # <<<<<<<<<<<<<<
 *         if (not entry.cf_references
 *                 and not entry.is_pyclass_attr):
*/
  __pyx_t_2 = 0;
  __pyx_t_12 = __Pyx_set_iterator(__pyx_v_flow->entries, 1, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_12;
  __pyx_t_12 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_12, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_12);
    __pyx_t_12 = 0;

    /* "Cython/Compiler/FlowControl.py":658
 *     # Unused entries
 *     for entry in flow.entries:
 *         if (not entry.cf_references             # <<<<<<<<<<<<<<
 *                 and not entry.is_pyclass_attr):
 *             if entry.name != '_' and not entry.name.startswith('unused'):
*/
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_cf_references); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 658, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_18 = (!__pyx_t_19);
    if (__pyx_t_18) {
    } else {
      __pyx_t_10 = __pyx_t_18;
      goto __pyx_L50_bool_binop_done;
    }

    /* "Cython/Compiler/FlowControl.py":659
 *     for entry in flow.entries:
 *         if (not entry.cf_references
 *                 and not entry.is_pyclass_attr):             # <<<<<<<<<<<<<<
 *             if entry.name != '_' and not entry.name.startswith('unused'):
 *                 # '_' is often used for unused variables, e.g. in loops
*/
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_pyclass_attr); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 659, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_19 = (!__pyx_t_18);
    __pyx_t_10 = __pyx_t_19;
    __pyx_L50_bool_binop_done:;

    /* "Cython/Compiler/FlowControl.py":658
 *     # Unused entries
 *     for entry in flow.entries:
 *         if (not entry.cf_references             # <<<<<<<<<<<<<<
 *                 and not entry.is_pyclass_attr):
 *             if entry.name != '_' and not entry.name.startswith('unused'):
*/
    if (__pyx_t_10) {

      /* "Cython/Compiler/FlowControl.py":660
 *         if (not entry.cf_references
 *                 and not entry.is_pyclass_attr):
 *             if entry.name != '_' and not entry.name.startswith('unused'):             # <<<<<<<<<<<<<<
 *                 # '_' is often used for unused variables, e.g. in loops
 *                 if entry.is_arg:
*/
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_19 = (__Pyx_PyUnicode_Equals(__pyx_t_12, __pyx_mstate_global->__pyx_n_u__16, Py_NE)); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (__pyx_t_19) {
      } else {
        __pyx_t_10 = __pyx_t_19;
        goto __pyx_L53_bool_binop_done;
      }
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __pyx_t_9;
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_13 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_mstate_global->__pyx_n_u_unused};
        __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 660, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
      }
      __pyx_t_19 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_19 < 0))) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_18 = (!__pyx_t_19);
      __pyx_t_10 = __pyx_t_18;
      __pyx_L53_bool_binop_done:;
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":662
 *             if entry.name != '_' and not entry.name.startswith('unused'):
 *                 # '_' is often used for unused variables, e.g. in loops
 *                 if entry.is_arg:             # <<<<<<<<<<<<<<
 *                     if warn_unused_arg:
 *                         messages.warning(entry.pos, "Unused argument '%s'" %
*/
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_arg); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 662, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 662, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (__pyx_t_10) {

          /* "Cython/Compiler/FlowControl.py":663
 *                 # '_' is often used for unused variables, e.g. in loops
 *                 if entry.is_arg:
 *                     if warn_unused_arg:             # <<<<<<<<<<<<<<
 *                         messages.warning(entry.pos, "Unused argument '%s'" %
 *                                          entry.name)
*/
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_warn_unused_arg); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 663, __pyx_L1_error)
          if (__pyx_t_10) {

            /* "Cython/Compiler/FlowControl.py":664
 *                 if entry.is_arg:
 *                     if warn_unused_arg:
 *                         messages.warning(entry.pos, "Unused argument '%s'" %             # <<<<<<<<<<<<<<
 *                                          entry.name)
 *                 else:
*/
            __pyx_t_9 = ((PyObject *)__pyx_v_messages);
            __Pyx_INCREF(__pyx_t_9);
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 664, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);

            /* "Cython/Compiler/FlowControl.py":665
 *                     if warn_unused_arg:
 *                         messages.warning(entry.pos, "Unused argument '%s'" %
 *                                          entry.name)             # <<<<<<<<<<<<<<
 *                 else:
 *                     if warn_unused:
*/
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 665, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);

            /* "Cython/Compiler/FlowControl.py":664
 *                 if entry.is_arg:
 *                     if warn_unused_arg:
 *                         messages.warning(entry.pos, "Unused argument '%s'" %             # <<<<<<<<<<<<<<
 *                                          entry.name)
 *                 else:
*/
            __pyx_t_11 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Unused_argument_s, __pyx_t_5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 664, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_13 = 0;
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_t_8, __pyx_t_11};
              __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_warning, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 664, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "Cython/Compiler/FlowControl.py":663
 *                 # '_' is often used for unused variables, e.g. in loops
 *                 if entry.is_arg:
 *                     if warn_unused_arg:             # <<<<<<<<<<<<<<
 *                         messages.warning(entry.pos, "Unused argument '%s'" %
 *                                          entry.name)
*/
          }

          /* "Cython/Compiler/FlowControl.py":662
 *             if entry.name != '_' and not entry.name.startswith('unused'):
 *                 # '_' is often used for unused variables, e.g. in loops
 *                 if entry.is_arg:             # <<<<<<<<<<<<<<
 *                     if warn_unused_arg:
 *                         messages.warning(entry.pos, "Unused argument '%s'" %
*/
          goto __pyx_L55;
        }

        /* "Cython/Compiler/FlowControl.py":667
 *                                          entry.name)
 *                 else:
 *                     if warn_unused:             # <<<<<<<<<<<<<<
 *                         messages.warning(entry.pos, "Unused entry '%s'" %
 *                                          entry.name)
*/
        /*else*/ {
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_warn_unused); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 667, __pyx_L1_error)
          if (__pyx_t_10) {

            /* "Cython/Compiler/FlowControl.py":668
 *                 else:
 *                     if warn_unused:
 *                         messages.warning(entry.pos, "Unused entry '%s'" %             # <<<<<<<<<<<<<<
 *                                          entry.name)
 *             entry.cf_used = False
*/
            __pyx_t_11 = ((PyObject *)__pyx_v_messages);
            __Pyx_INCREF(__pyx_t_11);
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 668, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);

            /* "Cython/Compiler/FlowControl.py":669
 *                     if warn_unused:
 *                         messages.warning(entry.pos, "Unused entry '%s'" %
 *                                          entry.name)             # <<<<<<<<<<<<<<
 *             entry.cf_used = False
 * 
*/
            __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 669, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);

            /* "Cython/Compiler/FlowControl.py":668
 *                 else:
 *                     if warn_unused:
 *                         messages.warning(entry.pos, "Unused entry '%s'" %             # <<<<<<<<<<<<<<
 *                                          entry.name)
 *             entry.cf_used = False
*/
            __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Unused_entry_s, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 668, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_13 = 0;
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_8, __pyx_t_5};
              __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_warning, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 668, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "Cython/Compiler/FlowControl.py":667
 *                                          entry.name)
 *                 else:
 *                     if warn_unused:             # <<<<<<<<<<<<<<
 *                         messages.warning(entry.pos, "Unused entry '%s'" %
 *                                          entry.name)
*/
          }
        }
        __pyx_L55:;

        /* "Cython/Compiler/FlowControl.py":660
 *         if (not entry.cf_references
 *                 and not entry.is_pyclass_attr):
 *             if entry.name != '_' and not entry.name.startswith('unused'):             # <<<<<<<<<<<<<<
 *                 # '_' is often used for unused variables, e.g. in loops
 *                 if entry.is_arg:
*/
      }

      /* "Cython/Compiler/FlowControl.py":670
 *                         messages.warning(entry.pos, "Unused entry '%s'" %
 *                                          entry.name)
 *             entry.cf_used = False             # <<<<<<<<<<<<<<
 * 
 *     messages.report()
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_cf_used, Py_False) < (0)) __PYX_ERR(0, 670, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":658
 *     # Unused entries
 *     for entry in flow.entries:
 *         if (not entry.cf_references             # <<<<<<<<<<<<<<
 *                 and not entry.is_pyclass_attr):
 *             if entry.name != '_' and not entry.name.startswith('unused'):
*/
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":672
 *             entry.cf_used = False
 * 
 *     messages.report()             # <<<<<<<<<<<<<<
 * 
 *     for node in assmt_nodes:
*/
  __pyx_t_12 = ((PyObject *)__pyx_v_messages);
  __Pyx_INCREF(__pyx_t_12);
  __pyx_t_13 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_report, __pyx_callargs+__pyx_t_13, (1-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":674
 *     messages.report()
 * 
 *     for node in assmt_nodes:             # <<<<<<<<<<<<<<
 *         node.cf_state = ControlFlowState(node.cf_state)
 *     for node in references:
*/
  __pyx_t_3 = 0;
  __pyx_t_12 = __Pyx_set_iterator(__pyx_v_assmt_nodes, 1, (&__pyx_t_2), (&__pyx_t_4)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_12;
  __pyx_t_12 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_2, &__pyx_t_3, &__pyx_t_12, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_12);
    __pyx_t_12 = 0;

    /* "Cython/Compiler/FlowControl.py":675
 * 
 *     for node in assmt_nodes:
 *         node.cf_state = ControlFlowState(node.cf_state)             # <<<<<<<<<<<<<<
 *     for node in references:
 *         node.cf_state = ControlFlowState(node.cf_state)
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_ControlFlowState); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_13 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
      __pyx_t_13 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_11};
      __pyx_t_12 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state, __pyx_t_12) < (0)) __PYX_ERR(0, 675, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":676
 *     for node in assmt_nodes:
 *         node.cf_state = ControlFlowState(node.cf_state)
 *     for node in references:             # <<<<<<<<<<<<<<
 *         node.cf_state = ControlFlowState(node.cf_state)
 * 
*/
  __pyx_t_2 = 0;
  __pyx_t_12 = __Pyx_dict_iterator(__pyx_v_references, 1, ((PyObject *)NULL), (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_12;
  __pyx_t_12 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_12, NULL, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_12);
    __pyx_t_12 = 0;

    /* "Cython/Compiler/FlowControl.py":677
 *         node.cf_state = ControlFlowState(node.cf_state)
 *     for node in references:
 *         node.cf_state = ControlFlowState(node.cf_state)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_t_8 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_ControlFlowState); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_13 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_11);
      assert(__pyx_t_8);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
      __pyx_t_13 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_5};
      __pyx_t_12 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 677, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cf_state, __pyx_t_12) < (0)) __PYX_ERR(0, 677, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":540
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def check_definitions(flow: ControlFlow, compiler_directives: dict):
 *     flow.initialize()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.check_definitions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_assignments);
  __Pyx_XDECREF(__pyx_v_references);
  __Pyx_XDECREF(__pyx_v_assmt_nodes);
  __Pyx_XDECREF((PyObject *)__pyx_v_block);
  __Pyx_XDECREF((PyObject *)__pyx_v_assmt);
  __Pyx_XDECREF(__pyx_v_i_state);
  __Pyx_XDECREF(__pyx_v_stat);
  __Pyx_XDECREF(__pyx_v_i_assmts);
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v_warn_maybe_uninitialized);
  __Pyx_XDECREF(__pyx_v_warn_unused_result);
  __Pyx_XDECREF(__pyx_v_warn_unused);
  __Pyx_XDECREF(__pyx_v_warn_unused_arg);
  __Pyx_XDECREF((PyObject *)__pyx_v_messages);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":681
 * 
 * class AssignmentCollector(TreeVisitor):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.assignments = []
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector___init__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector___init__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/FlowControl.py":682
 * class AssignmentCollector(TreeVisitor):
 *     def __init__(self):
 *         super().__init__()             # <<<<<<<<<<<<<<
 *         self.assignments = []
 * 
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector), ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":683
 *     def __init__(self):
 *         super().__init__()
 *         self.assignments = []             # <<<<<<<<<<<<<<
 * 
 *     def visit_Node(self):
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->assignments);
  __Pyx_DECREF(__pyx_v_self->assignments);
  __pyx_v_self->assignments = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":681
 * 
 * class AssignmentCollector(TreeVisitor):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.assignments = []
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentCollector.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":685
 *         self.assignments = []
 * 
 *     def visit_Node(self):             # <<<<<<<<<<<<<<
 *         self._visitchildren(self, None, None)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_3visit_Node(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_3visit_Node = {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_3visit_Node, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_3visit_Node(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_Node (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_2visit_Node(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_2visit_Node(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_Node", 0);

  /* "Cython/Compiler/FlowControl.py":686
 * 
 *     def visit_Node(self):
 *         self._visitchildren(self, None, None)             # <<<<<<<<<<<<<<
 * 
 *     def visit_SingleAssignmentNode(self, node):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), ((PyObject *)__pyx_v_self), Py_None, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":685
 *         self.assignments = []
 * 
 *     def visit_Node(self):             # <<<<<<<<<<<<<<
 *         self._visitchildren(self, None, None)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentCollector.visit_Node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":688
 *         self._visitchildren(self, None, None)
 * 
 *     def visit_SingleAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self.assignments.append((node.lhs, node.rhs))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_5visit_SingleAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_5visit_SingleAssignmentNode = {"visit_SingleAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_5visit_SingleAssignmentNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_5visit_SingleAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_SingleAssignmentNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_4visit_SingleAssignmentNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_4visit_SingleAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_SingleAssignmentNode", 0);

  /* "Cython/Compiler/FlowControl.py":689
 * 
 *     def visit_SingleAssignmentNode(self, node):
 *         self.assignments.append((node.lhs, node.rhs))             # <<<<<<<<<<<<<<
 * 
 *     def visit_CascadedAssignmentNode(self, node):
*/
  if (unlikely(__pyx_v_self->assignments == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 689, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_lhs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 689, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 689, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_self->assignments, __pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":688
 *         self._visitchildren(self, None, None)
 * 
 *     def visit_SingleAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self.assignments.append((node.lhs, node.rhs))
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentCollector.visit_SingleAssignmentNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":691
 *         self.assignments.append((node.lhs, node.rhs))
 * 
 *     def visit_CascadedAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         for lhs in node.lhs_list:
 *             self.assignments.append((lhs, node.rhs))
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_7visit_CascadedAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_7visit_CascadedAssignmentNode = {"visit_CascadedAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_7visit_CascadedAssignmentNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_7visit_CascadedAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CascadedAssignmentNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_6visit_CascadedAssignmentNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_6visit_CascadedAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_lhs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CascadedAssignmentNode", 0);

  /* "Cython/Compiler/FlowControl.py":692
 * 
 *     def visit_CascadedAssignmentNode(self, node):
 *         for lhs in node.lhs_list:             # <<<<<<<<<<<<<<
 *             self.assignments.append((lhs, node.rhs))
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_lhs_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 692, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 692, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 692, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 692, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_lhs, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":693
 *     def visit_CascadedAssignmentNode(self, node):
 *         for lhs in node.lhs_list:
 *             self.assignments.append((lhs, node.rhs))             # <<<<<<<<<<<<<<
 * 
 * 
*/
    if (unlikely(__pyx_v_self->assignments == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 693, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_lhs);
    __Pyx_GIVEREF(__pyx_v_lhs);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_lhs) != (0)) __PYX_ERR(0, 693, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(0, 693, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_self->assignments, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":692
 * 
 *     def visit_CascadedAssignmentNode(self, node):
 *         for lhs in node.lhs_list:             # <<<<<<<<<<<<<<
 *             self.assignments.append((lhs, node.rhs))
 * 
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":691
 *         self.assignments.append((node.lhs, node.rhs))
 * 
 *     def visit_CascadedAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         for lhs in node.lhs_list:
 *             self.assignments.append((lhs, node.rhs))
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentCollector.visit_CascadedAssignmentNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lhs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_9__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_8__reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_8__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.access_path, self.assignments, self.dispatch_table)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.access_path);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.access_path);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->__pyx_base.access_path) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->assignments);
  __Pyx_GIVEREF(__pyx_v_self->assignments);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->assignments) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.dispatch_table);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.dispatch_table);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->__pyx_base.dispatch_table) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.access_path, self.assignments, self.dispatch_table)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.access_path, self.assignments, self.dispatch_table)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.access_path is not None or self.assignments is not None or self.dispatch_table is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.access_path, self.assignments, self.dispatch_table)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.access_path is not None or self.assignments is not None or self.dispatch_table is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, None), state
*/
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->__pyx_base.access_path != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->assignments != ((PyObject*)Py_None));
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->__pyx_base.dispatch_table != ((PyObject*)Py_None));
    __pyx_t_2 = __pyx_t_3;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.access_path is not None or self.assignments is not None or self.dispatch_table is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.access_path is not None or self.assignments is not None or self.dispatch_table is not None
 *     if use_setstate:
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_AssignmentCollect); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_48084501);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_48084501);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_48084501) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.access_path is not None or self.assignments is not None or self.dispatch_table is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, None), state
 *     else:
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_AssignmentCollector__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_AssignmentCollect); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_48084501);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_48084501);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_48084501) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentCollector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_AssignmentCollector__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_11__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_10__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19AssignmentCollector_10__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_AssignmentCollector__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_AssignmentCollector__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_AssignmentCollector__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.AssignmentCollector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":698
 * class ControlFlowAnalysis(CythonTransform):
 * 
 *     def find_in_stack(self, env):             # <<<<<<<<<<<<<<
 *         if env == self.env:
 *             return self.flow
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_1find_in_stack(PyObject *__pyx_v_self, PyObject *__pyx_v_env); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_1find_in_stack = {"find_in_stack", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_1find_in_stack, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_1find_in_stack(PyObject *__pyx_v_self, PyObject *__pyx_v_env) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_in_stack (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_find_in_stack(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_env));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_find_in_stack(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_env) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_flow = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_in_stack", 0);

  /* "Cython/Compiler/FlowControl.py":699
 * 
 *     def find_in_stack(self, env):
 *         if env == self.env:             # <<<<<<<<<<<<<<
 *             return self.flow
 *         for e, flow in reversed(self.stack):
*/
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_env, __pyx_v_self->env, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 699, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":700
 *     def find_in_stack(self, env):
 *         if env == self.env:
 *             return self.flow             # <<<<<<<<<<<<<<
 *         for e, flow in reversed(self.stack):
 *             if e is env:
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_self->flow);
    __pyx_r = ((PyObject *)__pyx_v_self->flow);
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":699
 * 
 *     def find_in_stack(self, env):
 *         if env == self.env:             # <<<<<<<<<<<<<<
 *             return self.flow
 *         for e, flow in reversed(self.stack):
*/
  }

  /* "Cython/Compiler/FlowControl.py":701
 *         if env == self.env:
 *             return self.flow
 *         for e, flow in reversed(self.stack):             # <<<<<<<<<<<<<<
 *             if e is env:
 *                 return flow
*/
  if (unlikely(__pyx_v_self->stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 701, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->stack; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyList_GET_SIZE(__pyx_t_1);
  #if !CYTHON_ASSUME_SAFE_SIZE
  if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 701, __pyx_L1_error)
  #endif
  --__pyx_t_3;
  for (;;) {
    if (__pyx_t_3 < 0) break;
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 701, __pyx_L1_error)
      #endif
      if (__pyx_t_3 >= __pyx_temp) break;
    }
    __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
    --__pyx_t_3;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 701, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_6);
      } else {
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 701, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 701, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
      }
      #else
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < (0)) __PYX_ERR(0, 701, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 701, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_flow, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/FlowControl.py":702
 *             return self.flow
 *         for e, flow in reversed(self.stack):
 *             if e is env:             # <<<<<<<<<<<<<<
 *                 return flow
 *         assert False
*/
    __pyx_t_2 = (__pyx_v_e == __pyx_v_env);
    if (__pyx_t_2) {

      /* "Cython/Compiler/FlowControl.py":703
 *         for e, flow in reversed(self.stack):
 *             if e is env:
 *                 return flow             # <<<<<<<<<<<<<<
 *         assert False
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_flow);
      __pyx_r = __pyx_v_flow;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/FlowControl.py":702
 *             return self.flow
 *         for e, flow in reversed(self.stack):
 *             if e is env:             # <<<<<<<<<<<<<<
 *                 return flow
 *         assert False
*/
    }

    /* "Cython/Compiler/FlowControl.py":701
 *         if env == self.env:
 *             return self.flow
 *         for e, flow in reversed(self.stack):             # <<<<<<<<<<<<<<
 *             if e is env:
 *                 return flow
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":704
 *             if e is env:
 *                 return flow
 *         assert False             # <<<<<<<<<<<<<<
 * 
 *     def visit_ModuleNode(self, node):
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    if (unlikely(!0)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 704, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 704, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/FlowControl.py":698
 * class ControlFlowAnalysis(CythonTransform):
 * 
 *     def find_in_stack(self, env):             # <<<<<<<<<<<<<<
 *         if env == self.env:
 *             return self.flow
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.find_in_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_flow);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":706
 *         assert False
 * 
 *     def visit_ModuleNode(self, node):             # <<<<<<<<<<<<<<
 *         dot_output = self.current_directives['control_flow.dot_output']
 *         self.gv_ctx = GVContext() if dot_output else None
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_3visit_ModuleNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_3visit_ModuleNode = {"visit_ModuleNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_3visit_ModuleNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_3visit_ModuleNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ModuleNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_2visit_ModuleNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_2visit_ModuleNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_dot_output = NULL;
  PyObject *__pyx_v_ConstantFolding = NULL;
  PyObject *__pyx_v_annotate_defs = NULL;
  PyObject *__pyx_v_fp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ModuleNode", 0);

  /* "Cython/Compiler/FlowControl.py":707
 * 
 *     def visit_ModuleNode(self, node):
 *         dot_output = self.current_directives['control_flow.dot_output']             # <<<<<<<<<<<<<<
 *         self.gv_ctx = GVContext() if dot_output else None
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->__pyx_base.current_directives, __pyx_mstate_global->__pyx_kp_u_control_flow_dot_output); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_dot_output = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":708
 *     def visit_ModuleNode(self, node):
 *         dot_output = self.current_directives['control_flow.dot_output']
 *         self.gv_ctx = GVContext() if dot_output else None             # <<<<<<<<<<<<<<
 * 
 *         from .Optimize import ConstantFolding
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_dot_output); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 708, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_GVContext); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 708, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 708, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->gv_ctx);
  __Pyx_DECREF(__pyx_v_self->gv_ctx);
  __pyx_v_self->gv_ctx = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":710
 *         self.gv_ctx = GVContext() if dot_output else None
 * 
 *         from .Optimize import ConstantFolding             # <<<<<<<<<<<<<<
 *         self.constant_folder = ConstantFolding()
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ConstantFolding};
    __pyx_t_7 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Optimize, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Optimize, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 710, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_t_7;
  __Pyx_GOTREF(__pyx_t_1);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ConstantFolding};
    __pyx_t_8 = 0; {
      __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_1, __pyx_imported_names[__pyx_t_8]); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 710, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      switch (__pyx_t_8) {
        case 0:
        __Pyx_INCREF(__pyx_t_3);
        __pyx_v_ConstantFolding = __pyx_t_3;
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":711
 * 
 *         from .Optimize import ConstantFolding
 *         self.constant_folder = ConstantFolding()             # <<<<<<<<<<<<<<
 * 
 *         # Set of NameNode reductions
*/
  __pyx_t_3 = NULL;
  __Pyx_INCREF(__pyx_v_ConstantFolding);
  __pyx_t_5 = __pyx_v_ConstantFolding; 
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->constant_folder);
  __Pyx_DECREF(__pyx_v_self->constant_folder);
  __pyx_v_self->constant_folder = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":714
 * 
 *         # Set of NameNode reductions
 *         self.reductions = set()             # <<<<<<<<<<<<<<
 * 
 *         self.in_inplace_assignment = False
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->reductions);
  __Pyx_DECREF(__pyx_v_self->reductions);
  __pyx_v_self->reductions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":716
 *         self.reductions = set()
 * 
 *         self.in_inplace_assignment = False             # <<<<<<<<<<<<<<
 *         self.env = node.scope
 *         self.flow = ControlFlow()
*/
  __pyx_v_self->in_inplace_assignment = 0;

  /* "Cython/Compiler/FlowControl.py":717
 * 
 *         self.in_inplace_assignment = False
 *         self.env = node.scope             # <<<<<<<<<<<<<<
 *         self.flow = ControlFlow()
 *         self.stack = []  # a stack of (env, flow) tuples
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->env);
  __Pyx_DECREF(__pyx_v_self->env);
  __pyx_v_self->env = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":718
 *         self.in_inplace_assignment = False
 *         self.env = node.scope
 *         self.flow = ControlFlow()             # <<<<<<<<<<<<<<
 *         self.stack = []  # a stack of (env, flow) tuples
 *         self.object_expr = TypedExprNode(PyrexTypes.py_object_type, may_be_none=True)
*/
  __pyx_t_5 = NULL;
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 718, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __Pyx_GIVEREF((PyObject *)__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow);
  __pyx_v_self->flow = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":719
 *         self.env = node.scope
 *         self.flow = ControlFlow()
 *         self.stack = []  # a stack of (env, flow) tuples             # <<<<<<<<<<<<<<
 *         self.object_expr = TypedExprNode(PyrexTypes.py_object_type, may_be_none=True)
 *         self.visitchildren(node)
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->stack);
  __Pyx_DECREF(__pyx_v_self->stack);
  __pyx_v_self->stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":720
 *         self.flow = ControlFlow()
 *         self.stack = []  # a stack of (env, flow) tuples
 *         self.object_expr = TypedExprNode(PyrexTypes.py_object_type, may_be_none=True)             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 * 
*/
  __pyx_t_5 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode);
  __pyx_t_3 = __pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode; 
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_PyrexTypes, __pyx_mstate_global->__pyx_n_u_py_object_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_may_be_none, Py_True, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 720, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->object_expr);
  __Pyx_DECREF(__pyx_v_self->object_expr);
  __pyx_v_self->object_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":721
 *         self.stack = []  # a stack of (env, flow) tuples
 *         self.object_expr = TypedExprNode(PyrexTypes.py_object_type, may_be_none=True)
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 * 
 *         check_definitions(self.flow, self.current_directives)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":723
 *         self.visitchildren(node)
 * 
 *         check_definitions(self.flow, self.current_directives)             # <<<<<<<<<<<<<<
 * 
 *         if dot_output:
*/
  if (unlikely(((PyObject *)__pyx_v_self->flow) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 723, __pyx_L1_error)
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_self->flow);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = __pyx_v_self->__pyx_base.current_directives;
  __Pyx_INCREF(__pyx_t_3);
  if (!(likely(PyDict_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_3))) __PYX_ERR(0, 723, __pyx_L1_error)
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 723, __pyx_L1_error)
  }
  __pyx_t_9 = __pyx_f_6Cython_8Compiler_11FlowControl_check_definitions(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_t_1), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "Cython/Compiler/FlowControl.py":725
 *         check_definitions(self.flow, self.current_directives)
 * 
 *         if dot_output:             # <<<<<<<<<<<<<<
 *             annotate_defs = self.current_directives['control_flow.dot_annotate_defs']
 *             with open(dot_output, 'w') as fp:
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_dot_output); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 725, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":726
 * 
 *         if dot_output:
 *             annotate_defs = self.current_directives['control_flow.dot_annotate_defs']             # <<<<<<<<<<<<<<
 *             with open(dot_output, 'w') as fp:
 *                 self.gv_ctx.render(fp, 'module', annotate_defs=annotate_defs)
*/
    __pyx_t_9 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->__pyx_base.current_directives, __pyx_mstate_global->__pyx_kp_u_control_flow_dot_annotate_defs); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_v_annotate_defs = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "Cython/Compiler/FlowControl.py":727
 *         if dot_output:
 *             annotate_defs = self.current_directives['control_flow.dot_annotate_defs']
 *             with open(dot_output, 'w') as fp:             # <<<<<<<<<<<<<<
 *                 self.gv_ctx.render(fp, 'module', annotate_defs=annotate_defs)
 *         return node
*/
    /*with:*/ {
      __pyx_t_3 = NULL;
      __pyx_t_6 = 1;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_dot_output, __pyx_mstate_global->__pyx_n_u_w};
        __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_open, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 727, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
      }
      __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 727, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = NULL;
      __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 727, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 727, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_4 = __pyx_t_3;
      __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          /*try:*/ {
            __pyx_v_fp = __pyx_t_4;
            __pyx_t_4 = 0;

            /* "Cython/Compiler/FlowControl.py":728
 *             annotate_defs = self.current_directives['control_flow.dot_annotate_defs']
 *             with open(dot_output, 'w') as fp:
 *                 self.gv_ctx.render(fp, 'module', annotate_defs=annotate_defs)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
            __pyx_t_9 = __pyx_v_self->gv_ctx;
            __Pyx_INCREF(__pyx_t_9);
            __pyx_t_6 = 0;
            {
              PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_9, __pyx_v_fp, __pyx_mstate_global->__pyx_n_u_module};
              __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 728, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_3);
              if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_annotate_defs, __pyx_v_annotate_defs, __pyx_t_3, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 728, __pyx_L8_error)
              __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_render, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 728, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_4);
            }
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

            /* "Cython/Compiler/FlowControl.py":727
 *         if dot_output:
 *             annotate_defs = self.current_directives['control_flow.dot_annotate_defs']
 *             with open(dot_output, 'w') as fp:             # <<<<<<<<<<<<<<
 *                 self.gv_ctx.render(fp, 'module', annotate_defs=annotate_defs)
 *         return node
*/
          }
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          goto __pyx_L13_try_end;
          __pyx_L8_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ModuleNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_9) < 0) __PYX_ERR(0, 727, __pyx_L10_except_error)
            __Pyx_XGOTREF(__pyx_t_4);
            __Pyx_XGOTREF(__pyx_t_3);
            __Pyx_XGOTREF(__pyx_t_9);
            __pyx_t_1 = PyTuple_Pack(3, __pyx_t_4, __pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 727, __pyx_L10_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, NULL);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 727, __pyx_L10_except_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (__pyx_t_2 < (0)) __PYX_ERR(0, 727, __pyx_L10_except_error)
            __pyx_t_14 = (!__pyx_t_2);
            if (unlikely(__pyx_t_14)) {
              __Pyx_GIVEREF(__pyx_t_4);
              __Pyx_GIVEREF(__pyx_t_3);
              __Pyx_XGIVEREF(__pyx_t_9);
              __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_3, __pyx_t_9);
              __pyx_t_4 = 0;  __pyx_t_3 = 0;  __pyx_t_9 = 0; 
              __PYX_ERR(0, 727, __pyx_L10_except_error)
            }
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            goto __pyx_L9_exception_handled;
          }
          __pyx_L10_except_error:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L1_error;
          __pyx_L9_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          __pyx_L13_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_7) {
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[2], NULL);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 727, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          }
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
      goto __pyx_L17;
      __pyx_L4_error:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L1_error;
      __pyx_L17:;
    }

    /* "Cython/Compiler/FlowControl.py":725
 *         check_definitions(self.flow, self.current_directives)
 * 
 *         if dot_output:             # <<<<<<<<<<<<<<
 *             annotate_defs = self.current_directives['control_flow.dot_annotate_defs']
 *             with open(dot_output, 'w') as fp:
*/
  }

  /* "Cython/Compiler/FlowControl.py":729
 *             with open(dot_output, 'w') as fp:
 *                 self.gv_ctx.render(fp, 'module', annotate_defs=annotate_defs)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_FuncDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":706
 *         assert False
 * 
 *     def visit_ModuleNode(self, node):             # <<<<<<<<<<<<<<
 *         dot_output = self.current_directives['control_flow.dot_output']
 *         self.gv_ctx = GVContext() if dot_output else None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ModuleNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dot_output);
  __Pyx_XDECREF(__pyx_v_ConstantFolding);
  __Pyx_XDECREF(__pyx_v_annotate_defs);
  __Pyx_XDECREF(__pyx_v_fp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":731
 *         return node
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         for arg in node.args:
 *             if arg.default:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_5visit_FuncDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_5visit_FuncDefNode = {"visit_FuncDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_5visit_FuncDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_5visit_FuncDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_FuncDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_4visit_FuncDefNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_4visit_FuncDefNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren __pyx_t_6;
  int __pyx_t_7;
  size_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *(*__pyx_t_17)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_FuncDefNode", 0);

  /* "Cython/Compiler/FlowControl.py":732
 * 
 *     def visit_FuncDefNode(self, node):
 *         for arg in node.args:             # <<<<<<<<<<<<<<
 *             if arg.default:
 *                 self.visitchildren(arg)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 732, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 732, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 732, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 732, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 732, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":733
 *     def visit_FuncDefNode(self, node):
 *         for arg in node.args:
 *             if arg.default:             # <<<<<<<<<<<<<<
 *                 self.visitchildren(arg)
 *         self.visitchildren(node, ('decorators',))
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_default); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 733, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "Cython/Compiler/FlowControl.py":734
 *         for arg in node.args:
 *             if arg.default:
 *                 self.visitchildren(arg)             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, ('decorators',))
 *         self.stack.append((self.env, self.flow))
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_arg, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 734, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":733
 *     def visit_FuncDefNode(self, node):
 *         for arg in node.args:
 *             if arg.default:             # <<<<<<<<<<<<<<
 *                 self.visitchildren(arg)
 *         self.visitchildren(node, ('decorators',))
*/
    }

    /* "Cython/Compiler/FlowControl.py":732
 * 
 *     def visit_FuncDefNode(self, node):
 *         for arg in node.args:             # <<<<<<<<<<<<<<
 *             if arg.default:
 *                 self.visitchildren(arg)
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":735
 *             if arg.default:
 *                 self.visitchildren(arg)
 *         self.visitchildren(node, ('decorators',))             # <<<<<<<<<<<<<<
 *         self.stack.append((self.env, self.flow))
 *         self.env = node.local_scope
*/
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.attrs = __pyx_mstate_global->__pyx_tuple[3];
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, &__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":736
 *                 self.visitchildren(arg)
 *         self.visitchildren(node, ('decorators',))
 *         self.stack.append((self.env, self.flow))             # <<<<<<<<<<<<<<
 *         self.env = node.local_scope
 *         self.flow = ControlFlow()
*/
  if (unlikely(__pyx_v_self->stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 736, __pyx_L1_error)
  }
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->env);
  __Pyx_GIVEREF(__pyx_v_self->env);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->env) != (0)) __PYX_ERR(0, 736, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->flow);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->flow);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self->flow)) != (0)) __PYX_ERR(0, 736, __pyx_L1_error);
  __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->stack, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 736, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":737
 *         self.visitchildren(node, ('decorators',))
 *         self.stack.append((self.env, self.flow))
 *         self.env = node.local_scope             # <<<<<<<<<<<<<<
 *         self.flow = ControlFlow()
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_local_scope); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->env);
  __Pyx_DECREF(__pyx_v_self->env);
  __pyx_v_self->env = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":738
 *         self.stack.append((self.env, self.flow))
 *         self.env = node.local_scope
 *         self.flow = ControlFlow()             # <<<<<<<<<<<<<<
 * 
 *         # Collect all entries
*/
  __pyx_t_1 = NULL;
  __pyx_t_8 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_callargs+__pyx_t_8, (1-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_2);
  }
  __Pyx_GIVEREF((PyObject *)__pyx_t_2);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow);
  __pyx_v_self->flow = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":741
 * 
 *         # Collect all entries
 *         for entry in node.local_scope.entries.values():             # <<<<<<<<<<<<<<
 *             if self.flow.is_tracked(entry):
 *                 self.flow.entries.add(entry)
*/
  __pyx_t_3 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_local_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_entries); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_11 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
    __PYX_ERR(0, 741, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_dict_iterator(__pyx_t_11, 0, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_9), (&__pyx_t_10)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_XDECREF(__pyx_t_2);
  __pyx_t_2 = __pyx_t_1;
  __pyx_t_1 = 0;
  while (1) {
    __pyx_t_12 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_9, &__pyx_t_3, NULL, &__pyx_t_1, NULL, __pyx_t_10);
    if (unlikely(__pyx_t_12 == 0)) break;
    if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":742
 *         # Collect all entries
 *         for entry in node.local_scope.entries.values():
 *             if self.flow.is_tracked(entry):             # <<<<<<<<<<<<<<
 *                 self.flow.entries.add(entry)
 * 
*/
    __pyx_t_5 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked(__pyx_v_self->flow, __pyx_v_entry, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 742, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "Cython/Compiler/FlowControl.py":743
 *         for entry in node.local_scope.entries.values():
 *             if self.flow.is_tracked(entry):
 *                 self.flow.entries.add(entry)             # <<<<<<<<<<<<<<
 * 
 *         self.mark_position(node)
*/
      if (unlikely(__pyx_v_self->flow->entries == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
        __PYX_ERR(0, 743, __pyx_L1_error)
      }
      __pyx_t_7 = PySet_Add(__pyx_v_self->flow->entries, __pyx_v_entry); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 743, __pyx_L1_error)

      /* "Cython/Compiler/FlowControl.py":742
 *         # Collect all entries
 *         for entry in node.local_scope.entries.values():
 *             if self.flow.is_tracked(entry):             # <<<<<<<<<<<<<<
 *                 self.flow.entries.add(entry)
 * 
*/
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":745
 *                 self.flow.entries.add(entry)
 * 
 *         self.mark_position(node)             # <<<<<<<<<<<<<<
 *         # Function body block
 *         self.flow.nextblock()
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":747
 *         self.mark_position(node)
 *         # Function body block
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 * 
 *         for arg in node.args:
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":749
 *         self.flow.nextblock()
 * 
 *         for arg in node.args:             # <<<<<<<<<<<<<<
 *             self._visit(arg)
 *         if node.star_arg:
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_9 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_9 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 749, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 749, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_9;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 749, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_9));
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_9);
        #endif
        ++__pyx_t_9;
      }
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 749, __pyx_L1_error)
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 749, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":750
 * 
 *         for arg in node.args:
 *             self._visit(arg)             # <<<<<<<<<<<<<<
 *         if node.star_arg:
 *             self.flow.mark_argument(node.star_arg,
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_arg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":749
 *         self.flow.nextblock()
 * 
 *         for arg in node.args:             # <<<<<<<<<<<<<<
 *             self._visit(arg)
 *         if node.star_arg:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":751
 *         for arg in node.args:
 *             self._visit(arg)
 *         if node.star_arg:             # <<<<<<<<<<<<<<
 *             self.flow.mark_argument(node.star_arg,
 *                                     TypedExprNode(Builtin.tuple_type,
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_star_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":752
 *             self._visit(arg)
 *         if node.star_arg:
 *             self.flow.mark_argument(node.star_arg,             # <<<<<<<<<<<<<<
 *                                     TypedExprNode(Builtin.tuple_type,
 *                                                   may_be_none=False),
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_star_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "Cython/Compiler/FlowControl.py":753
 *         if node.star_arg:
 *             self.flow.mark_argument(node.star_arg,
 *                                     TypedExprNode(Builtin.tuple_type,             # <<<<<<<<<<<<<<
 *                                                   may_be_none=False),
 *                                     node.star_arg.entry)
*/
    __pyx_t_11 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode);
    __pyx_t_13 = __pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode; 
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_Builtin, __pyx_mstate_global->__pyx_n_u_tuple_type); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);

    /* "Cython/Compiler/FlowControl.py":754
 *             self.flow.mark_argument(node.star_arg,
 *                                     TypedExprNode(Builtin.tuple_type,
 *                                                   may_be_none=False),             # <<<<<<<<<<<<<<
 *                                     node.star_arg.entry)
 *         if node.starstar_arg:
*/
    __pyx_t_8 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_13))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
      assert(__pyx_t_11);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
      __pyx_t_8 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_11, __pyx_t_14};
      __pyx_t_15 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 753, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_may_be_none, Py_False, __pyx_t_15, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 753, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_15);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 753, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }

    /* "Cython/Compiler/FlowControl.py":755
 *                                     TypedExprNode(Builtin.tuple_type,
 *                                                   may_be_none=False),
 *                                     node.star_arg.entry)             # <<<<<<<<<<<<<<
 *         if node.starstar_arg:
 *             self.flow.mark_argument(node.starstar_arg,
*/
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_star_arg); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "Cython/Compiler/FlowControl.py":752
 *             self._visit(arg)
 *         if node.star_arg:
 *             self.flow.mark_argument(node.star_arg,             # <<<<<<<<<<<<<<
 *                                     TypedExprNode(Builtin.tuple_type,
 *                                                   may_be_none=False),
*/
    __pyx_t_13 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_argument(__pyx_v_self->flow, __pyx_t_1, __pyx_t_2, __pyx_t_15, 0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "Cython/Compiler/FlowControl.py":751
 *         for arg in node.args:
 *             self._visit(arg)
 *         if node.star_arg:             # <<<<<<<<<<<<<<
 *             self.flow.mark_argument(node.star_arg,
 *                                     TypedExprNode(Builtin.tuple_type,
*/
  }

  /* "Cython/Compiler/FlowControl.py":756
 *                                                   may_be_none=False),
 *                                     node.star_arg.entry)
 *         if node.starstar_arg:             # <<<<<<<<<<<<<<
 *             self.flow.mark_argument(node.starstar_arg,
 *                                     TypedExprNode(Builtin.dict_type,
*/
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_starstar_arg); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":757
 *                                     node.star_arg.entry)
 *         if node.starstar_arg:
 *             self.flow.mark_argument(node.starstar_arg,             # <<<<<<<<<<<<<<
 *                                     TypedExprNode(Builtin.dict_type,
 *                                                   may_be_none=False),
*/
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_starstar_arg); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);

    /* "Cython/Compiler/FlowControl.py":758
 *         if node.starstar_arg:
 *             self.flow.mark_argument(node.starstar_arg,
 *                                     TypedExprNode(Builtin.dict_type,             # <<<<<<<<<<<<<<
 *                                                   may_be_none=False),
 *                                     node.starstar_arg.entry)
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode);
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode; 
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_Builtin, __pyx_mstate_global->__pyx_n_u_dict_type); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);

    /* "Cython/Compiler/FlowControl.py":759
 *             self.flow.mark_argument(node.starstar_arg,
 *                                     TypedExprNode(Builtin.dict_type,
 *                                                   may_be_none=False),             # <<<<<<<<<<<<<<
 *                                     node.starstar_arg.entry)
 *         self._visit(node.body)
*/
    __pyx_t_8 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
      __pyx_t_8 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_t_14};
      __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 758, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_may_be_none, Py_False, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 758, __pyx_L1_error)
      __pyx_t_15 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 758, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
    }

    /* "Cython/Compiler/FlowControl.py":760
 *                                     TypedExprNode(Builtin.dict_type,
 *                                                   may_be_none=False),
 *                                     node.starstar_arg.entry)             # <<<<<<<<<<<<<<
 *         self._visit(node.body)
 *         # Workaround for generators
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_starstar_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":757
 *                                     node.star_arg.entry)
 *         if node.starstar_arg:
 *             self.flow.mark_argument(node.starstar_arg,             # <<<<<<<<<<<<<<
 *                                     TypedExprNode(Builtin.dict_type,
 *                                                   may_be_none=False),
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_argument(__pyx_v_self->flow, __pyx_t_13, __pyx_t_15, __pyx_t_11, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":756
 *                                                   may_be_none=False),
 *                                     node.star_arg.entry)
 *         if node.starstar_arg:             # <<<<<<<<<<<<<<
 *             self.flow.mark_argument(node.starstar_arg,
 *                                     TypedExprNode(Builtin.dict_type,
*/
  }

  /* "Cython/Compiler/FlowControl.py":761
 *                                                   may_be_none=False),
 *                                     node.starstar_arg.entry)
 *         self._visit(node.body)             # <<<<<<<<<<<<<<
 *         # Workaround for generators
 *         if node.is_generator:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_11 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "Cython/Compiler/FlowControl.py":763
 *         self._visit(node.body)
 *         # Workaround for generators
 *         if node.is_generator:             # <<<<<<<<<<<<<<
 *             self._visit(node.gbody.body)
 * 
*/
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_is_generator); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 763, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":764
 *         # Workaround for generators
 *         if node.is_generator:
 *             self._visit(node.gbody.body)             # <<<<<<<<<<<<<<
 * 
 *         # Exit point
*/
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_gbody); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "Cython/Compiler/FlowControl.py":763
 *         self._visit(node.body)
 *         # Workaround for generators
 *         if node.is_generator:             # <<<<<<<<<<<<<<
 *             self._visit(node.gbody.body)
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":767
 * 
 *         # Exit point
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(self.flow.exit_point)
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 767, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":768
 *         # Exit point
 *         if self.flow.block:
 *             self.flow.block.add_child(self.flow.exit_point)             # <<<<<<<<<<<<<<
 * 
 *         # Cleanup graph
*/
    __pyx_t_11 = ((PyObject *)__pyx_v_self->flow->exit_point);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_11, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 768, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":767
 * 
 *         # Exit point
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(self.flow.exit_point)
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":771
 * 
 *         # Cleanup graph
 *         self.flow.normalize()             # <<<<<<<<<<<<<<
 *         check_definitions(self.flow, self.current_directives)
 *         self.flow.blocks.add(self.flow.entry_point)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_normalize(__pyx_v_self->flow, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":772
 *         # Cleanup graph
 *         self.flow.normalize()
 *         check_definitions(self.flow, self.current_directives)             # <<<<<<<<<<<<<<
 *         self.flow.blocks.add(self.flow.entry_point)
 * 
*/
  if (unlikely(((PyObject *)__pyx_v_self->flow) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 772, __pyx_L1_error)
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_self->flow);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_11 = __pyx_v_self->__pyx_base.current_directives;
  __Pyx_INCREF(__pyx_t_11);
  if (!(likely(PyDict_CheckExact(__pyx_t_11))||((__pyx_t_11) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_11))) __PYX_ERR(0, 772, __pyx_L1_error)
  if (unlikely(__pyx_t_11 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 772, __pyx_L1_error)
  }
  __pyx_t_15 = __pyx_f_6Cython_8Compiler_11FlowControl_check_definitions(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_t_1), ((PyObject*)__pyx_t_11)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "Cython/Compiler/FlowControl.py":773
 *         self.flow.normalize()
 *         check_definitions(self.flow, self.current_directives)
 *         self.flow.blocks.add(self.flow.entry_point)             # <<<<<<<<<<<<<<
 * 
 *         if self.gv_ctx is not None:
*/
  if (unlikely(__pyx_v_self->flow->blocks == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(0, 773, __pyx_L1_error)
  }
  __pyx_t_15 = ((PyObject *)__pyx_v_self->flow->entry_point);
  __Pyx_INCREF(__pyx_t_15);
  __pyx_t_7 = PySet_Add(__pyx_v_self->flow->blocks, __pyx_t_15); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 773, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "Cython/Compiler/FlowControl.py":775
 *         self.flow.blocks.add(self.flow.entry_point)
 * 
 *         if self.gv_ctx is not None:             # <<<<<<<<<<<<<<
 *             self.gv_ctx.add(GV(node.local_scope.name, self.flow))
 * 
*/
  __pyx_t_5 = (__pyx_v_self->gv_ctx != Py_None);
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":776
 * 
 *         if self.gv_ctx is not None:
 *             self.gv_ctx.add(GV(node.local_scope.name, self.flow))             # <<<<<<<<<<<<<<
 * 
 *         self.env, self.flow = self.stack.pop()
*/
    __pyx_t_11 = __pyx_v_self->gv_ctx;
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_13 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_GV); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 776, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_local_scope); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 776, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 776, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
      assert(__pyx_t_13);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
      __pyx_t_8 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_t_16, ((PyObject *)__pyx_v_self->flow)};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 776, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_1};
      __pyx_t_15 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 776, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "Cython/Compiler/FlowControl.py":775
 *         self.flow.blocks.add(self.flow.entry_point)
 * 
 *         if self.gv_ctx is not None:             # <<<<<<<<<<<<<<
 *             self.gv_ctx.add(GV(node.local_scope.name, self.flow))
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":778
 *             self.gv_ctx.add(GV(node.local_scope.name, self.flow))
 * 
 *         self.env, self.flow = self.stack.pop()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  if (unlikely(__pyx_v_self->stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 778, __pyx_L1_error)
  }
  __pyx_t_15 = __Pyx_PyList_Pop(__pyx_v_self->stack); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  if ((likely(PyTuple_CheckExact(__pyx_t_15))) || (PyList_CheckExact(__pyx_t_15))) {
    PyObject* sequence = __pyx_t_15;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 778, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_11);
    } else {
      __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 778, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 778, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_11);
    }
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    #endif
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_14 = PyObject_GetIter(__pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_17 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_14);
    index = 0; __pyx_t_1 = __pyx_t_17(__pyx_t_14); if (unlikely(!__pyx_t_1)) goto __pyx_L18_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_11 = __pyx_t_17(__pyx_t_14); if (unlikely(!__pyx_t_11)) goto __pyx_L18_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_11);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_17(__pyx_t_14), 2) < (0)) __PYX_ERR(0, 778, __pyx_L1_error)
    __pyx_t_17 = NULL;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    goto __pyx_L19_unpacking_done;
    __pyx_L18_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_17 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 778, __pyx_L1_error)
    __pyx_L19_unpacking_done:;
  }
  if (!(likely(((__pyx_t_11) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_11, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow))))) __PYX_ERR(0, 778, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->env);
  __Pyx_DECREF(__pyx_v_self->env);
  __pyx_v_self->env = __pyx_t_1;
  __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_11);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow);
  __pyx_v_self->flow = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_t_11);
  __pyx_t_11 = 0;

  /* "Cython/Compiler/FlowControl.py":779
 * 
 *         self.env, self.flow = self.stack.pop()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_DefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":731
 *         return node
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         for arg in node.args:
 *             if arg.default:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_FuncDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":781
 *         return node
 * 
 *     def visit_DefNode(self, node):             # <<<<<<<<<<<<<<
 *         node.used = True
 *         return self.visit_FuncDefNode(node)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_7visit_DefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_7visit_DefNode = {"visit_DefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_7visit_DefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_7visit_DefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_DefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_6visit_DefNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_6visit_DefNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_DefNode", 0);

  /* "Cython/Compiler/FlowControl.py":782
 * 
 *     def visit_DefNode(self, node):
 *         node.used = True             # <<<<<<<<<<<<<<
 *         return self.visit_FuncDefNode(node)
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_used, Py_True) < (0)) __PYX_ERR(0, 782, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":783
 *     def visit_DefNode(self, node):
 *         node.used = True
 *         return self.visit_FuncDefNode(node)             # <<<<<<<<<<<<<<
 * 
 *     def visit_GeneratorBodyDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_node};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visit_FuncDefNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":781
 *         return node
 * 
 *     def visit_DefNode(self, node):             # <<<<<<<<<<<<<<
 *         node.used = True
 *         return self.visit_FuncDefNode(node)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_DefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":785
 *         return self.visit_FuncDefNode(node)
 * 
 *     def visit_GeneratorBodyDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_9visit_GeneratorBodyDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_9visit_GeneratorBodyDefNode = {"visit_GeneratorBodyDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_9visit_GeneratorBodyDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_9visit_GeneratorBodyDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_GeneratorBodyDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_8visit_GeneratorBodyDefNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_8visit_GeneratorBodyDefNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_GeneratorBodyDefNode", 0);

  /* "Cython/Compiler/FlowControl.py":786
 * 
 *     def visit_GeneratorBodyDefNode(self, node):
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CTypeDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":785
 *         return self.visit_FuncDefNode(node)
 * 
 *     def visit_GeneratorBodyDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":788
 *         return node
 * 
 *     def visit_CTypeDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_11visit_CTypeDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_11visit_CTypeDefNode = {"visit_CTypeDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_11visit_CTypeDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_11visit_CTypeDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CTypeDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_10visit_CTypeDefNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_10visit_CTypeDefNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CTypeDefNode", 0);

  /* "Cython/Compiler/FlowControl.py":789
 * 
 *     def visit_CTypeDefNode(self, node):
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def mark_assignment(self, lhs, rhs=None, rhs_scope=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":788
 *         return node
 * 
 *     def visit_CTypeDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":791
 *         return node
 * 
 *     def mark_assignment(self, lhs, rhs=None, rhs_scope=None):             # <<<<<<<<<<<<<<
 *         if not self.flow.block:
 *             return
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_13mark_assignment(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_lhs, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment *__pyx_optional_args) {
  PyObject *__pyx_v_rhs = ((PyObject *)Py_None);
  PyObject *__pyx_v_rhs_scope = ((PyObject *)Py_None);
  PyObject *__pyx_v_exc_descr = NULL;
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_item_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_assignment", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_rhs = __pyx_optional_args->rhs;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_rhs_scope = __pyx_optional_args->rhs_scope;
      }
    }
  }
  __Pyx_INCREF(__pyx_v_rhs);

  /* "Cython/Compiler/FlowControl.py":792
 * 
 *     def mark_assignment(self, lhs, rhs=None, rhs_scope=None):
 *         if not self.flow.block:             # <<<<<<<<<<<<<<
 *             return
 *         if self.flow.exceptions:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 792, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":793
 *     def mark_assignment(self, lhs, rhs=None, rhs_scope=None):
 *         if not self.flow.block:
 *             return             # <<<<<<<<<<<<<<
 *         if self.flow.exceptions:
 *             exc_descr = self.flow.exceptions[-1]
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":792
 * 
 *     def mark_assignment(self, lhs, rhs=None, rhs_scope=None):
 *         if not self.flow.block:             # <<<<<<<<<<<<<<
 *             return
 *         if self.flow.exceptions:
*/
  }

  /* "Cython/Compiler/FlowControl.py":794
 *         if not self.flow.block:
 *             return
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             exc_descr = self.flow.exceptions[-1]
 *             self.flow.block.add_child(exc_descr.entry_point)
*/
  if (__pyx_v_self->flow->exceptions == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->exceptions);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 794, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":795
 *             return
 *         if self.flow.exceptions:
 *             exc_descr = self.flow.exceptions[-1]             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(exc_descr.entry_point)
 *             self.flow.nextblock()
*/
    if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 795, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->flow->exceptions, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_exc_descr = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":796
 *         if self.flow.exceptions:
 *             exc_descr = self.flow.exceptions[-1]
 *             self.flow.block.add_child(exc_descr.entry_point)             # <<<<<<<<<<<<<<
 *             self.flow.nextblock()
 * 
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc_descr, __pyx_mstate_global->__pyx_n_u_entry_point); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_3, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":797
 *             exc_descr = self.flow.exceptions[-1]
 *             self.flow.block.add_child(exc_descr.entry_point)
 *             self.flow.nextblock()             # <<<<<<<<<<<<<<
 * 
 *         if not rhs:
*/
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 797, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":794
 *         if not self.flow.block:
 *             return
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             exc_descr = self.flow.exceptions[-1]
 *             self.flow.block.add_child(exc_descr.entry_point)
*/
  }

  /* "Cython/Compiler/FlowControl.py":799
 *             self.flow.nextblock()
 * 
 *         if not rhs:             # <<<<<<<<<<<<<<
 *             rhs = self.object_expr
 *         if lhs.is_name:
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_rhs); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 799, __pyx_L1_error)
  __pyx_t_1 = (!__pyx_t_2);
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":800
 * 
 *         if not rhs:
 *             rhs = self.object_expr             # <<<<<<<<<<<<<<
 *         if lhs.is_name:
 *             if lhs.entry is not None:
*/
    __pyx_t_4 = __pyx_v_self->object_expr;
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_rhs, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":799
 *             self.flow.nextblock()
 * 
 *         if not rhs:             # <<<<<<<<<<<<<<
 *             rhs = self.object_expr
 *         if lhs.is_name:
*/
  }

  /* "Cython/Compiler/FlowControl.py":801
 *         if not rhs:
 *             rhs = self.object_expr
 *         if lhs.is_name:             # <<<<<<<<<<<<<<
 *             if lhs.entry is not None:
 *                 entry = lhs.entry
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 801, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":802
 *             rhs = self.object_expr
 *         if lhs.is_name:
 *             if lhs.entry is not None:             # <<<<<<<<<<<<<<
 *                 entry = lhs.entry
 *             else:
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 802, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = (__pyx_t_4 != Py_None);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/FlowControl.py":803
 *         if lhs.is_name:
 *             if lhs.entry is not None:
 *                 entry = lhs.entry             # <<<<<<<<<<<<<<
 *             else:
 *                 entry = self.env.lookup(lhs.name)
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_entry = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "Cython/Compiler/FlowControl.py":802
 *             rhs = self.object_expr
 *         if lhs.is_name:
 *             if lhs.entry is not None:             # <<<<<<<<<<<<<<
 *                 entry = lhs.entry
 *             else:
*/
      goto __pyx_L7;
    }

    /* "Cython/Compiler/FlowControl.py":805
 *                 entry = lhs.entry
 *             else:
 *                 entry = self.env.lookup(lhs.name)             # <<<<<<<<<<<<<<
 *             if entry is None:  # TODO: This shouldn't happen...
 *                 return
*/
    /*else*/ {
      __pyx_t_3 = __pyx_v_self->env;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 805, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_v_entry = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __pyx_L7:;

    /* "Cython/Compiler/FlowControl.py":806
 *             else:
 *                 entry = self.env.lookup(lhs.name)
 *             if entry is None:  # TODO: This shouldn't happen...             # <<<<<<<<<<<<<<
 *                 return
 *             self.flow.mark_assignment(lhs, rhs, entry, rhs_scope=(rhs_scope or self.env))
*/
    __pyx_t_1 = (__pyx_v_entry == Py_None);
    if (__pyx_t_1) {

      /* "Cython/Compiler/FlowControl.py":807
 *                 entry = self.env.lookup(lhs.name)
 *             if entry is None:  # TODO: This shouldn't happen...
 *                 return             # <<<<<<<<<<<<<<
 *             self.flow.mark_assignment(lhs, rhs, entry, rhs_scope=(rhs_scope or self.env))
 *         elif lhs.is_sequence_constructor:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "Cython/Compiler/FlowControl.py":806
 *             else:
 *                 entry = self.env.lookup(lhs.name)
 *             if entry is None:  # TODO: This shouldn't happen...             # <<<<<<<<<<<<<<
 *                 return
 *             self.flow.mark_assignment(lhs, rhs, entry, rhs_scope=(rhs_scope or self.env))
*/
    }

    /* "Cython/Compiler/FlowControl.py":808
 *             if entry is None:  # TODO: This shouldn't happen...
 *                 return
 *             self.flow.mark_assignment(lhs, rhs, entry, rhs_scope=(rhs_scope or self.env))             # <<<<<<<<<<<<<<
 *         elif lhs.is_sequence_constructor:
 *             for i, arg in enumerate(lhs.args):
*/
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_rhs_scope); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 808, __pyx_L1_error)
    if (!__pyx_t_1) {
    } else {
      __Pyx_INCREF(__pyx_v_rhs_scope);
      __pyx_t_4 = __pyx_v_rhs_scope;
      goto __pyx_L9_bool_binop_done;
    }
    __Pyx_INCREF(__pyx_v_self->env);
    __pyx_t_4 = __pyx_v_self->env;
    __pyx_L9_bool_binop_done:;
    __pyx_t_7.__pyx_n = 1;
    __pyx_t_7.rhs_scope = __pyx_t_4;
    __pyx_t_5 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment(__pyx_v_self->flow, __pyx_v_lhs, __pyx_v_rhs, __pyx_v_entry, 0, &__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 808, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":801
 *         if not rhs:
 *             rhs = self.object_expr
 *         if lhs.is_name:             # <<<<<<<<<<<<<<
 *             if lhs.entry is not None:
 *                 entry = lhs.entry
*/
    goto __pyx_L6;
  }

  /* "Cython/Compiler/FlowControl.py":809
 *                 return
 *             self.flow.mark_assignment(lhs, rhs, entry, rhs_scope=(rhs_scope or self.env))
 *         elif lhs.is_sequence_constructor:             # <<<<<<<<<<<<<<
 *             for i, arg in enumerate(lhs.args):
 *                 if arg.is_starred:
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_is_sequence_constructor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":810
 *             self.flow.mark_assignment(lhs, rhs, entry, rhs_scope=(rhs_scope or self.env))
 *         elif lhs.is_sequence_constructor:
 *             for i, arg in enumerate(lhs.args):             # <<<<<<<<<<<<<<
 *                 if arg.is_starred:
 *                     # "a, *b = x" assigns a list to "b"
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
    __pyx_t_5 = __pyx_mstate_global->__pyx_int_0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 810, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 810, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 810, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_8;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 810, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_8));
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_8);
          #endif
          ++__pyx_t_8;
        }
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 810, __pyx_L1_error)
      } else {
        __pyx_t_4 = __pyx_t_9(__pyx_t_3);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 810, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_4 = __Pyx_PyLong_AddObjC(__pyx_t_5, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5);
      __pyx_t_5 = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "Cython/Compiler/FlowControl.py":811
 *         elif lhs.is_sequence_constructor:
 *             for i, arg in enumerate(lhs.args):
 *                 if arg.is_starred:             # <<<<<<<<<<<<<<
 *                     # "a, *b = x" assigns a list to "b"
 *                     item_node = TypedExprNode(Builtin.list_type, may_be_none=False, pos=arg.pos)
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_is_starred); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 811, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 811, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_1) {

        /* "Cython/Compiler/FlowControl.py":813
 *                 if arg.is_starred:
 *                     # "a, *b = x" assigns a list to "b"
 *                     item_node = TypedExprNode(Builtin.list_type, may_be_none=False, pos=arg.pos)             # <<<<<<<<<<<<<<
 *                 elif rhs is self.object_expr:
 *                     item_node = rhs
*/
        __pyx_t_10 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode);
        __pyx_t_11 = __pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode; 
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_Builtin, __pyx_mstate_global->__pyx_n_u_list_type); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
          assert(__pyx_t_10);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_10, __pyx_t_12};
          __pyx_t_14 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 813, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_may_be_none, Py_False, __pyx_t_14, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 813, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_13, __pyx_t_14, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 813, __pyx_L1_error)
          __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_14);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 813, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_item_node, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Compiler/FlowControl.py":811
 *         elif lhs.is_sequence_constructor:
 *             for i, arg in enumerate(lhs.args):
 *                 if arg.is_starred:             # <<<<<<<<<<<<<<
 *                     # "a, *b = x" assigns a list to "b"
 *                     item_node = TypedExprNode(Builtin.list_type, may_be_none=False, pos=arg.pos)
*/
        goto __pyx_L13;
      }

      /* "Cython/Compiler/FlowControl.py":814
 *                     # "a, *b = x" assigns a list to "b"
 *                     item_node = TypedExprNode(Builtin.list_type, may_be_none=False, pos=arg.pos)
 *                 elif rhs is self.object_expr:             # <<<<<<<<<<<<<<
 *                     item_node = rhs
 *                 else:
*/
      __pyx_t_1 = (__pyx_v_rhs == __pyx_v_self->object_expr);
      if (__pyx_t_1) {

        /* "Cython/Compiler/FlowControl.py":815
 *                     item_node = TypedExprNode(Builtin.list_type, may_be_none=False, pos=arg.pos)
 *                 elif rhs is self.object_expr:
 *                     item_node = rhs             # <<<<<<<<<<<<<<
 *                 else:
 *                     item_node = rhs.inferable_item_node(i)
*/
        __Pyx_INCREF(__pyx_v_rhs);
        __Pyx_XDECREF_SET(__pyx_v_item_node, __pyx_v_rhs);

        /* "Cython/Compiler/FlowControl.py":814
 *                     # "a, *b = x" assigns a list to "b"
 *                     item_node = TypedExprNode(Builtin.list_type, may_be_none=False, pos=arg.pos)
 *                 elif rhs is self.object_expr:             # <<<<<<<<<<<<<<
 *                     item_node = rhs
 *                 else:
*/
        goto __pyx_L13;
      }

      /* "Cython/Compiler/FlowControl.py":817
 *                     item_node = rhs
 *                 else:
 *                     item_node = rhs.inferable_item_node(i)             # <<<<<<<<<<<<<<
 *                 self.mark_assignment(arg, item_node, rhs_scope=rhs_scope)
 *         else:
*/
      /*else*/ {
        __pyx_t_11 = __pyx_v_rhs;
        __Pyx_INCREF(__pyx_t_11);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_i};
          __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_inferable_item_node, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_item_node, __pyx_t_4);
        __pyx_t_4 = 0;
      }
      __pyx_L13:;

      /* "Cython/Compiler/FlowControl.py":818
 *                 else:
 *                     item_node = rhs.inferable_item_node(i)
 *                 self.mark_assignment(arg, item_node, rhs_scope=rhs_scope)             # <<<<<<<<<<<<<<
 *         else:
 *             self._visit(lhs)
*/
      __pyx_t_15.__pyx_n = 2;
      __pyx_t_15.rhs = __pyx_v_item_node;
      __pyx_t_15.rhs_scope = __pyx_v_rhs_scope;
      __pyx_t_4 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_arg, 0, &__pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "Cython/Compiler/FlowControl.py":810
 *             self.flow.mark_assignment(lhs, rhs, entry, rhs_scope=(rhs_scope or self.env))
 *         elif lhs.is_sequence_constructor:
 *             for i, arg in enumerate(lhs.args):             # <<<<<<<<<<<<<<
 *                 if arg.is_starred:
 *                     # "a, *b = x" assigns a list to "b"
*/
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":809
 *                 return
 *             self.flow.mark_assignment(lhs, rhs, entry, rhs_scope=(rhs_scope or self.env))
 *         elif lhs.is_sequence_constructor:             # <<<<<<<<<<<<<<
 *             for i, arg in enumerate(lhs.args):
 *                 if arg.is_starred:
*/
    goto __pyx_L6;
  }

  /* "Cython/Compiler/FlowControl.py":820
 *                 self.mark_assignment(arg, item_node, rhs_scope=rhs_scope)
 *         else:
 *             self._visit(lhs)             # <<<<<<<<<<<<<<
 * 
 *         if self.flow.exceptions:
*/
  /*else*/ {
    __pyx_t_5 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_lhs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_L6:;

  /* "Cython/Compiler/FlowControl.py":822
 *             self._visit(lhs)
 * 
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             exc_descr = self.flow.exceptions[-1]
 *             self.flow.block.add_child(exc_descr.entry_point)
*/
  if (__pyx_v_self->flow->exceptions == Py_None) __pyx_t_1 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->exceptions);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 822, __pyx_L1_error)
    __pyx_t_1 = (__pyx_temp != 0);
  }

  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":823
 * 
 *         if self.flow.exceptions:
 *             exc_descr = self.flow.exceptions[-1]             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(exc_descr.entry_point)
 *             self.flow.nextblock()
*/
    if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 823, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_self->flow->exceptions, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_exc_descr, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":824
 *         if self.flow.exceptions:
 *             exc_descr = self.flow.exceptions[-1]
 *             self.flow.block.add_child(exc_descr.entry_point)             # <<<<<<<<<<<<<<
 *             self.flow.nextblock()
 * 
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc_descr, __pyx_mstate_global->__pyx_n_u_entry_point); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_5, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":825
 *             exc_descr = self.flow.exceptions[-1]
 *             self.flow.block.add_child(exc_descr.entry_point)
 *             self.flow.nextblock()             # <<<<<<<<<<<<<<
 * 
 *     def mark_position(self, node):
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":822
 *             self._visit(lhs)
 * 
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             exc_descr = self.flow.exceptions[-1]
 *             self.flow.block.add_child(exc_descr.entry_point)
*/
  }

  /* "Cython/Compiler/FlowControl.py":791
 *         return node
 * 
 *     def mark_assignment(self, lhs, rhs=None, rhs_scope=None):             # <<<<<<<<<<<<<<
 *         if not self.flow.block:
 *             return
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.mark_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc_descr);
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_item_node);
  __Pyx_XDECREF(__pyx_v_rhs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_13mark_assignment(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_13mark_assignment = {"mark_assignment", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_13mark_assignment, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_13mark_assignment(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_lhs = 0;
  PyObject *__pyx_v_rhs = 0;
  PyObject *__pyx_v_rhs_scope = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_assignment (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_lhs,&__pyx_mstate_global->__pyx_n_u_rhs,&__pyx_mstate_global->__pyx_n_u_rhs_scope,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 791, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 791, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 791, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 791, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "mark_assignment", 0) < (0)) __PYX_ERR(0, 791, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("mark_assignment", 0, 1, 3, i); __PYX_ERR(0, 791, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 791, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 791, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 791, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_lhs = values[0];
    __pyx_v_rhs = values[1];
    __pyx_v_rhs_scope = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mark_assignment", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 791, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.mark_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_12mark_assignment(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), __pyx_v_lhs, __pyx_v_rhs, __pyx_v_rhs_scope);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_12mark_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_lhs, PyObject *__pyx_v_rhs, PyObject *__pyx_v_rhs_scope) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_assignment", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.rhs = __pyx_v_rhs;
  __pyx_t_2.rhs_scope = __pyx_v_rhs_scope;
  __pyx_t_1 = __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis->mark_assignment(__pyx_v_self, __pyx_v_lhs, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.mark_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":827
 *             self.flow.nextblock()
 * 
 *     def mark_position(self, node):             # <<<<<<<<<<<<<<
 *         """Mark position if DOT output is enabled."""
 *         if self.current_directives['control_flow.dot_output']:
*/

static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_15mark_position(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_position", 0);

  /* "Cython/Compiler/FlowControl.py":829
 *     def mark_position(self, node):
 *         """Mark position if DOT output is enabled."""
 *         if self.current_directives['control_flow.dot_output']:             # <<<<<<<<<<<<<<
 *             self.flow.mark_position(node)
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->__pyx_base.current_directives, __pyx_mstate_global->__pyx_kp_u_control_flow_dot_output); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":830
 *         """Mark position if DOT output is enabled."""
 *         if self.current_directives['control_flow.dot_output']:
 *             self.flow.mark_position(node)             # <<<<<<<<<<<<<<
 * 
 *     def visit_FromImportStatNode(self, node):
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_position(__pyx_v_self->flow, __pyx_v_node, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":829
 *     def mark_position(self, node):
 *         """Mark position if DOT output is enabled."""
 *         if self.current_directives['control_flow.dot_output']:             # <<<<<<<<<<<<<<
 *             self.flow.mark_position(node)
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":827
 *             self.flow.nextblock()
 * 
 *     def mark_position(self, node):             # <<<<<<<<<<<<<<
 *         """Mark position if DOT output is enabled."""
 *         if self.current_directives['control_flow.dot_output']:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.mark_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_15mark_position(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_14mark_position, "Mark position if DOT output is enabled.");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_15mark_position = {"mark_position", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_15mark_position, METH_O, __pyx_doc_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_14mark_position};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_15mark_position(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_position (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_14mark_position(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_14mark_position(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_position", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.mark_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":832
 *             self.flow.mark_position(node)
 * 
 *     def visit_FromImportStatNode(self, node):             # <<<<<<<<<<<<<<
 *         for name, target in node.items:
 *             if name != "*":
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_17visit_FromImportStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_17visit_FromImportStatNode = {"visit_FromImportStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_17visit_FromImportStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_17visit_FromImportStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_FromImportStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_16visit_FromImportStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_16visit_FromImportStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_FromImportStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":833
 * 
 *     def visit_FromImportStatNode(self, node):
 *         for name, target in node.items:             # <<<<<<<<<<<<<<
 *             if name != "*":
 *                 self.mark_assignment(target)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_items); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 833, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 833, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 833, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 833, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 833, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_6);
      } else {
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 833, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 833, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
      }
      #else
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < (0)) __PYX_ERR(0, 833, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 833, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_target, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/FlowControl.py":834
 *     def visit_FromImportStatNode(self, node):
 *         for name, target in node.items:
 *             if name != "*":             # <<<<<<<<<<<<<<
 *                 self.mark_assignment(target)
 *         self.visitchildren(node)
*/
    __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_kp_u__18, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 834, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "Cython/Compiler/FlowControl.py":835
 *         for name, target in node.items:
 *             if name != "*":
 *                 self.mark_assignment(target)             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         return node
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_target, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 835, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":834
 *     def visit_FromImportStatNode(self, node):
 *         for name, target in node.items:
 *             if name != "*":             # <<<<<<<<<<<<<<
 *                 self.mark_assignment(target)
 *         self.visitchildren(node)
*/
    }

    /* "Cython/Compiler/FlowControl.py":833
 * 
 *     def visit_FromImportStatNode(self, node):
 *         for name, target in node.items:             # <<<<<<<<<<<<<<
 *             if name != "*":
 *                 self.mark_assignment(target)
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":836
 *             if name != "*":
 *                 self.mark_assignment(target)
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":837
 *                 self.mark_assignment(target)
 *         self.visitchildren(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_AssignmentNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":832
 *             self.flow.mark_position(node)
 * 
 *     def visit_FromImportStatNode(self, node):             # <<<<<<<<<<<<<<
 *         for name, target in node.items:
 *             if name != "*":
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_FromImportStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":839
 *         return node
 * 
 *     def visit_AssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         raise InternalError("Unhandled assignment node %s" % type(node))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_19visit_AssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_19visit_AssignmentNode = {"visit_AssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_19visit_AssignmentNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_19visit_AssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_AssignmentNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_18visit_AssignmentNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_18visit_AssignmentNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_AssignmentNode", 0);

  /* "Cython/Compiler/FlowControl.py":840
 * 
 *     def visit_AssignmentNode(self, node):
 *         raise InternalError("Unhandled assignment node %s" % type(node))             # <<<<<<<<<<<<<<
 * 
 *     def visit_SingleAssignmentNode(self, node):
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_InternalError);
  __pyx_t_3 = __pyx_v_6Cython_8Compiler_11FlowControl_InternalError; 
  __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Unhandled_assignment_node_s, ((PyObject *)Py_TYPE(__pyx_v_node))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 840, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":839
 *         return node
 * 
 *     def visit_AssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         raise InternalError("Unhandled assignment node %s" % type(node))
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_AssignmentNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":842
 *         raise InternalError("Unhandled assignment node %s" % type(node))
 * 
 *     def visit_SingleAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.rhs)
 *         self.mark_assignment(node.lhs, node.rhs)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_21visit_SingleAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_21visit_SingleAssignmentNode = {"visit_SingleAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_21visit_SingleAssignmentNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_21visit_SingleAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_SingleAssignmentNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_20visit_SingleAssignmentNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_20visit_SingleAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_SingleAssignmentNode", 0);

  /* "Cython/Compiler/FlowControl.py":843
 * 
 *     def visit_SingleAssignmentNode(self, node):
 *         self._visit(node.rhs)             # <<<<<<<<<<<<<<
 *         self.mark_assignment(node.lhs, node.rhs)
 *         return node
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":844
 *     def visit_SingleAssignmentNode(self, node):
 *         self._visit(node.rhs)
 *         self.mark_assignment(node.lhs, node.rhs)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_lhs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4.__pyx_n = 1;
  __pyx_t_4.rhs = __pyx_t_1;
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_2, 0, &__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":845
 *         self._visit(node.rhs)
 *         self.mark_assignment(node.lhs, node.rhs)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CascadedAssignmentNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":842
 *         raise InternalError("Unhandled assignment node %s" % type(node))
 * 
 *     def visit_SingleAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.rhs)
 *         self.mark_assignment(node.lhs, node.rhs)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_SingleAssignmentNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":847
 *         return node
 * 
 *     def visit_CascadedAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.rhs)
 *         for lhs in node.lhs_list:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_23visit_CascadedAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_23visit_CascadedAssignmentNode = {"visit_CascadedAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_23visit_CascadedAssignmentNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_23visit_CascadedAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CascadedAssignmentNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_22visit_CascadedAssignmentNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_22visit_CascadedAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_lhs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CascadedAssignmentNode", 0);

  /* "Cython/Compiler/FlowControl.py":848
 * 
 *     def visit_CascadedAssignmentNode(self, node):
 *         self._visit(node.rhs)             # <<<<<<<<<<<<<<
 *         for lhs in node.lhs_list:
 *             self.mark_assignment(lhs, node.rhs)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":849
 *     def visit_CascadedAssignmentNode(self, node):
 *         self._visit(node.rhs)
 *         for lhs in node.lhs_list:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(lhs, node.rhs)
 *         return node
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_lhs_list); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 849, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 849, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 849, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 849, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3));
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 849, __pyx_L1_error)
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 849, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_lhs, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":850
 *         self._visit(node.rhs)
 *         for lhs in node.lhs_list:
 *             self.mark_assignment(lhs, node.rhs)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6.__pyx_n = 1;
    __pyx_t_6.rhs = __pyx_t_2;
    __pyx_t_5 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_lhs, 0, &__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":849
 *     def visit_CascadedAssignmentNode(self, node):
 *         self._visit(node.rhs)
 *         for lhs in node.lhs_list:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(lhs, node.rhs)
 *         return node
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":851
 *         for lhs in node.lhs_list:
 *             self.mark_assignment(lhs, node.rhs)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ParallelAssignmentNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":847
 *         return node
 * 
 *     def visit_CascadedAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.rhs)
 *         for lhs in node.lhs_list:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_CascadedAssignmentNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lhs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":853
 *         return node
 * 
 *     def visit_ParallelAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         collector = AssignmentCollector()
 *         collector.visitchildren(node)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_25visit_ParallelAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_25visit_ParallelAssignmentNode = {"visit_ParallelAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_25visit_ParallelAssignmentNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_25visit_ParallelAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ParallelAssignmentNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_24visit_ParallelAssignmentNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_24visit_ParallelAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v_collector = NULL;
  PyObject *__pyx_v_lhs = NULL;
  PyObject *__pyx_v_rhs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ParallelAssignmentNode", 0);

  /* "Cython/Compiler/FlowControl.py":854
 * 
 *     def visit_ParallelAssignmentNode(self, node):
 *         collector = AssignmentCollector()             # <<<<<<<<<<<<<<
 *         collector.visitchildren(node)
 *         for lhs, rhs in collector.assignments:
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 854, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_collector = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":855
 *     def visit_ParallelAssignmentNode(self, node):
 *         collector = AssignmentCollector()
 *         collector.visitchildren(node)             # <<<<<<<<<<<<<<
 *         for lhs, rhs in collector.assignments:
 *             self._visit(rhs)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v_collector->__pyx_base.__pyx_vtab)->__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_collector), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":856
 *         collector = AssignmentCollector()
 *         collector.visitchildren(node)
 *         for lhs, rhs in collector.assignments:             # <<<<<<<<<<<<<<
 *             self._visit(rhs)
 *         for lhs, rhs in collector.assignments:
*/
  if (unlikely(__pyx_v_collector->assignments == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 856, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_collector->assignments; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 856, __pyx_L1_error)
      #endif
      if (__pyx_t_4 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_4, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_4;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 856, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 856, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_6);
      } else {
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 856, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 856, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
      }
      #else
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < (0)) __PYX_ERR(0, 856, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 856, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_lhs, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_rhs, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/FlowControl.py":857
 *         collector.visitchildren(node)
 *         for lhs, rhs in collector.assignments:
 *             self._visit(rhs)             # <<<<<<<<<<<<<<
 *         for lhs, rhs in collector.assignments:
 *             self.mark_assignment(lhs, rhs)
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_rhs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":856
 *         collector = AssignmentCollector()
 *         collector.visitchildren(node)
 *         for lhs, rhs in collector.assignments:             # <<<<<<<<<<<<<<
 *             self._visit(rhs)
 *         for lhs, rhs in collector.assignments:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":858
 *         for lhs, rhs in collector.assignments:
 *             self._visit(rhs)
 *         for lhs, rhs in collector.assignments:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(lhs, rhs)
 *         return node
*/
  if (unlikely(__pyx_v_collector->assignments == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 858, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_collector->assignments; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 858, __pyx_L1_error)
      #endif
      if (__pyx_t_4 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_4, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_4;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 858, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_5);
      } else {
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 858, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 858, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
      }
      #else
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 858, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 858, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 858, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L10_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L10_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < (0)) __PYX_ERR(0, 858, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L11_unpacking_done;
      __pyx_L10_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 858, __pyx_L1_error)
      __pyx_L11_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_lhs, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_rhs, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":859
 *             self._visit(rhs)
 *         for lhs, rhs in collector.assignments:
 *             self.mark_assignment(lhs, rhs)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    __pyx_t_9.__pyx_n = 1;
    __pyx_t_9.rhs = __pyx_v_rhs;
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_lhs, 0, &__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":858
 *         for lhs, rhs in collector.assignments:
 *             self._visit(rhs)
 *         for lhs, rhs in collector.assignments:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(lhs, rhs)
 *         return node
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":860
 *         for lhs, rhs in collector.assignments:
 *             self.mark_assignment(lhs, rhs)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_InPlaceAssignmentNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":853
 *         return node
 * 
 *     def visit_ParallelAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         collector = AssignmentCollector()
 *         collector.visitchildren(node)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ParallelAssignmentNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_collector);
  __Pyx_XDECREF(__pyx_v_lhs);
  __Pyx_XDECREF(__pyx_v_rhs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":862
 *         return node
 * 
 *     def visit_InPlaceAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self.in_inplace_assignment = True
 *         self.visitchildren(node)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_27visit_InPlaceAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_27visit_InPlaceAssignmentNode = {"visit_InPlaceAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_27visit_InPlaceAssignmentNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_27visit_InPlaceAssignmentNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_InPlaceAssignmentNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_26visit_InPlaceAssignmentNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_26visit_InPlaceAssignmentNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_InPlaceAssignmentNode", 0);

  /* "Cython/Compiler/FlowControl.py":863
 * 
 *     def visit_InPlaceAssignmentNode(self, node):
 *         self.in_inplace_assignment = True             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         self.in_inplace_assignment = False
*/
  __pyx_v_self->in_inplace_assignment = 1;

  /* "Cython/Compiler/FlowControl.py":864
 *     def visit_InPlaceAssignmentNode(self, node):
 *         self.in_inplace_assignment = True
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         self.in_inplace_assignment = False
 *         self.mark_assignment(node.lhs, self.constant_folder(node.create_binop_node()))
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":865
 *         self.in_inplace_assignment = True
 *         self.visitchildren(node)
 *         self.in_inplace_assignment = False             # <<<<<<<<<<<<<<
 *         self.mark_assignment(node.lhs, self.constant_folder(node.create_binop_node()))
 *         return node
*/
  __pyx_v_self->in_inplace_assignment = 0;

  /* "Cython/Compiler/FlowControl.py":866
 *         self.visitchildren(node)
 *         self.in_inplace_assignment = False
 *         self.mark_assignment(node.lhs, self.constant_folder(node.create_binop_node()))             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_lhs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __Pyx_INCREF(__pyx_v_self->constant_folder);
  __pyx_t_4 = __pyx_v_self->constant_folder; 
  __pyx_t_6 = __pyx_v_node;
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_create_binop_node, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 866, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 866, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_8.__pyx_n = 1;
  __pyx_t_8.rhs = __pyx_t_2;
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_1, 0, &__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":867
 *         self.in_inplace_assignment = False
 *         self.mark_assignment(node.lhs, self.constant_folder(node.create_binop_node()))
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_DelStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":862
 *         return node
 * 
 *     def visit_InPlaceAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self.in_inplace_assignment = True
 *         self.visitchildren(node)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_InPlaceAssignmentNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":869
 *         return node
 * 
 *     def visit_DelStatNode(self, node):             # <<<<<<<<<<<<<<
 *         for arg in node.args:
 *             if arg.is_name:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_29visit_DelStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_29visit_DelStatNode = {"visit_DelStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_29visit_DelStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_29visit_DelStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_DelStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_28visit_DelStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_28visit_DelStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_DelStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":870
 * 
 *     def visit_DelStatNode(self, node):
 *         for arg in node.args:             # <<<<<<<<<<<<<<
 *             if arg.is_name:
 *                 entry = arg.entry or self.env.lookup(arg.name)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 870, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 870, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 870, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 870, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 870, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":871
 *     def visit_DelStatNode(self, node):
 *         for arg in node.args:
 *             if arg.is_name:             # <<<<<<<<<<<<<<
 *                 entry = arg.entry or self.env.lookup(arg.name)
 *                 if entry.in_closure or entry.from_closure:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 871, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "Cython/Compiler/FlowControl.py":872
 *         for arg in node.args:
 *             if arg.is_name:
 *                 entry = arg.entry or self.env.lookup(arg.name)             # <<<<<<<<<<<<<<
 *                 if entry.in_closure or entry.from_closure:
 *                     error(arg.pos,
*/
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 872, __pyx_L1_error)
      if (!__pyx_t_5) {
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_1 = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L6_bool_binop_done;
      }
      __pyx_t_7 = __pyx_v_self->env;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 872, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_1 = __pyx_t_6;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_L6_bool_binop_done:;
      __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":873
 *             if arg.is_name:
 *                 entry = arg.entry or self.env.lookup(arg.name)
 *                 if entry.in_closure or entry.from_closure:             # <<<<<<<<<<<<<<
 *                     error(arg.pos,
 *                           "can not delete variable '%s' "
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_in_closure); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 873, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!__pyx_t_10) {
      } else {
        __pyx_t_5 = __pyx_t_10;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_from_closure); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 873, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_5 = __pyx_t_10;
      __pyx_L9_bool_binop_done:;
      if (__pyx_t_5) {

        /* "Cython/Compiler/FlowControl.py":874
 *                 entry = arg.entry or self.env.lookup(arg.name)
 *                 if entry.in_closure or entry.from_closure:
 *                     error(arg.pos,             # <<<<<<<<<<<<<<
 *                           "can not delete variable '%s' "
 *                           "referenced in nested scope" % entry.name)
*/
        __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_error);
        __pyx_t_8 = __pyx_v_6Cython_8Compiler_11FlowControl_error; 
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 874, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "Cython/Compiler/FlowControl.py":876
 *                     error(arg.pos,
 *                           "can not delete variable '%s' "
 *                           "referenced in nested scope" % entry.name)             # <<<<<<<<<<<<<<
 *                 if not node.ignore_nonexisting:
 *                     self._visit(arg)  # mark reference
*/
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 876, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_can_not_delete_variable_s_refere, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 876, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_9 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_6);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_9 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_7, __pyx_t_12};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_9, (3-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 874, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/FlowControl.py":873
 *             if arg.is_name:
 *                 entry = arg.entry or self.env.lookup(arg.name)
 *                 if entry.in_closure or entry.from_closure:             # <<<<<<<<<<<<<<
 *                     error(arg.pos,
 *                           "can not delete variable '%s' "
*/
      }

      /* "Cython/Compiler/FlowControl.py":877
 *                           "can not delete variable '%s' "
 *                           "referenced in nested scope" % entry.name)
 *                 if not node.ignore_nonexisting:             # <<<<<<<<<<<<<<
 *                     self._visit(arg)  # mark reference
 *                 self.flow.mark_deletion(arg, entry)
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_ignore_nonexisting); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 877, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_10 = (!__pyx_t_5);
      if (__pyx_t_10) {

        /* "Cython/Compiler/FlowControl.py":878
 *                           "referenced in nested scope" % entry.name)
 *                 if not node.ignore_nonexisting:
 *                     self._visit(arg)  # mark reference             # <<<<<<<<<<<<<<
 *                 self.flow.mark_deletion(arg, entry)
 *             else:
*/
        __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 878, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/FlowControl.py":877
 *                           "can not delete variable '%s' "
 *                           "referenced in nested scope" % entry.name)
 *                 if not node.ignore_nonexisting:             # <<<<<<<<<<<<<<
 *                     self._visit(arg)  # mark reference
 *                 self.flow.mark_deletion(arg, entry)
*/
      }

      /* "Cython/Compiler/FlowControl.py":879
 *                 if not node.ignore_nonexisting:
 *                     self._visit(arg)  # mark reference
 *                 self.flow.mark_deletion(arg, entry)             # <<<<<<<<<<<<<<
 *             else:
 *                 self._visit(arg)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_deletion(__pyx_v_self->flow, __pyx_v_arg, __pyx_v_entry, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 879, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":871
 *     def visit_DelStatNode(self, node):
 *         for arg in node.args:
 *             if arg.is_name:             # <<<<<<<<<<<<<<
 *                 entry = arg.entry or self.env.lookup(arg.name)
 *                 if entry.in_closure or entry.from_closure:
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/FlowControl.py":881
 *                 self.flow.mark_deletion(arg, entry)
 *             else:
 *                 self._visit(arg)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    /*else*/ {
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "Cython/Compiler/FlowControl.py":870
 * 
 *     def visit_DelStatNode(self, node):
 *         for arg in node.args:             # <<<<<<<<<<<<<<
 *             if arg.is_name:
 *                 entry = arg.entry or self.env.lookup(arg.name)
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":882
 *             else:
 *                 self._visit(arg)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CArgDeclNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":869
 *         return node
 * 
 *     def visit_DelStatNode(self, node):             # <<<<<<<<<<<<<<
 *         for arg in node.args:
 *             if arg.is_name:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_DelStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":884
 *         return node
 * 
 *     def visit_CArgDeclNode(self, node):             # <<<<<<<<<<<<<<
 *         entry = self.env.lookup(node.name)
 *         if entry:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_31visit_CArgDeclNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_31visit_CArgDeclNode = {"visit_CArgDeclNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_31visit_CArgDeclNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_31visit_CArgDeclNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CArgDeclNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_30visit_CArgDeclNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_30visit_CArgDeclNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_entry = NULL;
  int __pyx_v_may_be_none;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CArgDeclNode", 0);

  /* "Cython/Compiler/FlowControl.py":885
 * 
 *     def visit_CArgDeclNode(self, node):
 *         entry = self.env.lookup(node.name)             # <<<<<<<<<<<<<<
 *         if entry:
 *             may_be_none = not node.not_none
*/
  __pyx_t_2 = __pyx_v_self->env;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_entry = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":886
 *     def visit_CArgDeclNode(self, node):
 *         entry = self.env.lookup(node.name)
 *         if entry:             # <<<<<<<<<<<<<<
 *             may_be_none = not node.not_none
 *             self.flow.mark_argument(
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_entry); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 886, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/FlowControl.py":887
 *         entry = self.env.lookup(node.name)
 *         if entry:
 *             may_be_none = not node.not_none             # <<<<<<<<<<<<<<
 *             self.flow.mark_argument(
 *                 node, TypedExprNode(entry.type, may_be_none), entry)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_not_none); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 887, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_may_be_none = (!__pyx_t_5);

    /* "Cython/Compiler/FlowControl.py":889
 *             may_be_none = not node.not_none
 *             self.flow.mark_argument(
 *                 node, TypedExprNode(entry.type, may_be_none), entry)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode; 
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_may_be_none); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_6, __pyx_t_7};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }

    /* "Cython/Compiler/FlowControl.py":888
 *         if entry:
 *             may_be_none = not node.not_none
 *             self.flow.mark_argument(             # <<<<<<<<<<<<<<
 *                 node, TypedExprNode(entry.type, may_be_none), entry)
 *         return node
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_argument(__pyx_v_self->flow, __pyx_v_node, __pyx_t_1, __pyx_v_entry, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":886
 *     def visit_CArgDeclNode(self, node):
 *         entry = self.env.lookup(node.name)
 *         if entry:             # <<<<<<<<<<<<<<
 *             may_be_none = not node.not_none
 *             self.flow.mark_argument(
*/
  }

  /* "Cython/Compiler/FlowControl.py":890
 *             self.flow.mark_argument(
 *                 node, TypedExprNode(entry.type, may_be_none), entry)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_NameNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":884
 *         return node
 * 
 *     def visit_CArgDeclNode(self, node):             # <<<<<<<<<<<<<<
 *         entry = self.env.lookup(node.name)
 *         if entry:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_CArgDeclNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":892
 *         return node
 * 
 *     def visit_NameNode(self, node):             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             entry = node.entry or self.env.lookup(node.name)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_33visit_NameNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_33visit_NameNode = {"visit_NameNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_33visit_NameNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_33visit_NameNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_NameNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_32visit_NameNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_32visit_NameNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_NameNode", 0);

  /* "Cython/Compiler/FlowControl.py":893
 * 
 *     def visit_NameNode(self, node):
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             entry = node.entry or self.env.lookup(node.name)
 *             if entry:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 893, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":894
 *     def visit_NameNode(self, node):
 *         if self.flow.block:
 *             entry = node.entry or self.env.lookup(node.name)             # <<<<<<<<<<<<<<
 *             if entry:
 *                 self.flow.mark_reference(node, entry)
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 894, __pyx_L1_error)
    if (!__pyx_t_1) {
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = __pyx_v_self->env;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_L4_bool_binop_done:;
    __pyx_v_entry = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":895
 *         if self.flow.block:
 *             entry = node.entry or self.env.lookup(node.name)
 *             if entry:             # <<<<<<<<<<<<<<
 *                 self.flow.mark_reference(node, entry)
 * 
*/
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_entry); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 895, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/FlowControl.py":896
 *             entry = node.entry or self.env.lookup(node.name)
 *             if entry:
 *                 self.flow.mark_reference(node, entry)             # <<<<<<<<<<<<<<
 * 
 *                 if entry in self.reductions and not self.in_inplace_assignment:
*/
      __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_reference(__pyx_v_self->flow, __pyx_v_node, __pyx_v_entry, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 896, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":898
 *                 self.flow.mark_reference(node, entry)
 * 
 *                 if entry in self.reductions and not self.in_inplace_assignment:             # <<<<<<<<<<<<<<
 *                     error(node.pos,
 *                           "Cannot read reduction variable in loop body")
*/
      if (unlikely(__pyx_v_self->reductions == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 898, __pyx_L1_error)
      }
      __pyx_t_7 = (__Pyx_PySet_ContainsTF(__pyx_v_entry, __pyx_v_self->reductions, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 898, __pyx_L1_error)
      if (__pyx_t_7) {
      } else {
        __pyx_t_1 = __pyx_t_7;
        goto __pyx_L8_bool_binop_done;
      }
      __pyx_t_7 = (!__pyx_v_self->in_inplace_assignment);
      __pyx_t_1 = __pyx_t_7;
      __pyx_L8_bool_binop_done:;
      if (__pyx_t_1) {

        /* "Cython/Compiler/FlowControl.py":899
 * 
 *                 if entry in self.reductions and not self.in_inplace_assignment:
 *                     error(node.pos,             # <<<<<<<<<<<<<<
 *                           "Cannot read reduction variable in loop body")
 * 
*/
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_error);
        __pyx_t_5 = __pyx_v_6Cython_8Compiler_11FlowControl_error; 
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 899, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Cannot_read_reduction_variable_i};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 899, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "Cython/Compiler/FlowControl.py":898
 *                 self.flow.mark_reference(node, entry)
 * 
 *                 if entry in self.reductions and not self.in_inplace_assignment:             # <<<<<<<<<<<<<<
 *                     error(node.pos,
 *                           "Cannot read reduction variable in loop body")
*/
      }

      /* "Cython/Compiler/FlowControl.py":895
 *         if self.flow.block:
 *             entry = node.entry or self.env.lookup(node.name)
 *             if entry:             # <<<<<<<<<<<<<<
 *                 self.flow.mark_reference(node, entry)
 * 
*/
    }

    /* "Cython/Compiler/FlowControl.py":893
 * 
 *     def visit_NameNode(self, node):
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             entry = node.entry or self.env.lookup(node.name)
 *             if entry:
*/
  }

  /* "Cython/Compiler/FlowControl.py":902
 *                           "Cannot read reduction variable in loop body")
 * 
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_StatListNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":892
 *         return node
 * 
 *     def visit_NameNode(self, node):             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             entry = node.entry or self.env.lookup(node.name)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_NameNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":904
 *         return node
 * 
 *     def visit_StatListNode(self, node):             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             for stat in node.stats:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_35visit_StatListNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_35visit_StatListNode = {"visit_StatListNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_35visit_StatListNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_35visit_StatListNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_StatListNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_34visit_StatListNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_34visit_StatListNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_stat = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_StatListNode", 0);

  /* "Cython/Compiler/FlowControl.py":905
 * 
 *     def visit_StatListNode(self, node):
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             for stat in node.stats:
 *                 self._visit(stat)
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 905, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/FlowControl.py":906
 *     def visit_StatListNode(self, node):
 *         if self.flow.block:
 *             for stat in node.stats:             # <<<<<<<<<<<<<<
 *                 self._visit(stat)
 *                 if not self.flow.block:
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_stats); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 906, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 906, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 906, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 906, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_4, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_4;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 906, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4));
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4);
          #endif
          ++__pyx_t_4;
        }
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 906, __pyx_L1_error)
      } else {
        __pyx_t_2 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 906, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_stat, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":907
 *         if self.flow.block:
 *             for stat in node.stats:
 *                 self._visit(stat)             # <<<<<<<<<<<<<<
 *                 if not self.flow.block:
 *                     stat.is_terminator = True
*/
      __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_stat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 907, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":908
 *             for stat in node.stats:
 *                 self._visit(stat)
 *                 if not self.flow.block:             # <<<<<<<<<<<<<<
 *                     stat.is_terminator = True
 *                     break
*/
      __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 908, __pyx_L1_error)
      __pyx_t_6 = (!__pyx_t_1);
      if (__pyx_t_6) {

        /* "Cython/Compiler/FlowControl.py":909
 *                 self._visit(stat)
 *                 if not self.flow.block:
 *                     stat.is_terminator = True             # <<<<<<<<<<<<<<
 *                     break
 *         return node
*/
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_is_terminator, Py_True) < (0)) __PYX_ERR(0, 909, __pyx_L1_error)

        /* "Cython/Compiler/FlowControl.py":910
 *                 if not self.flow.block:
 *                     stat.is_terminator = True
 *                     break             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
        goto __pyx_L5_break;

        /* "Cython/Compiler/FlowControl.py":908
 *             for stat in node.stats:
 *                 self._visit(stat)
 *                 if not self.flow.block:             # <<<<<<<<<<<<<<
 *                     stat.is_terminator = True
 *                     break
*/
      }

      /* "Cython/Compiler/FlowControl.py":906
 *     def visit_StatListNode(self, node):
 *         if self.flow.block:
 *             for stat in node.stats:             # <<<<<<<<<<<<<<
 *                 self._visit(stat)
 *                 if not self.flow.block:
*/
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L7_for_end;
    __pyx_L5_break:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L7_for_end;
    __pyx_L7_for_end:;

    /* "Cython/Compiler/FlowControl.py":905
 * 
 *     def visit_StatListNode(self, node):
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             for stat in node.stats:
 *                 self._visit(stat)
*/
  }

  /* "Cython/Compiler/FlowControl.py":911
 *                     stat.is_terminator = True
 *                     break
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_Node(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":904
 *         return node
 * 
 *     def visit_StatListNode(self, node):             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             for stat in node.stats:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_StatListNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_stat);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":913
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         self.mark_position(node)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_37visit_Node(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_37visit_Node = {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_37visit_Node, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_37visit_Node(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_Node (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_36visit_Node(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_36visit_Node(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_Node", 0);

  /* "Cython/Compiler/FlowControl.py":914
 * 
 *     def visit_Node(self, node):
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         return node
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":915
 *     def visit_Node(self, node):
 *         self.visitchildren(node)
 *         self.mark_position(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":916
 *         self.visitchildren(node)
 *         self.mark_position(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_SizeofVarNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":913
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         self.mark_position(node)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_Node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":918
 *         return node
 * 
 *     def visit_SizeofVarNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_39visit_SizeofVarNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_39visit_SizeofVarNode = {"visit_SizeofVarNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_39visit_SizeofVarNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_39visit_SizeofVarNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_SizeofVarNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_38visit_SizeofVarNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_38visit_SizeofVarNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_SizeofVarNode", 0);

  /* "Cython/Compiler/FlowControl.py":919
 * 
 *     def visit_SizeofVarNode(self, node):
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_TypeidNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":918
 *         return node
 * 
 *     def visit_SizeofVarNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":921
 *         return node
 * 
 *     def visit_TypeidNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_41visit_TypeidNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_41visit_TypeidNode = {"visit_TypeidNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_41visit_TypeidNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_41visit_TypeidNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_TypeidNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_40visit_TypeidNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_40visit_TypeidNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_TypeidNode", 0);

  /* "Cython/Compiler/FlowControl.py":922
 * 
 *     def visit_TypeidNode(self, node):
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_IfStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":921
 *         return node
 * 
 *     def visit_TypeidNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":924
 *         return node
 * 
 *     def visit_IfStatNode(self, node):             # <<<<<<<<<<<<<<
 *         next_block = self.flow.newblock()
 *         parent = self.flow.block
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_43visit_IfStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_43visit_IfStatNode = {"visit_IfStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_43visit_IfStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_43visit_IfStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_IfStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_42visit_IfStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_42visit_IfStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_next_block = NULL;
  PyObject *__pyx_v_parent = NULL;
  PyObject *__pyx_v_clause = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_IfStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":925
 * 
 *     def visit_IfStatNode(self, node):
 *         next_block = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         parent = self.flow.block
 *         # If clauses
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_next_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":926
 *     def visit_IfStatNode(self, node):
 *         next_block = self.flow.newblock()
 *         parent = self.flow.block             # <<<<<<<<<<<<<<
 *         # If clauses
 *         for clause in node.if_clauses:
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->flow->block);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_parent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":928
 *         parent = self.flow.block
 *         # If clauses
 *         for clause in node.if_clauses:             # <<<<<<<<<<<<<<
 *             parent = self.flow.nextblock(parent)
 *             self._visit(clause.condition)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_if_clauses); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 928, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 928, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 928, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 928, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 928, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_clause, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":929
 *         # If clauses
 *         for clause in node.if_clauses:
 *             parent = self.flow.nextblock(parent)             # <<<<<<<<<<<<<<
 *             self._visit(clause.condition)
 *             self.flow.nextblock()
*/
    if (!(likely(((__pyx_v_parent) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_parent, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 929, __pyx_L1_error)
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_parent);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 929, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_parent, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":930
 *         for clause in node.if_clauses:
 *             parent = self.flow.nextblock(parent)
 *             self._visit(clause.condition)             # <<<<<<<<<<<<<<
 *             self.flow.nextblock()
 *             self._visit(clause.body)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_clause, __pyx_mstate_global->__pyx_n_u_condition); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 930, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 930, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/FlowControl.py":931
 *             parent = self.flow.nextblock(parent)
 *             self._visit(clause.condition)
 *             self.flow.nextblock()             # <<<<<<<<<<<<<<
 *             self._visit(clause.body)
 *             if self.flow.block:
*/
    __pyx_t_6 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/FlowControl.py":932
 *             self._visit(clause.condition)
 *             self.flow.nextblock()
 *             self._visit(clause.body)             # <<<<<<<<<<<<<<
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_clause, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":933
 *             self.flow.nextblock()
 *             self._visit(clause.body)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         # Else clause
*/
    __pyx_t_7 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 933, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/FlowControl.py":934
 *             self._visit(clause.body)
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 *         # Else clause
 *         if node.else_clause:
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 934, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":933
 *             self.flow.nextblock()
 *             self._visit(clause.body)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         # Else clause
*/
    }

    /* "Cython/Compiler/FlowControl.py":928
 *         parent = self.flow.block
 *         # If clauses
 *         for clause in node.if_clauses:             # <<<<<<<<<<<<<<
 *             parent = self.flow.nextblock(parent)
 *             self._visit(clause.condition)
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":936
 *                 self.flow.block.add_child(next_block)
 *         # Else clause
 *         if node.else_clause:             # <<<<<<<<<<<<<<
 *             self.flow.nextblock(parent=parent)
 *             self._visit(node.else_clause)
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "Cython/Compiler/FlowControl.py":937
 *         # Else clause
 *         if node.else_clause:
 *             self.flow.nextblock(parent=parent)             # <<<<<<<<<<<<<<
 *             self._visit(node.else_clause)
 *             if self.flow.block:
*/
    if (!(likely(((__pyx_v_parent) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_parent, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 937, __pyx_L1_error)
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_parent);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, &__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":938
 *         if node.else_clause:
 *             self.flow.nextblock(parent=parent)
 *             self._visit(node.else_clause)             # <<<<<<<<<<<<<<
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 938, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 938, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":939
 *             self.flow.nextblock(parent=parent)
 *             self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         else:
*/
    __pyx_t_7 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 939, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/FlowControl.py":940
 *             self._visit(node.else_clause)
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 *         else:
 *             parent.add_child(next_block)
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 940, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":939
 *             self.flow.nextblock(parent=parent)
 *             self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         else:
*/
    }

    /* "Cython/Compiler/FlowControl.py":936
 *                 self.flow.block.add_child(next_block)
 *         # Else clause
 *         if node.else_clause:             # <<<<<<<<<<<<<<
 *             self.flow.nextblock(parent=parent)
 *             self._visit(node.else_clause)
*/
    goto __pyx_L7;
  }

  /* "Cython/Compiler/FlowControl.py":942
 *                 self.flow.block.add_child(next_block)
 *         else:
 *             parent.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         if next_block.parents:
*/
  /*else*/ {
    __pyx_t_2 = __pyx_v_parent;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_next_block};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 942, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L7:;

  /* "Cython/Compiler/FlowControl.py":944
 *             parent.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "Cython/Compiler/FlowControl.py":945
 * 
 *         if next_block.parents:
 *             self.flow.block = next_block             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block = None
*/
    __pyx_t_1 = __pyx_v_next_block;
    __Pyx_INCREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 945, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":944
 *             parent.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
    goto __pyx_L9;
  }

  /* "Cython/Compiler/FlowControl.py":947
 *             self.flow.block = next_block
 *         else:
 *             self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  }
  __pyx_L9:;

  /* "Cython/Compiler/FlowControl.py":948
 *         else:
 *             self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_AssertStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":924
 *         return node
 * 
 *     def visit_IfStatNode(self, node):             # <<<<<<<<<<<<<<
 *         next_block = self.flow.newblock()
 *         parent = self.flow.block
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_IfStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_next_block);
  __Pyx_XDECREF(__pyx_v_parent);
  __Pyx_XDECREF(__pyx_v_clause);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":950
 *         return node
 * 
 *     def visit_AssertStatNode(self, node):             # <<<<<<<<<<<<<<
 *         """Essentially an if-condition that wraps a RaiseStatNode.
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_45visit_AssertStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_44visit_AssertStatNode, "Essentially an if-condition that wraps a RaiseStatNode.\n        ");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_45visit_AssertStatNode = {"visit_AssertStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_45visit_AssertStatNode, METH_O, __pyx_doc_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_44visit_AssertStatNode};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_45visit_AssertStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_AssertStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_44visit_AssertStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_44visit_AssertStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_next_block = NULL;
  PyObject *__pyx_v_parent = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_AssertStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":953
 *         """Essentially an if-condition that wraps a RaiseStatNode.
 *         """
 *         self.mark_position(node)             # <<<<<<<<<<<<<<
 *         next_block = self.flow.newblock()
 *         parent = self.flow.block
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":954
 *         """
 *         self.mark_position(node)
 *         next_block = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         parent = self.flow.block
 *         # failure case
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_next_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":955
 *         self.mark_position(node)
 *         next_block = self.flow.newblock()
 *         parent = self.flow.block             # <<<<<<<<<<<<<<
 *         # failure case
 *         parent = self.flow.nextblock(parent)
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->flow->block);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_parent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":957
 *         parent = self.flow.block
 *         # failure case
 *         parent = self.flow.nextblock(parent)             # <<<<<<<<<<<<<<
 *         self._visit(node.condition)
 *         self.flow.nextblock()
*/
  if (!(likely(((__pyx_v_parent) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_parent, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 957, __pyx_L1_error)
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_parent);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_parent, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":958
 *         # failure case
 *         parent = self.flow.nextblock(parent)
 *         self._visit(node.condition)             # <<<<<<<<<<<<<<
 *         self.flow.nextblock()
 *         self._visit(node.exception)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_condition); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":959
 *         parent = self.flow.nextblock(parent)
 *         self._visit(node.condition)
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self._visit(node.exception)
 *         if self.flow.block:
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":960
 *         self._visit(node.condition)
 *         self.flow.nextblock()
 *         self._visit(node.exception)             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":961
 *         self.flow.nextblock()
 *         self._visit(node.exception)
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 *         parent.add_child(next_block)
*/
  __pyx_t_4 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 961, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/FlowControl.py":962
 *         self._visit(node.exception)
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 *         parent.add_child(next_block)
 *         if next_block.parents:
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":961
 *         self.flow.nextblock()
 *         self._visit(node.exception)
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 *         parent.add_child(next_block)
*/
  }

  /* "Cython/Compiler/FlowControl.py":963
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)
 *         parent.add_child(next_block)             # <<<<<<<<<<<<<<
 *         if next_block.parents:
 *             self.flow.block = next_block
*/
  __pyx_t_3 = __pyx_v_parent;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_next_block};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":964
 *             self.flow.block.add_child(next_block)
 *         parent.add_child(next_block)
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "Cython/Compiler/FlowControl.py":965
 *         parent.add_child(next_block)
 *         if next_block.parents:
 *             self.flow.block = next_block             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block = None
*/
    __pyx_t_1 = __pyx_v_next_block;
    __Pyx_INCREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 965, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":964
 *             self.flow.block.add_child(next_block)
 *         parent.add_child(next_block)
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/FlowControl.py":967
 *             self.flow.block = next_block
 *         else:
 *             self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  }
  __pyx_L4:;

  /* "Cython/Compiler/FlowControl.py":968
 *         else:
 *             self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_WhileStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":950
 *         return node
 * 
 *     def visit_AssertStatNode(self, node):             # <<<<<<<<<<<<<<
 *         """Essentially an if-condition that wraps a RaiseStatNode.
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_AssertStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_next_block);
  __Pyx_XDECREF(__pyx_v_parent);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":970
 *         return node
 * 
 *     def visit_WhileStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_47visit_WhileStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_47visit_WhileStatNode = {"visit_WhileStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_47visit_WhileStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_47visit_WhileStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_WhileStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_46visit_WhileStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_46visit_WhileStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_condition_block = NULL;
  PyObject *__pyx_v_next_block = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_WhileStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":971
 * 
 *     def visit_WhileStatNode(self, node):
 *         condition_block = self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         next_block = self.flow.newblock()
 *         # Condition block
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_condition_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":972
 *     def visit_WhileStatNode(self, node):
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         # Condition block
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_next_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":974
 *         next_block = self.flow.newblock()
 *         # Condition block
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))             # <<<<<<<<<<<<<<
 *         if node.condition:
 *             self._visit(node.condition)
*/
  if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 974, __pyx_L1_error)
  }
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_LoopDescr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_next_block, __pyx_v_condition_block};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->flow->loops, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":975
 *         # Condition block
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
 *         if node.condition:             # <<<<<<<<<<<<<<
 *             self._visit(node.condition)
 *         # Body block
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_condition); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":976
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
 *         if node.condition:
 *             self._visit(node.condition)             # <<<<<<<<<<<<<<
 *         # Body block
 *         self.flow.nextblock()
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_condition); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":975
 *         # Condition block
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
 *         if node.condition:             # <<<<<<<<<<<<<<
 *             self._visit(node.condition)
 *         # Body block
*/
  }

  /* "Cython/Compiler/FlowControl.py":978
 *             self._visit(node.condition)
 *         # Body block
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self._visit(node.body)
 *         self.flow.loops.pop()
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":979
 *         # Body block
 *         self.flow.nextblock()
 *         self._visit(node.body)             # <<<<<<<<<<<<<<
 *         self.flow.loops.pop()
 *         # Loop it
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":980
 *         self.flow.nextblock()
 *         self._visit(node.body)
 *         self.flow.loops.pop()             # <<<<<<<<<<<<<<
 *         # Loop it
 *         if self.flow.block:
*/
  if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 980, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->flow->loops); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":982
 *         self.flow.loops.pop()
 *         # Loop it
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(condition_block)
 *             self.flow.block.add_child(next_block)
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 982, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":983
 *         # Loop it
 *         if self.flow.block:
 *             self.flow.block.add_child(condition_block)             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 *         # Else clause
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_condition_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 983, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":984
 *         if self.flow.block:
 *             self.flow.block.add_child(condition_block)
 *             self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 *         # Else clause
 *         if node.else_clause:
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":982
 *         self.flow.loops.pop()
 *         # Loop it
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(condition_block)
 *             self.flow.block.add_child(next_block)
*/
  }

  /* "Cython/Compiler/FlowControl.py":986
 *             self.flow.block.add_child(next_block)
 *         # Else clause
 *         if node.else_clause:             # <<<<<<<<<<<<<<
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":987
 *         # Else clause
 *         if node.else_clause:
 *             self.flow.nextblock(parent=condition_block)             # <<<<<<<<<<<<<<
 *             self._visit(node.else_clause)
 *             if self.flow.block:
*/
    if (!(likely(((__pyx_v_condition_block) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_condition_block, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 987, __pyx_L1_error)
    __pyx_t_7.__pyx_n = 1;
    __pyx_t_7.parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_condition_block);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, &__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":988
 *         if node.else_clause:
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)             # <<<<<<<<<<<<<<
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":989
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         else:
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 989, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/FlowControl.py":990
 *             self._visit(node.else_clause)
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 *         else:
 *             condition_block.add_child(next_block)
*/
      __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/FlowControl.py":989
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         else:
*/
    }

    /* "Cython/Compiler/FlowControl.py":986
 *             self.flow.block.add_child(next_block)
 *         # Else clause
 *         if node.else_clause:             # <<<<<<<<<<<<<<
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
*/
    goto __pyx_L5;
  }

  /* "Cython/Compiler/FlowControl.py":992
 *                 self.flow.block.add_child(next_block)
 *         else:
 *             condition_block.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         if next_block.parents:
*/
  /*else*/ {
    __pyx_t_1 = __pyx_v_condition_block;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_next_block};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L5:;

  /* "Cython/Compiler/FlowControl.py":994
 *             condition_block.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":995
 * 
 *         if next_block.parents:
 *             self.flow.block = next_block             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block = None
*/
    __pyx_t_3 = __pyx_v_next_block;
    __Pyx_INCREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 995, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":994
 *             condition_block.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
    goto __pyx_L7;
  }

  /* "Cython/Compiler/FlowControl.py":997
 *             self.flow.block = next_block
 *         else:
 *             self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  }
  __pyx_L7:;

  /* "Cython/Compiler/FlowControl.py":998
 *         else:
 *             self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def mark_forloop_target(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":970
 *         return node
 * 
 *     def visit_WhileStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_WhileStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_condition_block);
  __Pyx_XDECREF(__pyx_v_next_block);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1000
 *         return node
 * 
 *     def mark_forloop_target(self, node):             # <<<<<<<<<<<<<<
 *         # TODO: Remove redundancy with range optimization...
 *         is_special = False
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_49mark_forloop_target(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_49mark_forloop_target = {"mark_forloop_target", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_49mark_forloop_target, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_49mark_forloop_target(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_forloop_target (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_48mark_forloop_target(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_48mark_forloop_target(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  int __pyx_v_is_special;
  PyObject *__pyx_v_sequence = NULL;
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_v_env = NULL;
  PyObject *__pyx_v_function = NULL;
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_v_iterator = NULL;
  PyObject *__pyx_v_iterator_type = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  size_t __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_forloop_target", 0);

  /* "Cython/Compiler/FlowControl.py":1002
 *     def mark_forloop_target(self, node):
 *         # TODO: Remove redundancy with range optimization...
 *         is_special = False             # <<<<<<<<<<<<<<
 *         sequence = node.iterator.sequence
 *         target = node.target
*/
  __pyx_v_is_special = 0;

  /* "Cython/Compiler/FlowControl.py":1003
 *         # TODO: Remove redundancy with range optimization...
 *         is_special = False
 *         sequence = node.iterator.sequence             # <<<<<<<<<<<<<<
 *         target = node.target
 *         env = node.iterator.expr_scope or self.env
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_iterator); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_sequence); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_sequence = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1004
 *         is_special = False
 *         sequence = node.iterator.sequence
 *         target = node.target             # <<<<<<<<<<<<<<
 *         env = node.iterator.expr_scope or self.env
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_target = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1005
 *         sequence = node.iterator.sequence
 *         target = node.target
 *         env = node.iterator.expr_scope or self.env             # <<<<<<<<<<<<<<
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
 *             function = sequence.function
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_iterator); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1005, __pyx_L1_error)
  if (!__pyx_t_4) {
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_self->env);
  __pyx_t_2 = __pyx_v_self->env;
  __pyx_L3_bool_binop_done:;
  __pyx_v_env = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1006
 *         target = node.target
 *         env = node.iterator.expr_scope or self.env
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):             # <<<<<<<<<<<<<<
 *             function = sequence.function
 *             if sequence.self is None and function.is_name:
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes, __pyx_mstate_global->__pyx_n_u_SimpleCallNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_sequence, __pyx_t_2); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "Cython/Compiler/FlowControl.py":1007
 *         env = node.iterator.expr_scope or self.env
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
 *             function = sequence.function             # <<<<<<<<<<<<<<
 *             if sequence.self is None and function.is_name:
 *                 entry = env.lookup(function.name)
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_function); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_function = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1008
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
 *             function = sequence.function
 *             if sequence.self is None and function.is_name:             # <<<<<<<<<<<<<<
 *                 entry = env.lookup(function.name)
 *                 if not entry or entry.is_builtin:
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = (__pyx_t_2 == Py_None);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1008, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __pyx_t_5;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/FlowControl.py":1009
 *             function = sequence.function
 *             if sequence.self is None and function.is_name:
 *                 entry = env.lookup(function.name)             # <<<<<<<<<<<<<<
 *                 if not entry or entry.is_builtin:
 *                     if function.name == 'reversed' and len(sequence.args) == 1:
*/
      __pyx_t_3 = __pyx_v_env;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1009, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_1};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1009, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_v_entry = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":1010
 *             if sequence.self is None and function.is_name:
 *                 entry = env.lookup(function.name)
 *                 if not entry or entry.is_builtin:             # <<<<<<<<<<<<<<
 *                     if function.name == 'reversed' and len(sequence.args) == 1:
 *                         sequence = sequence.args[0]
*/
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_entry); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1010, __pyx_L1_error)
      __pyx_t_7 = (!__pyx_t_5);
      if (!__pyx_t_7) {
      } else {
        __pyx_t_4 = __pyx_t_7;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_builtin); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1010, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1010, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_4 = __pyx_t_7;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_4) {

        /* "Cython/Compiler/FlowControl.py":1011
 *                 entry = env.lookup(function.name)
 *                 if not entry or entry.is_builtin:
 *                     if function.name == 'reversed' and len(sequence.args) == 1:             # <<<<<<<<<<<<<<
 *                         sequence = sequence.args[0]
 *                     elif function.name == 'enumerate' and len(sequence.args) == 1:
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_reversed, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1011, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_7) {
        } else {
          __pyx_t_4 = __pyx_t_7;
          goto __pyx_L13_bool_binop_done;
        }
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1011, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_7 = (__pyx_t_8 == 1);
        __pyx_t_4 = __pyx_t_7;
        __pyx_L13_bool_binop_done:;
        if (__pyx_t_4) {

          /* "Cython/Compiler/FlowControl.py":1012
 *                 if not entry or entry.is_builtin:
 *                     if function.name == 'reversed' and len(sequence.args) == 1:
 *                         sequence = sequence.args[0]             # <<<<<<<<<<<<<<
 *                     elif function.name == 'enumerate' and len(sequence.args) == 1:
 *                         if target.is_sequence_constructor and len(target.args) == 2:
*/
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1012, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1012, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_sequence, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "Cython/Compiler/FlowControl.py":1011
 *                 entry = env.lookup(function.name)
 *                 if not entry or entry.is_builtin:
 *                     if function.name == 'reversed' and len(sequence.args) == 1:             # <<<<<<<<<<<<<<
 *                         sequence = sequence.args[0]
 *                     elif function.name == 'enumerate' and len(sequence.args) == 1:
*/
          goto __pyx_L12;
        }

        /* "Cython/Compiler/FlowControl.py":1013
 *                     if function.name == 'reversed' and len(sequence.args) == 1:
 *                         sequence = sequence.args[0]
 *                     elif function.name == 'enumerate' and len(sequence.args) == 1:             # <<<<<<<<<<<<<<
 *                         if target.is_sequence_constructor and len(target.args) == 2:
 *                             iterator = sequence.args[0]
*/
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1013, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enumerate, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1013, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_7) {
        } else {
          __pyx_t_4 = __pyx_t_7;
          goto __pyx_L15_bool_binop_done;
        }
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1013, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_8 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1013, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_7 = (__pyx_t_8 == 1);
        __pyx_t_4 = __pyx_t_7;
        __pyx_L15_bool_binop_done:;
        if (__pyx_t_4) {

          /* "Cython/Compiler/FlowControl.py":1014
 *                         sequence = sequence.args[0]
 *                     elif function.name == 'enumerate' and len(sequence.args) == 1:
 *                         if target.is_sequence_constructor and len(target.args) == 2:             # <<<<<<<<<<<<<<
 *                             iterator = sequence.args[0]
 *                             if iterator.is_name:
*/
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_mstate_global->__pyx_n_u_is_sequence_constructor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1014, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1014, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_7) {
          } else {
            __pyx_t_4 = __pyx_t_7;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1014, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1014, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_7 = (__pyx_t_8 == 2);
          __pyx_t_4 = __pyx_t_7;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_4) {

            /* "Cython/Compiler/FlowControl.py":1015
 *                     elif function.name == 'enumerate' and len(sequence.args) == 1:
 *                         if target.is_sequence_constructor and len(target.args) == 2:
 *                             iterator = sequence.args[0]             # <<<<<<<<<<<<<<
 *                             if iterator.is_name:
 *                                 iterator_type = iterator.infer_type(env)
*/
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1015, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_v_iterator = __pyx_t_2;
            __pyx_t_2 = 0;

            /* "Cython/Compiler/FlowControl.py":1016
 *                         if target.is_sequence_constructor and len(target.args) == 2:
 *                             iterator = sequence.args[0]
 *                             if iterator.is_name:             # <<<<<<<<<<<<<<
 *                                 iterator_type = iterator.infer_type(env)
 *                                 if iterator_type.is_builtin_type:
*/
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_iterator, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1016, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1016, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (__pyx_t_4) {

              /* "Cython/Compiler/FlowControl.py":1017
 *                             iterator = sequence.args[0]
 *                             if iterator.is_name:
 *                                 iterator_type = iterator.infer_type(env)             # <<<<<<<<<<<<<<
 *                                 if iterator_type.is_builtin_type:
 *                                     # assume that builtin types have a length within Py_ssize_t
*/
              __pyx_t_1 = __pyx_v_iterator;
              __Pyx_INCREF(__pyx_t_1);
              __pyx_t_6 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_env};
                __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_infer_type, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1017, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
              }
              __pyx_v_iterator_type = __pyx_t_2;
              __pyx_t_2 = 0;

              /* "Cython/Compiler/FlowControl.py":1018
 *                             if iterator.is_name:
 *                                 iterator_type = iterator.infer_type(env)
 *                                 if iterator_type.is_builtin_type:             # <<<<<<<<<<<<<<
 *                                     # assume that builtin types have a length within Py_ssize_t
 *                                     self.mark_assignment(
*/
              __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_iterator_type, __pyx_mstate_global->__pyx_n_u_is_builtin_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1018, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1018, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (__pyx_t_4) {

                /* "Cython/Compiler/FlowControl.py":1021
 *                                     # assume that builtin types have a length within Py_ssize_t
 *                                     self.mark_assignment(
 *                                         target.args[0],             # <<<<<<<<<<<<<<
 *                                         ExprNodes.IntNode(target.pos, value='PY_SSIZE_T_MAX',
 *                                                           type=PyrexTypes.c_py_ssize_t_type),
*/
                __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1021, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1021, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "Cython/Compiler/FlowControl.py":1022
 *                                     self.mark_assignment(
 *                                         target.args[0],
 *                                         ExprNodes.IntNode(target.pos, value='PY_SSIZE_T_MAX',             # <<<<<<<<<<<<<<
 *                                                           type=PyrexTypes.c_py_ssize_t_type),
 *                                         rhs_scope=node.iterator.expr_scope)
*/
                __pyx_t_3 = __pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes;
                __Pyx_INCREF(__pyx_t_3);
                __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1022, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_9);

                /* "Cython/Compiler/FlowControl.py":1023
 *                                         target.args[0],
 *                                         ExprNodes.IntNode(target.pos, value='PY_SSIZE_T_MAX',
 *                                                           type=PyrexTypes.c_py_ssize_t_type),             # <<<<<<<<<<<<<<
 *                                         rhs_scope=node.iterator.expr_scope)
 *                                     target = target.args[1]
*/
                __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_PyrexTypes, __pyx_mstate_global->__pyx_n_u_c_py_ssize_t_type); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1023, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                __pyx_t_6 = 0;
                {
                  PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_t_9};
                  __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1022, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_11);
                  if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_mstate_global->__pyx_n_u_PY_SSIZE_T_MAX, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1022, __pyx_L1_error)
                  if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_type, __pyx_t_10, __pyx_t_11, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1022, __pyx_L1_error)
                  __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IntNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
                  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
                  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1022, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                }

                /* "Cython/Compiler/FlowControl.py":1024
 *                                         ExprNodes.IntNode(target.pos, value='PY_SSIZE_T_MAX',
 *                                                           type=PyrexTypes.c_py_ssize_t_type),
 *                                         rhs_scope=node.iterator.expr_scope)             # <<<<<<<<<<<<<<
 *                                     target = target.args[1]
 *                                     sequence = sequence.args[0]
*/
                __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_iterator); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1024, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_11);
                __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1024, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

                /* "Cython/Compiler/FlowControl.py":1020
 *                                 if iterator_type.is_builtin_type:
 *                                     # assume that builtin types have a length within Py_ssize_t
 *                                     self.mark_assignment(             # <<<<<<<<<<<<<<
 *                                         target.args[0],
 *                                         ExprNodes.IntNode(target.pos, value='PY_SSIZE_T_MAX',
*/
                __pyx_t_12.__pyx_n = 2;
                __pyx_t_12.rhs = __pyx_t_2;
                __pyx_t_12.rhs_scope = __pyx_t_10;
                __pyx_t_11 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_1, 0, &__pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1020, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_11);
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

                /* "Cython/Compiler/FlowControl.py":1025
 *                                                           type=PyrexTypes.c_py_ssize_t_type),
 *                                         rhs_scope=node.iterator.expr_scope)
 *                                     target = target.args[1]             # <<<<<<<<<<<<<<
 *                                     sequence = sequence.args[0]
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
*/
                __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1025, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_11);
                __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_11, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1025, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
                __Pyx_DECREF_SET(__pyx_v_target, __pyx_t_10);
                __pyx_t_10 = 0;

                /* "Cython/Compiler/FlowControl.py":1026
 *                                         rhs_scope=node.iterator.expr_scope)
 *                                     target = target.args[1]
 *                                     sequence = sequence.args[0]             # <<<<<<<<<<<<<<
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
 *             function = sequence.function
*/
                __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1026, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                __pyx_t_11 = __Pyx_GetItemInt(__pyx_t_10, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1026, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_11);
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                __Pyx_DECREF_SET(__pyx_v_sequence, __pyx_t_11);
                __pyx_t_11 = 0;

                /* "Cython/Compiler/FlowControl.py":1018
 *                             if iterator.is_name:
 *                                 iterator_type = iterator.infer_type(env)
 *                                 if iterator_type.is_builtin_type:             # <<<<<<<<<<<<<<
 *                                     # assume that builtin types have a length within Py_ssize_t
 *                                     self.mark_assignment(
*/
              }

              /* "Cython/Compiler/FlowControl.py":1016
 *                         if target.is_sequence_constructor and len(target.args) == 2:
 *                             iterator = sequence.args[0]
 *                             if iterator.is_name:             # <<<<<<<<<<<<<<
 *                                 iterator_type = iterator.infer_type(env)
 *                                 if iterator_type.is_builtin_type:
*/
            }

            /* "Cython/Compiler/FlowControl.py":1014
 *                         sequence = sequence.args[0]
 *                     elif function.name == 'enumerate' and len(sequence.args) == 1:
 *                         if target.is_sequence_constructor and len(target.args) == 2:             # <<<<<<<<<<<<<<
 *                             iterator = sequence.args[0]
 *                             if iterator.is_name:
*/
          }

          /* "Cython/Compiler/FlowControl.py":1013
 *                     if function.name == 'reversed' and len(sequence.args) == 1:
 *                         sequence = sequence.args[0]
 *                     elif function.name == 'enumerate' and len(sequence.args) == 1:             # <<<<<<<<<<<<<<
 *                         if target.is_sequence_constructor and len(target.args) == 2:
 *                             iterator = sequence.args[0]
*/
        }
        __pyx_L12:;

        /* "Cython/Compiler/FlowControl.py":1010
 *             if sequence.self is None and function.is_name:
 *                 entry = env.lookup(function.name)
 *                 if not entry or entry.is_builtin:             # <<<<<<<<<<<<<<
 *                     if function.name == 'reversed' and len(sequence.args) == 1:
 *                         sequence = sequence.args[0]
*/
      }

      /* "Cython/Compiler/FlowControl.py":1008
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
 *             function = sequence.function
 *             if sequence.self is None and function.is_name:             # <<<<<<<<<<<<<<
 *                 entry = env.lookup(function.name)
 *                 if not entry or entry.is_builtin:
*/
    }

    /* "Cython/Compiler/FlowControl.py":1006
 *         target = node.target
 *         env = node.iterator.expr_scope or self.env
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):             # <<<<<<<<<<<<<<
 *             function = sequence.function
 *             if sequence.self is None and function.is_name:
*/
  }

  /* "Cython/Compiler/FlowControl.py":1027
 *                                     target = target.args[1]
 *                                     sequence = sequence.args[0]
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):             # <<<<<<<<<<<<<<
 *             function = sequence.function
 *             if sequence.self is None and function.is_name and function.name in ('range', 'xrange'):
*/
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes, __pyx_mstate_global->__pyx_n_u_SimpleCallNode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_sequence, __pyx_t_11); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1027, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (__pyx_t_4) {

    /* "Cython/Compiler/FlowControl.py":1028
 *                                     sequence = sequence.args[0]
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
 *             function = sequence.function             # <<<<<<<<<<<<<<
 *             if sequence.self is None and function.is_name and function.name in ('range', 'xrange'):
 *                 entry = env.lookup(function.name)
*/
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_function); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1028, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_XDECREF_SET(__pyx_v_function, __pyx_t_11);
    __pyx_t_11 = 0;

    /* "Cython/Compiler/FlowControl.py":1029
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
 *             function = sequence.function
 *             if sequence.self is None and function.is_name and function.name in ('range', 'xrange'):             # <<<<<<<<<<<<<<
 *                 entry = env.lookup(function.name)
 *                 if entry and entry.is_type and entry.type is Builtin.range_type:
*/
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_self); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_7 = (__pyx_t_11 == Py_None);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (__pyx_t_7) {
    } else {
      __pyx_t_4 = __pyx_t_7;
      goto __pyx_L24_bool_binop_done;
    }
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1029, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (__pyx_t_7) {
    } else {
      __pyx_t_4 = __pyx_t_7;
      goto __pyx_L24_bool_binop_done;
    }
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_range, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1029, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_7 = __pyx_t_5;
      goto __pyx_L27_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_xrange, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1029, __pyx_L1_error)
    __pyx_t_7 = __pyx_t_5;
    __pyx_L27_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_5 = __pyx_t_7;
    __pyx_t_4 = __pyx_t_5;
    __pyx_L24_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/FlowControl.py":1030
 *             function = sequence.function
 *             if sequence.self is None and function.is_name and function.name in ('range', 'xrange'):
 *                 entry = env.lookup(function.name)             # <<<<<<<<<<<<<<
 *                 if entry and entry.is_type and entry.type is Builtin.range_type:
 *                     is_special = True
*/
      __pyx_t_10 = __pyx_v_env;
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1030, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_2};
        __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1030, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "Cython/Compiler/FlowControl.py":1031
 *             if sequence.self is None and function.is_name and function.name in ('range', 'xrange'):
 *                 entry = env.lookup(function.name)
 *                 if entry and entry.is_type and entry.type is Builtin.range_type:             # <<<<<<<<<<<<<<
 *                     is_special = True
 *                     for arg in sequence.args[:2]:
*/
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_entry); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1031, __pyx_L1_error)
      if (__pyx_t_5) {
      } else {
        __pyx_t_4 = __pyx_t_5;
        goto __pyx_L30_bool_binop_done;
      }
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_type); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1031, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1031, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (__pyx_t_5) {
      } else {
        __pyx_t_4 = __pyx_t_5;
        goto __pyx_L30_bool_binop_done;
      }
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1031, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_Builtin, __pyx_mstate_global->__pyx_n_u_range_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1031, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = (__pyx_t_11 == __pyx_t_2);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_4 = __pyx_t_5;
      __pyx_L30_bool_binop_done:;
      if (__pyx_t_4) {

        /* "Cython/Compiler/FlowControl.py":1032
 *                 entry = env.lookup(function.name)
 *                 if entry and entry.is_type and entry.type is Builtin.range_type:
 *                     is_special = True             # <<<<<<<<<<<<<<
 *                     for arg in sequence.args[:2]:
 *                         self.mark_assignment(target, arg, rhs_scope=node.iterator.expr_scope)
*/
        __pyx_v_is_special = 1;

        /* "Cython/Compiler/FlowControl.py":1033
 *                 if entry and entry.is_type and entry.type is Builtin.range_type:
 *                     is_special = True
 *                     for arg in sequence.args[:2]:             # <<<<<<<<<<<<<<
 *                         self.mark_assignment(target, arg, rhs_scope=node.iterator.expr_scope)
 *                     if len(sequence.args) > 2:
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1033, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_11 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, 2, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1033, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (likely(PyList_CheckExact(__pyx_t_11)) || PyTuple_CheckExact(__pyx_t_11)) {
          __pyx_t_2 = __pyx_t_11; __Pyx_INCREF(__pyx_t_2);
          __pyx_t_8 = 0;
          __pyx_t_13 = NULL;
        } else {
          __pyx_t_8 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1033, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_13 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1033, __pyx_L1_error)
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        for (;;) {
          if (likely(!__pyx_t_13)) {
            if (likely(PyList_CheckExact(__pyx_t_2))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1033, __pyx_L1_error)
                #endif
                if (__pyx_t_8 >= __pyx_temp) break;
              }
              __pyx_t_11 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
              ++__pyx_t_8;
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1033, __pyx_L1_error)
                #endif
                if (__pyx_t_8 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_11 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_8));
              #else
              __pyx_t_11 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_8);
              #endif
              ++__pyx_t_8;
            }
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1033, __pyx_L1_error)
          } else {
            __pyx_t_11 = __pyx_t_13(__pyx_t_2);
            if (unlikely(!__pyx_t_11)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1033, __pyx_L1_error)
                PyErr_Clear();
              }
              break;
            }
          }
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_11);
          __pyx_t_11 = 0;

          /* "Cython/Compiler/FlowControl.py":1034
 *                     is_special = True
 *                     for arg in sequence.args[:2]:
 *                         self.mark_assignment(target, arg, rhs_scope=node.iterator.expr_scope)             # <<<<<<<<<<<<<<
 *                     if len(sequence.args) > 2:
 *                         self.mark_assignment(target, self.constant_folder(
*/
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_iterator); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1034, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1034, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_12.__pyx_n = 2;
          __pyx_t_12.rhs = __pyx_v_arg;
          __pyx_t_12.rhs_scope = __pyx_t_10;
          __pyx_t_11 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_target, 0, &__pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1034, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "Cython/Compiler/FlowControl.py":1033
 *                 if entry and entry.is_type and entry.type is Builtin.range_type:
 *                     is_special = True
 *                     for arg in sequence.args[:2]:             # <<<<<<<<<<<<<<
 *                         self.mark_assignment(target, arg, rhs_scope=node.iterator.expr_scope)
 *                     if len(sequence.args) > 2:
*/
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "Cython/Compiler/FlowControl.py":1035
 *                     for arg in sequence.args[:2]:
 *                         self.mark_assignment(target, arg, rhs_scope=node.iterator.expr_scope)
 *                     if len(sequence.args) > 2:             # <<<<<<<<<<<<<<
 *                         self.mark_assignment(target, self.constant_folder(
 *                             ExprNodes.binop_node(node.pos,
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1035, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_4 = (__pyx_t_8 > 2);
        if (__pyx_t_4) {

          /* "Cython/Compiler/FlowControl.py":1036
 *                         self.mark_assignment(target, arg, rhs_scope=node.iterator.expr_scope)
 *                     if len(sequence.args) > 2:
 *                         self.mark_assignment(target, self.constant_folder(             # <<<<<<<<<<<<<<
 *                             ExprNodes.binop_node(node.pos,
 *                                                     '+',
*/
          __pyx_t_11 = NULL;
          __Pyx_INCREF(__pyx_v_self->constant_folder);
          __pyx_t_10 = __pyx_v_self->constant_folder; 

          /* "Cython/Compiler/FlowControl.py":1037
 *                     if len(sequence.args) > 2:
 *                         self.mark_assignment(target, self.constant_folder(
 *                             ExprNodes.binop_node(node.pos,             # <<<<<<<<<<<<<<
 *                                                     '+',
 *                                                     sequence.args[0],
*/
          __pyx_t_9 = __pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes;
          __Pyx_INCREF(__pyx_t_9);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1037, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);

          /* "Cython/Compiler/FlowControl.py":1039
 *                             ExprNodes.binop_node(node.pos,
 *                                                     '+',
 *                                                     sequence.args[0],             # <<<<<<<<<<<<<<
 *                                                     sequence.args[2])),
 *                                             rhs_scope=node.iterator.expr_scope)
*/
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1039, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_15 = __Pyx_GetItemInt(__pyx_t_14, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1039, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

          /* "Cython/Compiler/FlowControl.py":1040
 *                                                     '+',
 *                                                     sequence.args[0],
 *                                                     sequence.args[2])),             # <<<<<<<<<<<<<<
 *                                             rhs_scope=node.iterator.expr_scope)
 * 
*/
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_sequence, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1040, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_16 = __Pyx_GetItemInt(__pyx_t_14, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1040, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_9, __pyx_t_3, __pyx_mstate_global->__pyx_kp_u__19, __pyx_t_15, __pyx_t_16};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_binop_node, __pyx_callargs+__pyx_t_6, (5-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1037, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __pyx_t_6 = 1;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
            assert(__pyx_t_11);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
            __pyx_t_6 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_1};
            __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1036, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
          }

          /* "Cython/Compiler/FlowControl.py":1041
 *                                                     sequence.args[0],
 *                                                     sequence.args[2])),
 *                                             rhs_scope=node.iterator.expr_scope)             # <<<<<<<<<<<<<<
 * 
 *         if not is_special:
*/
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_iterator); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1041, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1041, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "Cython/Compiler/FlowControl.py":1036
 *                         self.mark_assignment(target, arg, rhs_scope=node.iterator.expr_scope)
 *                     if len(sequence.args) > 2:
 *                         self.mark_assignment(target, self.constant_folder(             # <<<<<<<<<<<<<<
 *                             ExprNodes.binop_node(node.pos,
 *                                                     '+',
*/
          __pyx_t_12.__pyx_n = 2;
          __pyx_t_12.rhs = __pyx_t_2;
          __pyx_t_12.rhs_scope = __pyx_t_1;
          __pyx_t_10 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_target, 0, &__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1036, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "Cython/Compiler/FlowControl.py":1035
 *                     for arg in sequence.args[:2]:
 *                         self.mark_assignment(target, arg, rhs_scope=node.iterator.expr_scope)
 *                     if len(sequence.args) > 2:             # <<<<<<<<<<<<<<
 *                         self.mark_assignment(target, self.constant_folder(
 *                             ExprNodes.binop_node(node.pos,
*/
        }

        /* "Cython/Compiler/FlowControl.py":1031
 *             if sequence.self is None and function.is_name and function.name in ('range', 'xrange'):
 *                 entry = env.lookup(function.name)
 *                 if entry and entry.is_type and entry.type is Builtin.range_type:             # <<<<<<<<<<<<<<
 *                     is_special = True
 *                     for arg in sequence.args[:2]:
*/
      }

      /* "Cython/Compiler/FlowControl.py":1029
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):
 *             function = sequence.function
 *             if sequence.self is None and function.is_name and function.name in ('range', 'xrange'):             # <<<<<<<<<<<<<<
 *                 entry = env.lookup(function.name)
 *                 if entry and entry.is_type and entry.type is Builtin.range_type:
*/
    }

    /* "Cython/Compiler/FlowControl.py":1027
 *                                     target = target.args[1]
 *                                     sequence = sequence.args[0]
 *         if isinstance(sequence, ExprNodes.SimpleCallNode):             # <<<<<<<<<<<<<<
 *             function = sequence.function
 *             if sequence.self is None and function.is_name and function.name in ('range', 'xrange'):
*/
  }

  /* "Cython/Compiler/FlowControl.py":1043
 *                                             rhs_scope=node.iterator.expr_scope)
 * 
 *         if not is_special:             # <<<<<<<<<<<<<<
 *             # A for-loop basically translates to subsequent calls to
 *             # __getitem__(), so using an IndexNode here allows us to
*/
  __pyx_t_4 = (!__pyx_v_is_special);
  if (__pyx_t_4) {

    /* "Cython/Compiler/FlowControl.py":1050
 *             # object type when the base type cannot be handled.
 * 
 *             self.mark_assignment(target, node.item, rhs_scope=node.iterator.expr_scope)             # <<<<<<<<<<<<<<
 * 
 *     def mark_parallel_forloop_assignment(self, node):
*/
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_item); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1050, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_iterator); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1050, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1050, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_12.__pyx_n = 2;
    __pyx_t_12.rhs = __pyx_t_10;
    __pyx_t_12.rhs_scope = __pyx_t_2;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_target, 0, &__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1050, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1043
 *                                             rhs_scope=node.iterator.expr_scope)
 * 
 *         if not is_special:             # <<<<<<<<<<<<<<
 *             # A for-loop basically translates to subsequent calls to
 *             # __getitem__(), so using an IndexNode here allows us to
*/
  }

  /* "Cython/Compiler/FlowControl.py":1000
 *         return node
 * 
 *     def mark_forloop_target(self, node):             # <<<<<<<<<<<<<<
 *         # TODO: Remove redundancy with range optimization...
 *         is_special = False
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.mark_forloop_target", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XDECREF(__pyx_v_env);
  __Pyx_XDECREF(__pyx_v_function);
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XDECREF(__pyx_v_iterator);
  __Pyx_XDECREF(__pyx_v_iterator_type);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1052
 *             self.mark_assignment(target, node.item, rhs_scope=node.iterator.expr_scope)
 * 
 *     def mark_parallel_forloop_assignment(self, node):             # <<<<<<<<<<<<<<
 *         target = node.target
 *         for arg in node.args[:2]:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_51mark_parallel_forloop_assignment(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_51mark_parallel_forloop_assignment = {"mark_parallel_forloop_assignment", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_51mark_parallel_forloop_assignment, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_51mark_parallel_forloop_assignment(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mark_parallel_forloop_assignment (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_50mark_parallel_forloop_assignment(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_50mark_parallel_forloop_assignment(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  size_t __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mark_parallel_forloop_assignment", 0);

  /* "Cython/Compiler/FlowControl.py":1053
 * 
 *     def mark_parallel_forloop_assignment(self, node):
 *         target = node.target             # <<<<<<<<<<<<<<
 *         for arg in node.args[:2]:
 *             self.mark_assignment(target, arg)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_target = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1054
 *     def mark_parallel_forloop_assignment(self, node):
 *         target = node.target
 *         for arg in node.args[:2]:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(target, arg)
 *         if len(node.args) > 2:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 2, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1054, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1054, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1054, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3));
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1054, __pyx_L1_error)
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1054, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1055
 *         target = node.target
 *         for arg in node.args[:2]:
 *             self.mark_assignment(target, arg)             # <<<<<<<<<<<<<<
 *         if len(node.args) > 2:
 *             self.mark_assignment(target, self.constant_folder(
*/
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.rhs = __pyx_v_arg;
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_target, 0, &__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1054
 *     def mark_parallel_forloop_assignment(self, node):
 *         target = node.target
 *         for arg in node.args[:2]:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(target, arg)
 *         if len(node.args) > 2:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1056
 *         for arg in node.args[:2]:
 *             self.mark_assignment(target, arg)
 *         if len(node.args) > 2:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(target, self.constant_folder(
 *                 ExprNodes.binop_node(node.pos,
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__pyx_t_3 > 2);
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1057
 *             self.mark_assignment(target, arg)
 *         if len(node.args) > 2:
 *             self.mark_assignment(target, self.constant_folder(             # <<<<<<<<<<<<<<
 *                 ExprNodes.binop_node(node.pos,
 *                                         '+',
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_self->constant_folder);
    __pyx_t_7 = __pyx_v_self->constant_folder; 

    /* "Cython/Compiler/FlowControl.py":1058
 *         if len(node.args) > 2:
 *             self.mark_assignment(target, self.constant_folder(
 *                 ExprNodes.binop_node(node.pos,             # <<<<<<<<<<<<<<
 *                                         '+',
 *                                         node.args[0],
*/
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes;
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);

    /* "Cython/Compiler/FlowControl.py":1060
 *                 ExprNodes.binop_node(node.pos,
 *                                         '+',
 *                                         node.args[0],             # <<<<<<<<<<<<<<
 *                                         node.args[2])))
 *         if not node.args:
*/
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1060, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_11, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1060, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "Cython/Compiler/FlowControl.py":1061
 *                                         '+',
 *                                         node.args[0],
 *                                         node.args[2])))             # <<<<<<<<<<<<<<
 *         if not node.args:
 *             # Almost certainly an error
*/
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1061, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_13 = __Pyx_GetItemInt(__pyx_t_11, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1061, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_14 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_9, __pyx_t_10, __pyx_mstate_global->__pyx_kp_u__19, __pyx_t_12, __pyx_t_13};
      __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_binop_node, __pyx_callargs+__pyx_t_14, (5-__pyx_t_14) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1058, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __pyx_t_14 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_14 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (__pyx_t_14*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1057, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }

    /* "Cython/Compiler/FlowControl.py":1057
 *             self.mark_assignment(target, arg)
 *         if len(node.args) > 2:
 *             self.mark_assignment(target, self.constant_folder(             # <<<<<<<<<<<<<<
 *                 ExprNodes.binop_node(node.pos,
 *                                         '+',
*/
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.rhs = __pyx_t_1;
    __pyx_t_7 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_target, 0, &__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1057, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "Cython/Compiler/FlowControl.py":1056
 *         for arg in node.args[:2]:
 *             self.mark_assignment(target, arg)
 *         if len(node.args) > 2:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(target, self.constant_folder(
 *                 ExprNodes.binop_node(node.pos,
*/
  }

  /* "Cython/Compiler/FlowControl.py":1062
 *                                         node.args[0],
 *                                         node.args[2])))
 *         if not node.args:             # <<<<<<<<<<<<<<
 *             # Almost certainly an error
 *             self.mark_assignment(target)
*/
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1062, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_15 = (!__pyx_t_6);
  if (__pyx_t_15) {

    /* "Cython/Compiler/FlowControl.py":1064
 *         if not node.args:
 *             # Almost certainly an error
 *             self.mark_assignment(target)             # <<<<<<<<<<<<<<
 * 
 *     def visit_AsyncForStatNode(self, node):
*/
    __pyx_t_7 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_v_target, 0, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1064, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "Cython/Compiler/FlowControl.py":1062
 *                                         node.args[0],
 *                                         node.args[2])))
 *         if not node.args:             # <<<<<<<<<<<<<<
 *             # Almost certainly an error
 *             self.mark_assignment(target)
*/
  }

  /* "Cython/Compiler/FlowControl.py":1052
 *             self.mark_assignment(target, node.item, rhs_scope=node.iterator.expr_scope)
 * 
 *     def mark_parallel_forloop_assignment(self, node):             # <<<<<<<<<<<<<<
 *         target = node.target
 *         for arg in node.args[:2]:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.mark_parallel_forloop_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1066
 *             self.mark_assignment(target)
 * 
 *     def visit_AsyncForStatNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_ForInStatNode(node)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_53visit_AsyncForStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_53visit_AsyncForStatNode = {"visit_AsyncForStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_53visit_AsyncForStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_53visit_AsyncForStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_AsyncForStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_52visit_AsyncForStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_52visit_AsyncForStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_AsyncForStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1067
 * 
 *     def visit_AsyncForStatNode(self, node):
 *         return self.visit_ForInStatNode(node)             # <<<<<<<<<<<<<<
 * 
 *     def visit_ForInStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_node};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visit_ForInStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1067, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1066
 *             self.mark_assignment(target)
 * 
 *     def visit_AsyncForStatNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_ForInStatNode(node)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_AsyncForStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1069
 *         return self.visit_ForInStatNode(node)
 * 
 *     def visit_ForInStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_55visit_ForInStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_55visit_ForInStatNode = {"visit_ForInStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_55visit_ForInStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_55visit_ForInStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ForInStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_54visit_ForInStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_54visit_ForInStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_condition_block = NULL;
  PyObject *__pyx_v_next_block = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_7;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ForInStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1070
 * 
 *     def visit_ForInStatNode(self, node):
 *         condition_block = self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         next_block = self.flow.newblock()
 *         # Condition with iterator
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_condition_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1071
 *     def visit_ForInStatNode(self, node):
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         # Condition with iterator
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_next_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1073
 *         next_block = self.flow.newblock()
 *         # Condition with iterator
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))             # <<<<<<<<<<<<<<
 *         self._visit(node.iterator)
 *         # Target assignment
*/
  if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 1073, __pyx_L1_error)
  }
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_LoopDescr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_next_block, __pyx_v_condition_block};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->flow->loops, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1073, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1074
 *         # Condition with iterator
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
 *         self._visit(node.iterator)             # <<<<<<<<<<<<<<
 *         # Target assignment
 *         self.flow.nextblock()
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_iterator); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1076
 *         self._visit(node.iterator)
 *         # Target assignment
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(node, Nodes.ForInStatNode):
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1078
 *         self.flow.nextblock()
 * 
 *         if isinstance(node, Nodes.ForInStatNode):             # <<<<<<<<<<<<<<
 *             self.mark_forloop_target(node)
 *         elif isinstance(node, Nodes.AsyncForStatNode):
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_Nodes, __pyx_mstate_global->__pyx_n_u_ForInStatNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_node, __pyx_t_3); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 1078, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1079
 * 
 *         if isinstance(node, Nodes.ForInStatNode):
 *             self.mark_forloop_target(node)             # <<<<<<<<<<<<<<
 *         elif isinstance(node, Nodes.AsyncForStatNode):
 *             # not entirely correct, but good enough for now
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_node};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_mark_forloop_target, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1079, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":1078
 *         self.flow.nextblock()
 * 
 *         if isinstance(node, Nodes.ForInStatNode):             # <<<<<<<<<<<<<<
 *             self.mark_forloop_target(node)
 *         elif isinstance(node, Nodes.AsyncForStatNode):
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/FlowControl.py":1080
 *         if isinstance(node, Nodes.ForInStatNode):
 *             self.mark_forloop_target(node)
 *         elif isinstance(node, Nodes.AsyncForStatNode):             # <<<<<<<<<<<<<<
 *             # not entirely correct, but good enough for now
 *             self.mark_assignment(node.target, node.item)
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_Nodes, __pyx_mstate_global->__pyx_n_u_AsyncForStatNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_node, __pyx_t_3); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 1080, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1082
 *         elif isinstance(node, Nodes.AsyncForStatNode):
 *             # not entirely correct, but good enough for now
 *             self.mark_assignment(node.target, node.item)             # <<<<<<<<<<<<<<
 *         elif isinstance(node, Nodes.ParallelRangeNode):  # Parallel
 *             self.mark_parallel_forloop_assignment(node)
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7.__pyx_n = 1;
    __pyx_t_7.rhs = __pyx_t_1;
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_3, 0, &__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1080
 *         if isinstance(node, Nodes.ForInStatNode):
 *             self.mark_forloop_target(node)
 *         elif isinstance(node, Nodes.AsyncForStatNode):             # <<<<<<<<<<<<<<
 *             # not entirely correct, but good enough for now
 *             self.mark_assignment(node.target, node.item)
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/FlowControl.py":1083
 *             # not entirely correct, but good enough for now
 *             self.mark_assignment(node.target, node.item)
 *         elif isinstance(node, Nodes.ParallelRangeNode):  # Parallel             # <<<<<<<<<<<<<<
 *             self.mark_parallel_forloop_assignment(node)
 *         else:
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_Nodes, __pyx_mstate_global->__pyx_n_u_ParallelRangeNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_node, __pyx_t_2); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 1083, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1084
 *             self.mark_assignment(node.target, node.item)
 *         elif isinstance(node, Nodes.ParallelRangeNode):  # Parallel
 *             self.mark_parallel_forloop_assignment(node)             # <<<<<<<<<<<<<<
 *         else:
 *             assert False, type(node)
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_node};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_mark_parallel_forloop_assignment, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1084, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1083
 *             # not entirely correct, but good enough for now
 *             self.mark_assignment(node.target, node.item)
 *         elif isinstance(node, Nodes.ParallelRangeNode):  # Parallel             # <<<<<<<<<<<<<<
 *             self.mark_parallel_forloop_assignment(node)
 *         else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/FlowControl.py":1086
 *             self.mark_parallel_forloop_assignment(node)
 *         else:
 *             assert False, type(node)             # <<<<<<<<<<<<<<
 * 
 *         # Body block
*/
  /*else*/ {
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      if (unlikely(!0)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), ((PyObject *)Py_TYPE(__pyx_v_node)), 0, 0);
        __PYX_ERR(0, 1086, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 1086, __pyx_L1_error)
    #endif
  }
  __pyx_L3:;

  /* "Cython/Compiler/FlowControl.py":1090
 *         # Body block
 * 
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self._visit(node.body)
 *         self.flow.loops.pop()
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1091
 * 
 *         self.flow.nextblock()
 *         self._visit(node.body)             # <<<<<<<<<<<<<<
 *         self.flow.loops.pop()
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1092
 *         self.flow.nextblock()
 *         self._visit(node.body)
 *         self.flow.loops.pop()             # <<<<<<<<<<<<<<
 * 
 *         # Loop it
*/
  if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 1092, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->flow->loops); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1095
 * 
 *         # Loop it
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(condition_block)
 *         # Else clause
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1095, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1096
 *         # Loop it
 *         if self.flow.block:
 *             self.flow.block.add_child(condition_block)             # <<<<<<<<<<<<<<
 *         # Else clause
 *         if node.else_clause:
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_condition_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1096, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1095
 * 
 *         # Loop it
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(condition_block)
 *         # Else clause
*/
  }

  /* "Cython/Compiler/FlowControl.py":1098
 *             self.flow.block.add_child(condition_block)
 *         # Else clause
 *         if node.else_clause:             # <<<<<<<<<<<<<<
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1098, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1099
 *         # Else clause
 *         if node.else_clause:
 *             self.flow.nextblock(parent=condition_block)             # <<<<<<<<<<<<<<
 *             self._visit(node.else_clause)
 *             if self.flow.block:
*/
    if (!(likely(((__pyx_v_condition_block) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_condition_block, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1099, __pyx_L1_error)
    __pyx_t_8.__pyx_n = 1;
    __pyx_t_8.parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_condition_block);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, &__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1100
 *         if node.else_clause:
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)             # <<<<<<<<<<<<<<
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1101
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         else:
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1101, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/FlowControl.py":1102
 *             self._visit(node.else_clause)
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 *         else:
 *             condition_block.add_child(next_block)
*/
      __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1102, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":1101
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         else:
*/
    }

    /* "Cython/Compiler/FlowControl.py":1098
 *             self.flow.block.add_child(condition_block)
 *         # Else clause
 *         if node.else_clause:             # <<<<<<<<<<<<<<
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
*/
    goto __pyx_L5;
  }

  /* "Cython/Compiler/FlowControl.py":1104
 *                 self.flow.block.add_child(next_block)
 *         else:
 *             condition_block.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         if next_block.parents:
*/
  /*else*/ {
    __pyx_t_1 = __pyx_v_condition_block;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_next_block};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1104, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "Cython/Compiler/FlowControl.py":1106
 *             condition_block.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1107
 * 
 *         if next_block.parents:
 *             self.flow.block = next_block             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block = None
*/
    __pyx_t_2 = __pyx_v_next_block;
    __Pyx_INCREF(__pyx_t_2);
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1106
 *             condition_block.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
    goto __pyx_L7;
  }

  /* "Cython/Compiler/FlowControl.py":1109
 *             self.flow.block = next_block
 *         else:
 *             self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  }
  __pyx_L7:;

  /* "Cython/Compiler/FlowControl.py":1110
 *         else:
 *             self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def _delete_privates(self, node, exclude=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1069
 *         return self.visit_ForInStatNode(node)
 * 
 *     def visit_ForInStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ForInStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_condition_block);
  __Pyx_XDECREF(__pyx_v_next_block);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1112
 *         return node
 * 
 *     def _delete_privates(self, node, exclude=None):             # <<<<<<<<<<<<<<
 *         for private_node in node.assigned_nodes:
 *             if not exclude or private_node.entry is not exclude:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_57_delete_privates(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_57_delete_privates = {"_delete_privates", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_57_delete_privates, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_57_delete_privates(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_node = 0;
  PyObject *__pyx_v_exclude = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_delete_privates (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_exclude,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1112, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1112, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1112, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_delete_privates", 0) < (0)) __PYX_ERR(0, 1112, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_delete_privates", 0, 1, 2, i); __PYX_ERR(0, 1112, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1112, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1112, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_node = values[0];
    __pyx_v_exclude = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_delete_privates", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1112, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis._delete_privates", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_56_delete_privates(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), __pyx_v_node, __pyx_v_exclude);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_56_delete_privates(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_exclude) {
  PyObject *__pyx_v_private_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_delete_privates", 0);

  /* "Cython/Compiler/FlowControl.py":1113
 * 
 *     def _delete_privates(self, node, exclude=None):
 *         for private_node in node.assigned_nodes:             # <<<<<<<<<<<<<<
 *             if not exclude or private_node.entry is not exclude:
 *                 self.flow.mark_deletion(private_node, private_node.entry)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_assigned_nodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1113, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1113, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1113, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1113, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1113, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_private_node, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1114
 *     def _delete_privates(self, node, exclude=None):
 *         for private_node in node.assigned_nodes:
 *             if not exclude or private_node.entry is not exclude:             # <<<<<<<<<<<<<<
 *                 self.flow.mark_deletion(private_node, private_node.entry)
 * 
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_exclude); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1114, __pyx_L1_error)
    __pyx_t_7 = (!__pyx_t_6);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_private_node, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__pyx_t_1 != __pyx_v_exclude);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __pyx_t_7;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_5) {

      /* "Cython/Compiler/FlowControl.py":1115
 *         for private_node in node.assigned_nodes:
 *             if not exclude or private_node.entry is not exclude:
 *                 self.flow.mark_deletion(private_node, private_node.entry)             # <<<<<<<<<<<<<<
 * 
 *     def visit_ParallelRangeNode(self, node):
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_private_node, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_deletion(__pyx_v_self->flow, __pyx_v_private_node, __pyx_t_1, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "Cython/Compiler/FlowControl.py":1114
 *     def _delete_privates(self, node, exclude=None):
 *         for private_node in node.assigned_nodes:
 *             if not exclude or private_node.entry is not exclude:             # <<<<<<<<<<<<<<
 *                 self.flow.mark_deletion(private_node, private_node.entry)
 * 
*/
    }

    /* "Cython/Compiler/FlowControl.py":1113
 * 
 *     def _delete_privates(self, node, exclude=None):
 *         for private_node in node.assigned_nodes:             # <<<<<<<<<<<<<<
 *             if not exclude or private_node.entry is not exclude:
 *                 self.flow.mark_deletion(private_node, private_node.entry)
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1112
 *         return node
 * 
 *     def _delete_privates(self, node, exclude=None):             # <<<<<<<<<<<<<<
 *         for private_node in node.assigned_nodes:
 *             if not exclude or private_node.entry is not exclude:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis._delete_privates", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_private_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1117
 *                 self.flow.mark_deletion(private_node, private_node.entry)
 * 
 *     def visit_ParallelRangeNode(self, node):             # <<<<<<<<<<<<<<
 *         reductions = self.reductions
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_59visit_ParallelRangeNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_59visit_ParallelRangeNode = {"visit_ParallelRangeNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_59visit_ParallelRangeNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_59visit_ParallelRangeNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ParallelRangeNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_58visit_ParallelRangeNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_58visit_ParallelRangeNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_reductions = NULL;
  PyObject *__pyx_v_private_node = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_reduction = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  size_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ParallelRangeNode", 0);
  __Pyx_INCREF(__pyx_v_node);

  /* "Cython/Compiler/FlowControl.py":1118
 * 
 *     def visit_ParallelRangeNode(self, node):
 *         reductions = self.reductions             # <<<<<<<<<<<<<<
 * 
 *         # if node.target is None or not a NameNode, an error will have
*/
  __pyx_t_1 = __pyx_v_self->reductions;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_reductions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1122
 *         # if node.target is None or not a NameNode, an error will have
 *         # been previously issued
 *         if hasattr(node.target, 'entry'):             # <<<<<<<<<<<<<<
 *             self.reductions = set(reductions)
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_HasAttr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":1123
 *         # been previously issued
 *         if hasattr(node.target, 'entry'):
 *             self.reductions = set(reductions)             # <<<<<<<<<<<<<<
 * 
 *             for private_node in node.assigned_nodes:
*/
    __pyx_t_1 = PySet_New(__pyx_v_reductions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->reductions);
    __Pyx_DECREF(__pyx_v_self->reductions);
    __pyx_v_self->reductions = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1125
 *             self.reductions = set(reductions)
 * 
 *             for private_node in node.assigned_nodes:             # <<<<<<<<<<<<<<
 *                 private_node.entry.error_on_uninitialized = True
 *                 pos, reduction = node.assignments[private_node.entry]
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_assigned_nodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1125, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1125, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1125, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_4, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_4;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1125, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4));
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4);
          #endif
          ++__pyx_t_4;
        }
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1125, __pyx_L1_error)
      } else {
        __pyx_t_1 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1125, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_private_node, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":1126
 * 
 *             for private_node in node.assigned_nodes:
 *                 private_node.entry.error_on_uninitialized = True             # <<<<<<<<<<<<<<
 *                 pos, reduction = node.assignments[private_node.entry]
 *                 if reduction:
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_private_node, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_error_on_uninitialized, Py_True) < (0)) __PYX_ERR(0, 1126, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":1127
 *             for private_node in node.assigned_nodes:
 *                 private_node.entry.error_on_uninitialized = True
 *                 pos, reduction = node.assignments[private_node.entry]             # <<<<<<<<<<<<<<
 *                 if reduction:
 *                     self.reductions.add(private_node.entry)
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_assignments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1127, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_private_node, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1127, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1127, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
        PyObject* sequence = __pyx_t_7;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1127, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_1);
        } else {
          __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1127, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_6);
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1127, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_1);
        }
        #else
        __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1127, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1127, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1127, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
        index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_1 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_1)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < (0)) __PYX_ERR(0, 1127, __pyx_L1_error)
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_unpacking_done;
        __pyx_L6_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1127, __pyx_L1_error)
        __pyx_L7_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_pos, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_reduction, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":1128
 *                 private_node.entry.error_on_uninitialized = True
 *                 pos, reduction = node.assignments[private_node.entry]
 *                 if reduction:             # <<<<<<<<<<<<<<
 *                     self.reductions.add(private_node.entry)
 * 
*/
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_reduction); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1128, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/FlowControl.py":1129
 *                 pos, reduction = node.assignments[private_node.entry]
 *                 if reduction:
 *                     self.reductions.add(private_node.entry)             # <<<<<<<<<<<<<<
 * 
 *             node = self.visit_ForInStatNode(node)
*/
        if (unlikely(__pyx_v_self->reductions == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
          __PYX_ERR(0, 1129, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_private_node, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1129, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = PySet_Add(__pyx_v_self->reductions, __pyx_t_7); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 1129, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/FlowControl.py":1128
 *                 private_node.entry.error_on_uninitialized = True
 *                 pos, reduction = node.assignments[private_node.entry]
 *                 if reduction:             # <<<<<<<<<<<<<<
 *                     self.reductions.add(private_node.entry)
 * 
*/
      }

      /* "Cython/Compiler/FlowControl.py":1125
 *             self.reductions = set(reductions)
 * 
 *             for private_node in node.assigned_nodes:             # <<<<<<<<<<<<<<
 *                 private_node.entry.error_on_uninitialized = True
 *                 pos, reduction = node.assignments[private_node.entry]
*/
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":1131
 *                     self.reductions.add(private_node.entry)
 * 
 *             node = self.visit_ForInStatNode(node)             # <<<<<<<<<<<<<<
 * 
 *         self.reductions = reductions
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_11 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_node};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visit_ForInStatNode, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_node, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":1122
 *         # if node.target is None or not a NameNode, an error will have
 *         # been previously issued
 *         if hasattr(node.target, 'entry'):             # <<<<<<<<<<<<<<
 *             self.reductions = set(reductions)
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":1133
 *             node = self.visit_ForInStatNode(node)
 * 
 *         self.reductions = reductions             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __Pyx_INCREF(__pyx_v_reductions);
  __Pyx_GIVEREF(__pyx_v_reductions);
  __Pyx_GOTREF(__pyx_v_self->reductions);
  __Pyx_DECREF(__pyx_v_self->reductions);
  __pyx_v_self->reductions = __pyx_v_reductions;

  /* "Cython/Compiler/FlowControl.py":1134
 * 
 *         self.reductions = reductions
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ParallelWithBlockNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1117
 *                 self.flow.mark_deletion(private_node, private_node.entry)
 * 
 *     def visit_ParallelRangeNode(self, node):             # <<<<<<<<<<<<<<
 *         reductions = self.reductions
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ParallelRangeNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_reductions);
  __Pyx_XDECREF(__pyx_v_private_node);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_reduction);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1136
 *         return node
 * 
 *     def visit_ParallelWithBlockNode(self, node):             # <<<<<<<<<<<<<<
 *         for private_node in node.assigned_nodes:
 *             private_node.entry.error_on_uninitialized = True
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_61visit_ParallelWithBlockNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_61visit_ParallelWithBlockNode = {"visit_ParallelWithBlockNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_61visit_ParallelWithBlockNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_61visit_ParallelWithBlockNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ParallelWithBlockNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_60visit_ParallelWithBlockNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_60visit_ParallelWithBlockNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_private_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ParallelWithBlockNode", 0);

  /* "Cython/Compiler/FlowControl.py":1137
 * 
 *     def visit_ParallelWithBlockNode(self, node):
 *         for private_node in node.assigned_nodes:             # <<<<<<<<<<<<<<
 *             private_node.entry.error_on_uninitialized = True
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_assigned_nodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1137, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1137, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1137, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1137, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1137, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_private_node, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1138
 *     def visit_ParallelWithBlockNode(self, node):
 *         for private_node in node.assigned_nodes:
 *             private_node.entry.error_on_uninitialized = True             # <<<<<<<<<<<<<<
 * 
 *         self.visitchildren(node)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_private_node, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_error_on_uninitialized, Py_True) < (0)) __PYX_ERR(0, 1138, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1137
 * 
 *     def visit_ParallelWithBlockNode(self, node):
 *         for private_node in node.assigned_nodes:             # <<<<<<<<<<<<<<
 *             private_node.entry.error_on_uninitialized = True
 * 
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1140
 *             private_node.entry.error_on_uninitialized = True
 * 
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         # lastprivate isn't allowed/doesn't make sense for a parallel (non-for) block
 *         self._delete_privates(node)
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1142
 *         self.visitchildren(node)
 *         # lastprivate isn't allowed/doesn't make sense for a parallel (non-for) block
 *         self._delete_privates(node)             # <<<<<<<<<<<<<<
 * 
 *         return node
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_node};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_delete_privates, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1144
 *         self._delete_privates(node)
 * 
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ForFromStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1136
 *         return node
 * 
 *     def visit_ParallelWithBlockNode(self, node):             # <<<<<<<<<<<<<<
 *         for private_node in node.assigned_nodes:
 *             private_node.entry.error_on_uninitialized = True
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ParallelWithBlockNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_private_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1146
 *         return node
 * 
 *     def visit_ForFromStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_63visit_ForFromStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_63visit_ForFromStatNode = {"visit_ForFromStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_63visit_ForFromStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_63visit_ForFromStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ForFromStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_62visit_ForFromStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_62visit_ForFromStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_condition_block = NULL;
  PyObject *__pyx_v_next_block = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ForFromStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1147
 * 
 *     def visit_ForFromStatNode(self, node):
 *         condition_block = self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         next_block = self.flow.newblock()
 *         # Condition with iterator
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_condition_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1148
 *     def visit_ForFromStatNode(self, node):
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         # Condition with iterator
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_next_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1150
 *         next_block = self.flow.newblock()
 *         # Condition with iterator
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))             # <<<<<<<<<<<<<<
 *         self._visit(node.bound1)
 *         self._visit(node.bound2)
*/
  if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 1150, __pyx_L1_error)
  }
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_LoopDescr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_next_block, __pyx_v_condition_block};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->flow->loops, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1150, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1151
 *         # Condition with iterator
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
 *         self._visit(node.bound1)             # <<<<<<<<<<<<<<
 *         self._visit(node.bound2)
 *         if node.step is not None:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_bound1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1152
 *         self.flow.loops.append(LoopDescr(next_block, condition_block))
 *         self._visit(node.bound1)
 *         self._visit(node.bound2)             # <<<<<<<<<<<<<<
 *         if node.step is not None:
 *             self._visit(node.step)
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_bound2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1153
 *         self._visit(node.bound1)
 *         self._visit(node.bound2)
 *         if node.step is not None:             # <<<<<<<<<<<<<<
 *             self._visit(node.step)
 *         # Target assignment
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_step); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1154
 *         self._visit(node.bound2)
 *         if node.step is not None:
 *             self._visit(node.step)             # <<<<<<<<<<<<<<
 *         # Target assignment
 *         self.flow.nextblock()
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_step); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":1153
 *         self._visit(node.bound1)
 *         self._visit(node.bound2)
 *         if node.step is not None:             # <<<<<<<<<<<<<<
 *             self._visit(node.step)
 *         # Target assignment
*/
  }

  /* "Cython/Compiler/FlowControl.py":1156
 *             self._visit(node.step)
 *         # Target assignment
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self.mark_assignment(node.target, node.bound1)
 *         if node.step is not None:
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1157
 *         # Target assignment
 *         self.flow.nextblock()
 *         self.mark_assignment(node.target, node.bound1)             # <<<<<<<<<<<<<<
 *         if node.step is not None:
 *             self.mark_assignment(node.target, self.constant_folder(
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_bound1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7.__pyx_n = 1;
  __pyx_t_7.rhs = __pyx_t_1;
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_3, 0, &__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1158
 *         self.flow.nextblock()
 *         self.mark_assignment(node.target, node.bound1)
 *         if node.step is not None:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(node.target, self.constant_folder(
 *                 ExprNodes.binop_node(node.pos, '+', node.bound1, node.step)))
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_step); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1159
 *         self.mark_assignment(node.target, node.bound1)
 *         if node.step is not None:
 *             self.mark_assignment(node.target, self.constant_folder(             # <<<<<<<<<<<<<<
 *                 ExprNodes.binop_node(node.pos, '+', node.bound1, node.step)))
 *         # Body block
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_self->constant_folder);
    __pyx_t_8 = __pyx_v_self->constant_folder; 

    /* "Cython/Compiler/FlowControl.py":1160
 *         if node.step is not None:
 *             self.mark_assignment(node.target, self.constant_folder(
 *                 ExprNodes.binop_node(node.pos, '+', node.bound1, node.step)))             # <<<<<<<<<<<<<<
 *         # Body block
 *         self.flow.nextblock()
*/
    __pyx_t_10 = __pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes;
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_bound1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_step); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_10, __pyx_t_11, __pyx_mstate_global->__pyx_kp_u__19, __pyx_t_12, __pyx_t_13};
      __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_binop_node, __pyx_callargs+__pyx_t_4, (5-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1160, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    }
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_9};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1159, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }

    /* "Cython/Compiler/FlowControl.py":1159
 *         self.mark_assignment(node.target, node.bound1)
 *         if node.step is not None:
 *             self.mark_assignment(node.target, self.constant_folder(             # <<<<<<<<<<<<<<
 *                 ExprNodes.binop_node(node.pos, '+', node.bound1, node.step)))
 *         # Body block
*/
    __pyx_t_7.__pyx_n = 1;
    __pyx_t_7.rhs = __pyx_t_1;
    __pyx_t_8 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_2, 0, &__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "Cython/Compiler/FlowControl.py":1158
 *         self.flow.nextblock()
 *         self.mark_assignment(node.target, node.bound1)
 *         if node.step is not None:             # <<<<<<<<<<<<<<
 *             self.mark_assignment(node.target, self.constant_folder(
 *                 ExprNodes.binop_node(node.pos, '+', node.bound1, node.step)))
*/
  }

  /* "Cython/Compiler/FlowControl.py":1162
 *                 ExprNodes.binop_node(node.pos, '+', node.bound1, node.step)))
 *         # Body block
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self._visit(node.body)
 *         self.flow.loops.pop()
*/
  __pyx_t_8 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "Cython/Compiler/FlowControl.py":1163
 *         # Body block
 *         self.flow.nextblock()
 *         self._visit(node.body)             # <<<<<<<<<<<<<<
 *         self.flow.loops.pop()
 *         # Loop it
*/
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1164
 *         self.flow.nextblock()
 *         self._visit(node.body)
 *         self.flow.loops.pop()             # <<<<<<<<<<<<<<
 *         # Loop it
 *         if self.flow.block:
*/
  if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 1164, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->flow->loops); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1166
 *         self.flow.loops.pop()
 *         # Loop it
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(condition_block)
 *         # Else clause
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1166, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1167
 *         # Loop it
 *         if self.flow.block:
 *             self.flow.block.add_child(condition_block)             # <<<<<<<<<<<<<<
 *         # Else clause
 *         if node.else_clause:
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_condition_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1166
 *         self.flow.loops.pop()
 *         # Loop it
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(condition_block)
 *         # Else clause
*/
  }

  /* "Cython/Compiler/FlowControl.py":1169
 *             self.flow.block.add_child(condition_block)
 *         # Else clause
 *         if node.else_clause:             # <<<<<<<<<<<<<<
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1170
 *         # Else clause
 *         if node.else_clause:
 *             self.flow.nextblock(parent=condition_block)             # <<<<<<<<<<<<<<
 *             self._visit(node.else_clause)
 *             if self.flow.block:
*/
    if (!(likely(((__pyx_v_condition_block) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_condition_block, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1170, __pyx_L1_error)
    __pyx_t_14.__pyx_n = 1;
    __pyx_t_14.parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_condition_block);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, &__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1171
 *         if node.else_clause:
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)             # <<<<<<<<<<<<<<
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "Cython/Compiler/FlowControl.py":1172
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         else:
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1172, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/FlowControl.py":1173
 *             self._visit(node.else_clause)
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 *         else:
 *             condition_block.add_child(next_block)
*/
      __pyx_t_8 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "Cython/Compiler/FlowControl.py":1172
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 *         else:
*/
    }

    /* "Cython/Compiler/FlowControl.py":1169
 *             self.flow.block.add_child(condition_block)
 *         # Else clause
 *         if node.else_clause:             # <<<<<<<<<<<<<<
 *             self.flow.nextblock(parent=condition_block)
 *             self._visit(node.else_clause)
*/
    goto __pyx_L6;
  }

  /* "Cython/Compiler/FlowControl.py":1175
 *                 self.flow.block.add_child(next_block)
 *         else:
 *             condition_block.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         if next_block.parents:
*/
  /*else*/ {
    __pyx_t_1 = __pyx_v_condition_block;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_next_block};
      __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1175, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_L6:;

  /* "Cython/Compiler/FlowControl.py":1177
 *             condition_block.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1178
 * 
 *         if next_block.parents:
 *             self.flow.block = next_block             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block = None
*/
    __pyx_t_8 = __pyx_v_next_block;
    __Pyx_INCREF(__pyx_t_8);
    if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1178, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_8);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_8);
    __pyx_t_8 = 0;

    /* "Cython/Compiler/FlowControl.py":1177
 *             condition_block.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
    goto __pyx_L8;
  }

  /* "Cython/Compiler/FlowControl.py":1180
 *             self.flow.block = next_block
 *         else:
 *             self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  }
  __pyx_L8:;

  /* "Cython/Compiler/FlowControl.py":1181
 *         else:
 *             self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_LoopNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1146
 *         return node
 * 
 *     def visit_ForFromStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ForFromStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_condition_block);
  __Pyx_XDECREF(__pyx_v_next_block);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1183
 *         return node
 * 
 *     def visit_LoopNode(self, node):             # <<<<<<<<<<<<<<
 *         raise InternalError("Generic loops are not supported")
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_65visit_LoopNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_65visit_LoopNode = {"visit_LoopNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_65visit_LoopNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_65visit_LoopNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_LoopNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_64visit_LoopNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_64visit_LoopNode(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_LoopNode", 0);

  /* "Cython/Compiler/FlowControl.py":1184
 * 
 *     def visit_LoopNode(self, node):
 *         raise InternalError("Generic loops are not supported")             # <<<<<<<<<<<<<<
 * 
 *     def visit_WithTargetAssignmentStatNode(self, node):
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_InternalError);
  __pyx_t_3 = __pyx_v_6Cython_8Compiler_11FlowControl_InternalError; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Generic_loops_are_not_supported};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 1184, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":1183
 *         return node
 * 
 *     def visit_LoopNode(self, node):             # <<<<<<<<<<<<<<
 *         raise InternalError("Generic loops are not supported")
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_LoopNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1186
 *         raise InternalError("Generic loops are not supported")
 * 
 *     def visit_WithTargetAssignmentStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_assignment(node.lhs, node.with_node.enter_call)
 *         return node
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_67visit_WithTargetAssignmentStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_67visit_WithTargetAssignmentStatNode = {"visit_WithTargetAssignmentStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_67visit_WithTargetAssignmentStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_67visit_WithTargetAssignmentStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_WithTargetAssignmentStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_66visit_WithTargetAssignmentStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_66visit_WithTargetAssignmentStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_WithTargetAssignmentStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1187
 * 
 *     def visit_WithTargetAssignmentStatNode(self, node):
 *         self.mark_assignment(node.lhs, node.with_node.enter_call)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_lhs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_with_node); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_enter_call); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4.__pyx_n = 1;
  __pyx_t_4.rhs = __pyx_t_3;
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_1, 0, &__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1188
 *     def visit_WithTargetAssignmentStatNode(self, node):
 *         self.mark_assignment(node.lhs, node.with_node.enter_call)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_WithStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1186
 *         raise InternalError("Generic loops are not supported")
 * 
 *     def visit_WithTargetAssignmentStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_assignment(node.lhs, node.with_node.enter_call)
 *         return node
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_WithTargetAssignmentStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1190
 *         return node
 * 
 *     def visit_WithStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.manager)
 *         self._visit(node.enter_call)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_69visit_WithStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_69visit_WithStatNode = {"visit_WithStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_69visit_WithStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_69visit_WithStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_WithStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_68visit_WithStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_68visit_WithStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_WithStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1191
 * 
 *     def visit_WithStatNode(self, node):
 *         self._visit(node.manager)             # <<<<<<<<<<<<<<
 *         self._visit(node.enter_call)
 *         self._visit(node.body)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_manager); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1192
 *     def visit_WithStatNode(self, node):
 *         self._visit(node.manager)
 *         self._visit(node.enter_call)             # <<<<<<<<<<<<<<
 *         self._visit(node.body)
 *         return node
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_enter_call); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1193
 *         self._visit(node.manager)
 *         self._visit(node.enter_call)
 *         self._visit(node.body)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1194
 *         self._visit(node.enter_call)
 *         self._visit(node.body)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_TryExceptStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1190
 *         return node
 * 
 *     def visit_WithStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.manager)
 *         self._visit(node.enter_call)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_WithStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1196
 *         return node
 * 
 *     def visit_TryExceptStatNode(self, node):             # <<<<<<<<<<<<<<
 *         # After exception handling
 *         next_block = self.flow.newblock()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_71visit_TryExceptStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_71visit_TryExceptStatNode = {"visit_TryExceptStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_71visit_TryExceptStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_71visit_TryExceptStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_TryExceptStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_70visit_TryExceptStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_70visit_TryExceptStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_next_block = NULL;
  PyObject *__pyx_v_entry_point = NULL;
  PyObject *__pyx_v_clause = NULL;
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_TryExceptStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1198
 *     def visit_TryExceptStatNode(self, node):
 *         # After exception handling
 *         next_block = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         # Body block
 *         self.flow.newblock()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_next_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1200
 *         next_block = self.flow.newblock()
 *         # Body block
 *         self.flow.newblock()             # <<<<<<<<<<<<<<
 *         # Exception entry point
 *         entry_point = self.flow.newblock()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1202
 *         self.flow.newblock()
 *         # Exception entry point
 *         entry_point = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         self.flow.exceptions.append(ExceptionDescr(entry_point))
 *         self.flow.nextblock()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_entry_point = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1203
 *         # Exception entry point
 *         entry_point = self.flow.newblock()
 *         self.flow.exceptions.append(ExceptionDescr(entry_point))             # <<<<<<<<<<<<<<
 *         self.flow.nextblock()
 *         ## XXX: links to exception handling point should be added by
*/
  if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 1203, __pyx_L1_error)
  }
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_ExceptionDescr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_entry_point};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->flow->exceptions, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1204
 *         entry_point = self.flow.newblock()
 *         self.flow.exceptions.append(ExceptionDescr(entry_point))
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         ## XXX: links to exception handling point should be added by
 *         ## XXX: children nodes
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1207
 *         ## XXX: links to exception handling point should be added by
 *         ## XXX: children nodes
 *         self.flow.block.add_child(entry_point)             # <<<<<<<<<<<<<<
 *         self.flow.nextblock()
 *         self.flow.in_try_block += 1
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_entry_point, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1208
 *         ## XXX: children nodes
 *         self.flow.block.add_child(entry_point)
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self.flow.in_try_block += 1
 *         self._visit(node.body)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1209
 *         self.flow.block.add_child(entry_point)
 *         self.flow.nextblock()
 *         self.flow.in_try_block += 1             # <<<<<<<<<<<<<<
 *         self._visit(node.body)
 *         self.flow.in_try_block -= 1
*/
  __pyx_v_self->flow->in_try_block = (__pyx_v_self->flow->in_try_block + 1);

  /* "Cython/Compiler/FlowControl.py":1210
 *         self.flow.nextblock()
 *         self.flow.in_try_block += 1
 *         self._visit(node.body)             # <<<<<<<<<<<<<<
 *         self.flow.in_try_block -= 1
 *         self.flow.exceptions.pop()
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1211
 *         self.flow.in_try_block += 1
 *         self._visit(node.body)
 *         self.flow.in_try_block -= 1             # <<<<<<<<<<<<<<
 *         self.flow.exceptions.pop()
 * 
*/
  __pyx_v_self->flow->in_try_block = (__pyx_v_self->flow->in_try_block - 1);

  /* "Cython/Compiler/FlowControl.py":1212
 *         self._visit(node.body)
 *         self.flow.in_try_block -= 1
 *         self.flow.exceptions.pop()             # <<<<<<<<<<<<<<
 * 
 *         # After exception
*/
  if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 1212, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyList_Pop(__pyx_v_self->flow->exceptions); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1215
 * 
 *         # After exception
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             if node.else_clause:
 *                 self.flow.nextblock()
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1215, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1216
 *         # After exception
 *         if self.flow.block:
 *             if node.else_clause:             # <<<<<<<<<<<<<<
 *                 self.flow.nextblock()
 *                 self._visit(node.else_clause)
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1216, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_6) {

      /* "Cython/Compiler/FlowControl.py":1217
 *         if self.flow.block:
 *             if node.else_clause:
 *                 self.flow.nextblock()             # <<<<<<<<<<<<<<
 *                 self._visit(node.else_clause)
 *             if self.flow.block:
*/
      __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/FlowControl.py":1218
 *             if node.else_clause:
 *                 self.flow.nextblock()
 *                 self._visit(node.else_clause)             # <<<<<<<<<<<<<<
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_else_clause); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":1216
 *         # After exception
 *         if self.flow.block:
 *             if node.else_clause:             # <<<<<<<<<<<<<<
 *                 self.flow.nextblock()
 *                 self._visit(node.else_clause)
*/
    }

    /* "Cython/Compiler/FlowControl.py":1219
 *                 self.flow.nextblock()
 *                 self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 * 
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1219, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/FlowControl.py":1220
 *                 self._visit(node.else_clause)
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         for clause in node.except_clauses:
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1220, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":1219
 *                 self.flow.nextblock()
 *                 self._visit(node.else_clause)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 * 
*/
    }

    /* "Cython/Compiler/FlowControl.py":1215
 * 
 *         # After exception
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             if node.else_clause:
 *                 self.flow.nextblock()
*/
  }

  /* "Cython/Compiler/FlowControl.py":1222
 *                 self.flow.block.add_child(next_block)
 * 
 *         for clause in node.except_clauses:             # <<<<<<<<<<<<<<
 *             self.flow.block = entry_point
 *             if clause.pattern:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_except_clauses); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1222, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1222, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_7;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1222, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_7));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_7);
        #endif
        ++__pyx_t_7;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1222, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_8(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1222, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_clause, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1223
 * 
 *         for clause in node.except_clauses:
 *             self.flow.block = entry_point             # <<<<<<<<<<<<<<
 *             if clause.pattern:
 *                 for pattern in clause.pattern:
*/
    __pyx_t_1 = __pyx_v_entry_point;
    __Pyx_INCREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1223, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1224
 *         for clause in node.except_clauses:
 *             self.flow.block = entry_point
 *             if clause.pattern:             # <<<<<<<<<<<<<<
 *                 for pattern in clause.pattern:
 *                     self._visit(pattern)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_clause, __pyx_mstate_global->__pyx_n_u_pattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1224, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_6) {

      /* "Cython/Compiler/FlowControl.py":1225
 *             self.flow.block = entry_point
 *             if clause.pattern:
 *                 for pattern in clause.pattern:             # <<<<<<<<<<<<<<
 *                     self._visit(pattern)
 *             else:
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_clause, __pyx_mstate_global->__pyx_n_u_pattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
        __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
      } else {
        __pyx_t_9 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1225, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_10 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1225, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_10)) {
          if (likely(PyList_CheckExact(__pyx_t_2))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1225, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_9;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1225, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_9));
            #else
            __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_9);
            #endif
            ++__pyx_t_9;
          }
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1225, __pyx_L1_error)
        } else {
          __pyx_t_1 = __pyx_t_10(__pyx_t_2);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1225, __pyx_L1_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_pattern, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/FlowControl.py":1226
 *             if clause.pattern:
 *                 for pattern in clause.pattern:
 *                     self._visit(pattern)             # <<<<<<<<<<<<<<
 *             else:
 *                 # TODO: handle * pattern
*/
        __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_pattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1226, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/FlowControl.py":1225
 *             self.flow.block = entry_point
 *             if clause.pattern:
 *                 for pattern in clause.pattern:             # <<<<<<<<<<<<<<
 *                     self._visit(pattern)
 *             else:
*/
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":1224
 *         for clause in node.except_clauses:
 *             self.flow.block = entry_point
 *             if clause.pattern:             # <<<<<<<<<<<<<<
 *                 for pattern in clause.pattern:
 *                     self._visit(pattern)
*/
      goto __pyx_L8;
    }

    /* "Cython/Compiler/FlowControl.py":1229
 *             else:
 *                 # TODO: handle * pattern
 *                 pass             # <<<<<<<<<<<<<<
 *             entry_point = self.flow.newblock(parent=self.flow.block)
 *             self.flow.nextblock()
*/
    /*else*/ {
    }
    __pyx_L8:;

    /* "Cython/Compiler/FlowControl.py":1230
 *                 # TODO: handle * pattern
 *                 pass
 *             entry_point = self.flow.newblock(parent=self.flow.block)             # <<<<<<<<<<<<<<
 *             self.flow.nextblock()
 *             if clause.target:
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_self->flow->block);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_11.__pyx_n = 1;
    __pyx_t_11.parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_2);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, &__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_entry_point, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1231
 *                 pass
 *             entry_point = self.flow.newblock(parent=self.flow.block)
 *             self.flow.nextblock()             # <<<<<<<<<<<<<<
 *             if clause.target:
 *                 self.mark_assignment(clause.target, clause.exc_value)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1232
 *             entry_point = self.flow.newblock(parent=self.flow.block)
 *             self.flow.nextblock()
 *             if clause.target:             # <<<<<<<<<<<<<<
 *                 self.mark_assignment(clause.target, clause.exc_value)
 *             self._visit(clause.body)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_clause, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1232, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_6) {

      /* "Cython/Compiler/FlowControl.py":1233
 *             self.flow.nextblock()
 *             if clause.target:
 *                 self.mark_assignment(clause.target, clause.exc_value)             # <<<<<<<<<<<<<<
 *             self._visit(clause.body)
 *             if self.flow.block:
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_clause, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_clause, __pyx_mstate_global->__pyx_n_u_exc_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_13.__pyx_n = 1;
      __pyx_t_13.rhs = __pyx_t_2;
      __pyx_t_12 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_1, 0, &__pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "Cython/Compiler/FlowControl.py":1232
 *             entry_point = self.flow.newblock(parent=self.flow.block)
 *             self.flow.nextblock()
 *             if clause.target:             # <<<<<<<<<<<<<<
 *                 self.mark_assignment(clause.target, clause.exc_value)
 *             self._visit(clause.body)
*/
    }

    /* "Cython/Compiler/FlowControl.py":1234
 *             if clause.target:
 *                 self.mark_assignment(clause.target, clause.exc_value)
 *             self._visit(clause.body)             # <<<<<<<<<<<<<<
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)
*/
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_clause, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1234, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1234, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1235
 *                 self.mark_assignment(clause.target, clause.exc_value)
 *             self._visit(clause.body)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 * 
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1235, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/FlowControl.py":1236
 *             self._visit(clause.body)
 *             if self.flow.block:
 *                 self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         if self.flow.exceptions:
*/
      __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1236, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/FlowControl.py":1235
 *                 self.mark_assignment(clause.target, clause.exc_value)
 *             self._visit(clause.body)
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(next_block)
 * 
*/
    }

    /* "Cython/Compiler/FlowControl.py":1222
 *                 self.flow.block.add_child(next_block)
 * 
 *         for clause in node.except_clauses:             # <<<<<<<<<<<<<<
 *             self.flow.block = entry_point
 *             if clause.pattern:
*/
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1238
 *                 self.flow.block.add_child(next_block)
 * 
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             entry_point.add_child(self.flow.exceptions[-1].entry_point)
 * 
*/
  if (__pyx_v_self->flow->exceptions == Py_None) __pyx_t_6 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->exceptions);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1238, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1239
 * 
 *         if self.flow.exceptions:
 *             entry_point.add_child(self.flow.exceptions[-1].entry_point)             # <<<<<<<<<<<<<<
 * 
 *         if next_block.parents:
*/
    __pyx_t_2 = __pyx_v_entry_point;
    __Pyx_INCREF(__pyx_t_2);
    if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1239, __pyx_L1_error)
    }
    __pyx_t_12 = __Pyx_GetItemInt_List(__pyx_v_self->flow->exceptions, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_entry_point); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":1238
 *                 self.flow.block.add_child(next_block)
 * 
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             entry_point.add_child(self.flow.exceptions[-1].entry_point)
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":1241
 *             entry_point.add_child(self.flow.exceptions[-1].entry_point)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/FlowControl.py":1242
 * 
 *         if next_block.parents:
 *             self.flow.block = next_block             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block = None
*/
    __pyx_t_3 = __pyx_v_next_block;
    __Pyx_INCREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1242, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":1241
 *             entry_point.add_child(self.flow.exceptions[-1].entry_point)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
    goto __pyx_L16;
  }

  /* "Cython/Compiler/FlowControl.py":1244
 *             self.flow.block = next_block
 *         else:
 *             self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  }
  __pyx_L16:;

  /* "Cython/Compiler/FlowControl.py":1245
 *         else:
 *             self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_TryFinallyStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1196
 *         return node
 * 
 *     def visit_TryExceptStatNode(self, node):             # <<<<<<<<<<<<<<
 *         # After exception handling
 *         next_block = self.flow.newblock()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_TryExceptStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_next_block);
  __Pyx_XDECREF(__pyx_v_entry_point);
  __Pyx_XDECREF(__pyx_v_clause);
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1247
 *         return node
 * 
 *     def visit_TryFinallyStatNode(self, node):             # <<<<<<<<<<<<<<
 *         body_block = self.flow.nextblock()
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_73visit_TryFinallyStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_73visit_TryFinallyStatNode = {"visit_TryFinallyStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_73visit_TryFinallyStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_73visit_TryFinallyStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_TryFinallyStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_72visit_TryFinallyStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_72visit_TryFinallyStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_body_block = NULL;
  PyObject *__pyx_v_entry_point = NULL;
  PyObject *__pyx_v_finally_enter = NULL;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_finally_exit = NULL;
  PyObject *__pyx_v_descr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_TryFinallyStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1248
 * 
 *     def visit_TryFinallyStatNode(self, node):
 *         body_block = self.flow.nextblock()             # <<<<<<<<<<<<<<
 * 
 *         # Exception entry point
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_body_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1251
 * 
 *         # Exception entry point
 *         entry_point = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         self.flow.block = entry_point
 *         self._visit(node.finally_except_clause)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_entry_point = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1252
 *         # Exception entry point
 *         entry_point = self.flow.newblock()
 *         self.flow.block = entry_point             # <<<<<<<<<<<<<<
 *         self._visit(node.finally_except_clause)
 * 
*/
  __pyx_t_1 = __pyx_v_entry_point;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1252, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
  __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1253
 *         entry_point = self.flow.newblock()
 *         self.flow.block = entry_point
 *         self._visit(node.finally_except_clause)             # <<<<<<<<<<<<<<
 * 
 *         if self.flow.block and self.flow.exceptions:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_finally_except_clause); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1255
 *         self._visit(node.finally_except_clause)
 * 
 *         if self.flow.block and self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 * 
*/
  __pyx_t_4 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1255, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  if (__pyx_v_self->flow->exceptions == Py_None) __pyx_t_4 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->exceptions);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1255, __pyx_L1_error)
    __pyx_t_4 = (__pyx_temp != 0);
  }

  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1256
 * 
 *         if self.flow.block and self.flow.exceptions:
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)             # <<<<<<<<<<<<<<
 * 
 *         # Normal execution
*/
    if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1256, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->flow->exceptions, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_entry_point); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1255
 *         self._visit(node.finally_except_clause)
 * 
 *         if self.flow.block and self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":1259
 * 
 *         # Normal execution
 *         finally_enter = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         self.flow.block = finally_enter
 *         self._visit(node.finally_clause)
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_finally_enter = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1260
 *         # Normal execution
 *         finally_enter = self.flow.newblock()
 *         self.flow.block = finally_enter             # <<<<<<<<<<<<<<
 *         self._visit(node.finally_clause)
 *         finally_exit = self.flow.block
*/
  __pyx_t_2 = __pyx_v_finally_enter;
  __Pyx_INCREF(__pyx_t_2);
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
  __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1261
 *         finally_enter = self.flow.newblock()
 *         self.flow.block = finally_enter
 *         self._visit(node.finally_clause)             # <<<<<<<<<<<<<<
 *         finally_exit = self.flow.block
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_finally_clause); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1262
 *         self.flow.block = finally_enter
 *         self._visit(node.finally_clause)
 *         finally_exit = self.flow.block             # <<<<<<<<<<<<<<
 * 
 *         descr = ExceptionDescr(entry_point, finally_enter, finally_exit)
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->flow->block);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_finally_exit = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1264
 *         finally_exit = self.flow.block
 * 
 *         descr = ExceptionDescr(entry_point, finally_enter, finally_exit)             # <<<<<<<<<<<<<<
 *         self.flow.exceptions.append(descr)
 *         if self.flow.loops:
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_ExceptionDescr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_entry_point, __pyx_v_finally_enter, ((PyObject *)__pyx_v_finally_exit)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_descr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1265
 * 
 *         descr = ExceptionDescr(entry_point, finally_enter, finally_exit)
 *         self.flow.exceptions.append(descr)             # <<<<<<<<<<<<<<
 *         if self.flow.loops:
 *             self.flow.loops[-1].exceptions.append(descr)
*/
  if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 1265, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->flow->exceptions, __pyx_v_descr); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1265, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":1266
 *         descr = ExceptionDescr(entry_point, finally_enter, finally_exit)
 *         self.flow.exceptions.append(descr)
 *         if self.flow.loops:             # <<<<<<<<<<<<<<
 *             self.flow.loops[-1].exceptions.append(descr)
 *         self.flow.block = body_block
*/
  if (__pyx_v_self->flow->loops == Py_None) __pyx_t_3 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->loops);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1266, __pyx_L1_error)
    __pyx_t_3 = (__pyx_temp != 0);
  }

  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1267
 *         self.flow.exceptions.append(descr)
 *         if self.flow.loops:
 *             self.flow.loops[-1].exceptions.append(descr)             # <<<<<<<<<<<<<<
 *         self.flow.block = body_block
 *         body_block.add_child(entry_point)
*/
    if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1267, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->flow->loops, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exceptions); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_v_descr); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1267, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":1266
 *         descr = ExceptionDescr(entry_point, finally_enter, finally_exit)
 *         self.flow.exceptions.append(descr)
 *         if self.flow.loops:             # <<<<<<<<<<<<<<
 *             self.flow.loops[-1].exceptions.append(descr)
 *         self.flow.block = body_block
*/
  }

  /* "Cython/Compiler/FlowControl.py":1268
 *         if self.flow.loops:
 *             self.flow.loops[-1].exceptions.append(descr)
 *         self.flow.block = body_block             # <<<<<<<<<<<<<<
 *         body_block.add_child(entry_point)
 *         self.flow.nextblock()
*/
  __pyx_t_5 = __pyx_v_body_block;
  __Pyx_INCREF(__pyx_t_5);
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1268, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
  __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "Cython/Compiler/FlowControl.py":1269
 *             self.flow.loops[-1].exceptions.append(descr)
 *         self.flow.block = body_block
 *         body_block.add_child(entry_point)             # <<<<<<<<<<<<<<
 *         self.flow.nextblock()
 *         self.flow.in_try_block += 1
*/
  __pyx_t_1 = __pyx_v_body_block;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_entry_point};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/FlowControl.py":1270
 *         self.flow.block = body_block
 *         body_block.add_child(entry_point)
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self.flow.in_try_block += 1
 *         self._visit(node.body)
*/
  __pyx_t_5 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/FlowControl.py":1271
 *         body_block.add_child(entry_point)
 *         self.flow.nextblock()
 *         self.flow.in_try_block += 1             # <<<<<<<<<<<<<<
 *         self._visit(node.body)
 *         self.flow.in_try_block -= 1
*/
  __pyx_v_self->flow->in_try_block = (__pyx_v_self->flow->in_try_block + 1);

  /* "Cython/Compiler/FlowControl.py":1272
 *         self.flow.nextblock()
 *         self.flow.in_try_block += 1
 *         self._visit(node.body)             # <<<<<<<<<<<<<<
 *         self.flow.in_try_block -= 1
 *         self.flow.exceptions.pop()
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1273
 *         self.flow.in_try_block += 1
 *         self._visit(node.body)
 *         self.flow.in_try_block -= 1             # <<<<<<<<<<<<<<
 *         self.flow.exceptions.pop()
 *         if self.flow.loops:
*/
  __pyx_v_self->flow->in_try_block = (__pyx_v_self->flow->in_try_block - 1);

  /* "Cython/Compiler/FlowControl.py":1274
 *         self._visit(node.body)
 *         self.flow.in_try_block -= 1
 *         self.flow.exceptions.pop()             # <<<<<<<<<<<<<<
 *         if self.flow.loops:
 *             self.flow.loops[-1].exceptions.pop()
*/
  if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 1274, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->flow->exceptions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1275
 *         self.flow.in_try_block -= 1
 *         self.flow.exceptions.pop()
 *         if self.flow.loops:             # <<<<<<<<<<<<<<
 *             self.flow.loops[-1].exceptions.pop()
 * 
*/
  if (__pyx_v_self->flow->loops == Py_None) __pyx_t_3 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->loops);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1275, __pyx_L1_error)
    __pyx_t_3 = (__pyx_temp != 0);
  }

  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1276
 *         self.flow.exceptions.pop()
 *         if self.flow.loops:
 *             self.flow.loops[-1].exceptions.pop()             # <<<<<<<<<<<<<<
 * 
 *         if self.flow.block:
*/
    if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1276, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->flow->loops, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exceptions); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Pop(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1275
 *         self.flow.in_try_block -= 1
 *         self.flow.exceptions.pop()
 *         if self.flow.loops:             # <<<<<<<<<<<<<<
 *             self.flow.loops[-1].exceptions.pop()
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":1278
 *             self.flow.loops[-1].exceptions.pop()
 * 
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(finally_enter)
 *             if finally_exit:
*/
  __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1278, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1279
 * 
 *         if self.flow.block:
 *             self.flow.block.add_child(finally_enter)             # <<<<<<<<<<<<<<
 *             if finally_exit:
 *                 self.flow.block = self.flow.nextblock(parent=finally_exit)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_finally_enter, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1280
 *         if self.flow.block:
 *             self.flow.block.add_child(finally_enter)
 *             if finally_exit:             # <<<<<<<<<<<<<<
 *                 self.flow.block = self.flow.nextblock(parent=finally_exit)
 *             else:
*/
    __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_finally_exit)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1280, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/FlowControl.py":1281
 *             self.flow.block.add_child(finally_enter)
 *             if finally_exit:
 *                 self.flow.block = self.flow.nextblock(parent=finally_exit)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.flow.block = None
*/
      __pyx_t_8.__pyx_n = 1;
      __pyx_t_8.parent = __pyx_v_finally_exit;
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, &__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1281, __pyx_L1_error)
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
      __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
      __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/FlowControl.py":1280
 *         if self.flow.block:
 *             self.flow.block.add_child(finally_enter)
 *             if finally_exit:             # <<<<<<<<<<<<<<
 *                 self.flow.block = self.flow.nextblock(parent=finally_exit)
 *             else:
*/
      goto __pyx_L9;
    }

    /* "Cython/Compiler/FlowControl.py":1283
 *                 self.flow.block = self.flow.nextblock(parent=finally_exit)
 *             else:
 *                 self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    /*else*/ {
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
      __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
      __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
    }
    __pyx_L9:;

    /* "Cython/Compiler/FlowControl.py":1278
 *             self.flow.loops[-1].exceptions.pop()
 * 
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(finally_enter)
 *             if finally_exit:
*/
  }

  /* "Cython/Compiler/FlowControl.py":1284
 *             else:
 *                 self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_RaiseStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1247
 *         return node
 * 
 *     def visit_TryFinallyStatNode(self, node):             # <<<<<<<<<<<<<<
 *         body_block = self.flow.nextblock()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_TryFinallyStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_body_block);
  __Pyx_XDECREF(__pyx_v_entry_point);
  __Pyx_XDECREF(__pyx_v_finally_enter);
  __Pyx_XDECREF((PyObject *)__pyx_v_finally_exit);
  __Pyx_XDECREF(__pyx_v_descr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1286
 *         return node
 * 
 *     def visit_RaiseStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         self.visitchildren(node)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_75visit_RaiseStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_75visit_RaiseStatNode = {"visit_RaiseStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_75visit_RaiseStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_75visit_RaiseStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_RaiseStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_74visit_RaiseStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_74visit_RaiseStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_RaiseStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1287
 * 
 *     def visit_RaiseStatNode(self, node):
 *         self.mark_position(node)             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         if self.flow.exceptions:
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1288
 *     def visit_RaiseStatNode(self, node):
 *         self.mark_position(node)
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         if self.flow.exceptions:
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1289
 *         self.mark_position(node)
 *         self.visitchildren(node)
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None
*/
  if (__pyx_v_self->flow->exceptions == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->exceptions);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1289, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":1290
 *         self.visitchildren(node)
 *         if self.flow.exceptions:
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)             # <<<<<<<<<<<<<<
 *         self.flow.block = None
 *         if self.flow.in_try_block:
*/
    if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1290, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->flow->exceptions, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_entry_point); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_3, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1289
 *         self.mark_position(node)
 *         self.visitchildren(node)
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None
*/
  }

  /* "Cython/Compiler/FlowControl.py":1291
 *         if self.flow.exceptions:
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None             # <<<<<<<<<<<<<<
 *         if self.flow.in_try_block:
 *             node.in_try_block = True
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
  __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);

  /* "Cython/Compiler/FlowControl.py":1292
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None
 *         if self.flow.in_try_block:             # <<<<<<<<<<<<<<
 *             node.in_try_block = True
 *         return node
*/
  __pyx_t_2 = (__pyx_v_self->flow->in_try_block != 0);
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":1293
 *         self.flow.block = None
 *         if self.flow.in_try_block:
 *             node.in_try_block = True             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_in_try_block, Py_True) < (0)) __PYX_ERR(0, 1293, __pyx_L1_error)

    /* "Cython/Compiler/FlowControl.py":1292
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None
 *         if self.flow.in_try_block:             # <<<<<<<<<<<<<<
 *             node.in_try_block = True
 *         return node
*/
  }

  /* "Cython/Compiler/FlowControl.py":1294
 *         if self.flow.in_try_block:
 *             node.in_try_block = True
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ReraiseStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1286
 *         return node
 * 
 *     def visit_RaiseStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         self.visitchildren(node)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_RaiseStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1296
 *         return node
 * 
 *     def visit_ReraiseStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         if self.flow.exceptions:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_77visit_ReraiseStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_77visit_ReraiseStatNode = {"visit_ReraiseStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_77visit_ReraiseStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_77visit_ReraiseStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ReraiseStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_76visit_ReraiseStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_76visit_ReraiseStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ReraiseStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1297
 * 
 *     def visit_ReraiseStatNode(self, node):
 *         self.mark_position(node)             # <<<<<<<<<<<<<<
 *         if self.flow.exceptions:
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1298
 *     def visit_ReraiseStatNode(self, node):
 *         self.mark_position(node)
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None
*/
  if (__pyx_v_self->flow->exceptions == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->exceptions);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1298, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":1299
 *         self.mark_position(node)
 *         if self.flow.exceptions:
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)             # <<<<<<<<<<<<<<
 *         self.flow.block = None
 *         return node
*/
    if (unlikely(__pyx_v_self->flow->exceptions == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1299, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->flow->exceptions, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_entry_point); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_3, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1298
 *     def visit_ReraiseStatNode(self, node):
 *         self.mark_position(node)
 *         if self.flow.exceptions:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None
*/
  }

  /* "Cython/Compiler/FlowControl.py":1300
 *         if self.flow.exceptions:
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
  __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);

  /* "Cython/Compiler/FlowControl.py":1301
 *             self.flow.block.add_child(self.flow.exceptions[-1].entry_point)
 *         self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ReturnStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1296
 *         return node
 * 
 *     def visit_ReraiseStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         if self.flow.exceptions:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ReraiseStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1303
 *         return node
 * 
 *     def visit_ReturnStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         self.visitchildren(node)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_79visit_ReturnStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_79visit_ReturnStatNode = {"visit_ReturnStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_79visit_ReturnStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_79visit_ReturnStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ReturnStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_78visit_ReturnStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_78visit_ReturnStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_outer_exception_handlers = NULL;
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_v_exit_point = NULL;
  PyObject *__pyx_v_next_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ReturnStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1304
 * 
 *     def visit_ReturnStatNode(self, node):
 *         self.mark_position(node)             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1305
 *     def visit_ReturnStatNode(self, node):
 *         self.mark_position(node)
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 * 
 *         outer_exception_handlers = iter(self.flow.exceptions[::-1])
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1307
 *         self.visitchildren(node)
 * 
 *         outer_exception_handlers = iter(self.flow.exceptions[::-1])             # <<<<<<<<<<<<<<
 *         for handler in outer_exception_handlers:
 *             if handler.finally_enter:
*/
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_self->flow->exceptions, __pyx_mstate_global->__pyx_slice[1]); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_outer_exception_handlers = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1308
 * 
 *         outer_exception_handlers = iter(self.flow.exceptions[::-1])
 *         for handler in outer_exception_handlers:             # <<<<<<<<<<<<<<
 *             if handler.finally_enter:
 *                 self.flow.block.add_child(handler.finally_enter)
*/
  if (likely(PyList_CheckExact(__pyx_v_outer_exception_handlers)) || PyTuple_CheckExact(__pyx_v_outer_exception_handlers)) {
    __pyx_t_2 = __pyx_v_outer_exception_handlers; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_outer_exception_handlers); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1308, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1308, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1308, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1308, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1308, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_handler, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1309
 *         outer_exception_handlers = iter(self.flow.exceptions[::-1])
 *         for handler in outer_exception_handlers:
 *             if handler.finally_enter:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(handler.finally_enter)
 *                 if handler.finally_exit:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_handler, __pyx_mstate_global->__pyx_n_u_finally_enter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1309, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "Cython/Compiler/FlowControl.py":1310
 *         for handler in outer_exception_handlers:
 *             if handler.finally_enter:
 *                 self.flow.block.add_child(handler.finally_enter)             # <<<<<<<<<<<<<<
 *                 if handler.finally_exit:
 *                     # 'return' goes to function exit, or to the next outer 'finally' clause
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_handler, __pyx_mstate_global->__pyx_n_u_finally_enter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/FlowControl.py":1311
 *             if handler.finally_enter:
 *                 self.flow.block.add_child(handler.finally_enter)
 *                 if handler.finally_exit:             # <<<<<<<<<<<<<<
 *                     # 'return' goes to function exit, or to the next outer 'finally' clause
 *                     exit_point = self.flow.exit_point
*/
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_handler, __pyx_mstate_global->__pyx_n_u_finally_exit); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_5) {

        /* "Cython/Compiler/FlowControl.py":1313
 *                 if handler.finally_exit:
 *                     # 'return' goes to function exit, or to the next outer 'finally' clause
 *                     exit_point = self.flow.exit_point             # <<<<<<<<<<<<<<
 *                     for next_handler in outer_exception_handlers:
 *                         if next_handler.finally_enter:
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_self->flow->exit_point);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_exit_point = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "Cython/Compiler/FlowControl.py":1314
 *                     # 'return' goes to function exit, or to the next outer 'finally' clause
 *                     exit_point = self.flow.exit_point
 *                     for next_handler in outer_exception_handlers:             # <<<<<<<<<<<<<<
 *                         if next_handler.finally_enter:
 *                             exit_point = next_handler.finally_enter
*/
        if (likely(PyList_CheckExact(__pyx_v_outer_exception_handlers)) || PyTuple_CheckExact(__pyx_v_outer_exception_handlers)) {
          __pyx_t_6 = __pyx_v_outer_exception_handlers; __Pyx_INCREF(__pyx_t_6);
          __pyx_t_7 = 0;
          __pyx_t_8 = NULL;
        } else {
          __pyx_t_7 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_v_outer_exception_handlers); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1314, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_8)) {
            if (likely(PyList_CheckExact(__pyx_t_6))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1314, __pyx_L1_error)
                #endif
                if (__pyx_t_7 >= __pyx_temp) break;
              }
              __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_6, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
              ++__pyx_t_7;
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1314, __pyx_L1_error)
                #endif
                if (__pyx_t_7 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_7));
              #else
              __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_7);
              #endif
              ++__pyx_t_7;
            }
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1314, __pyx_L1_error)
          } else {
            __pyx_t_1 = __pyx_t_8(__pyx_t_6);
            if (unlikely(!__pyx_t_1)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1314, __pyx_L1_error)
                PyErr_Clear();
              }
              break;
            }
          }
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_next_handler, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "Cython/Compiler/FlowControl.py":1315
 *                     exit_point = self.flow.exit_point
 *                     for next_handler in outer_exception_handlers:
 *                         if next_handler.finally_enter:             # <<<<<<<<<<<<<<
 *                             exit_point = next_handler.finally_enter
 *                             break
*/
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_handler, __pyx_mstate_global->__pyx_n_u_finally_enter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1315, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_5) {

            /* "Cython/Compiler/FlowControl.py":1316
 *                     for next_handler in outer_exception_handlers:
 *                         if next_handler.finally_enter:
 *                             exit_point = next_handler.finally_enter             # <<<<<<<<<<<<<<
 *                             break
 *                     handler.finally_exit.add_child(exit_point)
*/
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_handler, __pyx_mstate_global->__pyx_n_u_finally_enter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1316, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF_SET(__pyx_v_exit_point, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "Cython/Compiler/FlowControl.py":1317
 *                         if next_handler.finally_enter:
 *                             exit_point = next_handler.finally_enter
 *                             break             # <<<<<<<<<<<<<<
 *                     handler.finally_exit.add_child(exit_point)
 *                 break
*/
            goto __pyx_L8_break;

            /* "Cython/Compiler/FlowControl.py":1315
 *                     exit_point = self.flow.exit_point
 *                     for next_handler in outer_exception_handlers:
 *                         if next_handler.finally_enter:             # <<<<<<<<<<<<<<
 *                             exit_point = next_handler.finally_enter
 *                             break
*/
          }

          /* "Cython/Compiler/FlowControl.py":1314
 *                     # 'return' goes to function exit, or to the next outer 'finally' clause
 *                     exit_point = self.flow.exit_point
 *                     for next_handler in outer_exception_handlers:             # <<<<<<<<<<<<<<
 *                         if next_handler.finally_enter:
 *                             exit_point = next_handler.finally_enter
*/
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L10_for_end;
        __pyx_L8_break:;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L10_for_end;
        __pyx_L10_for_end:;

        /* "Cython/Compiler/FlowControl.py":1318
 *                             exit_point = next_handler.finally_enter
 *                             break
 *                     handler.finally_exit.add_child(exit_point)             # <<<<<<<<<<<<<<
 *                 break
 *         else:
*/
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_handler, __pyx_mstate_global->__pyx_n_u_finally_exit); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1318, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_1 = __pyx_t_9;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_exit_point};
          __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "Cython/Compiler/FlowControl.py":1311
 *             if handler.finally_enter:
 *                 self.flow.block.add_child(handler.finally_enter)
 *                 if handler.finally_exit:             # <<<<<<<<<<<<<<
 *                     # 'return' goes to function exit, or to the next outer 'finally' clause
 *                     exit_point = self.flow.exit_point
*/
      }

      /* "Cython/Compiler/FlowControl.py":1319
 *                             break
 *                     handler.finally_exit.add_child(exit_point)
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             if self.flow.block:
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/FlowControl.py":1309
 *         outer_exception_handlers = iter(self.flow.exceptions[::-1])
 *         for handler in outer_exception_handlers:
 *             if handler.finally_enter:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(handler.finally_enter)
 *                 if handler.finally_exit:
*/
    }

    /* "Cython/Compiler/FlowControl.py":1308
 * 
 *         outer_exception_handlers = iter(self.flow.exceptions[::-1])
 *         for handler in outer_exception_handlers:             # <<<<<<<<<<<<<<
 *             if handler.finally_enter:
 *                 self.flow.block.add_child(handler.finally_enter)
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L11_for_else;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L12_for_end;
  /*else*/ {
    __pyx_L11_for_else:;

    /* "Cython/Compiler/FlowControl.py":1321
 *                 break
 *         else:
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(self.flow.exit_point)
 *         self.flow.block = None
*/
    __pyx_t_5 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1321, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "Cython/Compiler/FlowControl.py":1322
 *         else:
 *             if self.flow.block:
 *                 self.flow.block.add_child(self.flow.exit_point)             # <<<<<<<<<<<<<<
 *         self.flow.block = None
 *         return node
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_self->flow->exit_point);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_2, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1322, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/FlowControl.py":1321
 *                 break
 *         else:
 *             if self.flow.block:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(self.flow.exit_point)
 *         self.flow.block = None
*/
    }
  }
  __pyx_L12_for_end:;

  /* "Cython/Compiler/FlowControl.py":1323
 *             if self.flow.block:
 *                 self.flow.block.add_child(self.flow.exit_point)
 *         self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
  __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);

  /* "Cython/Compiler/FlowControl.py":1324
 *                 self.flow.block.add_child(self.flow.exit_point)
 *         self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_BreakStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1303
 *         return node
 * 
 *     def visit_ReturnStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         self.visitchildren(node)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ReturnStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_outer_exception_handlers);
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XDECREF(__pyx_v_exit_point);
  __Pyx_XDECREF(__pyx_v_next_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1326
 *         return node
 * 
 *     def visit_BreakStatNode(self, node):             # <<<<<<<<<<<<<<
 *         if not self.flow.loops:
 *             #error(node.pos, "break statement not inside loop")
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_81visit_BreakStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_81visit_BreakStatNode = {"visit_BreakStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_81visit_BreakStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_81visit_BreakStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_BreakStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_80visit_BreakStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_80visit_BreakStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_loop = NULL;
  PyObject *__pyx_v_exception = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_BreakStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1327
 * 
 *     def visit_BreakStatNode(self, node):
 *         if not self.flow.loops:             # <<<<<<<<<<<<<<
 *             #error(node.pos, "break statement not inside loop")
 *             return node
*/
  if (__pyx_v_self->flow->loops == Py_None) __pyx_t_1 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->loops);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1327, __pyx_L1_error)
    __pyx_t_1 = (__pyx_temp != 0);
  }

  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":1329
 *         if not self.flow.loops:
 *             #error(node.pos, "break statement not inside loop")
 *             return node             # <<<<<<<<<<<<<<
 *         loop = self.flow.loops[-1]
 *         self.mark_position(node)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":1327
 * 
 *     def visit_BreakStatNode(self, node):
 *         if not self.flow.loops:             # <<<<<<<<<<<<<<
 *             #error(node.pos, "break statement not inside loop")
 *             return node
*/
  }

  /* "Cython/Compiler/FlowControl.py":1330
 *             #error(node.pos, "break statement not inside loop")
 *             return node
 *         loop = self.flow.loops[-1]             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:
*/
  if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1330, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->flow->loops, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_loop = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1331
 *             return node
 *         loop = self.flow.loops[-1]
 *         self.mark_position(node)             # <<<<<<<<<<<<<<
 *         for exception in loop.exceptions[::-1]:
 *             if exception.finally_enter:
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1332
 *         loop = self.flow.loops[-1]
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:             # <<<<<<<<<<<<<<
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_loop, __pyx_mstate_global->__pyx_n_u_exceptions); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_mstate_global->__pyx_slice[1]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1332, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1332, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1332, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_5;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1332, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5);
        #endif
        ++__pyx_t_5;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1332, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_3);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1332, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_exception, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":1333
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:
 *             if exception.finally_enter:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_mstate_global->__pyx_n_u_finally_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1333, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/FlowControl.py":1334
 *         for exception in loop.exceptions[::-1]:
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)             # <<<<<<<<<<<<<<
 *                 if exception.finally_exit:
 *                     exception.finally_exit.add_child(loop.next_block)
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_mstate_global->__pyx_n_u_finally_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_4, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/FlowControl.py":1335
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:             # <<<<<<<<<<<<<<
 *                     exception.finally_exit.add_child(loop.next_block)
 *                 break
*/
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_mstate_global->__pyx_n_u_finally_exit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1335, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1335, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_2) {

        /* "Cython/Compiler/FlowControl.py":1336
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:
 *                     exception.finally_exit.add_child(loop.next_block)             # <<<<<<<<<<<<<<
 *                 break
 *         else:
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_mstate_global->__pyx_n_u_finally_exit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = __pyx_t_8;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_loop, __pyx_mstate_global->__pyx_n_u_next_block); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_9};
          __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1336, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/FlowControl.py":1335
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:             # <<<<<<<<<<<<<<
 *                     exception.finally_exit.add_child(loop.next_block)
 *                 break
*/
      }

      /* "Cython/Compiler/FlowControl.py":1337
 *                 if exception.finally_exit:
 *                     exception.finally_exit.add_child(loop.next_block)
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block.add_child(loop.next_block)
*/
      goto __pyx_L5_break;

      /* "Cython/Compiler/FlowControl.py":1333
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:
 *             if exception.finally_enter:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:
*/
    }

    /* "Cython/Compiler/FlowControl.py":1332
 *         loop = self.flow.loops[-1]
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:             # <<<<<<<<<<<<<<
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)
*/
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L8_for_else;
  __pyx_L5_break:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L9_for_end;
  /*else*/ {
    __pyx_L8_for_else:;

    /* "Cython/Compiler/FlowControl.py":1339
 *                 break
 *         else:
 *             self.flow.block.add_child(loop.next_block)             # <<<<<<<<<<<<<<
 *         self.flow.block = None
 *         return node
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_loop, __pyx_mstate_global->__pyx_n_u_next_block); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_3, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L9_for_end:;

  /* "Cython/Compiler/FlowControl.py":1340
 *         else:
 *             self.flow.block.add_child(loop.next_block)
 *         self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
  __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);

  /* "Cython/Compiler/FlowControl.py":1341
 *             self.flow.block.add_child(loop.next_block)
 *         self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ContinueStatNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1326
 *         return node
 * 
 *     def visit_BreakStatNode(self, node):             # <<<<<<<<<<<<<<
 *         if not self.flow.loops:
 *             #error(node.pos, "break statement not inside loop")
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_BreakStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_exception);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1343
 *         return node
 * 
 *     def visit_ContinueStatNode(self, node):             # <<<<<<<<<<<<<<
 *         if not self.flow.loops:
 *             #error(node.pos, "continue statement not inside loop")
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_83visit_ContinueStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_83visit_ContinueStatNode = {"visit_ContinueStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_83visit_ContinueStatNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_83visit_ContinueStatNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ContinueStatNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_82visit_ContinueStatNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_82visit_ContinueStatNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_loop = NULL;
  PyObject *__pyx_v_exception = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ContinueStatNode", 0);

  /* "Cython/Compiler/FlowControl.py":1344
 * 
 *     def visit_ContinueStatNode(self, node):
 *         if not self.flow.loops:             # <<<<<<<<<<<<<<
 *             #error(node.pos, "continue statement not inside loop")
 *             return node
*/
  if (__pyx_v_self->flow->loops == Py_None) __pyx_t_1 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->flow->loops);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1344, __pyx_L1_error)
    __pyx_t_1 = (__pyx_temp != 0);
  }

  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":1346
 *         if not self.flow.loops:
 *             #error(node.pos, "continue statement not inside loop")
 *             return node             # <<<<<<<<<<<<<<
 *         loop = self.flow.loops[-1]
 *         self.mark_position(node)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;

    /* "Cython/Compiler/FlowControl.py":1344
 * 
 *     def visit_ContinueStatNode(self, node):
 *         if not self.flow.loops:             # <<<<<<<<<<<<<<
 *             #error(node.pos, "continue statement not inside loop")
 *             return node
*/
  }

  /* "Cython/Compiler/FlowControl.py":1347
 *             #error(node.pos, "continue statement not inside loop")
 *             return node
 *         loop = self.flow.loops[-1]             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:
*/
  if (unlikely(__pyx_v_self->flow->loops == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1347, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->flow->loops, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_loop = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1348
 *             return node
 *         loop = self.flow.loops[-1]
 *         self.mark_position(node)             # <<<<<<<<<<<<<<
 *         for exception in loop.exceptions[::-1]:
 *             if exception.finally_enter:
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position(__pyx_v_self, __pyx_v_node, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1349
 *         loop = self.flow.loops[-1]
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:             # <<<<<<<<<<<<<<
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_loop, __pyx_mstate_global->__pyx_n_u_exceptions); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_mstate_global->__pyx_slice[1]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1349, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1349, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1349, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_5;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1349, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5);
        #endif
        ++__pyx_t_5;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1349, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_3);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1349, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_exception, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":1350
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:
 *             if exception.finally_enter:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_mstate_global->__pyx_n_u_finally_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1350, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/FlowControl.py":1351
 *         for exception in loop.exceptions[::-1]:
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)             # <<<<<<<<<<<<<<
 *                 if exception.finally_exit:
 *                     exception.finally_exit.add_child(loop.loop_block)
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_mstate_global->__pyx_n_u_finally_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1351, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_4, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1351, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/FlowControl.py":1352
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:             # <<<<<<<<<<<<<<
 *                     exception.finally_exit.add_child(loop.loop_block)
 *                 break
*/
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_mstate_global->__pyx_n_u_finally_exit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1352, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_2) {

        /* "Cython/Compiler/FlowControl.py":1353
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:
 *                     exception.finally_exit.add_child(loop.loop_block)             # <<<<<<<<<<<<<<
 *                 break
 *         else:
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_mstate_global->__pyx_n_u_finally_exit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1353, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = __pyx_t_8;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_loop, __pyx_mstate_global->__pyx_n_u_loop_block); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1353, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_9};
          __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_child, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1353, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/FlowControl.py":1352
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:             # <<<<<<<<<<<<<<
 *                     exception.finally_exit.add_child(loop.loop_block)
 *                 break
*/
      }

      /* "Cython/Compiler/FlowControl.py":1354
 *                 if exception.finally_exit:
 *                     exception.finally_exit.add_child(loop.loop_block)
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block.add_child(loop.loop_block)
*/
      goto __pyx_L5_break;

      /* "Cython/Compiler/FlowControl.py":1350
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:
 *             if exception.finally_enter:             # <<<<<<<<<<<<<<
 *                 self.flow.block.add_child(exception.finally_enter)
 *                 if exception.finally_exit:
*/
    }

    /* "Cython/Compiler/FlowControl.py":1349
 *         loop = self.flow.loops[-1]
 *         self.mark_position(node)
 *         for exception in loop.exceptions[::-1]:             # <<<<<<<<<<<<<<
 *             if exception.finally_enter:
 *                 self.flow.block.add_child(exception.finally_enter)
*/
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L8_for_else;
  __pyx_L5_break:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L9_for_end;
  /*else*/ {
    __pyx_L8_for_else:;

    /* "Cython/Compiler/FlowControl.py":1356
 *                 break
 *         else:
 *             self.flow.block.add_child(loop.loop_block)             # <<<<<<<<<<<<<<
 *         self.flow.block = None
 *         return node
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_loop, __pyx_mstate_global->__pyx_n_u_loop_block); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_t_3, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L9_for_end:;

  /* "Cython/Compiler/FlowControl.py":1357
 *         else:
 *             self.flow.block.add_child(loop.loop_block)
 *         self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
  __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
  __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);

  /* "Cython/Compiler/FlowControl.py":1358
 *             self.flow.block.add_child(loop.loop_block)
 *         self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ComprehensionNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1343
 *         return node
 * 
 *     def visit_ContinueStatNode(self, node):             # <<<<<<<<<<<<<<
 *         if not self.flow.loops:
 *             #error(node.pos, "continue statement not inside loop")
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ContinueStatNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_exception);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1360
 *         return node
 * 
 *     def visit_ComprehensionNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.stack.append((self.env, self.flow))
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_85visit_ComprehensionNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_85visit_ComprehensionNode = {"visit_ComprehensionNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_85visit_ComprehensionNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_85visit_ComprehensionNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ComprehensionNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_84visit_ComprehensionNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_84visit_ComprehensionNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ComprehensionNode", 0);

  /* "Cython/Compiler/FlowControl.py":1361
 * 
 *     def visit_ComprehensionNode(self, node):
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.stack.append((self.env, self.flow))
 *             self.env = node.expr_scope
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1361, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":1362
 *     def visit_ComprehensionNode(self, node):
 *         if node.expr_scope:
 *             self.stack.append((self.env, self.flow))             # <<<<<<<<<<<<<<
 *             self.env = node.expr_scope
 *         # Skip append node here
*/
    if (unlikely(__pyx_v_self->stack == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 1362, __pyx_L1_error)
    }
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_self->env);
    __Pyx_GIVEREF(__pyx_v_self->env);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->env) != (0)) __PYX_ERR(0, 1362, __pyx_L1_error);
    __Pyx_INCREF((PyObject *)__pyx_v_self->flow);
    __Pyx_GIVEREF((PyObject *)__pyx_v_self->flow);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self->flow)) != (0)) __PYX_ERR(0, 1362, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyList_Append(__pyx_v_self->stack, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1362, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1363
 *         if node.expr_scope:
 *             self.stack.append((self.env, self.flow))
 *             self.env = node.expr_scope             # <<<<<<<<<<<<<<
 *         # Skip append node here
 *         self._visit(node.loop)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->env);
    __Pyx_DECREF(__pyx_v_self->env);
    __pyx_v_self->env = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1361
 * 
 *     def visit_ComprehensionNode(self, node):
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.stack.append((self.env, self.flow))
 *             self.env = node.expr_scope
*/
  }

  /* "Cython/Compiler/FlowControl.py":1365
 *             self.env = node.expr_scope
 *         # Skip append node here
 *         self._visit(node.loop)             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.env, _ = self.stack.pop()
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1366
 *         # Skip append node here
 *         self._visit(node.loop)
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.env, _ = self.stack.pop()
 *         return node
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/FlowControl.py":1367
 *         self._visit(node.loop)
 *         if node.expr_scope:
 *             self.env, _ = self.stack.pop()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    if (unlikely(__pyx_v_self->stack == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 1367, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyList_Pop(__pyx_v_self->stack); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1367, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_5);
      } else {
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1367, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1367, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
      }
      #else
      __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
      index = 0; __pyx_t_1 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < (0)) __PYX_ERR(0, 1367, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1367, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->env);
    __Pyx_DECREF(__pyx_v_self->env);
    __pyx_v_self->env = __pyx_t_1;
    __pyx_t_1 = 0;
    __pyx_v__ = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "Cython/Compiler/FlowControl.py":1366
 *         # Skip append node here
 *         self._visit(node.loop)
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.env, _ = self.stack.pop()
 *         return node
*/
  }

  /* "Cython/Compiler/FlowControl.py":1368
 *         if node.expr_scope:
 *             self.env, _ = self.stack.pop()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ScopedExprNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1360
 *         return node
 * 
 *     def visit_ComprehensionNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.stack.append((self.env, self.flow))
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ComprehensionNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1370
 *         return node
 * 
 *     def visit_ScopedExprNode(self, node):             # <<<<<<<<<<<<<<
 *         # currently this is written to deal with these two types
 *         # (with comprehensions covered in their own function)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_87visit_ScopedExprNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_87visit_ScopedExprNode = {"visit_ScopedExprNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_87visit_ScopedExprNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_87visit_ScopedExprNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ScopedExprNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_86visit_ScopedExprNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_86visit_ScopedExprNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ScopedExprNode", 0);

  /* "Cython/Compiler/FlowControl.py":1373
 *         # currently this is written to deal with these two types
 *         # (with comprehensions covered in their own function)
 *         assert isinstance(node, (ExprNodes.IteratorNode, ExprNodes.AsyncIteratorNode)), node             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.stack.append((self.env, self.flow))
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes, __pyx_mstate_global->__pyx_n_u_IteratorNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1373, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes, __pyx_mstate_global->__pyx_n_u_AsyncIteratorNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1373, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyObject_IsInstance(__pyx_v_node, __pyx_t_1); 
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L3_bool_binop_done;
    }
    __pyx_t_4 = PyObject_IsInstance(__pyx_v_node, __pyx_t_2); 
    __pyx_t_3 = __pyx_t_4;
    __pyx_L3_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) {
      __pyx_t_1 = PyTuple_Pack(1, __pyx_v_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), __pyx_t_1, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 1373, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 1373, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/FlowControl.py":1374
 *         # (with comprehensions covered in their own function)
 *         assert isinstance(node, (ExprNodes.IteratorNode, ExprNodes.AsyncIteratorNode)), node
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.stack.append((self.env, self.flow))
 *             self.flow = self.find_in_stack(node.expr_scope)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1375
 *         assert isinstance(node, (ExprNodes.IteratorNode, ExprNodes.AsyncIteratorNode)), node
 *         if node.expr_scope:
 *             self.stack.append((self.env, self.flow))             # <<<<<<<<<<<<<<
 *             self.flow = self.find_in_stack(node.expr_scope)
 *             self.env = node.expr_scope
*/
    if (unlikely(__pyx_v_self->stack == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 1375, __pyx_L1_error)
    }
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_self->env);
    __Pyx_GIVEREF(__pyx_v_self->env);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->env) != (0)) __PYX_ERR(0, 1375, __pyx_L1_error);
    __Pyx_INCREF((PyObject *)__pyx_v_self->flow);
    __Pyx_GIVEREF((PyObject *)__pyx_v_self->flow);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self->flow)) != (0)) __PYX_ERR(0, 1375, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->stack, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1375, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1376
 *         if node.expr_scope:
 *             self.stack.append((self.env, self.flow))
 *             self.flow = self.find_in_stack(node.expr_scope)             # <<<<<<<<<<<<<<
 *             self.env = node.expr_scope
 *         self.visitchildren(node)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_find_in_stack, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1376, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow))))) __PYX_ERR(0, 1376, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow);
    __pyx_v_self->flow = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1377
 *             self.stack.append((self.env, self.flow))
 *             self.flow = self.find_in_stack(node.expr_scope)
 *             self.env = node.expr_scope             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         if node.expr_scope:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->env);
    __Pyx_DECREF(__pyx_v_self->env);
    __pyx_v_self->env = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1374
 *         # (with comprehensions covered in their own function)
 *         assert isinstance(node, (ExprNodes.IteratorNode, ExprNodes.AsyncIteratorNode)), node
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.stack.append((self.env, self.flow))
 *             self.flow = self.find_in_stack(node.expr_scope)
*/
  }

  /* "Cython/Compiler/FlowControl.py":1378
 *             self.flow = self.find_in_stack(node.expr_scope)
 *             self.env = node.expr_scope
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.env, self.flow = self.stack.pop()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1379
 *             self.env = node.expr_scope
 *         self.visitchildren(node)
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.env, self.flow = self.stack.pop()
 *         return node
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1380
 *         self.visitchildren(node)
 *         if node.expr_scope:
 *             self.env, self.flow = self.stack.pop()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    if (unlikely(__pyx_v_self->stack == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 1380, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->stack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1380, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_2);
      } else {
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1380, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1380, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_2);
      }
      #else
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1380, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1380, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1380, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < (0)) __PYX_ERR(0, 1380, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L8_unpacking_done;
      __pyx_L7_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1380, __pyx_L1_error)
      __pyx_L8_unpacking_done:;
    }
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow))))) __PYX_ERR(0, 1380, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_6);
    __Pyx_GOTREF(__pyx_v_self->env);
    __Pyx_DECREF(__pyx_v_self->env);
    __pyx_v_self->env = __pyx_t_6;
    __pyx_t_6 = 0;
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow);
    __pyx_v_self->flow = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/FlowControl.py":1379
 *             self.env = node.expr_scope
 *         self.visitchildren(node)
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.env, self.flow = self.stack.pop()
 *         return node
*/
  }

  /* "Cython/Compiler/FlowControl.py":1381
 *         if node.expr_scope:
 *             self.env, self.flow = self.stack.pop()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_PyClassDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1370
 *         return node
 * 
 *     def visit_ScopedExprNode(self, node):             # <<<<<<<<<<<<<<
 *         # currently this is written to deal with these two types
 *         # (with comprehensions covered in their own function)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_ScopedExprNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1383
 *         return node
 * 
 *     def visit_PyClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, ('dict', 'metaclass',
 *                                   'mkw', 'bases', 'class_result'))
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_89visit_PyClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_89visit_PyClassDefNode = {"visit_PyClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_89visit_PyClassDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_89visit_PyClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_PyClassDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_88visit_PyClassDefNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_88visit_PyClassDefNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_PyClassDefNode", 0);

  /* "Cython/Compiler/FlowControl.py":1384
 * 
 *     def visit_PyClassDefNode(self, node):
 *         self.visitchildren(node, ('dict', 'metaclass',             # <<<<<<<<<<<<<<
 *                                   'mkw', 'bases', 'class_result'))
 *         self.flow.mark_assignment(node.target, node.classobj,
*/
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.attrs = __pyx_mstate_global->__pyx_tuple[4];
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1386
 *         self.visitchildren(node, ('dict', 'metaclass',
 *                                   'mkw', 'bases', 'class_result'))
 *         self.flow.mark_assignment(node.target, node.classobj,             # <<<<<<<<<<<<<<
 *                                   self.env.lookup(node.target.name))
 *         self.stack.append((self.env, self.flow))
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_classobj); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "Cython/Compiler/FlowControl.py":1387
 *                                   'mkw', 'bases', 'class_result'))
 *         self.flow.mark_assignment(node.target, node.classobj,
 *                                   self.env.lookup(node.target.name))             # <<<<<<<<<<<<<<
 *         self.stack.append((self.env, self.flow))
 *         self.env = node.scope
*/
  __pyx_t_5 = __pyx_v_self->env;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_target); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }

  /* "Cython/Compiler/FlowControl.py":1386
 *         self.visitchildren(node, ('dict', 'metaclass',
 *                                   'mkw', 'bases', 'class_result'))
 *         self.flow.mark_assignment(node.target, node.classobj,             # <<<<<<<<<<<<<<
 *                                   self.env.lookup(node.target.name))
 *         self.stack.append((self.env, self.flow))
*/
  __pyx_t_7 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment(__pyx_v_self->flow, __pyx_t_1, __pyx_t_3, __pyx_t_4, 0, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":1388
 *         self.flow.mark_assignment(node.target, node.classobj,
 *                                   self.env.lookup(node.target.name))
 *         self.stack.append((self.env, self.flow))             # <<<<<<<<<<<<<<
 *         self.env = node.scope
 *         self.flow.nextblock()
*/
  if (unlikely(__pyx_v_self->stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 1388, __pyx_L1_error)
  }
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_v_self->env);
  __Pyx_GIVEREF(__pyx_v_self->env);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_self->env) != (0)) __PYX_ERR(0, 1388, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->flow);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->flow);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_v_self->flow)) != (0)) __PYX_ERR(0, 1388, __pyx_L1_error);
  __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_self->stack, __pyx_t_7); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 1388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":1389
 *                                   self.env.lookup(node.target.name))
 *         self.stack.append((self.env, self.flow))
 *         self.env = node.scope             # <<<<<<<<<<<<<<
 *         self.flow.nextblock()
 *         if node.doc_node:
*/
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __Pyx_GOTREF(__pyx_v_self->env);
  __Pyx_DECREF(__pyx_v_self->env);
  __pyx_v_self->env = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":1390
 *         self.stack.append((self.env, self.flow))
 *         self.env = node.scope
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         if node.doc_node:
 *             self.flow.mark_assignment(node.doc_node, fake_rhs_expr, node.doc_node.entry)
*/
  __pyx_t_7 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":1391
 *         self.env = node.scope
 *         self.flow.nextblock()
 *         if node.doc_node:             # <<<<<<<<<<<<<<
 *             self.flow.mark_assignment(node.doc_node, fake_rhs_expr, node.doc_node.entry)
 *         self.visitchildren(node, ('body',))
*/
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_doc_node); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 1391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "Cython/Compiler/FlowControl.py":1392
 *         self.flow.nextblock()
 *         if node.doc_node:
 *             self.flow.mark_assignment(node.doc_node, fake_rhs_expr, node.doc_node.entry)             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, ('body',))
 *         self.flow.nextblock()
*/
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_doc_node); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_11FlowControl_fake_rhs_expr;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_doc_node); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment(__pyx_v_self->flow, __pyx_t_7, __pyx_t_4, __pyx_t_1, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/FlowControl.py":1391
 *         self.env = node.scope
 *         self.flow.nextblock()
 *         if node.doc_node:             # <<<<<<<<<<<<<<
 *             self.flow.mark_assignment(node.doc_node, fake_rhs_expr, node.doc_node.entry)
 *         self.visitchildren(node, ('body',))
*/
  }

  /* "Cython/Compiler/FlowControl.py":1393
 *         if node.doc_node:
 *             self.flow.mark_assignment(node.doc_node, fake_rhs_expr, node.doc_node.entry)
 *         self.visitchildren(node, ('body',))             # <<<<<<<<<<<<<<
 *         self.flow.nextblock()
 *         self.env, _ = self.stack.pop()
*/
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.attrs = __pyx_mstate_global->__pyx_tuple[5];
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, &__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1394
 *             self.flow.mark_assignment(node.doc_node, fake_rhs_expr, node.doc_node.entry)
 *         self.visitchildren(node, ('body',))
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self.env, _ = self.stack.pop()
 *         return node
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/FlowControl.py":1395
 *         self.visitchildren(node, ('body',))
 *         self.flow.nextblock()
 *         self.env, _ = self.stack.pop()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  if (unlikely(__pyx_v_self->stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 1395, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyList_Pop(__pyx_v_self->stack); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1395, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_4);
    } else {
      __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1395, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1395, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_4);
    }
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_7 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
    index = 0; __pyx_t_1 = __pyx_t_11(__pyx_t_7); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_4 = __pyx_t_11(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_7), 2) < (0)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __pyx_t_11 = NULL;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_11 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1395, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->env);
  __Pyx_DECREF(__pyx_v_self->env);
  __pyx_v_self->env = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v__ = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1396
 *         self.flow.nextblock()
 *         self.env, _ = self.stack.pop()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CClassDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1383
 *         return node
 * 
 *     def visit_PyClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, ('dict', 'metaclass',
 *                                   'mkw', 'bases', 'class_result'))
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_PyClassDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1398
 *         return node
 * 
 *     def visit_CClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         # just make sure the nodes scope is findable in-case there is a list comprehension in it
 *         self.stack.append((node.scope, self.flow))
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_91visit_CClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_91visit_CClassDefNode = {"visit_CClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_91visit_CClassDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_91visit_CClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CClassDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_90visit_CClassDefNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_90visit_CClassDefNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CClassDefNode", 0);

  /* "Cython/Compiler/FlowControl.py":1400
 *     def visit_CClassDefNode(self, node):
 *         # just make sure the nodes scope is findable in-case there is a list comprehension in it
 *         self.stack.append((node.scope, self.flow))             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         self.stack.pop()
*/
  if (unlikely(__pyx_v_self->stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 1400, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 1400, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->flow);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->flow);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self->flow)) != (0)) __PYX_ERR(0, 1400, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyList_Append(__pyx_v_self->stack, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1400, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1401
 *         # just make sure the nodes scope is findable in-case there is a list comprehension in it
 *         self.stack.append((node.scope, self.flow))
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         self.stack.pop()
 *         return node
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1402
 *         self.stack.append((node.scope, self.flow))
 *         self.visitchildren(node)
 *         self.stack.pop()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  if (unlikely(__pyx_v_self->stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 1402, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyList_Pop(__pyx_v_self->stack); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":1403
 *         self.visitchildren(node)
 *         self.stack.pop()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_AmpersandNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1398
 *         return node
 * 
 *     def visit_CClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         # just make sure the nodes scope is findable in-case there is a list comprehension in it
 *         self.stack.append((node.scope, self.flow))
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_CClassDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1405
 *         return node
 * 
 *     def visit_AmpersandNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.operand.is_name:
 *             # Fake assignment to silence warning
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_93visit_AmpersandNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_93visit_AmpersandNode = {"visit_AmpersandNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_93visit_AmpersandNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_93visit_AmpersandNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_AmpersandNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_92visit_AmpersandNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_92visit_AmpersandNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_AmpersandNode", 0);

  /* "Cython/Compiler/FlowControl.py":1406
 * 
 *     def visit_AmpersandNode(self, node):
 *         if node.operand.is_name:             # <<<<<<<<<<<<<<
 *             # Fake assignment to silence warning
 *             self.mark_assignment(node.operand, fake_rhs_expr)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operand); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1408
 *         if node.operand.is_name:
 *             # Fake assignment to silence warning
 *             self.mark_assignment(node.operand, fake_rhs_expr)             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         return node
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operand); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_11FlowControl_fake_rhs_expr;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.rhs = __pyx_t_1;
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment(__pyx_v_self, __pyx_t_2, 0, &__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":1406
 * 
 *     def visit_AmpersandNode(self, node):
 *         if node.operand.is_name:             # <<<<<<<<<<<<<<
 *             # Fake assignment to silence warning
 *             self.mark_assignment(node.operand, fake_rhs_expr)
*/
  }

  /* "Cython/Compiler/FlowControl.py":1409
 *             # Fake assignment to silence warning
 *             self.mark_assignment(node.operand, fake_rhs_expr)
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1410
 *             self.mark_assignment(node.operand, fake_rhs_expr)
 *         self.visitchildren(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_BoolBinopNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1405
 *         return node
 * 
 *     def visit_AmpersandNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.operand.is_name:
 *             # Fake assignment to silence warning
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_AmpersandNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1412
 *         return node
 * 
 *     def visit_BoolBinopNode(self, node):             # <<<<<<<<<<<<<<
 *         # Note - I don't believe BoolBinopResultNode needs special handling beyond this
 *         assert len(node.subexprs) == 2  # operand1 and operand2 only
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_95visit_BoolBinopNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_95visit_BoolBinopNode = {"visit_BoolBinopNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_95visit_BoolBinopNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_95visit_BoolBinopNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_BoolBinopNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_94visit_BoolBinopNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_94visit_BoolBinopNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_next_block = NULL;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_BoolBinopNode", 0);

  /* "Cython/Compiler/FlowControl.py":1414
 *     def visit_BoolBinopNode(self, node):
 *         # Note - I don't believe BoolBinopResultNode needs special handling beyond this
 *         assert len(node.subexprs) == 2  # operand1 and operand2 only             # <<<<<<<<<<<<<<
 * 
 *         next_block = self.flow.newblock()
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_subexprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1414, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__pyx_t_2 == 2);
    if (unlikely(!__pyx_t_3)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 1414, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 1414, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/FlowControl.py":1416
 *         assert len(node.subexprs) == 2  # operand1 and operand2 only
 * 
 *         next_block = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         parent = self.flow.block
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_next_block = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1417
 * 
 *         next_block = self.flow.newblock()
 *         parent = self.flow.block             # <<<<<<<<<<<<<<
 * 
 *         self._visit(node.operand1)
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->flow->block);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1419
 *         parent = self.flow.block
 * 
 *         self._visit(node.operand1)             # <<<<<<<<<<<<<<
 * 
 *         self.flow.nextblock()
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operand1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1421
 *         self._visit(node.operand1)
 * 
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self._visit(node.operand2)
 *         if self.flow.block:
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1422
 * 
 *         self.flow.nextblock()
 *         self._visit(node.operand2)             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operand2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1423
 *         self.flow.nextblock()
 *         self._visit(node.operand2)
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 * 
*/
  __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1423, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1424
 *         self._visit(node.operand2)
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         parent.add_child(next_block)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1423
 *         self.flow.nextblock()
 *         self._visit(node.operand2)
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":1426
 *             self.flow.block.add_child(next_block)
 * 
 *         parent.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         if next_block.parents:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_parent->__pyx_vtab)->add_child(__pyx_v_parent, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1428
 *         parent.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1428, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1429
 * 
 *         if next_block.parents:
 *             self.flow.block = next_block             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block = None
*/
    __pyx_t_1 = __pyx_v_next_block;
    __Pyx_INCREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1429, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1428
 *         parent.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/FlowControl.py":1431
 *             self.flow.block = next_block
 *         else:
 *             self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  }
  __pyx_L4:;

  /* "Cython/Compiler/FlowControl.py":1432
 *         else:
 *             self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CondExprNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1412
 *         return node
 * 
 *     def visit_BoolBinopNode(self, node):             # <<<<<<<<<<<<<<
 *         # Note - I don't believe BoolBinopResultNode needs special handling beyond this
 *         assert len(node.subexprs) == 2  # operand1 and operand2 only
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_BoolBinopNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_next_block);
  __Pyx_XDECREF((PyObject *)__pyx_v_parent);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/FlowControl.py":1434
 *         return node
 * 
 *     def visit_CondExprNode(self, node):             # <<<<<<<<<<<<<<
 *         assert len(node.subexprs) == 3
 *         self._visit(node.test)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_97visit_CondExprNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_97visit_CondExprNode = {"visit_CondExprNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_97visit_CondExprNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_97visit_CondExprNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CondExprNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_96visit_CondExprNode(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_96visit_CondExprNode(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v_node) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v_parent = NULL;
  PyObject *__pyx_v_next_block = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CondExprNode", 0);

  /* "Cython/Compiler/FlowControl.py":1435
 * 
 *     def visit_CondExprNode(self, node):
 *         assert len(node.subexprs) == 3             # <<<<<<<<<<<<<<
 *         self._visit(node.test)
 *         parent = self.flow.block
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_subexprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1435, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1435, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__pyx_t_2 == 3);
    if (unlikely(!__pyx_t_3)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 1435, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 1435, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/FlowControl.py":1436
 *     def visit_CondExprNode(self, node):
 *         assert len(node.subexprs) == 3
 *         self._visit(node.test)             # <<<<<<<<<<<<<<
 *         parent = self.flow.block
 *         next_block = self.flow.newblock()
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_test); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1437
 *         assert len(node.subexprs) == 3
 *         self._visit(node.test)
 *         parent = self.flow.block             # <<<<<<<<<<<<<<
 *         next_block = self.flow.newblock()
 *         self.flow.nextblock()
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_self->flow->block);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_parent = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1438
 *         self._visit(node.test)
 *         parent = self.flow.block
 *         next_block = self.flow.newblock()             # <<<<<<<<<<<<<<
 *         self.flow.nextblock()
 *         self._visit(node.true_val)
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_next_block = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1439
 *         parent = self.flow.block
 *         next_block = self.flow.newblock()
 *         self.flow.nextblock()             # <<<<<<<<<<<<<<
 *         self._visit(node.true_val)
 *         if self.flow.block:
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1440
 *         next_block = self.flow.newblock()
 *         self.flow.nextblock()
 *         self._visit(node.true_val)             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_true_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1441
 *         self.flow.nextblock()
 *         self._visit(node.true_val)
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 *         self.flow.nextblock(parent=parent)
*/
  __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1441, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1442
 *         self._visit(node.true_val)
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 *         self.flow.nextblock(parent=parent)
 *         self._visit(node.false_val)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/FlowControl.py":1441
 *         self.flow.nextblock()
 *         self._visit(node.true_val)
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 *         self.flow.nextblock(parent=parent)
*/
  }

  /* "Cython/Compiler/FlowControl.py":1443
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)
 *         self.flow.nextblock(parent=parent)             # <<<<<<<<<<<<<<
 *         self._visit(node.false_val)
 *         if self.flow.block:
*/
  __pyx_t_5.__pyx_n = 1;
  __pyx_t_5.parent = __pyx_v_parent;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock(__pyx_v_self->flow, 0, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/FlowControl.py":1444
 *             self.flow.block.add_child(next_block)
 *         self.flow.nextblock(parent=parent)
 *         self._visit(node.false_val)             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_false_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1445
 *         self.flow.nextblock(parent=parent)
 *         self._visit(node.false_val)
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 * 
*/
  __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->flow->block)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1445, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1446
 *         self._visit(node.false_val)
 *         if self.flow.block:
 *             self.flow.block.add_child(next_block)             # <<<<<<<<<<<<<<
 * 
 *         if next_block.parents:
*/
    __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v_self->flow->block->__pyx_vtab)->add_child(__pyx_v_self->flow->block, __pyx_v_next_block, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":1445
 *         self.flow.nextblock(parent=parent)
 *         self._visit(node.false_val)
 *         if self.flow.block:             # <<<<<<<<<<<<<<
 *             self.flow.block.add_child(next_block)
 * 
*/
  }

  /* "Cython/Compiler/FlowControl.py":1448
 *             self.flow.block.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_block, __pyx_mstate_global->__pyx_n_u_parents); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/FlowControl.py":1449
 * 
 *         if next_block.parents:
 *             self.flow.block = next_block             # <<<<<<<<<<<<<<
 *         else:
 *             self.flow.block = None
*/
    __pyx_t_4 = __pyx_v_next_block;
    __Pyx_INCREF(__pyx_t_4);
    if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(0, 1449, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/FlowControl.py":1448
 *             self.flow.block.add_child(next_block)
 * 
 *         if next_block.parents:             # <<<<<<<<<<<<<<
 *             self.flow.block = next_block
 *         else:
*/
    goto __pyx_L5;
  }

  /* "Cython/Compiler/FlowControl.py":1451
 *             self.flow.block = next_block
 *         else:
 *             self.flow.block = None             # <<<<<<<<<<<<<<
 *         return node
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->flow->block);
    __Pyx_DECREF((PyObject *)__pyx_v_self->flow->block);
    __pyx_v_self->flow->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None);
  }
  __pyx_L5:;

  /* "Cython/Compiler/FlowControl.py":1452
 *         else:
 *             self.flow.block = None
 *         return node             # <<<<<<<<<<<<<<
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/FlowControl.py":1434
 *         return node
 * 
 *     def visit_CondExprNode(self, node):             # <<<<<<<<<<<<<<
 *         assert len(node.subexprs) == 3
 *         self._visit(node.test)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.visit_CondExprNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_parent);
  __Pyx_XDECREF(__pyx_v_next_block);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_99__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_99__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_99__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_99__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_98__reduce_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_98__reduce_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.access_path, self.constant_folder, self.context, self.current_directives, self.dispatch_table, self.env, self.flow, self.gv_ctx, self.in_inplace_assignment, self.object_expr, self.reductions, self.stack)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->in_inplace_assignment); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(12); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.access_path);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.access_path);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.access_path) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->constant_folder);
  __Pyx_GIVEREF(__pyx_v_self->constant_folder);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->constant_folder) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.context);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.context);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_self->__pyx_base.context) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.current_directives);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.current_directives);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_self->__pyx_base.current_directives) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.dispatch_table);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.dispatch_table);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.dispatch_table) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->env);
  __Pyx_GIVEREF(__pyx_v_self->env);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 5, __pyx_v_self->env) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->flow);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->flow);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 6, ((PyObject *)__pyx_v_self->flow)) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->gv_ctx);
  __Pyx_GIVEREF(__pyx_v_self->gv_ctx);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 7, __pyx_v_self->gv_ctx) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 8, __pyx_t_1) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->object_expr);
  __Pyx_GIVEREF(__pyx_v_self->object_expr);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 9, __pyx_v_self->object_expr) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->reductions);
  __Pyx_GIVEREF(__pyx_v_self->reductions);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 10, __pyx_v_self->reductions) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->stack);
  __Pyx_GIVEREF(__pyx_v_self->stack);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 11, __pyx_v_self->stack) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.access_path, self.constant_folder, self.context, self.current_directives, self.dispatch_table, self.env, self.flow, self.gv_ctx, self.in_inplace_assignment, self.object_expr, self.reductions, self.stack)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v__dict = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":7
 *     state = (self.access_path, self.constant_folder, self.context, self.current_directives, self.dispatch_table, self.env, self.flow, self.gv_ctx, self.in_inplace_assignment, self.object_expr, self.reductions, self.stack)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_4 = (__pyx_v__dict != Py_None);
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.access_path is not None or self.constant_folder is not None or self.context is not None or self.current_directives is not None or self.dispatch_table is not None or self.env is not None or self.flow is not None or self.gv_ctx is not None or self.object_expr is not None or self.reductions is not None or self.stack is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.access_path, self.constant_folder, self.context, self.current_directives, self.dispatch_table, self.env, self.flow, self.gv_ctx, self.in_inplace_assignment, self.object_expr, self.reductions, self.stack)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.access_path is not None or self.constant_folder is not None or self.context is not None or self.current_directives is not None or self.dispatch_table is not None or self.env is not None or self.flow is not None or self.gv_ctx is not None or self.object_expr is not None or self.reductions is not None or self.stack is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, None), state
*/
  /*else*/ {
    __pyx_t_4 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.access_path != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->constant_folder != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->__pyx_base.context != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->__pyx_base.current_directives != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.dispatch_table != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->env != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (((PyObject *)__pyx_v_self->flow) != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->gv_ctx != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->object_expr != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->reductions != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->stack != ((PyObject*)Py_None));
    __pyx_t_3 = __pyx_t_4;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.access_path is not None or self.constant_folder is not None or self.context is not None or self.current_directives is not None or self.dispatch_table is not None or self.env is not None or self.flow is not None or self.gv_ctx is not None or self.object_expr is not None or self.reductions is not None or self.stack is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.access_path is not None or self.constant_folder is not None or self.context is not None or self.current_directives is not None or self.dispatch_table is not None or self.env is not None or self.flow is not None or self.gv_ctx is not None or self.object_expr is not None or self.reductions is not None or self.stack is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlFlowAnalys); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_243737303);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_243737303);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_mstate_global->__pyx_int_243737303) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.access_path is not None or self.constant_folder is not None or self.context is not None or self.current_directives is not None or self.dispatch_table is not None or self.env is not None or self.flow is not None or self.gv_ctx is not None or self.object_expr is not None or self.reductions is not None or self.stack is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, None), state
 *     else:
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ControlFlowAnalysis__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlFlowAnalys); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_243737303);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_243737303);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_mstate_global->__pyx_int_243737303) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlFlowAnalysis__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_101__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_101__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_101__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_101__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_100__setstate_cython__(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_100__setstate_cython__(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ControlFlowAnalysis__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlFlowAnalysis__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlFlowAnalysis__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.ControlFlowAnalysis.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ControlBlock(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_1__pyx_unpickle_ControlBlock(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_1__pyx_unpickle_ControlBlock = {"__pyx_unpickle_ControlBlock", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_1__pyx_unpickle_ControlBlock, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_1__pyx_unpickle_ControlBlock(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlBlock (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_ControlBlock", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ControlBlock", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ControlBlock", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlBlock(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlBlock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlBlock", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_ControlBlock(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')             # <<<<<<<<<<<<<<
 *     __pyx_result = ControlBlock.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, __pyx_k_bounded_children_gen_i_gen_i_inp); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
 *     __pyx_result = ControlBlock.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlBlock__set_state(<ControlBlock> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
 *     __pyx_result = ControlBlock.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ControlBlock__set_state(<ControlBlock> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = ControlBlock.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlBlock__set_state(<ControlBlock> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlBlock__set_state(ControlBlock __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlBlock__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
 *     __pyx_result = ControlBlock.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ControlBlock__set_state(<ControlBlock> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlBlock__set_state(<ControlBlock> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ControlBlock__set_state(ControlBlock __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ControlBlock(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ControlBlock__set_state(<ControlBlock> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlBlock__set_state(ControlBlock __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 11)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlBlock__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlBlock__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlBlock__set_state(ControlBlock __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 11)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->bounded);
  __Pyx_DECREF(__pyx_v___pyx_result->bounded);
  __pyx_v___pyx_result->bounded = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->children);
  __Pyx_DECREF(__pyx_v___pyx_result->children);
  __pyx_v___pyx_result->children = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->gen);
  __Pyx_DECREF(__pyx_v___pyx_result->gen);
  __pyx_v___pyx_result->gen = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->i_gen);
  __Pyx_DECREF(__pyx_v___pyx_result->i_gen);
  __pyx_v___pyx_result->i_gen = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->i_input);
  __Pyx_DECREF(__pyx_v___pyx_result->i_input);
  __pyx_v___pyx_result->i_input = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->i_kill);
  __Pyx_DECREF(__pyx_v___pyx_result->i_kill);
  __pyx_v___pyx_result->i_kill = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->i_output);
  __Pyx_DECREF(__pyx_v___pyx_result->i_output);
  __pyx_v___pyx_result->i_output = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->i_state);
  __Pyx_DECREF(__pyx_v___pyx_result->i_state);
  __pyx_v___pyx_result->i_state = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->parents);
  __Pyx_DECREF(__pyx_v___pyx_result->parents);
  __pyx_v___pyx_result->parents = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->positions);
  __Pyx_DECREF(__pyx_v___pyx_result->positions);
  __pyx_v___pyx_result->positions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->stats);
  __Pyx_DECREF(__pyx_v___pyx_result->stats);
  __pyx_v___pyx_result->stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ControlBlock__set_state(ControlBlock __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 11)             # <<<<<<<<<<<<<<
*/
  __pyx_t_2 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 11); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_ControlBlock__set_state(<ControlBlock> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlBlock__set_state(ControlBlock __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 11)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlBlock__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ExitBlock(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_3__pyx_unpickle_ExitBlock(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_3__pyx_unpickle_ExitBlock = {"__pyx_unpickle_ExitBlock", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_3__pyx_unpickle_ExitBlock, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_3__pyx_unpickle_ExitBlock(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ExitBlock (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_ExitBlock", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ExitBlock", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ExitBlock", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ExitBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_2__pyx_unpickle_ExitBlock(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_2__pyx_unpickle_ExitBlock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ExitBlock", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_ExitBlock(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')             # <<<<<<<<<<<<<<
 *     __pyx_result = ExitBlock.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, __pyx_k_bounded_children_gen_i_gen_i_inp); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
 *     __pyx_result = ExitBlock.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ExitBlock__set_state(<ExitBlock> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
 *     __pyx_result = ExitBlock.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ExitBlock__set_state(<ExitBlock> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = ExitBlock.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ExitBlock__set_state(<ExitBlock> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ExitBlock__set_state(ExitBlock __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ExitBlock__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
 *     __pyx_result = ExitBlock.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ExitBlock__set_state(<ExitBlock> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ExitBlock__set_state(<ExitBlock> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ExitBlock__set_state(ExitBlock __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ExitBlock(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ExitBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ExitBlock__set_state(<ExitBlock> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ExitBlock__set_state(ExitBlock __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 11)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ExitBlock__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ExitBlock__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ExitBlock__set_state(ExitBlock __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 11)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.bounded);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.bounded);
  __pyx_v___pyx_result->__pyx_base.bounded = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.children);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.children);
  __pyx_v___pyx_result->__pyx_base.children = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.gen);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.gen);
  __pyx_v___pyx_result->__pyx_base.gen = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.i_gen);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.i_gen);
  __pyx_v___pyx_result->__pyx_base.i_gen = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.i_input);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.i_input);
  __pyx_v___pyx_result->__pyx_base.i_input = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.i_kill);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.i_kill);
  __pyx_v___pyx_result->__pyx_base.i_kill = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.i_output);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.i_output);
  __pyx_v___pyx_result->__pyx_base.i_output = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.i_state);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.i_state);
  __pyx_v___pyx_result->__pyx_base.i_state = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.parents);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.parents);
  __pyx_v___pyx_result->__pyx_base.parents = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.positions);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.positions);
  __pyx_v___pyx_result->__pyx_base.positions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.stats);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.stats);
  __pyx_v___pyx_result->__pyx_base.stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ExitBlock__set_state(ExitBlock __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 11)             # <<<<<<<<<<<<<<
*/
  __pyx_t_2 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 11); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_ExitBlock__set_state(<ExitBlock> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ExitBlock__set_state(ExitBlock __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.bounded = __pyx_state[0]; __pyx_result.children = __pyx_state[1]; __pyx_result.gen = __pyx_state[2]; __pyx_result.i_gen = __pyx_state[3]; __pyx_result.i_input = __pyx_state[4]; __pyx_result.i_kill = __pyx_state[5]; __pyx_result.i_output = __pyx_state[6]; __pyx_result.i_state = __pyx_state[7]; __pyx_result.parents = __pyx_state[8]; __pyx_result.positions = __pyx_state[9]; __pyx_result.stats = __pyx_state[10]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 11)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ExitBlock__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_AssignmentList(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9a2d7cf, 0xb1e68e4, 0x39670e9, b'bit, mask, stats')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_5__pyx_unpickle_AssignmentList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_5__pyx_unpickle_AssignmentList = {"__pyx_unpickle_AssignmentList", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_5__pyx_unpickle_AssignmentList, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_5__pyx_unpickle_AssignmentList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_AssignmentList (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_AssignmentList", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_AssignmentList", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_AssignmentList", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_AssignmentList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_4__pyx_unpickle_AssignmentList(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_4__pyx_unpickle_AssignmentList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_AssignmentList", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_AssignmentList(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9a2d7cf, 0xb1e68e4, 0x39670e9, b'bit, mask, stats')             # <<<<<<<<<<<<<<
 *     __pyx_result = AssignmentList.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0x9a2d7cf, 0xb1e68e4, 0x39670e9, __pyx_k_bit_mask_stats); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9a2d7cf, 0xb1e68e4, 0x39670e9, b'bit, mask, stats')
 *     __pyx_result = AssignmentList.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AssignmentList__set_state(<AssignmentList> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9a2d7cf, 0xb1e68e4, 0x39670e9, b'bit, mask, stats')
 *     __pyx_result = AssignmentList.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_AssignmentList__set_state(<AssignmentList> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = AssignmentList.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AssignmentList__set_state(<AssignmentList> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_AssignmentList__set_state(AssignmentList __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_AssignmentList__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9a2d7cf, 0xb1e68e4, 0x39670e9, b'bit, mask, stats')
 *     __pyx_result = AssignmentList.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_AssignmentList__set_state(<AssignmentList> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AssignmentList__set_state(<AssignmentList> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_AssignmentList__set_state(AssignmentList __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.mask = __pyx_state[1]; __pyx_result.stats = __pyx_state[2]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_AssignmentList(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9a2d7cf, 0xb1e68e4, 0x39670e9, b'bit, mask, stats')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_AssignmentList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_AssignmentList__set_state(<AssignmentList> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_AssignmentList__set_state(AssignmentList __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.mask = __pyx_state[1]; __pyx_result.stats = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_AssignmentList__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_AssignmentList__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_AssignmentList__set_state(AssignmentList __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.mask = __pyx_state[1]; __pyx_result.stats = __pyx_state[2]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->bit);
  __Pyx_DECREF(__pyx_v___pyx_result->bit);
  __pyx_v___pyx_result->bit = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->mask);
  __Pyx_DECREF(__pyx_v___pyx_result->mask);
  __pyx_v___pyx_result->mask = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->stats);
  __Pyx_DECREF(__pyx_v___pyx_result->stats);
  __pyx_v___pyx_result->stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_AssignmentList__set_state(AssignmentList __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.mask = __pyx_state[1]; __pyx_result.stats = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)             # <<<<<<<<<<<<<<
*/
  __pyx_t_2 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_AssignmentList__set_state(<AssignmentList> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_AssignmentList__set_state(AssignmentList __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.mask = __pyx_state[1]; __pyx_result.stats = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_AssignmentList__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ControlFlow(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xc9527a2, 0x6647335, 0xca40d48, b'assmts, block, blocks, entries, entry_point, exceptions, exit_point, in_try_block, loops')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_7__pyx_unpickle_ControlFlow(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_7__pyx_unpickle_ControlFlow = {"__pyx_unpickle_ControlFlow", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_7__pyx_unpickle_ControlFlow, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_7__pyx_unpickle_ControlFlow(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlFlow (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_ControlFlow", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ControlFlow", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ControlFlow", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlFlow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_6__pyx_unpickle_ControlFlow(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_6__pyx_unpickle_ControlFlow(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlFlow", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_ControlFlow(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xc9527a2, 0x6647335, 0xca40d48, b'assmts, block, blocks, entries, entry_point, exceptions, exit_point, in_try_block, loops')             # <<<<<<<<<<<<<<
 *     __pyx_result = ControlFlow.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0xc9527a2, 0x6647335, 0xca40d48, __pyx_k_assmts_block_blocks_entries_entr); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xc9527a2, 0x6647335, 0xca40d48, b'assmts, block, blocks, entries, entry_point, exceptions, exit_point, in_try_block, loops')
 *     __pyx_result = ControlFlow.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlFlow__set_state(<ControlFlow> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xc9527a2, 0x6647335, 0xca40d48, b'assmts, block, blocks, entries, entry_point, exceptions, exit_point, in_try_block, loops')
 *     __pyx_result = ControlFlow.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ControlFlow__set_state(<ControlFlow> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = ControlFlow.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlFlow__set_state(<ControlFlow> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlow__set_state(ControlFlow __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlFlow__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xc9527a2, 0x6647335, 0xca40d48, b'assmts, block, blocks, entries, entry_point, exceptions, exit_point, in_try_block, loops')
 *     __pyx_result = ControlFlow.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ControlFlow__set_state(<ControlFlow> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlFlow__set_state(<ControlFlow> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ControlFlow__set_state(ControlFlow __pyx_result, __pyx_state: tuple):
 *     __pyx_result.assmts = __pyx_state[0]; __pyx_result.block = __pyx_state[1]; __pyx_result.blocks = __pyx_state[2]; __pyx_result.entries = __pyx_state[3]; __pyx_result.entry_point = __pyx_state[4]; __pyx_result.exceptions = __pyx_state[5]; __pyx_result.exit_point = __pyx_state[6]; __pyx_result.in_try_block = __pyx_state[7]; __pyx_result.loops = __pyx_state[8]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ControlFlow(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xc9527a2, 0x6647335, 0xca40d48, b'assmts, block, blocks, entries, entry_point, exceptions, exit_point, in_try_block, loops')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlFlow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ControlFlow__set_state(<ControlFlow> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlow__set_state(ControlFlow __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.assmts = __pyx_state[0]; __pyx_result.block = __pyx_state[1]; __pyx_result.blocks = __pyx_state[2]; __pyx_result.entries = __pyx_state[3]; __pyx_result.entry_point = __pyx_state[4]; __pyx_result.exceptions = __pyx_state[5]; __pyx_result.exit_point = __pyx_state[6]; __pyx_result.in_try_block = __pyx_state[7]; __pyx_result.loops = __pyx_state[8]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 9)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlFlow__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlFlow__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlow__set_state(ControlFlow __pyx_result, __pyx_state: tuple):
 *     __pyx_result.assmts = __pyx_state[0]; __pyx_result.block = __pyx_state[1]; __pyx_result.blocks = __pyx_state[2]; __pyx_result.entries = __pyx_state[3]; __pyx_result.entry_point = __pyx_state[4]; __pyx_result.exceptions = __pyx_state[5]; __pyx_result.exit_point = __pyx_state[6]; __pyx_result.in_try_block = __pyx_state[7]; __pyx_result.loops = __pyx_state[8]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 9)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->assmts);
  __Pyx_DECREF(__pyx_v___pyx_result->assmts);
  __pyx_v___pyx_result->assmts = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v___pyx_result->block);
  __Pyx_DECREF((PyObject *)__pyx_v___pyx_result->block);
  __pyx_v___pyx_result->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->blocks);
  __Pyx_DECREF(__pyx_v___pyx_result->blocks);
  __pyx_v___pyx_result->blocks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->entries);
  __Pyx_DECREF(__pyx_v___pyx_result->entries);
  __pyx_v___pyx_result->entries = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock))))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v___pyx_result->entry_point);
  __Pyx_DECREF((PyObject *)__pyx_v___pyx_result->entry_point);
  __pyx_v___pyx_result->entry_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->exceptions);
  __Pyx_DECREF(__pyx_v___pyx_result->exceptions);
  __pyx_v___pyx_result->exceptions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock))))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v___pyx_result->exit_point);
  __Pyx_DECREF((PyObject *)__pyx_v___pyx_result->exit_point);
  __pyx_v___pyx_result->exit_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyIndex_AsSsize_t(__pyx_t_1); if (unlikely((__pyx_t_2 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->in_try_block = __pyx_t_2;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->loops);
  __Pyx_DECREF(__pyx_v___pyx_result->loops);
  __pyx_v___pyx_result->loops = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ControlFlow__set_state(ControlFlow __pyx_result, __pyx_state: tuple):
 *     __pyx_result.assmts = __pyx_state[0]; __pyx_result.block = __pyx_state[1]; __pyx_result.blocks = __pyx_state[2]; __pyx_result.entries = __pyx_state[3]; __pyx_result.entry_point = __pyx_state[4]; __pyx_result.exceptions = __pyx_state[5]; __pyx_result.exit_point = __pyx_state[6]; __pyx_result.in_try_block = __pyx_state[7]; __pyx_result.loops = __pyx_state[8]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 9)             # <<<<<<<<<<<<<<
*/
  __pyx_t_3 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 9); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_ControlFlow__set_state(<ControlFlow> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlow__set_state(ControlFlow __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.assmts = __pyx_state[0]; __pyx_result.block = __pyx_state[1]; __pyx_result.blocks = __pyx_state[2]; __pyx_result.entries = __pyx_state[3]; __pyx_result.entry_point = __pyx_state[4]; __pyx_result.exceptions = __pyx_state[5]; __pyx_result.exit_point = __pyx_state[6]; __pyx_result.in_try_block = __pyx_state[7]; __pyx_result.loops = __pyx_state[8]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 9)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlFlow__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_NameAssignment(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x09885d0, 0xe16df08, 0x8cd3e98, b'bit, entry, inferred_type, is_arg, is_deletion, lhs, pos, refs, rhs, rhs_scope')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9__pyx_unpickle_NameAssignment(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_9__pyx_unpickle_NameAssignment = {"__pyx_unpickle_NameAssignment", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_9__pyx_unpickle_NameAssignment, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_9__pyx_unpickle_NameAssignment(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_NameAssignment (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_NameAssignment", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_NameAssignment", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_NameAssignment", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_NameAssignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_8__pyx_unpickle_NameAssignment(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_8__pyx_unpickle_NameAssignment(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_NameAssignment", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_NameAssignment(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x09885d0, 0xe16df08, 0x8cd3e98, b'bit, entry, inferred_type, is_arg, is_deletion, lhs, pos, refs, rhs, rhs_scope')             # <<<<<<<<<<<<<<
 *     __pyx_result = NameAssignment.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0x09885d0, 0xe16df08, 0x8cd3e98, __pyx_k_bit_entry_inferred_type_is_arg_i); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x09885d0, 0xe16df08, 0x8cd3e98, b'bit, entry, inferred_type, is_arg, is_deletion, lhs, pos, refs, rhs, rhs_scope')
 *     __pyx_result = NameAssignment.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_NameAssignment__set_state(<NameAssignment> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x09885d0, 0xe16df08, 0x8cd3e98, b'bit, entry, inferred_type, is_arg, is_deletion, lhs, pos, refs, rhs, rhs_scope')
 *     __pyx_result = NameAssignment.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_NameAssignment__set_state(<NameAssignment> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = NameAssignment.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_NameAssignment__set_state(<NameAssignment> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_NameAssignment__set_state(NameAssignment __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_NameAssignment__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x09885d0, 0xe16df08, 0x8cd3e98, b'bit, entry, inferred_type, is_arg, is_deletion, lhs, pos, refs, rhs, rhs_scope')
 *     __pyx_result = NameAssignment.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_NameAssignment__set_state(<NameAssignment> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_NameAssignment__set_state(<NameAssignment> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_NameAssignment__set_state(NameAssignment __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.entry = __pyx_state[1]; __pyx_result.inferred_type = __pyx_state[2]; __pyx_result.is_arg = __pyx_state[3]; __pyx_result.is_deletion = __pyx_state[4]; __pyx_result.lhs = __pyx_state[5]; __pyx_result.pos = __pyx_state[6]; __pyx_result.refs = __pyx_state[7]; __pyx_result.rhs = __pyx_state[8]; __pyx_result.rhs_scope = __pyx_state[9]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_NameAssignment(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x09885d0, 0xe16df08, 0x8cd3e98, b'bit, entry, inferred_type, is_arg, is_deletion, lhs, pos, refs, rhs, rhs_scope')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_NameAssignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_NameAssignment__set_state(<NameAssignment> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_NameAssignment__set_state(NameAssignment __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.entry = __pyx_state[1]; __pyx_result.inferred_type = __pyx_state[2]; __pyx_result.is_arg = __pyx_state[3]; __pyx_result.is_deletion = __pyx_state[4]; __pyx_result.lhs = __pyx_state[5]; __pyx_result.pos = __pyx_state[6]; __pyx_result.refs = __pyx_state[7]; __pyx_result.rhs = __pyx_state[8]; __pyx_result.rhs_scope = __pyx_state[9]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 10)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_NameAssignment__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_NameAssignment__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_NameAssignment__set_state(NameAssignment __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.entry = __pyx_state[1]; __pyx_result.inferred_type = __pyx_state[2]; __pyx_result.is_arg = __pyx_state[3]; __pyx_result.is_deletion = __pyx_state[4]; __pyx_result.lhs = __pyx_state[5]; __pyx_result.pos = __pyx_state[6]; __pyx_result.refs = __pyx_state[7]; __pyx_result.rhs = __pyx_state[8]; __pyx_result.rhs_scope = __pyx_state[9]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 10)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->bit);
  __Pyx_DECREF(__pyx_v___pyx_result->bit);
  __pyx_v___pyx_result->bit = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->entry);
  __Pyx_DECREF(__pyx_v___pyx_result->entry);
  __pyx_v___pyx_result->entry = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->inferred_type);
  __Pyx_DECREF(__pyx_v___pyx_result->inferred_type);
  __pyx_v___pyx_result->inferred_type = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->is_arg = __pyx_t_2;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->is_deletion = __pyx_t_2;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->lhs);
  __Pyx_DECREF(__pyx_v___pyx_result->lhs);
  __pyx_v___pyx_result->lhs = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->pos);
  __Pyx_DECREF(__pyx_v___pyx_result->pos);
  __pyx_v___pyx_result->pos = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->refs);
  __Pyx_DECREF(__pyx_v___pyx_result->refs);
  __pyx_v___pyx_result->refs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->rhs);
  __Pyx_DECREF(__pyx_v___pyx_result->rhs);
  __pyx_v___pyx_result->rhs = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->rhs_scope);
  __Pyx_DECREF(__pyx_v___pyx_result->rhs_scope);
  __pyx_v___pyx_result->rhs_scope = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_NameAssignment__set_state(NameAssignment __pyx_result, __pyx_state: tuple):
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.entry = __pyx_state[1]; __pyx_result.inferred_type = __pyx_state[2]; __pyx_result.is_arg = __pyx_state[3]; __pyx_result.is_deletion = __pyx_state[4]; __pyx_result.lhs = __pyx_state[5]; __pyx_result.pos = __pyx_state[6]; __pyx_result.refs = __pyx_state[7]; __pyx_result.rhs = __pyx_state[8]; __pyx_result.rhs_scope = __pyx_state[9]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 10)             # <<<<<<<<<<<<<<
*/
  __pyx_t_3 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 10); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_NameAssignment__set_state(<NameAssignment> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_NameAssignment__set_state(NameAssignment __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.bit = __pyx_state[0]; __pyx_result.entry = __pyx_state[1]; __pyx_result.inferred_type = __pyx_state[2]; __pyx_result.is_arg = __pyx_state[3]; __pyx_result.is_deletion = __pyx_state[4]; __pyx_result.lhs = __pyx_state[5]; __pyx_result.pos = __pyx_state[6]; __pyx_result.refs = __pyx_state[7]; __pyx_result.rhs = __pyx_state[8]; __pyx_result.rhs_scope = __pyx_state[9]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 10)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_NameAssignment__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_Uninitialized(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11__pyx_unpickle_Uninitialized(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_11__pyx_unpickle_Uninitialized = {"__pyx_unpickle_Uninitialized", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_11__pyx_unpickle_Uninitialized, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_11__pyx_unpickle_Uninitialized(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Uninitialized (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_Uninitialized", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Uninitialized", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Uninitialized", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_Uninitialized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_10__pyx_unpickle_Uninitialized(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_10__pyx_unpickle_Uninitialized(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Uninitialized", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_Uninitialized(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')             # <<<<<<<<<<<<<<
 *     __pyx_result = Uninitialized.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, __pyx_k__2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
 *     __pyx_result = Uninitialized.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Uninitialized__set_state(<Uninitialized> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
 *     __pyx_result = Uninitialized.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Uninitialized__set_state(<Uninitialized> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = Uninitialized.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Uninitialized__set_state(<Uninitialized> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Uninitialized__set_state(Uninitialized __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_Uninitialized__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
 *     __pyx_result = Uninitialized.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Uninitialized__set_state(<Uninitialized> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Uninitialized__set_state(<Uninitialized> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Uninitialized__set_state(Uninitialized __pyx_result, __pyx_state: tuple):
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 0)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_Uninitialized(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_Uninitialized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Uninitialized__set_state(<Uninitialized> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Uninitialized__set_state(Uninitialized __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 0)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_Uninitialized__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Uninitialized__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Uninitialized__set_state(Uninitialized __pyx_result, __pyx_state: tuple):
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 0)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 0); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 12, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_Uninitialized__set_state(<Uninitialized> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Uninitialized__set_state(Uninitialized __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 0)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_Uninitialized__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_Unknown(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13__pyx_unpickle_Unknown(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_13__pyx_unpickle_Unknown = {"__pyx_unpickle_Unknown", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_13__pyx_unpickle_Unknown, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_13__pyx_unpickle_Unknown(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Unknown (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_Unknown", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Unknown", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Unknown", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_Unknown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_12__pyx_unpickle_Unknown(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_12__pyx_unpickle_Unknown(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Unknown", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_Unknown(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')             # <<<<<<<<<<<<<<
 *     __pyx_result = Unknown.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, __pyx_k__2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
 *     __pyx_result = Unknown.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Unknown__set_state(<Unknown> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
 *     __pyx_result = Unknown.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Unknown__set_state(<Unknown> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = Unknown.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Unknown__set_state(<Unknown> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Unknown__set_state(Unknown __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_Unknown__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
 *     __pyx_result = Unknown.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Unknown__set_state(<Unknown> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Unknown__set_state(<Unknown> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Unknown__set_state(Unknown __pyx_result, __pyx_state: tuple):
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 0)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_Unknown(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_Unknown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Unknown__set_state(<Unknown> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Unknown__set_state(Unknown __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 0)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_Unknown__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Unknown__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Unknown__set_state(Unknown __pyx_result, __pyx_state: tuple):
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 0)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 0); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 12, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_Unknown__set_state(<Unknown> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Unknown__set_state(Unknown __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 0)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_Unknown__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_MessageCollection(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xf5cccfb, 0x17f3467, 0xde70938, b'messages')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_15__pyx_unpickle_MessageCollection(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_15__pyx_unpickle_MessageCollection = {"__pyx_unpickle_MessageCollection", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_15__pyx_unpickle_MessageCollection, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_15__pyx_unpickle_MessageCollection(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_MessageCollection (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_MessageCollection", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_MessageCollection", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_MessageCollection", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_MessageCollection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_14__pyx_unpickle_MessageCollection(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_14__pyx_unpickle_MessageCollection(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_MessageCollection", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_MessageCollection(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xf5cccfb, 0x17f3467, 0xde70938, b'messages')             # <<<<<<<<<<<<<<
 *     __pyx_result = MessageCollection.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0xf5cccfb, 0x17f3467, 0xde70938, __pyx_k_messages); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xf5cccfb, 0x17f3467, 0xde70938, b'messages')
 *     __pyx_result = MessageCollection.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_MessageCollection__set_state(<MessageCollection> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xf5cccfb, 0x17f3467, 0xde70938, b'messages')
 *     __pyx_result = MessageCollection.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_MessageCollection__set_state(<MessageCollection> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = MessageCollection.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_MessageCollection__set_state(<MessageCollection> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_MessageCollection__set_state(MessageCollection __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_MessageCollection__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xf5cccfb, 0x17f3467, 0xde70938, b'messages')
 *     __pyx_result = MessageCollection.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_MessageCollection__set_state(<MessageCollection> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_MessageCollection__set_state(<MessageCollection> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_MessageCollection__set_state(MessageCollection __pyx_result, __pyx_state: tuple):
 *     __pyx_result.messages = __pyx_state[0]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_MessageCollection(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xf5cccfb, 0x17f3467, 0xde70938, b'messages')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_MessageCollection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_MessageCollection__set_state(<MessageCollection> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_MessageCollection__set_state(MessageCollection __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.messages = __pyx_state[0]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 1)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_MessageCollection__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_MessageCollection__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_MessageCollection__set_state(MessageCollection __pyx_result, __pyx_state: tuple):
 *     __pyx_result.messages = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 1)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->messages);
  __Pyx_DECREF(__pyx_v___pyx_result->messages);
  __pyx_v___pyx_result->messages = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_MessageCollection__set_state(MessageCollection __pyx_result, __pyx_state: tuple):
 *     __pyx_result.messages = __pyx_state[0]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 1)             # <<<<<<<<<<<<<<
*/
  __pyx_t_2 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_MessageCollection__set_state(<MessageCollection> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_MessageCollection__set_state(MessageCollection __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.messages = __pyx_state[0]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 1)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_MessageCollection__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_AssignmentCollector(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x2ddb615, 0x14033f8, 0xdf44812, b'access_path, assignments, dispatch_table')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17__pyx_unpickle_AssignmentCollector(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_17__pyx_unpickle_AssignmentCollector = {"__pyx_unpickle_AssignmentCollector", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_17__pyx_unpickle_AssignmentCollector, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_17__pyx_unpickle_AssignmentCollector(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_AssignmentCollector (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_AssignmentCollector", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_AssignmentCollector", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_AssignmentCollector", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_AssignmentCollector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_16__pyx_unpickle_AssignmentCollector(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_16__pyx_unpickle_AssignmentCollector(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_AssignmentCollector", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_AssignmentCollector(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x2ddb615, 0x14033f8, 0xdf44812, b'access_path, assignments, dispatch_table')             # <<<<<<<<<<<<<<
 *     __pyx_result = AssignmentCollector.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0x2ddb615, 0x14033f8, 0xdf44812, __pyx_k_access_path_assignments_dispatch); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x2ddb615, 0x14033f8, 0xdf44812, b'access_path, assignments, dispatch_table')
 *     __pyx_result = AssignmentCollector.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AssignmentCollector__set_state(<AssignmentCollector> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x2ddb615, 0x14033f8, 0xdf44812, b'access_path, assignments, dispatch_table')
 *     __pyx_result = AssignmentCollector.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_AssignmentCollector__set_state(<AssignmentCollector> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = AssignmentCollector.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AssignmentCollector__set_state(<AssignmentCollector> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_AssignmentCollector__set_state(AssignmentCollector __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_AssignmentCollector__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x2ddb615, 0x14033f8, 0xdf44812, b'access_path, assignments, dispatch_table')
 *     __pyx_result = AssignmentCollector.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_AssignmentCollector__set_state(<AssignmentCollector> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AssignmentCollector__set_state(<AssignmentCollector> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_AssignmentCollector__set_state(AssignmentCollector __pyx_result, __pyx_state: tuple):
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.assignments = __pyx_state[1]; __pyx_result.dispatch_table = __pyx_state[2]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_AssignmentCollector(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x2ddb615, 0x14033f8, 0xdf44812, b'access_path, assignments, dispatch_table')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_AssignmentCollector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_AssignmentCollector__set_state(<AssignmentCollector> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_AssignmentCollector__set_state(AssignmentCollector __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.assignments = __pyx_state[1]; __pyx_result.dispatch_table = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_AssignmentCollector__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_AssignmentCollector__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_AssignmentCollector__set_state(AssignmentCollector __pyx_result, __pyx_state: tuple):
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.assignments = __pyx_state[1]; __pyx_result.dispatch_table = __pyx_state[2]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.access_path);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.access_path);
  __pyx_v___pyx_result->__pyx_base.access_path = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->assignments);
  __Pyx_DECREF(__pyx_v___pyx_result->assignments);
  __pyx_v___pyx_result->assignments = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.dispatch_table);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.dispatch_table);
  __pyx_v___pyx_result->__pyx_base.dispatch_table = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_AssignmentCollector__set_state(AssignmentCollector __pyx_result, __pyx_state: tuple):
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.assignments = __pyx_state[1]; __pyx_result.dispatch_table = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)             # <<<<<<<<<<<<<<
*/
  __pyx_t_2 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_AssignmentCollector__set_state(<AssignmentCollector> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_AssignmentCollector__set_state(AssignmentCollector __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.assignments = __pyx_state[1]; __pyx_result.dispatch_table = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_AssignmentCollector__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ControlFlowAnalysis(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe8722d7, 0x70a7e04, 0x46831eb, b'access_path, constant_folder, context, current_directives, dispatch_table, env, flow, gv_ctx, in_inplace_assignment, object_expr, reductions, stack')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19__pyx_unpickle_ControlFlowAnalysis(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_11FlowControl_19__pyx_unpickle_ControlFlowAnalysis = {"__pyx_unpickle_ControlFlowAnalysis", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_19__pyx_unpickle_ControlFlowAnalysis, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_11FlowControl_19__pyx_unpickle_ControlFlowAnalysis(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlFlowAnalysis (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_ControlFlowAnalysis", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ControlFlowAnalysis", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ControlFlowAnalysis", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlFlowAnalysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_11FlowControl_18__pyx_unpickle_ControlFlowAnalysis(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_11FlowControl_18__pyx_unpickle_ControlFlowAnalysis(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlFlowAnalysis", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_ControlFlowAnalysis(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe8722d7, 0x70a7e04, 0x46831eb, b'access_path, constant_folder, context, current_directives, dispatch_table, env, flow, gv_ctx, in_inplace_assignment, object_expr, reductions, stack')             # <<<<<<<<<<<<<<
 *     __pyx_result = ControlFlowAnalysis.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0xe8722d7, 0x70a7e04, 0x46831eb, __pyx_k_access_path_constant_folder_cont); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe8722d7, 0x70a7e04, 0x46831eb, b'access_path, constant_folder, context, current_directives, dispatch_table, env, flow, gv_ctx, in_inplace_assignment, object_expr, reductions, stack')
 *     __pyx_result = ControlFlowAnalysis.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlFlowAnalysis__set_state(<ControlFlowAnalysis> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe8722d7, 0x70a7e04, 0x46831eb, b'access_path, constant_folder, context, current_directives, dispatch_table, env, flow, gv_ctx, in_inplace_assignment, object_expr, reductions, stack')
 *     __pyx_result = ControlFlowAnalysis.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ControlFlowAnalysis__set_state(<ControlFlowAnalysis> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = ControlFlowAnalysis.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlFlowAnalysis__set_state(<ControlFlowAnalysis> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlowAnalysis__set_state(ControlFlowAnalysis __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlFlowAnalysis__set_state(((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe8722d7, 0x70a7e04, 0x46831eb, b'access_path, constant_folder, context, current_directives, dispatch_table, env, flow, gv_ctx, in_inplace_assignment, object_expr, reductions, stack')
 *     __pyx_result = ControlFlowAnalysis.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ControlFlowAnalysis__set_state(<ControlFlowAnalysis> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ControlFlowAnalysis__set_state(<ControlFlowAnalysis> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ControlFlowAnalysis__set_state(ControlFlowAnalysis __pyx_result, __pyx_state: tuple):
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.constant_folder = __pyx_state[1]; __pyx_result.context = __pyx_state[2]; __pyx_result.current_directives = __pyx_state[3]; __pyx_result.dispatch_table = __pyx_state[4]; __pyx_result.env = __pyx_state[5]; __pyx_result.flow = __pyx_state[6]; __pyx_result.gv_ctx = __pyx_state[7]; __pyx_result.in_inplace_assignment = __pyx_state[8]; __pyx_result.object_expr = __pyx_state[9]; __pyx_result.reductions = __pyx_state[10]; __pyx_result.stack = __pyx_state[11]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ControlFlowAnalysis(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe8722d7, 0x70a7e04, 0x46831eb, b'access_path, constant_folder, context, current_directives, dispatch_table, env, flow, gv_ctx, in_inplace_assignment, object_expr, reductions, stack')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlFlowAnalysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ControlFlowAnalysis__set_state(<ControlFlowAnalysis> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlowAnalysis__set_state(ControlFlowAnalysis __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.constant_folder = __pyx_state[1]; __pyx_result.context = __pyx_state[2]; __pyx_result.current_directives = __pyx_state[3]; __pyx_result.dispatch_table = __pyx_state[4]; __pyx_result.env = __pyx_state[5]; __pyx_result.flow = __pyx_state[6]; __pyx_result.gv_ctx = __pyx_state[7]; __pyx_result.in_inplace_assignment = __pyx_state[8]; __pyx_result.object_expr = __pyx_state[9]; __pyx_result.reductions = __pyx_state[10]; __pyx_result.stack = __pyx_state[11]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 12)
*/

static PyObject *__pyx_f_6Cython_8Compiler_11FlowControl___pyx_unpickle_ControlFlowAnalysis__set_state(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ControlFlowAnalysis__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlowAnalysis__set_state(ControlFlowAnalysis __pyx_result, __pyx_state: tuple):
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.constant_folder = __pyx_state[1]; __pyx_result.context = __pyx_state[2]; __pyx_result.current_directives = __pyx_state[3]; __pyx_result.dispatch_table = __pyx_state[4]; __pyx_result.env = __pyx_state[5]; __pyx_result.flow = __pyx_state[6]; __pyx_result.gv_ctx = __pyx_state[7]; __pyx_result.in_inplace_assignment = __pyx_state[8]; __pyx_result.object_expr = __pyx_state[9]; __pyx_result.reductions = __pyx_state[10]; __pyx_result.stack = __pyx_state[11]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 12)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.__pyx_base.__pyx_base.access_path);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.__pyx_base.__pyx_base.access_path);
  __pyx_v___pyx_result->__pyx_base.__pyx_base.__pyx_base.access_path = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->constant_folder);
  __Pyx_DECREF(__pyx_v___pyx_result->constant_folder);
  __pyx_v___pyx_result->constant_folder = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.context);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.context);
  __pyx_v___pyx_result->__pyx_base.context = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.current_directives);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.current_directives);
  __pyx_v___pyx_result->__pyx_base.current_directives = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.__pyx_base.__pyx_base.dispatch_table);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.__pyx_base.__pyx_base.dispatch_table);
  __pyx_v___pyx_result->__pyx_base.__pyx_base.__pyx_base.dispatch_table = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->env);
  __Pyx_DECREF(__pyx_v___pyx_result->env);
  __pyx_v___pyx_result->env = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow))))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v___pyx_result->flow);
  __Pyx_DECREF((PyObject *)__pyx_v___pyx_result->flow);
  __pyx_v___pyx_result->flow = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->gv_ctx);
  __Pyx_DECREF(__pyx_v___pyx_result->gv_ctx);
  __pyx_v___pyx_result->gv_ctx = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->in_inplace_assignment = __pyx_t_2;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->object_expr);
  __Pyx_DECREF(__pyx_v___pyx_result->object_expr);
  __pyx_v___pyx_result->object_expr = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->reductions);
  __Pyx_DECREF(__pyx_v___pyx_result->reductions);
  __pyx_v___pyx_result->reductions = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 11, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->stack);
  __Pyx_DECREF(__pyx_v___pyx_result->stack);
  __pyx_v___pyx_result->stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ControlFlowAnalysis__set_state(ControlFlowAnalysis __pyx_result, __pyx_state: tuple):
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.constant_folder = __pyx_state[1]; __pyx_result.context = __pyx_state[2]; __pyx_result.current_directives = __pyx_state[3]; __pyx_result.dispatch_table = __pyx_state[4]; __pyx_result.env = __pyx_state[5]; __pyx_result.flow = __pyx_state[6]; __pyx_result.gv_ctx = __pyx_state[7]; __pyx_result.in_inplace_assignment = __pyx_state[8]; __pyx_result.object_expr = __pyx_state[9]; __pyx_result.reductions = __pyx_state[10]; __pyx_result.stack = __pyx_state[11]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 12)             # <<<<<<<<<<<<<<
*/
  __pyx_t_3 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 12); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_ControlFlowAnalysis__set_state(<ControlFlowAnalysis> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlowAnalysis__set_state(ControlFlowAnalysis __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.constant_folder = __pyx_state[1]; __pyx_result.context = __pyx_state[2]; __pyx_result.current_directives = __pyx_state[3]; __pyx_result.dispatch_table = __pyx_state[4]; __pyx_result.env = __pyx_state[5]; __pyx_result.flow = __pyx_state[6]; __pyx_result.gv_ctx = __pyx_state[7]; __pyx_result.in_inplace_assignment = __pyx_state[8]; __pyx_result.object_expr = __pyx_state[9]; __pyx_result.reductions = __pyx_state[10]; __pyx_result.stack = __pyx_state[11]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 12)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.FlowControl.__pyx_unpickle_ControlFlowAnalysis__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlBlock;

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlBlock(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)o);
  p->__pyx_vtab = __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlBlock;
  p->children = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->parents = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->positions = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->stats = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->gen = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->bounded = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->i_input = Py_None; Py_INCREF(Py_None);
  p->i_output = Py_None; Py_INCREF(Py_None);
  p->i_gen = Py_None; Py_INCREF(Py_None);
  p->i_kill = Py_None; Py_INCREF(Py_None);
  p->i_state = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlBlock(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlBlock) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->children);
  Py_CLEAR(p->parents);
  Py_CLEAR(p->positions);
  Py_CLEAR(p->stats);
  Py_CLEAR(p->gen);
  Py_CLEAR(p->bounded);
  Py_CLEAR(p->i_input);
  Py_CLEAR(p->i_output);
  Py_CLEAR(p->i_gen);
  Py_CLEAR(p->i_kill);
  Py_CLEAR(p->i_state);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlBlock(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->children) {
    e = (*v)(p->children, a); if (e) return e;
  }
  if (p->parents) {
    e = (*v)(p->parents, a); if (e) return e;
  }
  if (p->positions) {
    e = (*v)(p->positions, a); if (e) return e;
  }
  if (p->stats) {
    e = (*v)(p->stats, a); if (e) return e;
  }
  if (p->gen) {
    e = (*v)(p->gen, a); if (e) return e;
  }
  if (p->bounded) {
    e = (*v)(p->bounded, a); if (e) return e;
  }
  if (p->i_input) {
    e = (*v)(p->i_input, a); if (e) return e;
  }
  if (p->i_output) {
    e = (*v)(p->i_output, a); if (e) return e;
  }
  if (p->i_gen) {
    e = (*v)(p->i_gen, a); if (e) return e;
  }
  if (p->i_kill) {
    e = (*v)(p->i_kill, a); if (e) return e;
  }
  if (p->i_state) {
    e = (*v)(p->i_state, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlBlock(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)o;
  tmp = ((PyObject*)p->children);
  p->children = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->parents);
  p->parents = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->positions);
  p->positions = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->stats);
  p->stats = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->gen);
  p->gen = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->bounded);
  p->bounded = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->i_input);
  p->i_input = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->i_output);
  p->i_output = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->i_gen);
  p->i_gen = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->i_kill);
  p->i_kill = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->i_state);
  p->i_state = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_children(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_children(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8children_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_parents(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_parents(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7parents_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_positions(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_positions(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9positions_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_stats(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_stats(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5stats_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_gen(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_gen(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_3gen_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_bounded(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_bounded(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7bounded_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_input(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_input(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_input_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_output(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_output(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_8i_output_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_gen(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_gen(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_5i_gen_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_kill(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_kill(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_6i_kill_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_state(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_state(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_7i_state_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_ControlBlock[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_9__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_11__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_11FlowControl_ControlBlock[] = {
  {"children", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_children, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_children, 0, 0},
  {"parents", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_parents, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_parents, 0, 0},
  {"positions", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_positions, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_positions, 0, 0},
  {"stats", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_stats, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_stats, 0, 0},
  {"gen", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_gen, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_gen, 0, 0},
  {"bounded", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_bounded, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_bounded, 0, 0},
  {"i_input", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_input, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_input, 0, 0},
  {"i_output", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_output, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_output, 0, 0},
  {"i_gen", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_gen, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_gen, 0, 0},
  {"i_kill", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_kill, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_kill, 0, 0},
  {"i_state", __pyx_getprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_state, __pyx_setprop_6Cython_8Compiler_11FlowControl_12ControlBlock_i_state, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlBlock},
  {Py_tp_doc, (void *)PyDoc_STR("Control flow graph node. Sequence of assignments and name references.\n\n       children  set of children nodes\n       parents   set of parent nodes\n       positions set of position markers\n\n       stats     list of block statements\n       gen       dict of assignments generated by this block\n       bounded   set  of entries that are definitely bounded in this block\n\n       Example:\n\n        a = 1\n        b = a + c # 'c' is already bounded or exception here\n\n        stats = [Assignment(a), NameReference(a), NameReference(c),\n                     Assignment(b)]\n        gen = {Entry(a): Assignment(a), Entry(b): Assignment(b)}\n        bounded = {Entry(a), Entry(c)}\n\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlBlock},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlBlock},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_ControlBlock},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_11FlowControl_ControlBlock},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlBlock},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock_spec = {
  "Cython.Compiler.FlowControl.ControlBlock",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""ControlBlock", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Control flow graph node. Sequence of assignments and name references.\n\n       children  set of children nodes\n       parents   set of parent nodes\n       positions set of position markers\n\n       stats     list of block statements\n       gen       dict of assignments generated by this block\n       bounded   set  of entries that are definitely bounded in this block\n\n       Example:\n\n        a = 1\n        b = a + c # 'c' is already bounded or exception here\n\n        stats = [Assignment(a), NameReference(a), NameReference(c),\n                     Assignment(b)]\n        gen = {Entry(a): Assignment(a), Entry(b): Assignment(b)}\n        bounded = {Entry(a), Entry(c)}\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ExitBlock __pyx_vtable_6Cython_8Compiler_11FlowControl_ExitBlock;

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_ExitBlock(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *p;
  PyObject *o = __pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlBlock(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlBlock*)__pyx_vtabptr_6Cython_8Compiler_11FlowControl_ExitBlock;
  return o;
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_ExitBlock[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_9ExitBlock_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlBlock},
  {Py_tp_doc, (void *)PyDoc_STR("Non-empty exit point block.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlBlock},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlBlock},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_ExitBlock},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_ExitBlock},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock_spec = {
  "Cython.Compiler.FlowControl.ExitBlock",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""ExitBlock", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Non-empty exit point block."), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlBlock, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_ExitBlock, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6Cython_8Compiler_11FlowControl_12ControlBlock_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_ExitBlock, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_NameAssignment(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)o);
  p->lhs = Py_None; Py_INCREF(Py_None);
  p->rhs = Py_None; Py_INCREF(Py_None);
  p->entry = Py_None; Py_INCREF(Py_None);
  p->pos = Py_None; Py_INCREF(Py_None);
  p->refs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->bit = Py_None; Py_INCREF(Py_None);
  p->inferred_type = Py_None; Py_INCREF(Py_None);
  p->rhs_scope = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_NameAssignment(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_NameAssignment) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->lhs);
  Py_CLEAR(p->rhs);
  Py_CLEAR(p->entry);
  Py_CLEAR(p->pos);
  Py_CLEAR(p->refs);
  Py_CLEAR(p->bit);
  Py_CLEAR(p->inferred_type);
  Py_CLEAR(p->rhs_scope);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_NameAssignment(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->lhs) {
    e = (*v)(p->lhs, a); if (e) return e;
  }
  if (p->rhs) {
    e = (*v)(p->rhs, a); if (e) return e;
  }
  if (p->entry) {
    e = (*v)(p->entry, a); if (e) return e;
  }
  if (p->pos) {
    e = (*v)(p->pos, a); if (e) return e;
  }
  if (p->refs) {
    e = (*v)(p->refs, a); if (e) return e;
  }
  if (p->bit) {
    e = (*v)(p->bit, a); if (e) return e;
  }
  if (p->inferred_type) {
    e = (*v)(p->inferred_type, a); if (e) return e;
  }
  if (p->rhs_scope) {
    e = (*v)(p->rhs_scope, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_11FlowControl_NameAssignment(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment *)o;
  tmp = ((PyObject*)p->lhs);
  p->lhs = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->rhs);
  p->rhs = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->entry);
  p->entry = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->pos);
  p->pos = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->refs);
  p->refs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->bit);
  p->bit = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->inferred_type);
  p->inferred_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->rhs_scope);
  p->rhs_scope = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4type_1__get__(o);
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_is_arg(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_is_arg(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_6is_arg_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_is_deletion(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_is_deletion(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11is_deletion_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_lhs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_lhs(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3lhs_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_rhs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_rhs(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3rhs_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_entry(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_entry(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5entry_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3pos_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_refs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_refs(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_4refs_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_bit(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_bit(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3bit_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_inferred_type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_inferred_type(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_13inferred_type_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_rhs_scope(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_rhs_scope(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9rhs_scope_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_NameAssignment[] = {
  {"infer_type", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_5infer_type, METH_NOARGS, 0},
  {"type_dependencies", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_7type_dependencies, METH_NOARGS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_9__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_11__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_11FlowControl_NameAssignment[] = {
  {"type", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_type, 0, 0, 0},
  {"is_arg", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_is_arg, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_is_arg, 0, 0},
  {"is_deletion", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_is_deletion, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_is_deletion, 0, 0},
  {"lhs", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_lhs, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_lhs, 0, 0},
  {"rhs", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_rhs, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_rhs, 0, 0},
  {"entry", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_entry, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_entry, 0, 0},
  {"pos", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_pos, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_pos, 0, 0},
  {"refs", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_refs, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_refs, 0, 0},
  {"bit", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_bit, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_bit, 0, 0},
  {"inferred_type", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_inferred_type, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_inferred_type, 0, 0},
  {"rhs_scope", __pyx_getprop_6Cython_8Compiler_11FlowControl_14NameAssignment_rhs_scope, __pyx_setprop_6Cython_8Compiler_11FlowControl_14NameAssignment_rhs_scope, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_NameAssignment},
  {Py_tp_repr, (void *)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3__repr__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_11FlowControl_NameAssignment},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_11FlowControl_NameAssignment},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_NameAssignment},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_11FlowControl_NameAssignment},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_NameAssignment},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment_spec = {
  "Cython.Compiler.FlowControl.NameAssignment",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""NameAssignment", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_NameAssignment), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_NameAssignment, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_NameAssignment, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_11FlowControl_NameAssignment, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_NameAssignment, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_11FlowControl_NameAssignment, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_11FlowControl_14NameAssignment_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_NameAssignment, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_AssignmentList(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)o);
  p->bit = Py_None; Py_INCREF(Py_None);
  p->mask = Py_None; Py_INCREF(Py_None);
  p->stats = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentList(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentList) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->bit);
  Py_CLEAR(p->mask);
  Py_CLEAR(p->stats);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_AssignmentList(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->bit) {
    e = (*v)(p->bit, a); if (e) return e;
  }
  if (p->mask) {
    e = (*v)(p->mask, a); if (e) return e;
  }
  if (p->stats) {
    e = (*v)(p->stats, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_11FlowControl_AssignmentList(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList *)o;
  tmp = ((PyObject*)p->bit);
  p->bit = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->mask);
  p->mask = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->stats);
  p->stats = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14AssignmentList_bit(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14AssignmentList_bit(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3bit_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14AssignmentList_mask(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14AssignmentList_mask(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_4mask_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_14AssignmentList_stats(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_14AssignmentList_stats(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5stats_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_AssignmentList[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_11FlowControl_AssignmentList[] = {
  {"bit", __pyx_getprop_6Cython_8Compiler_11FlowControl_14AssignmentList_bit, __pyx_setprop_6Cython_8Compiler_11FlowControl_14AssignmentList_bit, 0, 0},
  {"mask", __pyx_getprop_6Cython_8Compiler_11FlowControl_14AssignmentList_mask, __pyx_setprop_6Cython_8Compiler_11FlowControl_14AssignmentList_mask, 0, 0},
  {"stats", __pyx_getprop_6Cython_8Compiler_11FlowControl_14AssignmentList_stats, __pyx_setprop_6Cython_8Compiler_11FlowControl_14AssignmentList_stats, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentList},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_11FlowControl_AssignmentList},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_11FlowControl_AssignmentList},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_AssignmentList},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_11FlowControl_AssignmentList},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_AssignmentList},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList_spec = {
  "Cython.Compiler.FlowControl.AssignmentList",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""AssignmentList", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentList), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentList, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_AssignmentList, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_11FlowControl_AssignmentList, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_AssignmentList, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_11FlowControl_AssignmentList, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_11FlowControl_14AssignmentList_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_AssignmentList, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_AssignmentCollector __pyx_vtable_6Cython_8Compiler_11FlowControl_AssignmentCollector;

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_AssignmentCollector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_11FlowControl_AssignmentCollector;
  p->assignments = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentCollector(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentCollector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->assignments);
  if (PyType_IS_GC(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor)) PyObject_GC_Track(o);
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor)) __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, tp_dealloc, destructor)(o); else
  #endif
  __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentCollector);
}

static int __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_AssignmentCollector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)o;
  #if !CYTHON_USE_MODULE_STATE
  e = 0;
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor)) {
    traverseproc traverse = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, tp_traverse, traverseproc);
    if (traverse) { e = traverse(o, v, a); }
  } else
  #endif
  { e = __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_AssignmentCollector); }
  if (e) return e;
  {
    e = __Pyx_call_type_traverse(o, 0, v, a);
    if (e) return e;
  }
  if (p->assignments) {
    e = (*v)(p->assignments, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_11FlowControl_AssignmentCollector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector *)o;
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor)) {
    inquiry clear = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, tp_clear, inquiry);
    if (clear) clear(o);
  } else
  #endif
  { __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6Cython_8Compiler_11FlowControl_AssignmentCollector); }
  tmp = ((PyObject*)p->assignments);
  p->assignments = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_AssignmentCollector[] = {
  {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_3visit_Node, METH_NOARGS, 0},
  {"visit_SingleAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_5visit_SingleAssignmentNode, METH_O, 0},
  {"visit_CascadedAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_7visit_CascadedAssignmentNode, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_9__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_11__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentCollector},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_11FlowControl_AssignmentCollector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_11FlowControl_AssignmentCollector},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_AssignmentCollector},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_AssignmentCollector},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector_spec = {
  "Cython.Compiler.FlowControl.AssignmentCollector",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""AssignmentCollector", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_AssignmentCollector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_AssignmentCollector, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_AssignmentCollector, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_11FlowControl_AssignmentCollector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_AssignmentCollector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_11FlowControl_19AssignmentCollector_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_AssignmentCollector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlow __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow;

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlFlow(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)o);
  p->__pyx_vtab = __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlow;
  p->blocks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->entries = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->loops = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->exceptions = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->entry_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None); Py_INCREF(Py_None);
  p->exit_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)Py_None); Py_INCREF(Py_None);
  p->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None); Py_INCREF(Py_None);
  p->assmts = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlFlow(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->blocks);
  Py_CLEAR(p->entries);
  Py_CLEAR(p->loops);
  Py_CLEAR(p->exceptions);
  Py_CLEAR(p->entry_point);
  Py_CLEAR(p->exit_point);
  Py_CLEAR(p->block);
  Py_CLEAR(p->assmts);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlFlow(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->blocks) {
    e = (*v)(p->blocks, a); if (e) return e;
  }
  if (p->entries) {
    e = (*v)(p->entries, a); if (e) return e;
  }
  if (p->loops) {
    e = (*v)(p->loops, a); if (e) return e;
  }
  if (p->exceptions) {
    e = (*v)(p->exceptions, a); if (e) return e;
  }
  if (p->entry_point) {
    e = (*v)(((PyObject *)p->entry_point), a); if (e) return e;
  }
  if (p->exit_point) {
    e = (*v)(((PyObject *)p->exit_point), a); if (e) return e;
  }
  if (p->block) {
    e = (*v)(((PyObject *)p->block), a); if (e) return e;
  }
  if (p->assmts) {
    e = (*v)(p->assmts, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlFlow(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)o;
  tmp = ((PyObject*)p->blocks);
  p->blocks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->entries);
  p->entries = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->loops);
  p->loops = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->exceptions);
  p->exceptions = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->entry_point);
  p->entry_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->exit_point);
  p->exit_point = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ExitBlock *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->block);
  p->block = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->assmts);
  p->assmts = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_blocks(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_blocks(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6blocks_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_entries(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_entries(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_7entries_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_loops(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_loops(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5loops_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_exceptions(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_exceptions(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exceptions_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_entry_point(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_entry_point(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_11entry_point_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_exit_point(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_exit_point(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_10exit_point_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_block(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_block(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_5block_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_assmts(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_assmts(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_6assmts_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_in_try_block(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_in_try_block(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_12in_try_block_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_ControlFlow[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_27__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_29__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_11FlowControl_ControlFlow[] = {
  {"blocks", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_blocks, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_blocks, 0, 0},
  {"entries", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_entries, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_entries, 0, 0},
  {"loops", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_loops, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_loops, 0, 0},
  {"exceptions", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_exceptions, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_exceptions, 0, 0},
  {"entry_point", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_entry_point, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_entry_point, 0, 0},
  {"exit_point", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_exit_point, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_exit_point, 0, 0},
  {"block", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_block, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_block, 0, 0},
  {"assmts", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_assmts, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_assmts, 0, 0},
  {"in_try_block", __pyx_getprop_6Cython_8Compiler_11FlowControl_11ControlFlow_in_try_block, __pyx_setprop_6Cython_8Compiler_11FlowControl_11ControlFlow_in_try_block, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlFlow},
  {Py_tp_doc, (void *)PyDoc_STR("Control-flow graph.\n\n       entry_point ControlBlock entry point for this graph\n       exit_point  ControlBlock normal exit point\n       block       ControlBlock current block\n       blocks      set    children nodes\n       entries     set    tracked entries\n       loops       list   stack for loop descriptors\n       exceptions  list   stack for exception descriptors\n       in_try_block  int  track if we're in a try...except or try...finally block\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlFlow},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlFlow},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_ControlFlow},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_11FlowControl_ControlFlow},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlFlow},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow_spec = {
  "Cython.Compiler.FlowControl.ControlFlow",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""ControlFlow", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlFlow, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Control-flow graph.\n\n       entry_point ControlBlock entry point for this graph\n       exit_point  ControlBlock normal exit point\n       block       ControlBlock current block\n       blocks      set    children nodes\n       entries     set    tracked entries\n       loops       list   stack for loop descriptors\n       exceptions  list   stack for exception descriptors\n       in_try_block  int  track if we're in a try...except or try...finally block\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlFlow, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlFlow, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_ControlFlow, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_11FlowControl_ControlFlow, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_11FlowControl_11ControlFlow_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlFlow, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_Uninitialized(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_Uninitialized(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_Uninitialized) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_Uninitialized[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_13Uninitialized_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_13Uninitialized_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_Uninitialized},
  {Py_tp_doc, (void *)PyDoc_STR("Definitely not initialised yet.")},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_Uninitialized},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_Uninitialized},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized_spec = {
  "Cython.Compiler.FlowControl.Uninitialized",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""Uninitialized", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Uninitialized), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_Uninitialized, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  PyDoc_STR("Definitely not initialised yet."), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_Uninitialized, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_Uninitialized, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_Unknown(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_Unknown(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_Unknown) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_Unknown[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_7Unknown_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_7Unknown_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_Unknown_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_Unknown},
  {Py_tp_doc, (void *)PyDoc_STR("Coming from outer closure, might be initialised or not.")},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_Unknown},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_Unknown},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_Unknown_spec = {
  "Cython.Compiler.FlowControl.Unknown",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6Cython_8Compiler_11FlowControl_Unknown_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_Unknown = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""Unknown", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_Unknown), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_Unknown, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  PyDoc_STR("Coming from outer closure, might be initialised or not."), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_Unknown, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_Unknown, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_MessageCollection(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)o);
  p->messages = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_MessageCollection(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_MessageCollection) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->messages);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_MessageCollection(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->messages) {
    e = (*v)(p->messages, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_11FlowControl_MessageCollection(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection *)o;
  tmp = ((PyObject*)p->messages);
  p->messages = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_MessageCollection[] = {
  {"error", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_3error, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"warning", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_5warning, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"report", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_7report, METH_NOARGS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_9__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_11__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_MessageCollection},
  {Py_tp_doc, (void *)PyDoc_STR("Collect error/warnings messages first then sort")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_11FlowControl_MessageCollection},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_11FlowControl_MessageCollection},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_MessageCollection},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_MessageCollection},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection_spec = {
  "Cython.Compiler.FlowControl.MessageCollection",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""MessageCollection", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_MessageCollection), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_MessageCollection, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Collect error/warnings messages first then sort"), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_MessageCollection, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_11FlowControl_MessageCollection, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_MessageCollection, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_11FlowControl_17MessageCollection_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_MessageCollection, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis;

static PyObject *__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis;
  p->gv_ctx = Py_None; Py_INCREF(Py_None);
  p->constant_folder = Py_None; Py_INCREF(Py_None);
  p->reductions = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->env = Py_None; Py_INCREF(Py_None);
  p->flow = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)Py_None); Py_INCREF(Py_None);
  p->object_expr = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->gv_ctx);
  Py_CLEAR(p->constant_folder);
  Py_CLEAR(p->reductions);
  Py_CLEAR(p->stack);
  Py_CLEAR(p->env);
  Py_CLEAR(p->flow);
  Py_CLEAR(p->object_expr);
  if (PyType_IS_GC(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform)) PyObject_GC_Track(o);
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform)) __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform, tp_dealloc, destructor)(o); else
  #endif
  __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis);
}

static int __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)o;
  #if !CYTHON_USE_MODULE_STATE
  e = 0;
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform)) {
    traverseproc traverse = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform, tp_traverse, traverseproc);
    if (traverse) { e = traverse(o, v, a); }
  } else
  #endif
  { e = __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis); }
  if (e) return e;
  {
    e = __Pyx_call_type_traverse(o, 0, v, a);
    if (e) return e;
  }
  if (p->gv_ctx) {
    e = (*v)(p->gv_ctx, a); if (e) return e;
  }
  if (p->constant_folder) {
    e = (*v)(p->constant_folder, a); if (e) return e;
  }
  if (p->reductions) {
    e = (*v)(p->reductions, a); if (e) return e;
  }
  if (p->stack) {
    e = (*v)(p->stack, a); if (e) return e;
  }
  if (p->env) {
    e = (*v)(p->env, a); if (e) return e;
  }
  if (p->flow) {
    e = (*v)(((PyObject *)p->flow), a); if (e) return e;
  }
  if (p->object_expr) {
    e = (*v)(p->object_expr, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *p = (struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *)o;
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform)) {
    inquiry clear = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform, tp_clear, inquiry);
    if (clear) clear(o);
  } else
  #endif
  { __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis); }
  tmp = ((PyObject*)p->gv_ctx);
  p->gv_ctx = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->constant_folder);
  p->constant_folder = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->reductions);
  p->reductions = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->stack);
  p->stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->env);
  p->env = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->flow);
  p->flow = ((struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->object_expr);
  p->object_expr = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis[] = {
  {"find_in_stack", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_1find_in_stack, METH_O, 0},
  {"visit_ModuleNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_3visit_ModuleNode, METH_O, 0},
  {"visit_FuncDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_5visit_FuncDefNode, METH_O, 0},
  {"visit_DefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_7visit_DefNode, METH_O, 0},
  {"visit_GeneratorBodyDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_9visit_GeneratorBodyDefNode, METH_O, 0},
  {"visit_CTypeDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_11visit_CTypeDefNode, METH_O, 0},
  {"visit_FromImportStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_17visit_FromImportStatNode, METH_O, 0},
  {"visit_AssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_19visit_AssignmentNode, METH_O, 0},
  {"visit_SingleAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_21visit_SingleAssignmentNode, METH_O, 0},
  {"visit_CascadedAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_23visit_CascadedAssignmentNode, METH_O, 0},
  {"visit_ParallelAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_25visit_ParallelAssignmentNode, METH_O, 0},
  {"visit_InPlaceAssignmentNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_27visit_InPlaceAssignmentNode, METH_O, 0},
  {"visit_DelStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_29visit_DelStatNode, METH_O, 0},
  {"visit_CArgDeclNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_31visit_CArgDeclNode, METH_O, 0},
  {"visit_NameNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_33visit_NameNode, METH_O, 0},
  {"visit_StatListNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_35visit_StatListNode, METH_O, 0},
  {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_37visit_Node, METH_O, 0},
  {"visit_SizeofVarNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_39visit_SizeofVarNode, METH_O, 0},
  {"visit_TypeidNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_41visit_TypeidNode, METH_O, 0},
  {"visit_IfStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_43visit_IfStatNode, METH_O, 0},
  {"visit_AssertStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_45visit_AssertStatNode, METH_O, __pyx_doc_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_44visit_AssertStatNode},
  {"visit_WhileStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_47visit_WhileStatNode, METH_O, 0},
  {"mark_forloop_target", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_49mark_forloop_target, METH_O, 0},
  {"mark_parallel_forloop_assignment", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_51mark_parallel_forloop_assignment, METH_O, 0},
  {"visit_AsyncForStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_53visit_AsyncForStatNode, METH_O, 0},
  {"visit_ForInStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_55visit_ForInStatNode, METH_O, 0},
  {"_delete_privates", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_57_delete_privates, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"visit_ParallelRangeNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_59visit_ParallelRangeNode, METH_O, 0},
  {"visit_ParallelWithBlockNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_61visit_ParallelWithBlockNode, METH_O, 0},
  {"visit_ForFromStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_63visit_ForFromStatNode, METH_O, 0},
  {"visit_LoopNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_65visit_LoopNode, METH_O, 0},
  {"visit_WithTargetAssignmentStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_67visit_WithTargetAssignmentStatNode, METH_O, 0},
  {"visit_WithStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_69visit_WithStatNode, METH_O, 0},
  {"visit_TryExceptStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_71visit_TryExceptStatNode, METH_O, 0},
  {"visit_TryFinallyStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_73visit_TryFinallyStatNode, METH_O, 0},
  {"visit_RaiseStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_75visit_RaiseStatNode, METH_O, 0},
  {"visit_ReraiseStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_77visit_ReraiseStatNode, METH_O, 0},
  {"visit_ReturnStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_79visit_ReturnStatNode, METH_O, 0},
  {"visit_BreakStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_81visit_BreakStatNode, METH_O, 0},
  {"visit_ContinueStatNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_83visit_ContinueStatNode, METH_O, 0},
  {"visit_ComprehensionNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_85visit_ComprehensionNode, METH_O, 0},
  {"visit_ScopedExprNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_87visit_ScopedExprNode, METH_O, 0},
  {"visit_PyClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_89visit_PyClassDefNode, METH_O, 0},
  {"visit_CClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_91visit_CClassDefNode, METH_O, 0},
  {"visit_AmpersandNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_93visit_AmpersandNode, METH_O, 0},
  {"visit_BoolBinopNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_95visit_BoolBinopNode, METH_O, 0},
  {"visit_CondExprNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_97visit_CondExprNode, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_99__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_101__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis_spec = {
  "Cython.Compiler.FlowControl.ControlFlowAnalysis",
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.FlowControl.""ControlFlowAnalysis", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6Cython_8Compiler_11FlowControl_PyrexTypes = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_Nodes = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_Builtin = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_Options = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_InternalError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_error = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_warning = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_fake_rhs_expr = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlBlock = &__pyx_vtable_6Cython_8Compiler_11FlowControl_ControlBlock;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlBlock.empty = (int (*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_empty;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlBlock.detach = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_detach;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlBlock.add_child = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_12ControlBlock_add_child;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock)) __PYX_ERR(0, 34, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock = &__pyx_type_6Cython_8Compiler_11FlowControl_ControlBlock;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlBlock) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ControlBlock, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ExitBlock = &__pyx_vtable_6Cython_8Compiler_11FlowControl_ExitBlock;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ExitBlock.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlBlock;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ExitBlock.__pyx_base.empty = (int (*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlBlock *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_9ExitBlock_empty;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock)) __PYX_ERR(0, 89, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock) < (0)) __PYX_ERR(0, 89, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock = &__pyx_type_6Cython_8Compiler_11FlowControl_ExitBlock;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock) < (0)) __PYX_ERR(0, 89, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock, __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ExitBlock) < (0)) __PYX_ERR(0, 89, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock) < (0)) __PYX_ERR(0, 89, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ExitBlock, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock) < (0)) __PYX_ERR(0, 89, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock) < (0)) __PYX_ERR(0, 89, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment)) __PYX_ERR(0, 328, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment) < (0)) __PYX_ERR(0, 328, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment = &__pyx_type_6Cython_8Compiler_11FlowControl_NameAssignment;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment) < (0)) __PYX_ERR(0, 328, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NameAssignment, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment) < (0)) __PYX_ERR(0, 328, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment) < (0)) __PYX_ERR(0, 328, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList)) __PYX_ERR(0, 96, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList) < (0)) __PYX_ERR(0, 96, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList = &__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentList;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList) < (0)) __PYX_ERR(0, 96, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_AssignmentList, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList) < (0)) __PYX_ERR(0, 96, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList) < (0)) __PYX_ERR(0, 96, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("Cython.Compiler.Visitor"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Visitor", "TreeVisitor",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_11FlowControl_AssignmentCollector = &__pyx_vtable_6Cython_8Compiler_11FlowControl_AssignmentCollector;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_AssignmentCollector.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector)) __PYX_ERR(0, 680, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector) < (0)) __PYX_ERR(0, 680, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector = &__pyx_type_6Cython_8Compiler_11FlowControl_AssignmentCollector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector) < (0)) __PYX_ERR(0, 680, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector, __pyx_vtabptr_6Cython_8Compiler_11FlowControl_AssignmentCollector) < (0)) __PYX_ERR(0, 680, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector) < (0)) __PYX_ERR(0, 680, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_AssignmentCollector, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector) < (0)) __PYX_ERR(0, 680, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector) < (0)) __PYX_ERR(0, 680, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlow = &__pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.newblock = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock *__pyx_optional_args))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_newblock;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.nextblock = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock *__pyx_optional_args))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_nextblock;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.is_tracked = (int (*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_tracked;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.is_statically_assigned = (int (*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_is_statically_assigned;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.mark_position = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_position;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.mark_assignment = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment *__pyx_optional_args))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_assignment;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.mark_argument = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_argument;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.mark_deletion = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_deletion;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.mark_reference = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_mark_reference;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.normalize = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_normalize;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.initialize = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_initialize;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.map_one = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_map_one;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlow.reaching_definitions = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlow *))__pyx_f_6Cython_8Compiler_11FlowControl_11ControlFlow_reaching_definitions;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow = &__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlow;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlow) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ControlFlow, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized)) __PYX_ERR(0, 399, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized) < (0)) __PYX_ERR(0, 399, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized = &__pyx_type_6Cython_8Compiler_11FlowControl_Uninitialized;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized) < (0)) __PYX_ERR(0, 399, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Uninitialized, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized) < (0)) __PYX_ERR(0, 399, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized) < (0)) __PYX_ERR(0, 399, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_Unknown_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown)) __PYX_ERR(0, 403, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_Unknown_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown) < (0)) __PYX_ERR(0, 403, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown = &__pyx_type_6Cython_8Compiler_11FlowControl_Unknown;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown) < (0)) __PYX_ERR(0, 403, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Unknown, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown) < (0)) __PYX_ERR(0, 403, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown) < (0)) __PYX_ERR(0, 403, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection)) __PYX_ERR(0, 521, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection) < (0)) __PYX_ERR(0, 521, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection = &__pyx_type_6Cython_8Compiler_11FlowControl_MessageCollection;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection) < (0)) __PYX_ERR(0, 521, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_MessageCollection, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection) < (0)) __PYX_ERR(0, 521, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection) < (0)) __PYX_ERR(0, 521, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Visitor", "CythonTransform",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis = &__pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis.mark_assignment = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment *__pyx_optional_args))__pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_assignment;
  __pyx_vtable_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis.mark_position = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_mark_position;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis)) __PYX_ERR(0, 696, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis = &__pyx_type_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_vtabptr_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("Cython.Compiler.Visitor"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Visitor", "VisitorTransform",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform) __PYX_ERR(3, 15, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform)) __PYX_ERR(3, 15, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Visitor", "ScopeTrackingTransform",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform) __PYX_ERR(3, 25, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_ScopeTrackingTransform = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_7Visitor_ScopeTrackingTransform)) __PYX_ERR(3, 25, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Visitor", "EnvTransform",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform) __PYX_ERR(3, 30, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_EnvTransform = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_7Visitor_EnvTransform)) __PYX_ERR(3, 30, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Visitor", "MethodDispatcherTransform",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform) __PYX_ERR(3, 33, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_MethodDispatcherTransform = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_7Visitor_MethodDispatcherTransform)) __PYX_ERR(3, 33, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Visitor", "RecursiveNodeReplacer",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer) __PYX_ERR(3, 47, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer)) __PYX_ERR(3, 47, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Visitor", "NodeFinder",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder) __PYX_ERR(3, 51, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_NodeFinder = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_NodeFinder*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_7Visitor_NodeFinder)) __PYX_ERR(3, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_FlowControl(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_FlowControl},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "FlowControl",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit_FlowControl(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_FlowControl(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_FlowControl(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'FlowControl' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "FlowControl" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit_FlowControl", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_Cython__Compiler__FlowControl) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "Cython.Compiler.FlowControl")) {
      if (unlikely((PyDict_SetItemString(modules, "Cython.Compiler.FlowControl", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  (void)__Pyx_modinit_function_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  (void)__Pyx_modinit_function_import_code(__pyx_mstate);
  /*--- Execution code ---*/

  /* "Cython/Compiler/FlowControl.py":10
 *                fake_rhs_expr=object, TypedExprNode=object)
 * 
 * from . import Builtin             # <<<<<<<<<<<<<<
 * from . import ExprNodes
 * from . import Nodes
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Builtin};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__2, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 10, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Builtin};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 10, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_Builtin);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_Builtin, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":11
 * 
 * from . import Builtin
 * from . import ExprNodes             # <<<<<<<<<<<<<<
 * from . import Nodes
 * from . import Options
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ExprNodes};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__2, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 11, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ExprNodes};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 11, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":12
 * from . import Builtin
 * from . import ExprNodes
 * from . import Nodes             # <<<<<<<<<<<<<<
 * from . import Options
 * from . import PyrexTypes
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Nodes};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__2, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Nodes};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 12, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_Nodes);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_Nodes, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":13
 * from . import ExprNodes
 * from . import Nodes
 * from . import Options             # <<<<<<<<<<<<<<
 * from . import PyrexTypes
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Options};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__2, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Options};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_Options);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_Options, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":14
 * from . import Nodes
 * from . import Options
 * from . import PyrexTypes             # <<<<<<<<<<<<<<
 * 
 * from .Visitor import TreeVisitor, CythonTransform
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PyrexTypes};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__2, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PyrexTypes};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_PyrexTypes);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_PyrexTypes, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":16
 * from . import PyrexTypes
 * 
 * from .Visitor import TreeVisitor, CythonTransform             # <<<<<<<<<<<<<<
 * from .Errors import error, warning, InternalError
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_TreeVisitor,__pyx_mstate_global->__pyx_n_u_CythonTransform};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Visitor, __pyx_imported_names, 2, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Visitor, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":17
 * 
 * from .Visitor import TreeVisitor, CythonTransform
 * from .Errors import error, warning, InternalError             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_error,__pyx_mstate_global->__pyx_n_u_warning,__pyx_mstate_global->__pyx_n_u_InternalError};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Errors, __pyx_imported_names, 3, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Errors, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_error,__pyx_mstate_global->__pyx_n_u_warning,__pyx_mstate_global->__pyx_n_u_InternalError};
    for (__pyx_t_3=0; __pyx_t_3 < 3; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_error);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_error, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        case 1:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_warning);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_warning, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        case 2:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_InternalError);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_InternalError, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":20
 * 
 * 
 * class TypedExprNode(ExprNodes.ExprNode):             # <<<<<<<<<<<<<<
 *     # Used for declaring assignments of a specified type without a known entry.
 *     def __init__(self, type, may_be_none=None, pos=None):
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_ExprNodes, __pyx_mstate_global->__pyx_n_u_ExprNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_Pack(1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_5, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_TypedExprNode, __pyx_mstate_global->__pyx_n_u_TypedExprNode, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__pyx_t_2 != __pyx_t_4) {
    if (unlikely((PyDict_SetItemString(__pyx_t_6, "__orig_bases__", __pyx_t_4) < 0))) __PYX_ERR(0, 20, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "Cython/Compiler/FlowControl.py":22
 * class TypedExprNode(ExprNodes.ExprNode):
 *     # Used for declaring assignments of a specified type without a known entry.
 *     def __init__(self, type, may_be_none=None, pos=None):             # <<<<<<<<<<<<<<
 *         super().__init__(pos)
 *         self.type = type
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_13TypedExprNode_1__init__, 0, __pyx_mstate_global->__pyx_n_u_TypedExprNode___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  PyList_Append(__pyx_t_4, __pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[6]);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_7) < (0)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":27
 *         self._may_be_none = may_be_none
 * 
 *     def may_be_none(self):             # <<<<<<<<<<<<<<
 *         return self._may_be_none != False
 * 
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_13TypedExprNode_3may_be_none, 0, __pyx_mstate_global->__pyx_n_u_TypedExprNode_may_be_none, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_may_be_none, __pyx_t_7) < (0)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":20
 * 
 * 
 * class TypedExprNode(ExprNodes.ExprNode):             # <<<<<<<<<<<<<<
 *     # Used for declaring assignments of a specified type without a known entry.
 *     def __init__(self, type, may_be_none=None, pos=None):
*/
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_TypedExprNode, __pyx_t_2, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_CyFunction_InitClassCell(__pyx_t_4, __pyx_t_7) < (0)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":31
 * 
 * # Fake rhs to silence "unused variable" warning
 * fake_rhs_expr = TypedExprNode(PyrexTypes.unspecified_type)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode);
  __pyx_t_6 = __pyx_v_6Cython_8Compiler_11FlowControl_TypedExprNode; 
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_11FlowControl_PyrexTypes, __pyx_mstate_global->__pyx_n_u_unspecified_type); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 31, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_11FlowControl_fake_rhs_expr);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_11FlowControl_fake_rhs_expr, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":72
 *         self.i_state = 0
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         return (not self.stats and not self.positions)
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_3empty, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlBlock_empty, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_mstate_global->__pyx_n_u_empty, __pyx_t_2) < (0)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":75
 *         return (not self.stats and not self.positions)
 * 
 *     def detach(self):             # <<<<<<<<<<<<<<
 *         """Detach block from parents and children."""
 *         for child in self.children:
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_5detach, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlBlock_detach, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_mstate_global->__pyx_n_u_detach, __pyx_t_2) < (0)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":84
 *         self.children.clear()
 * 
 *     def add_child(self, block):             # <<<<<<<<<<<<<<
 *         self.children.add(block)
 *         block.parents.add(self)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_7add_child, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlBlock_add_child, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_mstate_global->__pyx_n_u_add_child, __pyx_t_2) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlBlock___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlBlock, (type(self), 0x64ddf03, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlBlock__set_state(self, __pyx_state)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_12ControlBlock_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlBlock___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlBlock, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":92
 *     """Non-empty exit point block."""
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         return False
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9ExitBlock_1empty, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ExitBlock_empty, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock, __pyx_mstate_global->__pyx_n_u_empty, __pyx_t_2) < (0)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9ExitBlock_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ExitBlock___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ExitBlock, (type(self), 0x64ddf03, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ExitBlock__set_state(self, __pyx_state)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9ExitBlock_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ExitBlock___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ExitBlock, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_14AssignmentList_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_AssignmentList___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_AssignmentList, (type(self), 0x9a2d7cf, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_AssignmentList__set_state(self, __pyx_state)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_14AssignmentList_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_AssignmentList___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentList, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":126
 *         self.in_try_block = 0
 * 
 *     def newblock(self, parent=None):             # <<<<<<<<<<<<<<
 *         """Create floating block linked to `parent` if given.
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_3newblock, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_newblock, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[7]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_newblock, __pyx_t_2) < (0)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":137
 *         return block
 * 
 *     def nextblock(self, parent=None):             # <<<<<<<<<<<<<<
 *         """Create block children block linked to current or `parent` if given.
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_5nextblock, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_nextblock, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[7]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_nextblock, __pyx_t_2) < (0)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":151
 *         return self.block
 * 
 *     def is_tracked(self, entry):             # <<<<<<<<<<<<<<
 *         if entry.is_anonymous:
 *             return False
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_7is_tracked, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_is_tracked, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_is_tracked, __pyx_t_2) < (0)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":158
 *                 entry.error_on_uninitialized)
 * 
 *     def is_statically_assigned(self, entry):             # <<<<<<<<<<<<<<
 *         if (entry.is_local and entry.is_variable and
 *                 (entry.type.is_struct_or_union or
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_9is_statically_assigned, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_is_statically_assign, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_is_statically_assigned, __pyx_t_2) < (0)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":169
 *         return False
 * 
 *     def mark_position(self, node):             # <<<<<<<<<<<<<<
 *         """Mark position, will be used to draw graph nodes."""
 *         if self.block:
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_11mark_position, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_mark_position, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_mark_position, __pyx_t_2) < (0)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":174
 *             self.block.positions.add(node.pos[:2])
 * 
 *     def mark_assignment(self, lhs, rhs, entry, rhs_scope=None):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameAssignment(lhs, rhs, entry, rhs_scope=rhs_scope)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_13mark_assignment, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_mark_assignment, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[7]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_mark_assignment, __pyx_t_2) < (0)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":181
 *             self.entries.add(entry)
 * 
 *     def mark_argument(self, lhs, rhs, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = Argument(lhs, rhs, entry)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_15mark_argument, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_mark_argument, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_mark_argument, __pyx_t_2) < (0)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":188
 *             self.entries.add(entry)
 * 
 *     def mark_deletion(self, node, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             assignment = NameDeletion(node, entry)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_17mark_deletion, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_mark_deletion, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_mark_deletion, __pyx_t_2) < (0)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":195
 *             self.entries.add(entry)
 * 
 *     def mark_reference(self, node, entry):             # <<<<<<<<<<<<<<
 *         if self.block and self.is_tracked(entry):
 *             self.block.stats.append(NameReference(node, entry))
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_19mark_reference, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_mark_reference, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_mark_reference, __pyx_t_2) < (0)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":205
 *             self.entries.add(entry)
 * 
 *     def normalize(self):             # <<<<<<<<<<<<<<
 *         """Delete unreachable and orphan blocks."""
 *         queue = {self.entry_point}
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_21normalize, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_normalize, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_normalize, __pyx_t_2) < (0)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":233
 *         self.blocks -= unreachable
 * 
 *     def initialize(self):             # <<<<<<<<<<<<<<
 *         """Set initial state, map assignments to bits."""
 *         self.assmts = {}
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_23initialize, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_initialize, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_initialize, __pyx_t_2) < (0)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":271
 *         self.entry_point.i_output = self.entry_point.i_gen
 * 
 *     def map_one(self, istate, entry):             # <<<<<<<<<<<<<<
 *         ret = set()
 *         assmts: AssignmentList = self.assmts[entry]
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_25map_one, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow_map_one, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_map_one, __pyx_t_2) < (0)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_27__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlFlow, (type(self), 0xc9527a2, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlFlow__set_state(self, __pyx_state)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11ControlFlow_29__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlow___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlow, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":307
 * 
 * 
 * class LoopDescr:             # <<<<<<<<<<<<<<
 *     def __init__(self, next_block, loop_block):
 *         self.next_block = next_block
*/
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_LoopDescr, __pyx_mstate_global->__pyx_n_u_LoopDescr, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, (PyObject *) NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "Cython/Compiler/FlowControl.py":308
 * 
 * class LoopDescr:
 *     def __init__(self, next_block, loop_block):             # <<<<<<<<<<<<<<
 *         self.next_block = next_block
 *         self.loop_block = loop_block
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9LoopDescr_1__init__, 0, __pyx_mstate_global->__pyx_n_u_LoopDescr___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_6) < (0)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":307
 * 
 * 
 * class LoopDescr:             # <<<<<<<<<<<<<<
 *     def __init__(self, next_block, loop_block):
 *         self.next_block = next_block
*/
  __pyx_t_6 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_LoopDescr, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_LoopDescr, __pyx_t_6) < (0)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":314
 * 
 * 
 * class ExceptionDescr:             # <<<<<<<<<<<<<<
 *     """Exception handling helper.
 * 
*/
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_ExceptionDescr, __pyx_mstate_global->__pyx_n_u_ExceptionDescr, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_kp_u_Exception_handling_helper_entry); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "Cython/Compiler/FlowControl.py":322
 *     """
 * 
 *     def __init__(self, entry_point, finally_enter=None, finally_exit=None):             # <<<<<<<<<<<<<<
 *         self.entry_point = entry_point
 *         self.finally_enter = finally_enter
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_14ExceptionDescr_1__init__, 0, __pyx_mstate_global->__pyx_n_u_ExceptionDescr___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[6]);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_6) < (0)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":314
 * 
 * 
 * class ExceptionDescr:             # <<<<<<<<<<<<<<
 *     """Exception handling helper.
 * 
*/
  __pyx_t_6 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_ExceptionDescr, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_ExceptionDescr, __pyx_t_6) < (0)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":347
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         self.inferred_type = self.rhs.infer_type(self.rhs_scope or self.entry.scope)
 *         return self.inferred_type
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_14NameAssignment_5infer_type, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NameAssignment_infer_type, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment, __pyx_mstate_global->__pyx_n_u_infer_type, __pyx_t_2) < (0)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":351
 *         return self.inferred_type
 * 
 *     def type_dependencies(self):             # <<<<<<<<<<<<<<
 *         return self.rhs.type_dependencies(self.rhs_scope or self.entry.scope)
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_14NameAssignment_7type_dependencies, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NameAssignment_type_dependencies, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment, __pyx_mstate_global->__pyx_n_u_type_dependencies, __pyx_t_2) < (0)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_14NameAssignment_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NameAssignment___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_NameAssignment, (type(self), 0x09885d0, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_NameAssignment__set_state(self, __pyx_state)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_14NameAssignment_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NameAssignment___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":361
 * 
 * 
 * class StaticAssignment(NameAssignment):             # <<<<<<<<<<<<<<
 *     """Initialised at declaration time, e.g. stack allocation."""
 *     def __init__(self, entry):
*/
  __pyx_t_2 = PyTuple_Pack(1, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_CalculateMetaclass(NULL, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare(__pyx_t_7, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_StaticAssignment, __pyx_mstate_global->__pyx_n_u_StaticAssignment, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_kp_u_Initialised_at_declaration_time); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__pyx_t_6 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_5, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 361, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "Cython/Compiler/FlowControl.py":363
 * class StaticAssignment(NameAssignment):
 *     """Initialised at declaration time, e.g. stack allocation."""
 *     def __init__(self, entry):             # <<<<<<<<<<<<<<
 *         if not entry.type.is_pyobject:
 *             may_be_none = False
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_16StaticAssignment_1__init__, 0, __pyx_mstate_global->__pyx_n_u_StaticAssignment___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  PyList_Append(__pyx_t_2, __pyx_t_4);
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_4) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":372
 *         super().__init__(lhs, lhs, entry)
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         return self.entry.type
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_16StaticAssignment_3infer_type, 0, __pyx_mstate_global->__pyx_n_u_StaticAssignment_infer_type, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_infer_type, __pyx_t_4) < (0)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":375
 *         return self.entry.type
 * 
 *     def type_dependencies(self):             # <<<<<<<<<<<<<<
 *         return ()
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_16StaticAssignment_5type_dependencies, 0, __pyx_mstate_global->__pyx_n_u_StaticAssignment_type_dependenci, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[34])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_type_dependencies, __pyx_t_4) < (0)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":361
 * 
 * 
 * class StaticAssignment(NameAssignment):             # <<<<<<<<<<<<<<
 *     """Initialised at declaration time, e.g. stack allocation."""
 *     def __init__(self, entry):
*/
  __pyx_t_4 = __Pyx_Py3ClassCreate(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_StaticAssignment, __pyx_t_6, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_CyFunction_InitClassCell(__pyx_t_2, __pyx_t_4) < (0)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_StaticAssignment, __pyx_t_4) < (0)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":379
 * 
 * 
 * class Argument(NameAssignment):             # <<<<<<<<<<<<<<
 *     def __init__(self, lhs, rhs, entry):
 *         NameAssignment.__init__(self, lhs, rhs, entry)
*/
  __pyx_t_6 = PyTuple_Pack(1, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PEP560_update_bases(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_CalculateMetaclass(NULL, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_5, __pyx_t_7, __pyx_mstate_global->__pyx_n_u_Argument, __pyx_mstate_global->__pyx_n_u_Argument, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__pyx_t_7 != __pyx_t_6) {
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_t_6) < 0))) __PYX_ERR(0, 379, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":380
 * 
 * class Argument(NameAssignment):
 *     def __init__(self, lhs, rhs, entry):             # <<<<<<<<<<<<<<
 *         NameAssignment.__init__(self, lhs, rhs, entry)
 *         self.is_arg = True
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_8Argument_1__init__, 0, __pyx_mstate_global->__pyx_n_u_Argument___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[35])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_6) < (0)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":379
 * 
 * 
 * class Argument(NameAssignment):             # <<<<<<<<<<<<<<
 *     def __init__(self, lhs, rhs, entry):
 *         NameAssignment.__init__(self, lhs, rhs, entry)
*/
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Argument, __pyx_t_7, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_Argument, __pyx_t_6) < (0)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":385
 * 
 * 
 * class NameDeletion(NameAssignment):             # <<<<<<<<<<<<<<
 *     def __init__(self, lhs, entry):
 *         NameAssignment.__init__(self, lhs, lhs, entry)
*/
  __pyx_t_7 = PyTuple_Pack(1, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_NameAssignment)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_4, __pyx_t_5, __pyx_mstate_global->__pyx_n_u_NameDeletion, __pyx_mstate_global->__pyx_n_u_NameDeletion, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__pyx_t_5 != __pyx_t_7) {
    if (unlikely((PyDict_SetItemString(__pyx_t_6, "__orig_bases__", __pyx_t_7) < 0))) __PYX_ERR(0, 385, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":386
 * 
 * class NameDeletion(NameAssignment):
 *     def __init__(self, lhs, entry):             # <<<<<<<<<<<<<<
 *         NameAssignment.__init__(self, lhs, lhs, entry)
 *         self.is_deletion = True
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_12NameDeletion_1__init__, 0, __pyx_mstate_global->__pyx_n_u_NameDeletion___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[36])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_7) < (0)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":390
 *         self.is_deletion = True
 * 
 *     def infer_type(self):             # <<<<<<<<<<<<<<
 *         inferred_type = self.rhs.infer_type(self.entry.scope)
 *         if (not inferred_type.is_pyobject
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_12NameDeletion_3infer_type, 0, __pyx_mstate_global->__pyx_n_u_NameDeletion_infer_type, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[37])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_infer_type, __pyx_t_7) < (0)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/FlowControl.py":385
 * 
 * 
 * class NameDeletion(NameAssignment):             # <<<<<<<<<<<<<<
 *     def __init__(self, lhs, entry):
 *         NameAssignment.__init__(self, lhs, lhs, entry)
*/
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_NameDeletion, __pyx_t_5, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_NameDeletion, __pyx_t_7) < (0)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_13Uninitialized_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Uninitialized___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[38])); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Uninitialized, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Uninitialized__set_state(self, __pyx_state)
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_13Uninitialized_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Uninitialized___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[39])); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Uninitialized, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_7Unknown_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Unknown___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[40])); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Unknown, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Unknown__set_state(self, __pyx_state)
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_7Unknown_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Unknown___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[41])); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_Unknown, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/FlowControl.py":407
 * 
 * 
 * class NameReference:             # <<<<<<<<<<<<<<
 *     def __init__(self, node, entry):
 *         if node.cf_state is None:
*/
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_NameReference, __pyx_mstate_global->__pyx_n_u_NameReference, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Compiler/FlowControl.py":408
 * 
 * class NameReference:
 *     def __init__(self, node, entry):             # <<<<<<<<<<<<<<
 *         if node.cf_state is None:
 *             node.cf_state = set()
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_13NameReference_1__init__, 0, __pyx_mstate_global->__pyx_n_u_NameReference___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[42])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_4) < (0)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":415
 *         self.pos = node.pos
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '%s(entry=%r)' % (self.__class__.__name__, self.entry)
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_13NameReference_3__repr__, 0, __pyx_mstate_global->__pyx_n_u_NameReference___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[43])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_repr, __pyx_t_4) < (0)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":407
 * 
 * 
 * class NameReference:             # <<<<<<<<<<<<<<
 *     def __init__(self, node, entry):
 *         if node.cf_state is None:
*/
  __pyx_t_4 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_NameReference, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_NameReference, __pyx_t_4) < (0)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/FlowControl.py":419
 * 
 * 
 * class ControlFlowState(list):             # <<<<<<<<<<<<<<
 *     # Keeps track of Node's entry assignments
 *     #
*/
  __pyx_t_5 = PyTuple_Pack(1, ((PyObject *)(&PyList_Type))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PEP560_update_bases(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_CalculateMetaclass(NULL, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_6, __pyx_t_4, __pyx_mstate_global->__pyx_n_u_ControlFlowState, __pyx_mstate_global->__pyx_n_u_ControlFlowState, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, (PyObject *) NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__pyx_t_4 != __pyx_t_5) {
    if (unlikely((PyDict_SetItemString(__pyx_t_7, "__orig_bases__", __pyx_t_5) < 0))) __PYX_ERR(0, 419, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Compiler/FlowControl.py":426
 *     # is_single         [boolean] Has only one assignment at this point
 * 
 *     cf_maybe_null = False             # <<<<<<<<<<<<<<
 *     cf_is_null = False
 *     is_single = False
*/
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_cf_maybe_null, Py_False) < (0)) __PYX_ERR(0, 426, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":427
 * 
 *     cf_maybe_null = False
 *     cf_is_null = False             # <<<<<<<<<<<<<<
 *     is_single = False
 * 
*/
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_cf_is_null, Py_False) < (0)) __PYX_ERR(0, 427, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":428
 *     cf_maybe_null = False
 *     cf_is_null = False
 *     is_single = False             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, state):
*/
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_is_single, Py_False) < (0)) __PYX_ERR(0, 428, __pyx_L1_error)

  /* "Cython/Compiler/FlowControl.py":430
 *     is_single = False
 * 
 *     def __init__(self, state):             # <<<<<<<<<<<<<<
 *         if Uninitialized in state:
 *             state.discard(Uninitialized)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_16ControlFlowState_1__init__, 0, __pyx_mstate_global->__pyx_n_u_ControlFlowState___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[44])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  PyList_Append(__pyx_t_5, __pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_2) < (0)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":446
 *             [i for i in state if i.rhs is not fake_rhs_expr])
 * 
 *     def one(self):             # <<<<<<<<<<<<<<
 *         return self[0]
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_16ControlFlowState_3one, 0, __pyx_mstate_global->__pyx_n_u_ControlFlowState_one, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[45])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_one, __pyx_t_2) < (0)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/FlowControl.py":419
 * 
 * 
 * class ControlFlowState(list):             # <<<<<<<<<<<<<<
 *     # Keeps track of Node's entry assignments
 *     #
*/
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ControlFlowState, __pyx_t_4, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_CyFunction_InitClassCell(__pyx_t_5, __pyx_t_2) < (0)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_ControlFlowState, __pyx_t_2) < (0)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":450
 * 
 * 
 * class GVContext:             # <<<<<<<<<<<<<<
 *     """Graphviz subgraph object."""
 * 
*/
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_GVContext, __pyx_mstate_global->__pyx_n_u_GVContext, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_kp_u_Graphviz_subgraph_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "Cython/Compiler/FlowControl.py":453
 *     """Graphviz subgraph object."""
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.blockids = {}
 *         self.nextid = 0
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_1__init__, 0, __pyx_mstate_global->__pyx_n_u_GVContext___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[46])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_6) < (0)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":459
 *         self.sources = {}
 * 
 *     def add(self, child):             # <<<<<<<<<<<<<<
 *         self.children.append(child)
 * 
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_3add, 0, __pyx_mstate_global->__pyx_n_u_GVContext_add, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[47])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_add, __pyx_t_6) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":462
 *         self.children.append(child)
 * 
 *     def nodeid(self, block):             # <<<<<<<<<<<<<<
 *         if block not in self.blockids:
 *             self.blockids[block] = 'block%d' % self.nextid
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_5nodeid, 0, __pyx_mstate_global->__pyx_n_u_GVContext_nodeid, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[48])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_nodeid, __pyx_t_6) < (0)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":468
 *         return self.blockids[block]
 * 
 *     def extract_sources(self, block):             # <<<<<<<<<<<<<<
 *         if not block.positions:
 *             return ''
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_7extract_sources, 0, __pyx_mstate_global->__pyx_n_u_GVContext_extract_sources, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[49])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_extract_sources, __pyx_t_6) < (0)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":479
 *         return '\\n'.join([l.strip() for l in lines[start[1] - 1:stop[1]]])
 * 
 *     def render(self, fp, name, annotate_defs=False):             # <<<<<<<<<<<<<<
 *         """Render graphviz dot graph"""
 *         fp.write('digraph %s {\n' % name)
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_9render, 0, __pyx_mstate_global->__pyx_n_u_GVContext_render, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[50])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[8]);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_render, __pyx_t_6) < (0)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":487
 *         fp.write('}\n')
 * 
 *     def escape(self, text):             # <<<<<<<<<<<<<<
 *         return text.replace('"', '\\"').replace('\n', '\\n')
 * 
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9GVContext_11escape, 0, __pyx_mstate_global->__pyx_n_u_GVContext_escape, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[51])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_escape, __pyx_t_6) < (0)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":450
 * 
 * 
 * class GVContext:             # <<<<<<<<<<<<<<
 *     """Graphviz subgraph object."""
 * 
*/
  __pyx_t_6 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_GVContext, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_GVContext, __pyx_t_6) < (0)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":491
 * 
 * 
 * class GV:             # <<<<<<<<<<<<<<
 *     """Graphviz DOT renderer."""
 * 
*/
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_GV, __pyx_mstate_global->__pyx_n_u_GV, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_kp_u_Graphviz_DOT_renderer); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "Cython/Compiler/FlowControl.py":494
 *     """Graphviz DOT renderer."""
 * 
 *     def __init__(self, name, flow):             # <<<<<<<<<<<<<<
 *         self.name = name
 *         self.flow = flow
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_2GV_1__init__, 0, __pyx_mstate_global->__pyx_n_u_GV___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[52])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_6) < (0)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":498
 *         self.flow = flow
 * 
 *     def render(self, fp, ctx, annotate_defs=False):             # <<<<<<<<<<<<<<
 *         fp.write(' subgraph %s {\n' % self.name)
 *         for block in self.flow.blocks:
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_2GV_3render, 0, __pyx_mstate_global->__pyx_n_u_GV_render, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[53])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[8]);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_render, __pyx_t_6) < (0)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/FlowControl.py":491
 * 
 * 
 * class GV:             # <<<<<<<<<<<<<<
 *     """Graphviz DOT renderer."""
 * 
*/
  __pyx_t_6 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_GV, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_GV, __pyx_t_6) < (0)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":526
 *         self.messages = set()
 * 
 *     def error(self, pos, message):             # <<<<<<<<<<<<<<
 *         self.messages.add((pos, True, message))
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_3error, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MessageCollection_error, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[54])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection, __pyx_mstate_global->__pyx_n_u_error, __pyx_t_4) < (0)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":529
 *         self.messages.add((pos, True, message))
 * 
 *     def warning(self, pos, message):             # <<<<<<<<<<<<<<
 *         self.messages.add((pos, False, message))
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_5warning, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MessageCollection_warning, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[55])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection, __pyx_mstate_global->__pyx_n_u_warning, __pyx_t_4) < (0)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":532
 *         self.messages.add((pos, False, message))
 * 
 *     def report(self):             # <<<<<<<<<<<<<<
 *         for pos, is_error, message in sorted(self.messages):
 *             if is_error:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_7report, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MessageCollection_report, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[56])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection, __pyx_mstate_global->__pyx_n_u_report, __pyx_t_4) < (0)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MessageCollection___reduce_cytho, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[57])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_MessageCollection, (type(self), 0xf5cccfb, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_MessageCollection__set_state(self, __pyx_state)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_17MessageCollection_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MessageCollection___setstate_cyt, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[58])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_MessageCollection, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":685
 *         self.assignments = []
 * 
 *     def visit_Node(self):             # <<<<<<<<<<<<<<
 *         self._visitchildren(self, None, None)
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_3visit_Node, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_AssignmentCollector_visit_Node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[59])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector, __pyx_mstate_global->__pyx_n_u_visit_Node, __pyx_t_4) < (0)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":688
 *         self._visitchildren(self, None, None)
 * 
 *     def visit_SingleAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self.assignments.append((node.lhs, node.rhs))
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_5visit_SingleAssignmentNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_AssignmentCollector_visit_Single, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[60])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector, __pyx_mstate_global->__pyx_n_u_visit_SingleAssignmentNode, __pyx_t_4) < (0)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":691
 *         self.assignments.append((node.lhs, node.rhs))
 * 
 *     def visit_CascadedAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         for lhs in node.lhs_list:
 *             self.assignments.append((lhs, node.rhs))
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_7visit_CascadedAssignmentNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_AssignmentCollector_visit_Cascad, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[61])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector, __pyx_mstate_global->__pyx_n_u_visit_CascadedAssignmentNode, __pyx_t_4) < (0)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_AssignmentCollector___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[62])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_AssignmentCollector, (type(self), 0x2ddb615, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_AssignmentCollector__set_state(self, __pyx_state)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19AssignmentCollector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_AssignmentCollector___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[63])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_AssignmentCollector, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":698
 * class ControlFlowAnalysis(CythonTransform):
 * 
 *     def find_in_stack(self, env):             # <<<<<<<<<<<<<<
 *         if env == self.env:
 *             return self.flow
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_1find_in_stack, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_find_in_stac, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[64])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_find_in_stack, __pyx_t_4) < (0)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":706
 *         assert False
 * 
 *     def visit_ModuleNode(self, node):             # <<<<<<<<<<<<<<
 *         dot_output = self.current_directives['control_flow.dot_output']
 *         self.gv_ctx = GVContext() if dot_output else None
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_3visit_ModuleNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Module, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[65])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ModuleNode, __pyx_t_4) < (0)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":731
 *         return node
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         for arg in node.args:
 *             if arg.default:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_5visit_FuncDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_FuncDe, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[66])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_FuncDefNode, __pyx_t_4) < (0)) __PYX_ERR(0, 731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":781
 *         return node
 * 
 *     def visit_DefNode(self, node):             # <<<<<<<<<<<<<<
 *         node.used = True
 *         return self.visit_FuncDefNode(node)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_7visit_DefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_DefNod, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[67])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_DefNode, __pyx_t_4) < (0)) __PYX_ERR(0, 781, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":785
 *         return self.visit_FuncDefNode(node)
 * 
 *     def visit_GeneratorBodyDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_9visit_GeneratorBodyDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Genera, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[68])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_GeneratorBodyDefNode, __pyx_t_4) < (0)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":788
 *         return node
 * 
 *     def visit_CTypeDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_11visit_CTypeDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_CTypeD, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[69])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_CTypeDefNode, __pyx_t_4) < (0)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":791
 *         return node
 * 
 *     def mark_assignment(self, lhs, rhs=None, rhs_scope=None):             # <<<<<<<<<<<<<<
 *         if not self.flow.block:
 *             return
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_13mark_assignment, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_mark_assignm, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[70])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[6]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_mark_assignment, __pyx_t_4) < (0)) __PYX_ERR(0, 791, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":827
 *             self.flow.nextblock()
 * 
 *     def mark_position(self, node):             # <<<<<<<<<<<<<<
 *         """Mark position if DOT output is enabled."""
 *         if self.current_directives['control_flow.dot_output']:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_15mark_position, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_mark_positio, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[71])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_mark_position, __pyx_t_4) < (0)) __PYX_ERR(0, 827, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":832
 *             self.flow.mark_position(node)
 * 
 *     def visit_FromImportStatNode(self, node):             # <<<<<<<<<<<<<<
 *         for name, target in node.items:
 *             if name != "*":
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_17visit_FromImportStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_FromIm, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[72])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_FromImportStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":839
 *         return node
 * 
 *     def visit_AssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         raise InternalError("Unhandled assignment node %s" % type(node))
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_19visit_AssignmentNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Assign, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[73])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_AssignmentNode, __pyx_t_4) < (0)) __PYX_ERR(0, 839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":842
 *         raise InternalError("Unhandled assignment node %s" % type(node))
 * 
 *     def visit_SingleAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.rhs)
 *         self.mark_assignment(node.lhs, node.rhs)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_21visit_SingleAssignmentNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Single, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[74])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_SingleAssignmentNode, __pyx_t_4) < (0)) __PYX_ERR(0, 842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":847
 *         return node
 * 
 *     def visit_CascadedAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.rhs)
 *         for lhs in node.lhs_list:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_23visit_CascadedAssignmentNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Cascad, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[75])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_CascadedAssignmentNode, __pyx_t_4) < (0)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":853
 *         return node
 * 
 *     def visit_ParallelAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         collector = AssignmentCollector()
 *         collector.visitchildren(node)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_25visit_ParallelAssignmentNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Parall, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[76])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ParallelAssignmentNode, __pyx_t_4) < (0)) __PYX_ERR(0, 853, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":862
 *         return node
 * 
 *     def visit_InPlaceAssignmentNode(self, node):             # <<<<<<<<<<<<<<
 *         self.in_inplace_assignment = True
 *         self.visitchildren(node)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_27visit_InPlaceAssignmentNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_InPlac, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[77])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_InPlaceAssignmentNode, __pyx_t_4) < (0)) __PYX_ERR(0, 862, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":869
 *         return node
 * 
 *     def visit_DelStatNode(self, node):             # <<<<<<<<<<<<<<
 *         for arg in node.args:
 *             if arg.is_name:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_29visit_DelStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_DelSta, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[78])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_DelStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":884
 *         return node
 * 
 *     def visit_CArgDeclNode(self, node):             # <<<<<<<<<<<<<<
 *         entry = self.env.lookup(node.name)
 *         if entry:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_31visit_CArgDeclNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_CArgDe, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[79])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_CArgDeclNode, __pyx_t_4) < (0)) __PYX_ERR(0, 884, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":892
 *         return node
 * 
 *     def visit_NameNode(self, node):             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             entry = node.entry or self.env.lookup(node.name)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_33visit_NameNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_NameNo, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[80])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_NameNode, __pyx_t_4) < (0)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":904
 *         return node
 * 
 *     def visit_StatListNode(self, node):             # <<<<<<<<<<<<<<
 *         if self.flow.block:
 *             for stat in node.stats:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_35visit_StatListNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_StatLi, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[81])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_StatListNode, __pyx_t_4) < (0)) __PYX_ERR(0, 904, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":913
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         self.mark_position(node)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_37visit_Node, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[82])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_Node, __pyx_t_4) < (0)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":918
 *         return node
 * 
 *     def visit_SizeofVarNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_39visit_SizeofVarNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Sizeof, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[83])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_SizeofVarNode, __pyx_t_4) < (0)) __PYX_ERR(0, 918, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":921
 *         return node
 * 
 *     def visit_TypeidNode(self, node):             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_41visit_TypeidNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Typeid, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[84])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_TypeidNode, __pyx_t_4) < (0)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":924
 *         return node
 * 
 *     def visit_IfStatNode(self, node):             # <<<<<<<<<<<<<<
 *         next_block = self.flow.newblock()
 *         parent = self.flow.block
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_43visit_IfStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_IfStat, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[85])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_IfStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":950
 *         return node
 * 
 *     def visit_AssertStatNode(self, node):             # <<<<<<<<<<<<<<
 *         """Essentially an if-condition that wraps a RaiseStatNode.
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_45visit_AssertStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Assert, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[86])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_AssertStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":970
 *         return node
 * 
 *     def visit_WhileStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_47visit_WhileStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_WhileS, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[87])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_WhileStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1000
 *         return node
 * 
 *     def mark_forloop_target(self, node):             # <<<<<<<<<<<<<<
 *         # TODO: Remove redundancy with range optimization...
 *         is_special = False
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_49mark_forloop_target, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_mark_forloop, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[88])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_mark_forloop_target, __pyx_t_4) < (0)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1052
 *             self.mark_assignment(target, node.item, rhs_scope=node.iterator.expr_scope)
 * 
 *     def mark_parallel_forloop_assignment(self, node):             # <<<<<<<<<<<<<<
 *         target = node.target
 *         for arg in node.args[:2]:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_51mark_parallel_forloop_assignment, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_mark_paralle, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[89])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_mark_parallel_forloop_assignment, __pyx_t_4) < (0)) __PYX_ERR(0, 1052, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1066
 *             self.mark_assignment(target)
 * 
 *     def visit_AsyncForStatNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_ForInStatNode(node)
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_53visit_AsyncForStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_AsyncF, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[90])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_AsyncForStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1066, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1069
 *         return self.visit_ForInStatNode(node)
 * 
 *     def visit_ForInStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_55visit_ForInStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_ForInS, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[91])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ForInStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1112
 *         return node
 * 
 *     def _delete_privates(self, node, exclude=None):             # <<<<<<<<<<<<<<
 *         for private_node in node.assigned_nodes:
 *             if not exclude or private_node.entry is not exclude:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_57_delete_privates, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis__delete_priv, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[92])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[7]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_delete_privates, __pyx_t_4) < (0)) __PYX_ERR(0, 1112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1117
 *                 self.flow.mark_deletion(private_node, private_node.entry)
 * 
 *     def visit_ParallelRangeNode(self, node):             # <<<<<<<<<<<<<<
 *         reductions = self.reductions
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_59visit_ParallelRangeNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Parall_2, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[93])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ParallelRangeNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1136
 *         return node
 * 
 *     def visit_ParallelWithBlockNode(self, node):             # <<<<<<<<<<<<<<
 *         for private_node in node.assigned_nodes:
 *             private_node.entry.error_on_uninitialized = True
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_61visit_ParallelWithBlockNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Parall_3, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[94])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ParallelWithBlockNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1136, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1146
 *         return node
 * 
 *     def visit_ForFromStatNode(self, node):             # <<<<<<<<<<<<<<
 *         condition_block = self.flow.nextblock()
 *         next_block = self.flow.newblock()
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_63visit_ForFromStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_ForFro, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[95])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ForFromStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1183
 *         return node
 * 
 *     def visit_LoopNode(self, node):             # <<<<<<<<<<<<<<
 *         raise InternalError("Generic loops are not supported")
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_65visit_LoopNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_LoopNo, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[96])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_LoopNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1186
 *         raise InternalError("Generic loops are not supported")
 * 
 *     def visit_WithTargetAssignmentStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_assignment(node.lhs, node.with_node.enter_call)
 *         return node
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_67visit_WithTargetAssignmentStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_WithTa, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[97])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_WithTargetAssignmentStatNo, __pyx_t_4) < (0)) __PYX_ERR(0, 1186, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1190
 *         return node
 * 
 *     def visit_WithStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self._visit(node.manager)
 *         self._visit(node.enter_call)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_69visit_WithStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_WithSt, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[98])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_WithStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1196
 *         return node
 * 
 *     def visit_TryExceptStatNode(self, node):             # <<<<<<<<<<<<<<
 *         # After exception handling
 *         next_block = self.flow.newblock()
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_71visit_TryExceptStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_TryExc, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[99])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_TryExceptStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1247
 *         return node
 * 
 *     def visit_TryFinallyStatNode(self, node):             # <<<<<<<<<<<<<<
 *         body_block = self.flow.nextblock()
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_73visit_TryFinallyStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_TryFin, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[100])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_TryFinallyStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1286
 *         return node
 * 
 *     def visit_RaiseStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         self.visitchildren(node)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_75visit_RaiseStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_RaiseS, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[101])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_RaiseStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1286, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1296
 *         return node
 * 
 *     def visit_ReraiseStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         if self.flow.exceptions:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_77visit_ReraiseStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Rerais, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[102])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ReraiseStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1303
 *         return node
 * 
 *     def visit_ReturnStatNode(self, node):             # <<<<<<<<<<<<<<
 *         self.mark_position(node)
 *         self.visitchildren(node)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_79visit_ReturnStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Return, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[103])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ReturnStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1326
 *         return node
 * 
 *     def visit_BreakStatNode(self, node):             # <<<<<<<<<<<<<<
 *         if not self.flow.loops:
 *             #error(node.pos, "break statement not inside loop")
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_81visit_BreakStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_BreakS, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[104])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_BreakStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1343
 *         return node
 * 
 *     def visit_ContinueStatNode(self, node):             # <<<<<<<<<<<<<<
 *         if not self.flow.loops:
 *             #error(node.pos, "continue statement not inside loop")
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_83visit_ContinueStatNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Contin, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[105])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ContinueStatNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1360
 *         return node
 * 
 *     def visit_ComprehensionNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.stack.append((self.env, self.flow))
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_85visit_ComprehensionNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Compre, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[106])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ComprehensionNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1370
 *         return node
 * 
 *     def visit_ScopedExprNode(self, node):             # <<<<<<<<<<<<<<
 *         # currently this is written to deal with these two types
 *         # (with comprehensions covered in their own function)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_87visit_ScopedExprNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Scoped, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[107])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_ScopedExprNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1383
 *         return node
 * 
 *     def visit_PyClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, ('dict', 'metaclass',
 *                                   'mkw', 'bases', 'class_result'))
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_89visit_PyClassDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_PyClas, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[108])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_PyClassDefNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1398
 *         return node
 * 
 *     def visit_CClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         # just make sure the nodes scope is findable in-case there is a list comprehension in it
 *         self.stack.append((node.scope, self.flow))
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_91visit_CClassDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_CClass, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[109])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_CClassDefNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1405
 *         return node
 * 
 *     def visit_AmpersandNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.operand.is_name:
 *             # Fake assignment to silence warning
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_93visit_AmpersandNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_Ampers, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[110])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_AmpersandNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1412
 *         return node
 * 
 *     def visit_BoolBinopNode(self, node):             # <<<<<<<<<<<<<<
 *         # Note - I don't believe BoolBinopResultNode needs special handling beyond this
 *         assert len(node.subexprs) == 2  # operand1 and operand2 only
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_95visit_BoolBinopNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_BoolBi, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[111])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_BoolBinopNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/FlowControl.py":1434
 *         return node
 * 
 *     def visit_CondExprNode(self, node):             # <<<<<<<<<<<<<<
 *         assert len(node.subexprs) == 3
 *         self._visit(node.test)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_97visit_CondExprNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis_visit_CondEx, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[112])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_visit_CondExprNode, __pyx_t_4) < (0)) __PYX_ERR(0, 1434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_99__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[113])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ControlFlowAnalysis, (type(self), 0xe8722d7, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ControlFlowAnalysis__set_state(self, __pyx_state)
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19ControlFlowAnalysis_101__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ControlFlowAnalysis___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[114])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_11FlowControl_ControlFlowAnalysis, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_ControlBlock(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x64ddf03, 0x834e101, 0xf2b1408, b'bounded, children, gen, i_gen, i_input, i_kill, i_output, i_state, parents, positions, stats')
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_1__pyx_unpickle_ControlBlock, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlBlock, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[115])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlBlock, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * cdef extern from *:             # <<<<<<<<<<<<<<
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_3__pyx_unpickle_ExitBlock, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ExitBlock, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[116])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ExitBlock, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_AssignmentList(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9a2d7cf, 0xb1e68e4, 0x39670e9, b'bit, mask, stats')
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_5__pyx_unpickle_AssignmentList, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_AssignmentList, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[117])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_AssignmentList, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * cdef extern from *:             # <<<<<<<<<<<<<<
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_7__pyx_unpickle_ControlFlow, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlFlow, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[118])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlFlow, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_NameAssignment(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x09885d0, 0xe16df08, 0x8cd3e98, b'bit, entry, inferred_type, is_arg, is_deletion, lhs, pos, refs, rhs, rhs_scope')
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_9__pyx_unpickle_NameAssignment, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_NameAssignment, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[119])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_NameAssignment, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * cdef extern from *:             # <<<<<<<<<<<<<<
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_11__pyx_unpickle_Uninitialized, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Uninitialized, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[120])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Uninitialized, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_Unknown(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xe3b0c44, 0xda39a3e, 0xd41d8cd, b'')
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_13__pyx_unpickle_Unknown, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Unknown, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[121])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_Unknown, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * cdef extern from *:             # <<<<<<<<<<<<<<
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_15__pyx_unpickle_MessageCollection, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_MessageCollection, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[122])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_MessageCollection, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_AssignmentCollector(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x2ddb615, 0x14033f8, 0xdf44812, b'access_path, assignments, dispatch_table')
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_17__pyx_unpickle_AssignmentCollector, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_AssignmentCollect, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[123])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_AssignmentCollect, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * cdef extern from *:             # <<<<<<<<<<<<<<
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_11FlowControl_19__pyx_unpickle_ControlFlowAnalysis, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlFlowAnalys, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_FlowControl, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[124])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_ControlFlowAnalys, __pyx_t_4) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_ControlFlowAnalysis__set_state(<ControlFlowAnalysis> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ControlFlowAnalysis__set_state(ControlFlowAnalysis __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.access_path = __pyx_state[0]; __pyx_result.constant_folder = __pyx_state[1]; __pyx_result.context = __pyx_state[2]; __pyx_result.current_directives = __pyx_state[3]; __pyx_result.dispatch_table = __pyx_state[4]; __pyx_result.env = __pyx_state[5]; __pyx_result.flow = __pyx_state[6]; __pyx_result.gv_ctx = __pyx_state[7]; __pyx_result.in_inplace_assignment = __pyx_state[8]; __pyx_result.object_expr = __pyx_state[9]; __pyx_result.reductions = __pyx_state[10]; __pyx_result.stack = __pyx_state[11]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 12)
*/

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init Cython.Compiler.FlowControl", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init Cython.Compiler.FlowControl");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_super); if (!__pyx_builtin_super) __PYX_ERR(0, 23, __pyx_L1_error)
  __pyx_builtin_min = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_min); if (!__pyx_builtin_min) __PYX_ERR(0, 471, __pyx_L1_error)
  __pyx_builtin_max = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_max); if (!__pyx_builtin_max) __PYX_ERR(0, 472, __pyx_L1_error)
  __pyx_builtin_reversed = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_reversed); if (!__pyx_builtin_reversed) __PYX_ERR(0, 701, __pyx_L1_error)
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_open); if (!__pyx_builtin_open) __PYX_ERR(0, 727, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 810, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  __pyx_mstate->__pyx_umethod_PyList_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "Cython/Compiler/FlowControl.py":172
 *         """Mark position, will be used to draw graph nodes."""
 *         if self.block:
 *             self.block.positions.add(node.pos[:2])             # <<<<<<<<<<<<<<
 * 
 *     def mark_assignment(self, lhs, rhs, entry, rhs_scope=None):
*/
  __pyx_mstate_global->__pyx_slice[0] = PySlice_New(Py_None, __pyx_mstate_global->__pyx_int_2, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[0])) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[0]);

  /* "Cython/Compiler/FlowControl.py":488
 * 
 *     def escape(self, text):
 *         return text.replace('"', '\\"').replace('\n', '\\n')             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__4, __pyx_mstate_global->__pyx_kp_u__5); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__6, __pyx_mstate_global->__pyx_kp_u_n); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "Cython/Compiler/FlowControl.py":727
 *         if dot_output:
 *             annotate_defs = self.current_directives['control_flow.dot_annotate_defs']
 *             with open(dot_output, 'w') as fp:             # <<<<<<<<<<<<<<
 *                 self.gv_ctx.render(fp, 'module', annotate_defs=annotate_defs)
 *         return node
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "Cython/Compiler/FlowControl.py":735
 *             if arg.default:
 *                 self.visitchildren(arg)
 *         self.visitchildren(node, ('decorators',))             # <<<<<<<<<<<<<<
 *         self.stack.append((self.env, self.flow))
 *         self.env = node.local_scope
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_decorators); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "Cython/Compiler/FlowControl.py":1307
 *         self.visitchildren(node)
 * 
 *         outer_exception_handlers = iter(self.flow.exceptions[::-1])             # <<<<<<<<<<<<<<
 *         for handler in outer_exception_handlers:
 *             if handler.finally_enter:
*/
  __pyx_mstate_global->__pyx_slice[1] = PySlice_New(Py_None, Py_None, __pyx_mstate_global->__pyx_int_neg_1); if (unlikely(!__pyx_mstate_global->__pyx_slice[1])) __PYX_ERR(0, 1307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[1]);

  /* "Cython/Compiler/FlowControl.py":1384
 * 
 *     def visit_PyClassDefNode(self, node):
 *         self.visitchildren(node, ('dict', 'metaclass',             # <<<<<<<<<<<<<<
 *                                   'mkw', 'bases', 'class_result'))
 *         self.flow.mark_assignment(node.target, node.classobj,
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(5, __pyx_mstate_global->__pyx_n_u_dict_2, __pyx_mstate_global->__pyx_n_u_metaclass, __pyx_mstate_global->__pyx_n_u_mkw, __pyx_mstate_global->__pyx_n_u_bases, __pyx_mstate_global->__pyx_n_u_class_result); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "Cython/Compiler/FlowControl.py":1393
 *         if node.doc_node:
 *             self.flow.mark_assignment(node.doc_node, fake_rhs_expr, node.doc_node.entry)
 *         self.visitchildren(node, ('body',))             # <<<<<<<<<<<<<<
 *         self.flow.nextblock()
 *         self.env, _ = self.stack.pop()
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_body); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 1393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);

  /* "Cython/Compiler/FlowControl.py":22
 * class TypedExprNode(ExprNodes.ExprNode):
 *     # Used for declaring assignments of a specified type without a known entry.
 *     def __init__(self, type, may_be_none=None, pos=None):             # <<<<<<<<<<<<<<
 *         super().__init__(pos)
 *         self.type = type
*/
  __pyx_mstate_global->__pyx_tuple[6] = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[6])) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[6]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[6]);

  /* "Cython/Compiler/FlowControl.py":126
 *         self.in_try_block = 0
 * 
 *     def newblock(self, parent=None):             # <<<<<<<<<<<<<<
 *         """Create floating block linked to `parent` if given.
 * 
*/
  __pyx_mstate_global->__pyx_tuple[7] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[7])) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[7]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[7]);

  /* "Cython/Compiler/FlowControl.py":479
 *         return '\\n'.join([l.strip() for l in lines[start[1] - 1:stop[1]]])
 * 
 *     def render(self, fp, name, annotate_defs=False):             # <<<<<<<<<<<<<<
 *         """Render graphviz dot graph"""
 *         fp.write('digraph %s {\n' % name)
*/
  __pyx_mstate_global->__pyx_tuple[8] = PyTuple_Pack(1, ((PyObject*)Py_False)); if (unlikely(!__pyx_mstate_global->__pyx_tuple[8])) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[8]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[8]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<9; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_slice;
    for (Py_ssize_t i=0; i<2; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 10; } index[] = {{1},{43},{16},{22},{30},{24},{23},{223},{31},{22},{25},{55},{4},{179},{28},{20},{26},{17},{21},{1},{2},{4},{4},{2},{3},{1},{1},{1},{0},{1},{2},{1},{2},{1},{2},{2},{1},{8},{7},{55},{30},{23},{13},{7},{6},{7},{2},{9},{9},{57},{48},{37},{2},{19},{12},{15},{15},{24},{11},{15},{18},{8},{17},{19},{37},{39},{48},{30},{46},{14},{32},{34},{16},{17},{7},{15},{12},{30},{32},{22},{19},{18},{11},{19},{37},{39},{36},{33},{35},{39},{52},{33},{39},{40},{40},{42},{39},{39},{38},{39},{38},{48},{43},{38},{42},{33},{37},{41},{39},{44},{37},{46},{36},{47},{34},{36},{34},{30},{48},{43},{47},{40},{39},{41},{40},{40},{46},{39},{38},{43},{44},{36},{39},{38},{54},{16},{25},{20},{29},{31},{22},{34},{22},{19},{25},{27},{25},{25},{26},{20},{21},{21},{15},{27},{6},{14},{23},{9},{27},{29},{15},{8},{9},{13},{2},{9},{18},{13},{16},{25},{16},{16},{11},{9},{7},{13},{12},{9},{18},{17},{35},{37},{23},{24},{25},{14},{32},{34},{25},{32},{12},{21},{23},{13},{22},{22},{5},{8},{7},{14},{17},{10},{20},{14},{16},{25},{27},{34},{11},{13},{22},{25},{13},{31},{33},{7},{25},{27},{7},{1},{0},{3},{9},{10},{13},{6},{3},{4},{14},{11},{18},{5},{10},{3},{5},{8},{6},{4},{10},{6},{6},{17},{22},{14},{10},{13},{13},{8},{7},{5},{8},{9},{17},{12},{8},{6},{18},{9},{9},{15},{17},{3},{10},{7},{10},{16},{8},{5},{6},{8},{4},{5},{9},{7},{7},{8},{10},{1},{11},{5},{9},{10},{7},{5},{11},{9},{3},{5},{22},{6},{9},{14},{9},{10},{7},{8},{10},{10},{15},{9},{14},{13},{21},{12},{13},{4},{2},{12},{8},{8},{5},{9},{12},{7},{1},{10},{18},{10},{12},{10},{19},{13},{8},{10},{12},{6},{8},{10},{15},{10},{13},{12},{15},{19},{11},{8},{12},{8},{7},{15},{11},{23},{9},{10},{10},{22},{18},{13},{10},{7},{14},{11},{6},{4},{5},{8},{13},{1},{5},{3},{8},{5},{9},{11},{6},{4},{10},{8},{7},{7},{13},{15},{13},{19},{32},{13},{14},{4},{3},{11},{12},{7},{9},{13},{3},{3},{6},{10},{15},{8},{4},{7},{8},{10},{12},{9},{6},{4},{6},{9},{8},{3},{4},{7},{8},{8},{24},{6},{7},{7},{3},{3},{3},{9},{11},{12},{14},{14},{12},{11},{10},{34},{29},{27},{26},{34},{24},{32},{29},{28},{22},{14},{12},{5},{10},{10},{17},{13},{9},{10},{6},{6},{7},{6},{8},{8},{3},{9},{5},{22},{4},{8},{12},{10},{12},{19},{7},{8},{8},{12},{5},{10},{4},{5},{5},{4},{4},{5},{8},{5},{6},{4},{4},{8},{10},{4},{17},{16},{6},{6},{12},{4},{5},{6},{19},{20},{20},{22},{19},{19},{18},{19},{18},{28},{23},{18},{22},{13},{17},{21},{19},{24},{17},{26},{16},{27},{14},{16},{14},{10},{28},{23},{27},{20},{19},{21},{20},{20},{26},{19},{18},{23},{24},{16},{19},{18},{34},{1},{7},{9},{5},{6},{11},{11},{11},{307},{31},{76},{11},{25},{73},{28},{54},{127},{129},{56},{86},{60},{67},{51},{69},{39},{43},{54},{48},{25},{116},{64},{46},{60},{19},{80},{44},{42},{46},{34},{40},{41},{89},{89},{26},{116},{390},{16},{21},{17},{17},{60},{24},{13},{272},{30},{19},{57},{161},{83},{25},{138},{160},{23},{15},{513},{117},{59},{168},{35},{112},{180},{370},{187},{335},{114},{18},{217},{292},{306},{24},{24},{11},{20},{7},{67},{164},{129},{11},{26},{11},{23},{13},{14},{111},{47},{11},{452},{452},{98},{331},{127},{333},{503},{131},{11},{44},{246},{57},{55},{56},{55},{58},{58},{55},{55},{69},{59},{34},{11},{11}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (7369 bytes) */
const char* const cstring = "(\265/\375`\221M\375\345\000j\325\244-G\320\014\353\001\000_<\213N\314[tb\246p\013\234\302\374\322+\375\227^\351\025\227\301\037X\337\214,)\240\331\377\207\315d\320\023\275\203*\237\334,\337\233/~\321\317\030\263\223\365Ov\202\314z\240\232\335bs&\032\255\233\002\257\002\354\002f\336AyoU\026c\355\022\275\2211\221l\345t99\363\334Vu9>\253\233,\313\256\r5\261X\326\220\243\352\264\370&E\023\335&\271\325\275i\232\363}\243Mu\327\360\274H\276E\225=y^s\033\325</\236\027w\251\"\337\255\0317\265*[s\270mfT\337\324u\334\"\231y\312<e=\344\214N\225\351U\363\314\316=\024S\331U\335:\234\324:\272\332J\366l\232\251urn\032g\227\354x\336\234\030\266\250\313\034\263fV##\232\354\255\306\254\271\235\352L\271Y\025\315\271F\223oU6\333-V\213e\323[EO\223<eVus\316\325\215\336V$?\321\022\335k\31665\217B\244\212fNr\335J\267\242\267]\023\365\272\307\261$k\342X\2363\253)\243\325\275\326\3505\246\2363\242\251[9\211a\2271\234q\217Z\344\232\225\205\270\230\267\270\313\362d\255r\3169\265\312\254\311\346\224\251j\\\nM\253\263pouE\t\177rgP\314Fu\215\377\230@)[e\3719\222|\210\324\351\033J\270\325s\266\203\302\265F#o\245HL\271\203t\371\303I\221\026\203bnN\216\002\210B^B\216+\213\256\354\311g{\314;\257\347\230\302\235\345,\213\033=E\276\362m\216[\334\263\275nq,\t\332y\034u\370#\002$\" D\005\005*)\001!B\n\014B\001\0228\210\204!\207\265d\371V7[j\241\023^r\302\322T\326\334\341%\341\036o&\2154wR\233\227zf\013\221*9\206'\371$\\7\017\315\3155\032\236\3536C\366\324\205\263\2320\3057\252#\327\222d\203\302\331\031\362\31597u\270\022a\205A\216+'4u\345\336Ad\311\311\260\266\206{=q\266y\342\244J\255W\036\246h\251\035.\330Z\335c\270\352p\334\234,5\271\222fMj\025\367\207\2403\244\005\251{4e\031Z\341\020)TC\265\372\032\367\252\236(\312\362p\253:\344\"\251ns\277\302\225\314m\316\352R\014K}SO\034ug]Yj\223\234\205\241M<K\231\325$O4\353v(@\000Z\356ZH3\311r4u\r\335b\316\245\236+\311I\236=D\336\310\025\315\200\246\312S]\315\223\205;\313\231\006\r\270z\252\252+\245\356\222Do'+e\236\265U\307\322\215gP\210\236g\031\232d\270\313 M""\252Z(4Or\025\331q\324[\r\327\32345+%\273ot\235\"\014x\347=\2757\356E\357hM\027\267\242\214\036\252\033\270\350\201\030\340iS\377\200[/\370\266\374EK/\365\034~\344\023\244/\311\t\211\313{\200\323\306\211g\362)\036\337\203\245\257/\035\303\342S\254\302:\360\010l\202]\257\352\335~c\304\235\351,M\013\256`\225\027E\346\206\244}\245\277\332\227\256A\201R\241\372G\353B\371\261g\202e\357\352U\361\034\372\201\023o\325_To\312P\347\350\256\266\353<\350\177\372\251\337\250p\334\240>\241\352u\020\320h\325\264\347\332\\\021+mWZ\215\013\236z\035\031\350~H\213\006\370\226;\033\365V\253j_+\017\346O\276\305]\273N\247\361V$:\250\\\224+2\340\257H\250^\036\277\362\013`}E\361\322Q\253W\237\265\023\252\330\000|\362\356\370\022\202\376q\301Cy\223\267u\222>\2668\023\374\002\376U\017\201\365\003\027_\3253\024]PD \371$\340\357\215z\332\006\350\245p\005\225\277\343\256\\\222\323?\301#\377\033\361F\032\375c\203\007\364\363\177|\276\217\354\367\354Bb\240\227\346a\036\303\rO=\335Bh5\010\360R\227\345\252\334\224\356\322~\243\226\000\006O\026\373\353\216\265S\211e\034|\026\277K6\276\251\307Z!\225\377|\352\006p[\004z\252\376u\017\002\274\221\333\321OZ^4\240\010\202nI\332\002\275\264oH=\351\302\\\230\316\323\226Z\002\027<\355e<\210\353\352`\367\270\340\255Z\026\343\2027\352,\355Z\264RdA\301K_\227\223\177\002~\323\333\342Q^\005\365\316x\225W0\202M^\323\253\002y#\02293\343\370\210\262+\3139\212\236+G\367\312q\253\250\362<+\267\3465u\334|\013\235\267\255\362\334\316j\251\331t\025\332\245Mdo\354\316\351\362VQ\364DG\022]9{>P\251#\231q;\237\352\rg\273\231\244^o9\247o6\256\232&\231Q\326v\226\231\327\312\222\223\344\354\246\236\231\213\254jn6\335|]\365M\233\264\023Es\\\247U\232\312\331\363\246\323y\345\3529#I5\3232m\226s\236\241\263Y\316{d\313\315w\026s[\310\3347\326\334:5\347\315\313\275\305sT\265\310\311q\314y4I\315\317\334V\305\321<E1h\227\342m\257d\3169s2\317\304ST\367)fS\213k\346<\353\320,>P\215&{f\316G\222\014\342:\210o\223\\\331S=\305\324\25133GuY\262f\306e\023w\232\266\235m\236\0019\230\004\007\275""\022H:&P/0\270D\343_\334\r\202\001\263A\271\206Z\016\034\020\257\353%\034\275\024F\360\016\225&\010\341\357a\210[\020\276\201\030\355G\364\004\272#\310\370\031\024=\330\313R\362\205:\t\373\3708\035\277g\261\000\010h\005O\020\3713=\204\000*\003\325\272\230\204\342\225\370\213\177Nn\332c\372\320\021T\\hU\220\323\206\216\205\337\202U\260\004\005\277\304\244B\271\374\002\024^\n\312\312\005\201\3011\"k\221I\246\263\273\224x\204)0\370'\357\221QB\025\247\3000-(\027<a\205\307\262r\372qKBj^\276l\345E\274\213\033\201\373\204\374\020\017\326\3243\263\342SN\0334|\r9\277U\373X\301\354\233\363\rHF0\013\003\022^\n\223o\313n\010\256\000\303[\355f\361Dl\342\361\252PR((\037\205\2447zc\334\221\220\267\212U\261\005L\361:\010s=\301\352e}\316=\t\341\305t>\337\005\330\231\304\246X\204I`\030\324o\201\345\374\330\216\026\327`\330\370.\340pQ\037\243\227e\304\203\007\333\215\354\\\342\0100\n\346\357\312k\341c*\037\301\364z\224\334X\027js\035\276\202\247\264#L\2671\312`\322G\035\330\257\330\265\342\374*\200\3014\023\021\322\344\242L\377\375\360)\"(\032`-\314\007\255\262\323\236Z\023\005)k7HT\002|L\0079\361\016\204\204\370\224\020\020\017\024\324\311E\235\\t\213\213[0\310\353\032\321\260\014,\002\023Y\370\025\317\243\246\255\315{q\3211\\8\351\275t\305N\017\371\351\231\014\364|\370\t6@\0179\245\0308\215|\307\252dr+L:\312\306\251B\367z|\372\214KO\271\340\232&\n\224h|\223Z\017\005\217/\316O\320]\246\353\216\333p\321|\311\005\n\204\275\030\246\267\302\243\220PxpB\242O\026>2\214\n\000\023%\322n#\344\342\366`*\ro\300/.<V\354]\235\\\364\216\373\340\242\355\255v=\261\002\330\345E\245z:\306\3016o\217G\031\360{m\201SO\221\020\211\000 O\273\013\372\014\310[\025a\224\000P\224\030m\300\322\226\245\222+0\343j\350\245\276\333W\346%\244\351[\362\216\236\304\343t\266\355(\300\033\275\016\334\t=\365\r@\376n9L<\326\300\212\273\3624\234\361vx\327\255\345\030U\272\367\020\374\t\030U\314\003\237`\324\307h[\372\235Py\013\217\023o`}d\003\203\207rqT.\212\347A\001\366\302\370\325\345pe\375\245[\274+\214\251W\200-\351;""\001\302\306\216\"f\201?8\302\311/q\371\250ey\301\332\232UK\323\007\014\245~\203{r\t|\326-qM\256\207\t\003\300E\211\233\225\237\205\270\001\372\235xS\337\300t\340\037\000\277\312\345qE\\\221\036\306_\355LxD*\327'\354p`\323\273Z\002\316\016C\313\207\275,i\3155\351\241Y\371~\345i\\\022\215\037g\300\030h\372\213\336e\304\026\034\374\3247\240pcP1\316\253\202\002\246b\031\225\003\020\036\032\240\315\342\247=\001\330kW\260J\343\343\217\272I[ \205u\203\215\277jgE\031#\243\356\321\261k\211W\270B\311\367\230\031\371\340\221\260\017\253\360W\340\016\236\026\206\230\234h:>K\306%1\375QkR$\300T\001@@\t\360\217^\023\220\307\325\257\312>\033\003SpU\275\230\316w\331Y\214V<\224r.\371\370\224J\260R\351\246T\272P*\271@\021\"@U\005M\023\264\331\300\331\014\314\031\324\321\001qp@\033\033pf\346\0331\242C\007\035\235\317\306f\304\010\316q\037\207A\302__V\000\037\363\371\314\314|22(J\362\361!\372D\351O\201>\320\353\257\304\006`\331\3132\362WQ\374\200\200>\030\354\273\271\371.\\\370\\.\235\216\304\262\267\033i6#y\360\240A\003I&;\377)~\021\350\347\335i'\306\033\361\t\354Br\351>\317\317x\201\327\025-\001~\275\r~6\374\r\261\377\332\201\273X\\\212;\340\226w\365,\317j\027U\017\265s\211-\026|\354\267\256\337\355\366\315f_P\320\227\363\267a\303\027\213}\257\327\307b}\237\005\022\021\021i]I\265\032i\034IZ\357\354\220hhH\255\026i\265\032\201 Z\377j\3736\332\247i\354\\q\017\367%8\244\233\033RM\315H\307~v\374c\317\357\211\375\016)\265\217^\307\316\006\343\336\0070&\223M\245\247\332\275b\020\231gP\262\000\216\030\001\346r`\232\202\267\033\370\341\003\2707\330\241\003\030\213\201\0312\200\0300\200\340\013\004-|8\334\307\371\207\242\237\315\366\215\343\367\363\363\365\364|2\331\227!\303G\363\321\220D\210 \r\r\221p8\222\252\222l6\222(\222r&\001\001\345\344\220X,\222\205\021C\177\210\177^\376\262\366k\373o\017\337\203\354\313J\273\216x\350{\255$ \322\317\017\251\247\207dcCz\221^\243\020\000\000\224\000\221\3739\363\233\037\376\207\374\263\316\037w\027b0\246\230\311\2122J\342\362\315\200;\312\016\201\001""\370g((\217\243A\346\177\300\rN\272\211\300\211\253\341RH9T=\202I\267`\r\330\226\262j{\275\021\227\210#8\221\301\017`\t!\177\325w\312Q\301z\016T,\363\340\177\010Qh\350\3000\315Z\020\016\030\003\232\010\025\244}z!b\321\323\203\301>/\314G\217\350\301J\005g\360!\272F\371\217\017\026we;T\002\207\374\250\343Gs8d\016\321\214H\222$i\014\323@\030@H,\022\013\307\223\352\374\243CS=\313\301 \205!F\2201\216\020\021\021\021\221\021\221\221$I*\035\226\332\235\317)MN\014\205\242\023\005\350b\220\233\006\301\336MLyskx\027\226\347\243%\306\374_\034\231\245\301\243\337\332b\204v\214\250\3320\270\2159\037\034\277zn\240E\000uX\037t\344\277\010\0039\311\017\300\000\027N\330dZ\372\365\005y\244s\260\267(]\205\022\324 \245\307\034\363\323':\200\177\223\275\304T~a\036L\003\035\227\tm\324\366\036\224\3424@\200\373\250\347(d\301N\366\257\335Pn\251\365\233L\367\220\350\266\032\020\225\301\202\350:84\257\246M\240!lW\203\200\250\267Pp\264\200\323BZ\231\317X\265\321N\227xP\243\222r\376\006\341\352\323\025\25276\252h\276\214\244e\266/J\026\225U\t\3318s\245\242\336T\350\205-M x)J\344\300 \264]\267]\014\223\365)B\204{O\263YX2\317\337}:e\034\352\007\273M\013B\300\235J\t\033\212\022\021\231;\241$P9&\035\363\245\337en\372\240*\013]6t\360\361\345\332\326\253&9d\246\326\315\237\312\307\325R\376\272\320\024\274/&\0359\327\311\362)y\276\217N\253\026vU\306\3432!\311\240\036\344\324S\357_Z\376\004A\335\351\222\245sU!\2040\314\260\203C[\262\333Q2s\254\210\016'\022k'q\265\237\323\361\267\020\335C%\312\\\3048\250\253\371\030\0026\315P\321M\036\341\2106\317\303\336K\224\035-\253[w\243R\206\210\037xV\230\203#\030)\266\211=\222\206\331\337\030u\373\372M\233\366W+S -\321c\363(\345\256Lp\201Z\233c\016\235#\325\304\275\276\000PBIV\304\260c% \200u\032\304\252\354\323\361W\030\346\351(\371\021\365`\373`,\032>\300f\240\357t\317+\226\324s\003H\320\037\224\345zg4T\334\347\374\020%\377\004\23568S\034\224R0\023-\014\240\022K\321+Z\305\306`#r\277\373vv\277\366\245\275\331\356:\2749q\330\311\3401\332\307\003\002\375\330\322""\005^cb\tL\355\223\277\254Yz\334\035\256[re\307\310\033\026\343[\036\322\010\326G&\224\361Q\354\213NpI\235$\371Y\345I?ZA\362\317T*Q\337+M\302\367jR$q#\031*\337\003\017\235\264D\260\332\273\357Ut\263\253\027Ln\314\246\022\320\320Ee\314\221\231Wt\243[\215\302\256\304\354\250\224\243?,\210\215s\227\013\216\201\013%\036\177\365c\205h\273N\206\351t[)\257\016\345C\304\253yw\016\275\245\0322\000yq\336\275]\314\2542\325\370&\262\360I\350jR\201l\355OL\347\362\322p\\\212fP\000T\375i+\315\235\277]\036\344\235x9\345i\245\032\206\026|\316\3127\263/\017\031C1\354l\247\360\001)\367\273\247\214\320\260#\331\332\302\334\007M\216\354\331!s\310\364\223\203Ev\364z1~\311\363\023\035\010\330[\031N\310\r*2\023=\347\024\251\260\267D\356\350)\010,e\327\207z\213krvG`\217\030\256\346\027f\200\261\216L\265W\343:\230\n:Y\332r\331\304\033\"iX\030\375\272\344K\234\314\311\365\021\375\220\214\215x\362'\314\302;\330\204uV~\235Kt\265\206\220\t0\242Z\375\350\327<fH-w\251Ij\340\222U\340 \323\302Et\316~\357\351\025G`\236;\022\365r\034\312}\034\200\372\346\335\336\260v\343P\271\202\354\000JA\334GrR\320\332M1\007\233\227_\377/\315\006\376\247\212\033\035\265\222G\244\223\366\257\3665\032>WR\006\377\253{\022D\351P\221O\02567HuT\007,\005`\231\241\234\247\370\007\244\333N=\207\016\361wAB\276\"\\5J3\301\322\315\300\267F\325\2136(.9\251\274\323\225\322\316x\013\326\354J\241b13\016\351\n\360\210\240l\262\343\300J\017CI\341\004\026\204\320\244\217:Q\1770M\203\305\033\177$\215\310\016\323^\351\211P\343_\201\355\237\026\330(u\242\265 \266]\201/\367?\235\001\260\336\006\020\224Ac\331,\357G`N\310\350\325'\314~\360\t\002\227\330c\362\010@\326\323M\020q\242f\233\214V\013\031\032\t\372T\026~T\3504\031M\247\340\025\263\307\340\220,\237b\2120\024\"\"hW\206L\203d\265\235\240\366\r F\246\274F\335]\230mw\2773\027\036\307z\364ZTy\203\362\327\311\000\025\"Q\250\246\024\254\254\320+\351\235\026\233\023\235\255\236\243\333\036!\256\"\267\321*\350\217\256\347\337\177\211Y\201 \202\302\221\357\252W$\220Y\345\325\3727\343\007""\033d\n\326S\265\nq4\330\356C\013v\216um\272x\235\207\215\345w>\203\247\016\247\204\250[\355!\006\361\273f\365\017\365e#\365f+\332tD\005Bmw\241\377@\212\313\332\230\355\234\277\270\365\306g\203\373\362\254\276\n\375\230\321\335\275\366)\336\001\265\315*\227j\353!\220_!P\317\232\320}\030%\370\257\346\326]i\004\024\317u2/~d\230YWE\231%\314\000\371\271\237\307\2174#>\2224\262\340\264!\317\340\273{\030)\026^\367g\032\202\205=\021u\341\332#\250B\024$8sc\355^\024\264\327\331\000*\034\205\217fjh{\005\213bZ\022|\220\372\217\247yH\342r\305N\235\347\332i\362\365\351\341W}\261\376\354\216sJ\357`\321\263\242\034\036\206f\032-\374Pr>G\352+\211,\350\307\225\274m\326\322\"\023\026e6m\026W\210\300q\026\0130fvu\335)\221\266\204d,[\300\274\201t|[\231\351$\204\314FMg4\2505\301\312Z7\300\277\207\007\246\017\233\264\341'j\272\020\213\003\203\020\271\300\315#\243'\315\265\337D\264f\241\036%C\341\215\366\213\302\266\367\352ZV~\2664\010\2106l\233\372R\271N\305\215-\033\327\024\371H&3\353g\341J\256\325\241\211\355,>\240_ \324\204\373 \024'\250N<X9\016M\366J\020\316\002\211\006\035\267\0203\251\236\312\026\356\005\226\262\274\2062\007evt\022R.\245\373W\\\371ih\375z\026>S\"|\263\252ot<\231\314\241.\026\331\3454\245\000V\r\363\255h\377\222\320\277n\027Z\216\007\365\351\350\024\221s\271\246-\031\234\037T\327\361\360\362\360\327\220eY\013\343\253I\360\367.ja\212\365\310\t\3149r$\231o\227\236S\247\260w7\331\210\346\0375\242\262\027\3659\251'\n\344\010\276\024Im\230t.\353\316\027\261^\275\036\026\271\370\016o\016\247C\256\261\316\"`\351c\212e[\331\341\303Y66\255I\370\225\316.\031\320\005\003\373\300\227\200\000\307\310\316\372\330\374x\002\241# 9\0336\177\263\235\364\201\223\264\337i\032qh\221\325\357\352a\026\207\226\246B\353\212\023Kb\274\355\336b\021'\315\243\027\312:\361\203\316\000i\352C\240\220\235\266\023wq|7\304d\304\032\205\337\347\326\221\207\235\246[I\207\371\311\001\022|\211=1\354[\037\377\212\032\236]\215?\r\3072\223\300S\255p\340T\000\253\313\306R'\317V\310\021\223\002\232\254\013""\260\000\034\020?\016?\376jmX6\3633\360$\245P\251=d\375\360\270\362\203M\257J\332HrclAO\223!\001\227\267\005 \325\226o\360\241\277\275\307\330\276S]\341W\353\342\252\356\307\321\3055K\252\022q\264\030]\037n\241\201\340f\016\272rT@\020\335h_\244\336\300\302\006\323\263Q\nM\325\003*/\3059\r\252_wU\203\325O\005w\300)p\372\016\222\257\000\373O(\243\277\025N\227\013x\212v\3453;\256t\300\202\t\273\005*\013\232\255!3j>);F\231nsD\213\333C*\201\017\0200\034\243\343\3003\025\304\020\351\253:\364^}@\363\231\000:\206!\3413J\234\221!\274\260lb\336\243\r\320\300\026\356\324\234~\242\177\200:\032 &\332/A\226\255\010\335\377\005\316o\216\253B\255\362\3360Q.\004=\033Z\003\315<@C7\356\215\242T\30730W\204j\3021\211\2542\222\301}\336L\256\315%\352\0277q\225\276\357\275z\241\252Y\300CNr\322i\311\342\373\220\035\330iS\331\375/\312pK\255\336\274Z\222Ul\372\356dF\262N]Sl~5\030\222\036h\350,R\240*\215\t\321\211A\030\262A\007\262D\340\026m\001\006\254x\224\204 O\342v\010\375\027\344\336\005q\372&+\363B\336}\363\353\234V\276T\\\332\2673\2425\317\314\364&\255Z?\006\022Yt\310\363\352\320\332e\t\310\020\004p3\023\344\310\036k\345\213\006\240I$4\276\232r\316j2\251.iz\2742V\260$-St\356\026\025v\032\220\204,J\261\337Q\362\262\220y\331\000\027\001\344\270\266a\306m\236:#O\016\225\034]k\260J8\000\221\233\370I\320\204\341\305\323\246\203\307g\367\214\014\222\374\232t\227\376|\275\243\204H1v\353>+\246\005\\\215\023\214E\302\247}\314\021\341\000\254\334\211\240\262\031\372\026\n\000\023e\321s\036Z\355{\234\226R\037\323\034SG\2504H\366\031\030\210\234\230\252c%\251xXi\3418\310\362UJH84~eA\324jkz\315,\212<\251\374\177\326\212\3323\346M\21141\013\277\006\353\362\022\\\231\363\201\310\336\010\005\3559\0163\367\023\316B11n\371\257[\204:\211\310+ y\233h9Y\032p\254\005\027\016A\314!!\274\343\020\007L\204\345\300\210\270\350\010+\020\211\024'a\"X\242?bB\026\330D\026\354\204\017\200\242\026\212B\026(\305P<\205\025\240\212\004Ya\007\257\230a,,\201\026?\321\026\206 \027Wp\027\372\301\027\235\021\030\3420\214CX""\014\237\200\214NT\206*\320\214r|\206\024 \215\025H\r\211p\215\024\263a\002\270\361Fo8 \034\315q\034\312\2019\262 :db\035#\014\331\347\223|\350R\307\375\004T!H4\212^+\257\354\307\231\004s\004\264,p\324\016lG\261m\200\\p\177Y\251\250\316\215G\033Q\311qlF\005b\200\006\177|\263\001\0369\323\331o5K|\312\220\0261\341\322\327;\245\017\2714A\230\236\307DC\370\321)\013\251\005\245\342\rZqa\233\275\270\252\031\236\030,\340p\322.\217\354\231fi*\357Bf\356\217\336\364\020%\235\342;\"\363\276\0016\265\027\010@jg\0019\21786~\002\263\325)\020\014NTl\250\253QD\320\ny\207\036--\201\226\3608\022\326\314\025\020z\370Y*\3035y\027\034\007B2\372h2\355\005`\264y\204]\313\2454\345\021\353,\274R\250\273dt\021V?\252yk\236\020\222d\233\247\034$\311#\010OEsqC\306\002f\374\332\341\362\347;\236I\025O{@IU^~\033{\222\356\0107\240\322\237\212\216\244U\262\325\026\304\030\241\006-\020\212\324\003ql\234C\204\316r\017\232\275\377I0\335s#\247_\354\215\325\250\033\23704U\314T\274\014\347\241\201~wQ\245\276$4\230Z\0223\300\001\177\307C\245\232\276\333\233p*\256o\025\376[\004\237b\t\264\353u\333\271\330\256\200S\027\265.\242\247\013\204\346\324\363J\231N0\354\353\323W\321\334{\215\262TS\221\002\035\016y\243\317 2\275PO\365\016\032\234\222\341\030\0011\207\325\"\221\207\243r(DL\302\331\314\t\t\375O{\275\333\342\251\013\235\331\223\234y\274[\2011\330\223J\201\370\262\231E\\\242\357f\247\020\245\254\247x\376\336\305r\342N\305P\265@\241V\r\004Gs\356N\235\277\0039\336\207\241\332 \0332c*\037f\231m\253\240\2275-\325-%\001\006n<\244\331\026+\367\010o\254*\004\014\242n\257\024\351\006\033\202\331\255F\234\000\270\010\023]\216\212ij\300\332\276\0314\344W\0336\021\216\032@\261\271\335\t\340C\243\253\216!\350\270\301%\303\261\303\252\2227\307:\211Eu\312\274\"~\206\331\2566\033\273+\260N\265XzoK\247\227,\226\263/\233\372\n\014\305\350A\313\372\031t\233&\307\301[\031\353\237\323)\nM\267XM:\r\236\235(\035_\320\226?u&P\210\324t%Y\266\010\366\005%lW\316\222/\020F\251=]\343\221g\207\020%\310\021\004?\314\343\032\177\342""\311O,\303\303\254sq\343~\373Z\343\233\225j%@\177 h\304\300\311\3018\274\344k\010\204\0263\\\373a\272\020\255\371A<\331\276\027\031\224\206\221\357\264\030\213!{\tAk4\003X\rm\3604E\377\265\222\325\336w\267h\256\323S\202\347F\251@\302\227W<\nV\346Z\"\262r\330\225\362\216@\373\312\000Lx\nZ\017+q\246q\332]\375\236\263C\2365\336Kd\242\265!\273\r`\237\230\312\001\242B\340\026\005D\036`\301\231\303-\016XG\254\274y\312\n\024\262\034\016\365\026o\304\304\274!\247\035X\3539>\244o\242\366s\324\010q\244~S\270\341\200\201\237\350\365;W\346\022\367\232LN\335\274\026\277\223\260\273\351\300\2315\375l`\203\245\234\230\376\034_2i\234&#>\332\215c`V)P}6\374\322\301fK\203\037\036\275\307\363\353nYi\216n\360\306\370\202>\375\236\224T\343/\242y)\364[\263\241\\\241E*\327X#\372cK\032*>\036\353\323\016\244\311\314H\363\r-\034VB\022\375\200\017\362\374\2517\244\031\201\234u\317Q\2068\214\2165\257\304;\024s\271\266\224S5\201\nl\243\010\336\223J4\0009\356@o}]\271\331}@\366y\225\343+\240P~\200\310.a\345\343\244\004\010\216vCb\200\277\272\321\005\302\375\220\345\364\230\006A\275w\331\275\004\324\013\177\363\026\315\320\355=Ag\320\033\275\363\216\013\r\004a\366\327\202\276\254\002\261\363\277Z\326\333\251\314\251\2465CM h.\260s\340z\262\234\023\301\325@L\327\374\272\222\215a\3469Q\036\344 \270~\330\027\303\017\201r\004\364\215_\350\017\272E\232\212YY\"!)\377\270?\346\271\350\006\373\203\266M\200\020u\274B\376O\226\242G\031\376I\367D\223\001\300\316i\253;QSr\2712T\310CX\013\312C\2753\305\222\2069\253y\027\275\036\\\"]i\347A\357\365D\210\223\260\350\375\3650}\010\373\253\204\353c\226vJI\236CR\236\320\341\220\020}\346\2554\213\316\206\027\214\341#^x}Fa\007\337\246\247\324\257.%\334\260\203H\243\306\321Sp\346E\314\345(\20260\240]\343\251\367\254\\\002u\245\222\tpW\213\ty\371v\265H\223D\205\336|\025\217\177\223:\302\004\271\273Pq1\004\352\304J\017#\323\315\276lA\375\023Oq\356\227\322']\343\334\347\357\220\0053QmQk@\034Cj6\273\tg\230M\262&\312\212>h\014\327tY\256od\202\200\214\360A\006\247\177\022O""\262h\352\374i\t\264\006,B\245\005\324\320\323\230\263gi\207KT\327\270\200\tz\212LC-T\361\214qB\230T\302\001YB\235\244&\322\231\202^\366x\321\224P\257<\313^\242\211\341;\3015\320N%\207\"\353\342H\230\0031\270,z\260\345\225\2152\252\3122%I_\302#\353f\220n\320\234\257\253\361\035$\221\317U(\253\\\276k\346\211S#g\310\020\016\223\004\313M\255\013\000\253\303H\270^\341NP`_\255\002~\225p\256\362@\262F\014\273A\300\303\244\303\234es\302T\022RF\364RP\007\010r\235\313\322(\346J\tO0xV\262\201\017\327\272\366\340n\327\177B\260\t-\010\252?^\250#\334N4x_\364\346\315\020\036\237I*} \327\230h@\311g\217\214\316c\347\250\310\001\020\221\342`\243O\212\262\242\233G\201x2\\1\246\352|\377\017I\201\037\321\n\215\t\003\2256\374\277k+\031\371\210~F\014*\242G\2235\343}\0103vWF\324I\210O\312|0\"\264\217`A\3528\013x\247j\006\306\355Mri\031\222&Z\331\313\177\177\325rl,U\226\356Tt\200.\240\362\376\007";
    PyObject *data = __Pyx_DecompressString(cstring, 7369, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (7021 bytes) */
const char* const cstring = "BZh91AY&SY\205\216\026~\000\007\225\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\300@@@@@@@@@@@@\000@\000`\037\034v\365G\276\370K%\366\300\363\317pX\260\367r\367\260WK2\036n\341\356\311\320\002mP\202\252\205=Q\226\206\235u\320\006\212\t\006\347\000\010\013\330\002\000|T\254\000\016\002P\204@\220\320\324y\352\246\030\365\033RG\352\232h\332LL\233LSO\003I\355\032\022\023\006\246\237\250&\322\014M\001\240\321\215M\250\022HF\023\020\210LM5O\323\324\3225=4\36524\324mF\214\200h\320h4\000\003A\246\200\006\217I\215A\240\003LA$\211\t\240i\240\001\240h\006\232hf\243F\312\017H\321\341O`\322S\324i\246\206\217S&\200d\320\321\2404\022i$\2214dS4G\251\223jhzA\247\251\344\207\224\364L\206\200\017S@z\200\033P\007\250z\2002\036\204\007\251\342\236\240%\"\022@\000\0006\247\260\251\243\324\017P~\221\247\2054\215\003&\206\201\352\037\251\350\246\200~\250i\236\250\3654z\230\203C\324\365\000H\220\200\20050\232i\246\211\243\023&\200\211\007\251\275F\243\324\321\352z \032\000\000z\200\r\250\r\007\250\000\037\370\002C\214C~*\311\307-8y9\270\222x\354\222\007]%b0\225R(\"\nI=S\326=[\335\356\035\271\376\344\356Ha\016\3546#\261\265\327p\014\r\310\013\212\223I\235\3477\264c\266\263!\226be\240\322\243\000$?\342\262\315\222\002\320\002\340#t\201\262\256\302\016\213\325\271\350\235-\227w\035xp\343\250\235n\267e\307a\234\306\322`;\346\330\251\341\360x\220\310O\276{v\315\t\364\364\206~\272:\211\370\272~h\336\343\243\263\373\366\343\243\203\211I\016\010\335$lm\033(\322C\205\223)\275BT\311\227\212\222\313\217\222K,\251\221\220K),\2516ZM\002o\030\354\251\274\236\\\262\\\246^\320.\\\341\017\014(\271\2428\353o\032\1777\221\347Q\304u\267\022\377\004}\007\352\234\334*\264\366503\t\246\224\226\2715y\246%\232\27110Le\025\362\346\2576*M2W\231+\244\323&f\350\210&\352\177\300*0\252\n\242\270\261)\217\216q?\203\235\3058g\023\030\306\364\036\337\244\305\305=\177\351\361\356\231\251\232\202\034\2013P\315\344\232\022\022HI!$\2064\204\204\222\022HI!$\204\234gO\220\370\242;\235\276\337o\273\256""\340\005\271n[\216\366\355\306&\343\337\336\367\275\357\350\241M\013*YQ\224\353YI\3768%P\202\000\250U\031\213\004\273\027k\006\306\014\212\304\006 \",\212\240\261\221#\022\nD\214\221EXA`)\"\242\260\021D\220FE\010\240\240\240\261AH\013\000XEUUTEFE\212\n\000\242\301E\021\220@ci\266\300\254\n\256\322_\200\202\201xT_U\345\347\334\371\374>\323\037\322\276_\252\337\314\213\360\002\000A\227)\226\232\000\314\264\006m `\320\233A\024\210\t ,\222\"\260R\003\020U\222(\256\340\016d\036\230U!\005\2042I\005\202\312\326 \001.\006fM\364\211\245\351`\023\224\260\302\325\220\022 \310\221\0354\323\016\022bC\200D\220\304\030\305\001QA\024\026\033\366\020\342\003\327$P\005\202\302\nE\206\322N\037\261\266\363\031 ,\220\212\001\260\260J3\236z\316\205\034\300Q&\202F\t] \272\025\312\006O\236\017gX\034\034\242\225>F\252\202\004\022\201\273d\223!\036\031\224\202\243&\361s\213\216C\2216J\315C\212\0245\026,\325m`\3705m\n\342\023\256U\304\311%\243\000\3035CL\225A*\201P\n\210\272,\026\321^K<K\331@\372\370\032\262\013\261\000sY%`\235k\366\2516\006%\232\t\210\232&Ui\215\211\016a\024d\037f\343\331\262K%\221\226\2534f\2655\003Eq^\312\302\262\261`\261l\n\0244yC\355\272\265p\341\305PT\252\255s\261\025\222\2410D\326$\254k_\2756\242jP(X\265O\300]+*\nl\253J+\206\313\022\212$pz\220w\326lh\250\263\200\210\323\177T\023\0342=Ngr\335\277\2668 \266\371L\350\342\303@\377)\362\226+\234\337g\276\305h\265+a\026b\363\352\304AUk)\255\237\300/@\217\307\370\322\334\250{\005\303\035I\320Uy=.\253\242R/r\375T\310;\255\255\307\333e\272\353\264\327\262\355\267\305,\225\261<\344\345\205F\336\321\036a\364\3079\331\327\324G\225\020\201{,\257\262#\321\363\377\027\245/B\304\036\230\366\344\2369\221P6\244I\253!\030f;\241\000\210\t\312`8T\235\013q(!b\221\234C!\007\2713\376\237\216k\267\251\376m,\367\221L\256\250D\211\246\273\325\230Ik\231\357X2\311\031$\267\267\330\317\363d-\0227\321e\345dy\032\036\"Mb\236\360\217urX\262,\367\377\344l\242\363\362\301JF\234\276G2\321-\251\300\352\205L\277F\274\032\335\027E\360\341E\271\355\325\275""\316\241\314~\363|\273\274\252v&Mm\317ux\267\255co\027\257\321\277t_\212\373\305\016\032K\371\354\216\310\334\336\250\217\023\035\205\215HJ\376\245\370\332\324\231\305\321\313\356\272\235\244@:\216v\326{\235\377\036\246Yk\300\355l\256~R\314\232\314W8\245\317\204l\021R+I\232\021$\206\334\347\004\334\275R\272\2205R\013\230\003h\033A\031\262\232\367\316\255\025}\037E\201\347\344\345\326WV\304\022\324z|\351e\217-\275\004\272\3700A (\205Dx\350\312rX\227Q}\330\257\245\344\004\025@\244\301\322\025\354\223\tJ\010ld7\226\231\301$MA\272$\332I;q\034$U(\037\032;\276\3541>\310p\325Ic\216\273}\314\275\226'0B\232\0054\211\243EP\3204\214Lo\010@A!a$[\301\340\2450\363\257z\3242X\377Y\336\363\221!'\240\221^\351%#|\264\211\004\227\261\303\303\340\313f\314\350\250\212l\343\367%\266I\022$\204H$_\334\371\007%\245(\370{\226\005\206\013,{\333\347g\306\363\345 \227V\215\263\002\034\2443\317\313\346\377_=\036\006=\203\220\337\355\350\365\217\273\366\316\234!?\211\3230\3649\221^\226\030&\232\276Sm\361\\\313\216eQD\367w\364r\356\360\244J\004\014D\320Ms\316\223\360\340R\263\356\246\304\030\014a\004\210\303\020\210\206\345\304I\002\214\010n\200\325\270\0210\204\250h\002I \024m\247F\236\310\316\332\024\t\304,\311\212#\331\216\374l\316,\355\264\333\373$F\006\200\321\220\315\221g\\y\177\337)\224{\357\025\377\355\013\227\310\334\3217\310\235$=1\007?\240\210\306=\204\316q\223&\203\242\254\302\300Z\305A\251\035\030\205h&\030\010Dq\273\334\315\223\357\352\273\n7?[\220\3447.\2648\227\032\266\361\226Y\365\357\002\020\204'\"kG\3467L\330\222\027\021\031\321\235\031\320q?\343\314\252\226\006\234\033\356\371?\257\263\225\3476\366\0339\366\207\000\251\362\263`\010\330$\264\213f\300\331\250\327Z9\016\261\274\370\315\t\000ua\010\343\241`\371\3235\014\304\226\224-+N\223I,\350\345\357\031\032Y\270\305\213+\327\263<y%\335B\332ri\022F\221fKJ\320\215\274\345\246\221\214\260\013\013,\344\365\327\253\371y\263\035c5\254\357\016X\312\220\177\325\373\237\353\314\r\0329\n,\023\255\271\"\242\272D\010\034\202\255\364$\034""\037\207\277z\027\032\355\244\373\014V\316\n\351\306\232\223\315]fn\330\275\3642m\274EP\310\347\205\332\372~\331\026\325\022`\306R\302\311G\232\234Y&60\2105\262\031U\0325\201m\211\220\010\"\2644\326\324\342\246\332\265\256nr\275 -\006\343\r\336n\255F\321\232\317\362\307\257\0360\347\255r\235_\277\243\312\005\257j\375\346\271\206\261;\263>\025\244j\r}\020B\032\330\201g5\323g\376R\236\023\n\360\324\2224\215!m\\\226)\016\375\250\200D\302P\0060\331\262\3149\206\203\324#\2161M6s\310c\030\326\315\307afuW&\304\360\343\014\302\206^\267\252\"\245\206,vipcs%\2736\353i\257g\247\214\260\036\376\207\371/\203NxN\332\252\266\204\245l\255\227\255;\346s\032\226\315\334\334\313\356\006\243\254f\303\350\326\214y\215\035R\017q\2366\263\371\370\201\202H\301,\001q\\\207\032GJ\341\207'o\237&g\245\255?abF\206\206\231\273\327\021\3229\213\332\264\004RE\r\272\243T0q\205I\233\206\016\001\031\013,\214\203#\227\227\357\360\367\263\323Gv|;\021\245\356t\253\354\265\272\231Z\203\330\332\200\333\221\343\3411\3224<3SA#-\236\331\"\303\023;sC)\227\241\245\217\024\366\274\323$U&\257\311\261\347Z\265\335\352\363\313\261\255j\307\222d.\2376\344\260Z\246\213E\271\272\003t\347-+\010%AZ\026Z\005\020<k3\nV\213\026\007\r\244\361\030\027\247B\243\262-#'\272*\002\212cc;\374\360H&\224\250\331&\375~5z?\003\331u\224s\266<D9\373o\2418\360\222\0346\206\312\262\316O\002\301\260\201\336\032\332Bb\005K\320CCO\2043\276\315\345B\n\220t\332x\023\312\206\204\247)\024\276FX\262a!\271\334^\027\301\240\262&\304h\341\276\304q~m\200\335\320\230\363\021\211\322\231\224\300\026\231\277\0022%\023\014\\\030a'\232\0335\226\033\\\244\317\3337\351\255\024V\204\0079aQ\212\313c@\022\300\273\212\353\203\353\261\343\320\250\354\207\272\272\216\225\034\243q\316\301\303QeIb\303\341Z7>\021\3043\343\020\212\233\315\343\237\224ryv+\247\017\037\211 {\274C\275\024\\z\322\033\241\311\257Ti\235\t\272\007\323\"\0235q6\337\277j\274\014Vq\364\303w\022*(\377\372\035\232\203\000\335\370\240\206U\210<az\336\036l\221\004!{BL/\026%i\221\241\200\235\242e}""\375\235\306\206\375\tdA\024\357\030\236b^)\224n\365\277\332\"\255\360\330\250k\004e\000\357\024\252\r\013\232\227\343\005Vgp\323d9\021\242v\202F\346\205\211\351n\010\314\322\226x\201jd\030\261l1\201\221*\275^\244\376\002:=\223\321\257\032|1\016\200\261l@\371:W\2303\005M$\221dB\2358v\022\207T\340\252M\305\nD\310RiJ\266\202\223\244K\315\360j\333\326{9pPA\363\235\224UU_\271\025\010\216<\264l\36799Wu\361\325_\313\374uXh\321\263J\364'\206\010\350\026\r\375\237\251\235H1Ty5QS\205\253`\315\254`\245)\005\311\021)3e|Go\266\263\032\304Jv\246=\270\325l\023h\033i\231\0040\240Y3\227D\273\007\223a\3762E\222\203C\346y4\305Z\027\274a\022\3662H\255\317:\325\234\224\233%\t]\004\010l\255$n::e\355\303{[\302\301\030\257\2040k\231\2041\276l\221(n4\262d\310!\247Iv\376U'b9\213Z\004\264=\233\"\211\362\352\2664\223U\302\243#\032\234\223\200j\250\363\355\317@H\340V\\\336[\256\017\335w\225\261f,\"\362\223\262!\200\\\014\030\273|\200\034\307jGhyN\021\334d\372\377w\201\3576p\320\267\372\244n9\216J\273&\367\372\234\347\351\256w\332\370D\272\252\003\203\253$\246\027\203\021\356\374\363t @\321\221\241\250h\301\243\251\320Ik2c\274\340\030\220Z\241\235\334\201\033\270+\240\262\267\trY\264\366a\022I$\263330\3032\202t\342\320\315I\261y\032\312\323\216\026\230cY\321\231i\350\220\224\343\301^\223\266\000\211E\006\355\033\307\027f\221R\313\337z*\241]\007\177LD\334#\204e\034@\031E\304e\014\235\034\332\340\274\312\023p\314\310\220\363Q\207\235r+\034\2421F'\2068x\353\266H\3040\265@\333W\272\350\3159\355W\350xJ\275s\027\306\017\311\310\3302*\262\007\007\304(\320\206\2635\022GP\030$\355\234+\356rw3\221-u\251\264\206i\221\206\362C\344<\322\353\026X\020]\344q\030\255\353t\252E3{\271\010\345\276XcZ<sG\016+\317\202\343\245\240\366\032r\257#\232\rg\2669?\034N\230<\224\243\213K\323Ka\014`\327\010\362KPj\023\035q\020\034\314\t\340dW\026]h\204^\231\031\356\325\r\337Sq\312\325\272\230\037\025\021\205\223\313\334\273\200\356\027b\221\3458z\237\251\366t}\214hL\203~\366\215T4!\210s5\032\356\246\310\216NH6\035\220@_\367""\227o\241}G\216\244m6\243i\3564\254\317@\333\372\236\304\240\035\361\023]\263\206\347\253\302%\020\025M\000\270\267A\023\310d2d\365\231W/V\356\215k\230\243\006\314Z\026\323t\312J9I\007\244\324\023I'\273\006\345\325\n\233\373\346\377\222c\225L\366\325\020\250\213=\302\250\216\316!\t-qv<\335\242\204G\271\235\326\240\025\324\361\025\242\356\014K\341\330\240\350\323\245g\236c\352\214YY\203\2346\347[\321\036_^H\346\266\275\366H\246\220\023\353o@\353\030\366\0053\244\311\006C$\\\322\327\222\272!\013;\302\276\271\345t\323\024\264\225'+\234O=\345qIQ\255AU\273h\022>\n\366\305\010\371\216d\256\201\"\242\034\315\266\371\307\17794y\305\332(\"\206xp\212\225\331Lw7HA\264\362/ \036E\333\323\330z\016Da\330\274\013\202\345\243Yi\3345\342\235\374\300\215\343Z\300\030#\006\266\006B\007\323\257 xr\035\347\200\032\377\013\257(]\2610P\320 \307\314\346\224\206N\252}c\272+\367\203\020A\342\255|\350\275W\342L\364\010\2127:\322Q\316\353r\021X\246\256#\033\273\207\027W\227\236DB0p,j\256\222x\207\262K\320\223\361\247B\273 cM\222\204\023\364s\231X\343*\364\236\221\200\202\350\257\033|\014\302\322\022\261\205eLD!\013\257\207?1\325\326\372\331\326i\332\030\262\304j\230?\030rg1_!\250\2679\271\317\336\362\334\360\371r\007#\214>;dY\026\004Pn\233\257v8\225\205r\360\365S\3453\212\267\356\0315\203\360[\245\252\274\265\250=\362\262sh9\n\234\225\211\214\016<\304n\230Cm\256%\335e\202h\315\263B1!\n\354\233\332\236\2030;\222Qd\256m\270\031B\200II&\022za\232bA@\205+0t5\222\311\025$N\321@\277\326\203\013\324\2504\214\354D\302F$$J\260\274\275_\212;\030\024\250']UW\255\322\024\256\026\021z\205k#\002\t\340\364\n\014\n\354\201\354\016t\020=&\022\020\302\034I:\341\020\352\275\214z:>\002\345)gx\332\333|\332p\002\014\017\275@\223\001\215\210C\177~z\316\377\001\256\353\371\017\001rgcB\021\317\350\022od)*r\317%\030 ,\004\220V/\202\230:8O6r\031\212\250b+\255\241$2Z3\017\341\006\226E6\3301\224\025\230|t\231L\357f6\203B4\020Bj\034\252\217Ie\t\004\221\234\231B\205-\021\215Qblj\267\274\333\254\345[~<FRW\211 \264+\333\325""\327\342\327\212\324#C<\244A\210\333\233\223\204y,\300lE\216j m\271D\000\355\222v\254\266\022\304x\313\212H\332\221\210\241'E\242\354\225\227\0168\215X+;\210\255\267x\240\260vZ0\211\315\364@|\303D\234:\226\203\246V$\034\207\200\344o\361\363vB<X\016 P\304\276\026\020\222=\200I\"g\262\223t\200'\242\305\273a\322\007(5\304 P\014Q\"\206\200\207 !*T\211\315\250\256$R\204\025\301\001P\211:\250QUz\342\236<h6\030\"\030T\254Z\363\0059\215B\320\272\265\303\013\224(\362\341\315\246\310\030a\267\344\365\257\214\241SJ\336\316\022\340\247L\220D\207\034}\0058\333\235\345H\322V\356}\272\367\341\202bE\337\247>\2427\020v\3027\302\023\033d^\035xyd\3010\312\373\341\023\312\233\264m|\030\325\000$\202\204\006B\010\037\226\261!\036!\273:V\025\326\337\314\301\222 l\273e;)F\330\334\213\222\324\014:8\371|\275\373\374\215w\254\275\031/\333\037\206\201\314\020\236\023\007\001\305\321\315\214\225\002\030\207\350\204D@\224\001Q\257\256\273Y\277/\"\221m\"\267\307\211\r\212\347\316z,\007\r\250h\233\0269R\312\346\027T[4-.\274\315\371\035\200\nS\221\324\204+)z\004\216;\302\024\261at\256Ys\306\"\332Ev$X\203\250\204\230\223M\010b\255\312\313nK5E\263#\220\251CHuA\005w;\350k\271\325uS&\310\016G\\\262)]\2202p9\300\363\3608\035\336\177\223y\257\230\342>:\203c2\355x[:H\302G\221\371\336\306\334&1\252\345B\264LD2\215X<,\242\212Dc\272\222\252)\021\215\260\326\217c\265-+H\025\254\0016[d\352\225\326XY\027\023\223-\205\271\335\357\250\204\306\246]\001\357@\206%`\302\001\220\313mv\337k\216\212\347\221\010dE\227RJ\320\311Gc)\367\305\tc{\354M\2216\224\240\016p\351I(H\240\271:\360\016T\343\2347\200\321\275\302\362\254Q\3404f8f\233\253\252e\312\323\035u);Ls\240\254,c\207\020\333U\\T\257>+(<\220$\"\010\200\243V5flHP\342\"\270\267$\316\026eW%\340R\000\315\020\252:\022\027@#\240]\001\320\007A\333R\245'\307q\325\307\247\246\177N\304v\241r\264\366\033\210\212\014\367zYPT\253[\333}\202\227\211\336b9P\252{\316gt\370\341\025\246\244b+w\212\327'$U\300h\347[\204.s\230\346G8\267\357\277\267\227)\320\363a \316pr\267\367x~\023UUUU""\025UUUUUUUEUUUU\025UUU^\003{\330#B4-\001\365\237I\3225\322\262$ \275\237kG\007\227\331QU3\363\310&n\314\226`\335\271n]|4\036\342\353\374\360\333\022~\321\214\030T\324!\256\230A\t\006C\"2#b\014\246]\346M\275\235\203\033\372\346^^\266Jd\331B\031\235Rr\025P9\251\304\242V\354E\016\257qjCM\215&\302\353\220\205\361\001\336\222%ZK\014\003\003\004x\232CJ\363\010+++U\210\325\275o\322R\233JL\230p\205\266\234\323]p:\007\036\226Sz\252n\2539\274F\036B\276\201\273\323\355\374\377\250\272\375o\201\360\252\007\242G\314\tJ\320mHF,I@\224D6\246di\314B\244.\352\244+\242\230\024I\001\301\204\225\221\242\017\371\002#\356\301\335 \036\223\"\213$\024\223\324(\n\020U\222@Y\005RH\244\210v\200\363\310^\271\200~\240!\327\222 \262,\212\240/\327N&L\204\021V#\030#\320\324\317\331\256\374/\375`HxL\004O\262\317\000\351::\210\036\\\320\205\037\276\224\0201\000D\224\247g\242\037\330\202[>V%e\247\234\206tO\242\004\362R\027\265\375\002\305r$@E9\323)i\n1Y\336\001\271M\331,\213\336\362:\264>\004!\256\n\354\004\350\3271\364Hj\001\273\321\326\3045;\031w\223p\303\371\235\230\365\261\266\333p\007\334\232{\030LA \273B\235\202\003\351\033\215\264B1\212\366\374\377N\247\177:\032\275\371cC\372\355\273m\272\232\006\223Xk\rL\347\367\304\352\010\243&\373\021\264ALg\275\302\037!\330\326\342\276\37750IWc\"a\263\243T\247\225\330\370n\257\251\322\363\247N\002\311\330\022\273\356\353\237\203\373\270\006\266\331\234m`\330\033\0012\001\226\304\217\352B\177\204\240(\0211\207r\013BU\023S\342x~!\261\300\007O\326\361b\356\001K\320\202+\374f\307\004\r=OsB\204\241\002\304\r\333\265\251\000\300\273l\216\217p\220 tz1Q\343H\257Za\237?\307\000^`!LV\\Y+\3251\214R\210~r\233F^h@\364}\016\347H}S\352\364\252\2678 \230\203f\024\240<\242\365w\323\"i%\035Y\23166\357x\t\257\262\031B\302\004?\317Z\033\201\245\211\023\004m\021\220`\r\316\224\353\241A\377N\237\220\007O\354\1771\365\320Bn\007Xc\002\217Qu\023\223;!\223\324\340Oq\324\330O\311\341\312\000\211\275\201\344p;\270:\304\377]_C2\264\302\014\371\265\352\365\235m\331=3\350L\320/+\215)""\253\365\374\233\t\263\375\237\240\026\205W\302\340G9\020\021\307Ia\345\215\327\025\341IS\316\260@4P\035\207\345}\350\352\371\303\323\377\300\016~7@\346\033u\304\350I\256\320\255\303S\244\206\357_`7H\335\264zC\224@\341\240f\374\336n\262\000v{#\215\362L\0235\306Z\245+\0271~\226\370\305\"]aC\324\320\221]\216o\330z|\215\310\236Q\304J\034\307~\227\226r\0177\250\366jTl{[TL\312\034\274\233\374\225\034\245\002F\375\373\356\367\337\2324\317kk\334a\322\335\373\263\203\213\327\336\007o\225\216\337\333\241\337s\366\324m\235\242\2668\365\272\371\365\262d \305h\r\251\236Nnm\377Xs\357\345,{\247\242\014o\202\271\351\363\2649\332\025b\335R\361\371\342\007d\210Q\306\207 \3662\021!\362r\321\275\350Z2\r\roh\235i\001\261\035\217\277\311\307\376\304\016\366\207\021\026\224\023\021\314\220\023\322\307`\310\343\\\234\252k\030}\177\243\304P\353\362\006\227_\214\t\260/\314\316A6\001\\r\324{[x\034\352\372\035\\\023\231\367\272\224l\244j]k\3214u S{\307\337pB\231\005\331s\336\264~\241|\016x\263\253[\203\321\250\024{\213\330\021\356\"\025\226\352\2218\027:\352\317E\264`\337Z\270\316D\266\370\310\350\273R6\026\245%Fs\ruF\3653GJ\317\246\342\335W\035\333\224\027\333\021\327JB\276\021\271-QF\213\226\330\243\234\341g.O@\344\214\205\3109#b\205\366w}v\321m\244\351B\263\207\275Y\373n\013\366u\373\326\330\376T\272A[u\345\367+_rP\253\203[\327:\335\3575\342\rn\340\301J\027JwHGJ\365Q\365\022\253\255\364\313%\255\307\216i\334:\320\257@\271\255}x\314.\005,\230-[tS\307=<\014\345\202\225\"\212\213\226\274\232\345\223]\232\013\333\024\330{\005\n]]N\326\241\252\014\332\316]\206\235\255\021\274\201\247\253f\362\343\017z|\001\253\323\262>-v\3568)\225,i\355\026V\312\352\276\014.\263\240\272\324?T\351\n\273Vgq\232\343o\252h\350p\235\244i.\210\364\320\340\337\317\005\353\347\350\275\344_[8!\264\277w\313\320\233G\243\236v\231\3620c\265AD0G\360\216\322*6X\247\212\315\026\024K\201\236\257Lp\305@+\200\274:\330\\kIj\026\2315&\203\017\303\331\201\254x\327B\010,\220\305&P\315\005\252K\342\316v$\322\334\264\246\225\016\\DLW""\347\260\027\242\255\210g\315.\\w\313,\315Z\317\001i\032\316a\235\340\222\263\030-d?a\373\246C\014\310_\330\345\225V\274S\217\263\233\310\344\273\277\020\252\005\357{\215yK\034\375\361\327Z\376i\254X}\031\232\306A\227\246\306\217c#OI\327\333T\370\330\310\361+\316\316M*\237\226J\202\330VNb!\230\2445\226\351\250\020\370\201\252P\215\241T\305\346*\230a\3000\260\352\233\336\331\363T\372\217h\340\371\263i\001c\301\306\355o\37272;\272|\006\357\367)c\033\315\214MM,M\014jxX\233M\342\261\235\234)\021\315\003`\253F\016q\206o6\271\307o\177\362)\360\214vP\366\006muXC\271\224%\340\350\033$\250Fd\211\356M\342X:)t\341\367\367\306\3657i\332\315?\016\231\341\247\237\314V\306v}h}\"\034\214\312_\027\317\340{\326*\257\033.\2526\330R\217\n\300\025@\316\023\246\0266\245\031\3604\270:\n\311\002\302\222:\206vQ\261\003I\244\3655\022B\304t\325b\n\253,\320r\210@[\226\004\230\231\006d\202\231$1\210\250\226\206J\266\021h\264\035\205b\255C\3022\310FTV\031'q\2336M$T\220\222X^X\241T\030\223\311vl\341\301l\313\244$\314\240\2143\362\365\231Y\271\242d\202a\032\020\032\202E\006\004\210\032.Qf\234 \030\201*L\\\200$V\202\232\301)\3746*`\03499\242H\272 \t0\022\027`\n-@\262$\353!\tBX\222\t\200\310mQ\266\250\006\326;\313\221B\3361bl\342\234\233G+\010\2724\035\247N\024S\207C\301\324\203SX5JN\223\264\255&\000\243WL&\361\233\202\335J\031\213*\321U\266\263K\"\264\014\342\341kem\214\271!\322\362\036\252O\305\314\231\334\023\333\313RC\032\356\216\035\333`w\2603\330y1\267\322\261\276\254\001\254\255\242\252\267I\025!\324\335m@`\031\222V[H\343\001\306S\253\272ZUh\346M\307\000\247FJ\330@\274;B\0006\014\203\226\340'\202\206NZ\363\000\366\235q\337\004\010\261\361\0232\026\224\242\345\227%.e\023%\307\0210\242D\034h\210\3010\262\334\303\030\254\302\333Q,\266\331l\245\213b,e/5\017\032v\2134\355M\376G\003\304\271\311\341mHqk1\265\377\342\356H\247\n\022\020\261\302\317\300";
    PyObject *data = __Pyx_DecompressString(cstring, 7021, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (7462 bytes) */
const char* const cstring = "x\332\355:Kw\323V\267\215\355@\200@qqH\002)\265CB\022\332\206\032\002\341QZL^\204G\300I @(\252b\313\211\210m\331\222\234\027_K\207\031z\250\241\206\032j\250\241\207\036j\350\241\177B\177\302\335\373\034=m\307q{\327]\353\336\265.\213h\037\235\347>\373\275\267<1\303\346\363\202\034\02596\r\217t)%\363B>\272\303\212<\273\221\345\242|>\232\025\204BtCH\357\317\354\313[B~rF\310\025\370,'N6\276\317\211\242 J\264\367\206\335{c>+\354\316\010yY\024\262\223\205\246=^\026d>\307\037p\215\375ox\211\227\005qn/\305\025\010F[l>\235\345\363\233\321-.[\200\t\247OG\341\037\007\373\3563\005\201\317\313\360f\035\3638+\244\266\243-\226\222\331Q2\233\254\316\360y6\233\335g\240\237\023\375\253\227\0041\307f\355\031\321T\226-I\334\321\033\354\361r\264\243\rp\242\273~\201\313s\"\237\"$\226\242\254\310E\221\027R\251P\020D\231K/\210lak\207?\210\316\276\\\005\346\344\323\234\0107wz\245\322\306&\266\243\302\306'.%O.\346y\231g\263\274\304\245\243\254\034Msp\250\310\022\022\000\221\271\037\242\334\344\346dT\222Y@\017\220\022RdlrI\310sK\202\314E\345-XE\031\021\345%X\237\34578\330\200\003\374%\031\360D*\301\244|\364\325\334\253\037\247\356NE\201\260\200\027\036.!6p\236$qRT\310D7J|V\006\341\221\367\013\2344\031]\314D\367\205R4\317\001j\262\020-\300<\357\002y\213\313G%N\306Ft\214H$\301\215\201\345\300\270\261h\232\027\341\020~\207\303\325\363lV\342&_\347\t_\361\256\222\304o\346s\300\034 _\232\213\216J\257\363%B\004q\263D\272\307F\245\261\306\276\0356[\342\274#\224\271\236\016\221\223JY\031U\000;\177\213F\207\177{p:\372\343/Qx\376qz\362\372\367\277\376qz\370\3030J\342z\224M\247\031@\233\333@\356\217\246S@%\344%\020\221\003\322:\372\204;\301\306\031\340d>\005g\300\346yN\002^G\245\224P\340RT\204\230\014(\315dZ\220\031\213\026\034\223\3462R\323\250P\222\013%9\315S1\030\225\242\237O\247y\t\017\342\362\370\034'wz\270\231\002\231 \035\351\350z\226\335\340\262\017\207\221\375\331\006\274r\374\346\226\034\335\340\274\010np\031\001\344\322\245q\253\205\355\346G\307s\354\376\006Z\022*\235\007\344\326\022\017\214bA""-\004\251$r\023\037\362\224u\353\322\026[\340\036n\010{H\352ug\337\250+\354\344\226\343\262\310q\321\214\310n\342\021\023\273\254\230\237$\3070\245\274\347 \322_\"\334\3644\031\220\001\357+\345s\302\022\014\033N2\014\356\3040\t\347*3B6\013b(\210-\272`:1\237\034\223\"\032\324r\035L\002)\227\010C\333M\333A\353\307\314\260R\212Msiw\306\022\320\350\350\371\355GW@\221\262\334Q{=\347%\331\377\326\356B\326x\213\273\354\347S\363\202\270\002\275t\177x_\224\321\210\010\"v<\246f\001,%,\314\313\363B6\rhy\r\247\267\335\214B\303h\023\002\276qT\311\324\026\237M\373z\323\034\030\300-_\027\227+\310\373V\217\307]a3\001\346{_\342\245\026]Gb\3270\351($\375\323\250\241`\n\"\277\003s[\236\007\276$\r2\311\020\013\336jB\216\025\267\031\326#\001GL\001\rE\217\303\310\240\010\334\321\323\n\340=@\206\262\316\374\016\266.\010 k`\271[M\240r\230\310\201\373\226\300t\243<\264\231\006\216A\224mAj;\317#\320\355\346\371E\363\350\231\217\005\220\013>/\024\216\231\006!\323\366\361\273\315\200=\231\005O|\314\254\031\364\204\263\\\346\230i\253\340N\217\237\325\322n\264\231\017A\227\310\201\013\226\200q\307M\315\247\347\366\n\342\261\263@\311K\334\361\3249\366.\263\\\366\370]\200\255\363\242\220\353h\342b\276\203i\260\331b\016c\260\016\346\226\362\251coA\342<\264\201\217!\214>v\366b\346\370c\027\363\257\262l\212\353\224\305\317\205\343\304\371\205\220.e\271\366s\226\330\334q3\332\216\276\262\014J\247X\333\363\227\331\374&\327\331\3245^\336\"F\375\230\351\373\235)\3342\013\221\323\361\334X\006\356v8Q.\211\035H\340\n\006\203\035hZ+\247\336n\366\001'd\336\260\307m\n\350\241\207o?kU\334\247)\326\361\267\201\251\3634\017\352`.X8\376\030\337\260\006N\275\003b\243,t6k\2258B\227\214-VaW\323\273\023#6\r@N\345\351k\033*\034\023\"L\272\361\254\257W\3028@\346S$\001\245\236\231K7\314\220E\210\024\374\2759\266\3004 G\303\006+\354m\036h\345\364\351\020\211Y\374\316\376\310(\200\0168\001\275w$\317\355nxB?\253oOn\356$9\265S-X\025\331\274\004\261I\256\261x\340\211\341hM\302\251\005\314rRJ\364\2779<\234\203\334\234\230\016""\247\321\3146\357P\023\323\334A\022P\332\332kC\311\347}\026\336,\274A\034\341\236N\303A\305\355\201\030\326}\001t!;\362\274\357!\203eF\022Jb\212\223\334\001\314\245x\317BZ;Xx\3439\300\352[\2446c\021+ \240\027\204\\\336\200\035\035\007!\223\323p\366x\301I\022\273\311Yy\006\220\263\251\243\231~\255\2464\321\261y\022\207h5w\213\034\372\350\346~L\356\3000\242\273\362\230F\337[3jM\343Mx5\314\340\363 \313X\241\340\032\006\260\013t\243\200\004\316\247xN\302\361YKW\274m\207\224\276N\377\276\313\266\306\370^|+\275\275@\022\221!nX\262Kk/\211\254K\257\3361++\213\357\347\230U\346E\342m\223k}\265/r{h|%\006\274\343\036\374\315\362 ZK >\260\377\n\237+d\271\031X\202sW\210\341\361\233K\357\273\203]\323\200{\267\246\241&\252\255B\212o\225\001\021/\307\033\372^\234\243\374\2759v\237\331\340\230<X\272\327\336\202\200\357\245Y\006\032\207\233D\340u~;/\354\346-\320j\003{\240i\251u\025\0064\332IL\261\n\267\313\344K\331\254\257\316\303\026\220\n`\221\341\277d\233v\006\225Zr\25514!\243\341\205\311\224 \n%\210\2679i\203\225\340\201\251\013\231\274\301S\023J\036|Z\"P\302J.\3761tL(\345\323q\362\274\231b\n\373\014\354\177\30012\341Q\212\3153)\201\003\333\302\310\002\014\322:c*\343\361\t\022\274\201\243\301+@\213\226`\254\027\307\326\343\034B\013\200Xp!W'\017\030f\030R\004d\030\273\001\216\230\227\271\234\375J\2133\244\r\307\3232j*\013\267\305L\030\315\037\267\001>.e\027;R\220\240\020\327\3434\350=S\220\255\001u]\342\244\344=x\010\304\320I@t\026N\001@\370\017\213\032\322q\333\323\245\321\002\322\n\002\303\244QA\350\023\037\244\201dK\363`\247\3054\014\t)\372\300\003\335z\035\307e%\216\241W!\236\202\241\025h\033\240K\307\302\035\350\000\251\337y\212\334\\\036\2344\226d\271\374\0161\212\344\001\016\335_\367\242\216\202\333K1\244\312\311\021\207g\235(q\266\373s\032\330\225-\2459\206\024\262\255'=\017\024\212!\225\311\006_\223\301\032,\356n\227\300\351\346\276\212\272[\035\367\034\357-\231\373\n\032X\324\314\0242\220z1VU\220a2\220\\\321'\242\271\211b\013\342\301 \373Ab6m\025ch%X\344\371\214}I\020O ""\0161\000{\020\312\2027\200s\254}\211\340X\362\357\032$\322\302\222&C\304\217\270P\354\002\r'\343\266\241q\311\014r\317\302\001\3739\241$a[\334$O\221\335\007h\025\300\335\026=D\002\205BS\272\307\220\246\245\271\330.\024\250\304[m\201p\006\253\371\266\005At\355Mly\204&\221\000\036\365\306\3121\241Mj\264\250\226\340\035\000\024\366\251.\261\262,\222W\252\310\030Br\305\022\252(\240\222\227d\261\224\242\353%\222V`\003\214\000\371\244\200<BR\264\016;I/\256f@\030A\022\tb \0019`6\335\321\212D\261EoP\312\223\2753<\351\264\313\311<a(2\000\377\300`ZW\262 Y\234%\025\354\354\226\004\377A\024$\231\210\0036\3500\336\235\312lV\020\266K\005,]\221\362\025a8\003F\n\230\001\317<\004\r\242\025\016\373B\340\206\260\327\027\352\266\250\237\035W+\363E\304\376(8\307J\3339v\317\343\255\030O;G\003\233\034\232\033j#\275M>\237\333\336\315\221\254\035\336,\010-Q`,\343\201\257(\001\316\223\333%\017B\007\014\260\031\267ei\220\023vc\203O\243\022\320X\322\t\275\301M\021\344\360?x)\370\203(<m\201\270\005o\202X\203Z9\006\306\336^\0022\001r\364\t/2F\235\005>]\020\n@ \233F\200x\001\342\030\026-\200e\200\211:\202w\242\202k\351c\001\302\224\324\026\007>\255\224\243o\324Y\320\266e\032\260\351N/\301i\251m\240T\213:\371\22130\027n\030\364\226\217[\017a\016r\364\210\235\2036\314p2\210\206\376\246\020\267a\334\037\2006\014\372\202\232\2461\022\257\320\336\035\231\230?\370W,\261Y*3\"\306\207\344aQ\321\nx\230\246\320\307\351\000\333\3068_\222\235\206$r9a\207\243Y\007p\027\253W4~\267\203V\221\203a\010\017\304-\t\376S\rv\037(\022\304?c$\304\242jp\331\214c\2760\334\262\244\034Z\226;\367\004aL\213\200\314\362d\222\230\"^\035\r\034\232\000\204\336\266L\037\273\274\274\205\353\311\036\244!\311\\A\222\205\002~\032-H\245\r\364\225\222T\002\r\240v\001\247a\366\005\206\221xJ\031L\021\245\242\375\347\013w=\006\221L\242\037\247J\2054\234\007-\007\177\354%^\235<\244\026E\365V\005\364V\305\362\326\205\361\026E\360\026\005\357\346\342v\213Bvs\321\272]\201\372\210bts\341\271u\221\331WPn*\036\267,\024\267(\n\037U\000n*\366\036]""\330m,\342\266)\330\372\213\263\215\205X\177\321\325-\260\266+\246\036Q8mS$mU\020mQ\374lY\350lU\324lU\300<\272X\331\2420\331\\\204<\242\340xTq\261\261\220\330\242h\330\\ <\276\030\270k\225\025\320\022\020\177\264\213q\311\0361\216\177u\325Bq=\254_3\272\260\371\275\026\327\346\365\0306\257k1\355\216\0366Cc\346\330\264^\254\365\2349\234:\224\313\267\225\256Z\357Y\372V*'j\275\003JH\231S/k\2175\266\326{\276\334]~\243\334W\223*\257\025\351\353{\245X'\263\341\375\233\362H\231\305\265\267\016a\362\327\207RyL\351W\273j\347\007\224\240\022\257\237\307\275f\325\223jQ\013jq\234\260S^\201\363\316\207\311Vf\337(l\314i\267\315\237\036W\256Wg\252\262\271\262Z;{\276\334\205\303\301\362\2642\241\306\325\031\265X;\177\241|\253\314\326#Q\365\254\226\3246\365\017\225\241\352\232\271\372\326|\273n\256\177\250\365\r*\027\340\234\256\032L\350\302YA\363*\\\321\200\223\"fdDM\250\257\315\353\277\032\305:l{\262\\T\272\352\377\350\272fh\304\034\271\013\273\365\364\036\276T\342\000\314\336o\225$\201CJ\302\014\3353\302\224\200\273\345\2642\242lka-V\353\035T\256\300\305\273\265\327\372\230q\251\022\307\355N\2243\312\002\334)A_\322JL\271G_z\000\215\204\222DF\375\240%\2647z\374\257\004\301\322\374zX\215\251q\212\314G\\\373W\242f\323\0377\331T\226\025Y\275\243E\264d\215\334O\006\312\003\246\013\345xy\026\210\355\235\213\330e\324Y\rz\277>,Z'\330\203\237\324\020Pj\0256Z\326\212\366!\022\341p\357\205\362T\271\210\367\2379\334+\357)E\234\212\374\024\313\027\200\210\347\373q\220\354\350\021\253:\254\212c7\276\235P6TB\300%\2703\222\360\360\205\022Q\326\265\220F\366\331G\251\210\224\347\224\213\312\001PoB\217#\317\357)\211Z\344[\3457\355\272\236\320W\201\310\347\303u\017\217\322@e\330h\256<\250\304|\307\023\306\222\303Q\214\342\260m\030\307\245r\214\210{\317\005\004\n\341\331\275\362\2022\245\024)\013\272\224!\270\177X\033\327\257\033\t\\\034*?A\256\340\342\022\356\202\270+\363\352U\230\325\247qz\\\2373\302\306Uc\331\020+\221J\262\302\372\020\260\230\212\367Z\200e\t\274\321\024p\3476\n\352\20090\241\205k""\221\276f\304#\300\266\223\212\244\216\300\005\307@\225Gt\242[EJ\240\357\264.\355\242V\254\303fw\210\324\367j\263zH\237\005\361\214\014\002\206#\n[\273t\271\356\337\025\t\320{I\211\325\361Q\3539w\230\003\036\364\206\313\375J\257\372B\217\350\257\r\350={\270\214|P\372\024N\215\333k\033$z\010\310\236\321\022\235\311r\253-\334u/\250\225\372\273\367\253\263\341\266K\006\225\0015\254\216\252\245\177x\356^\031\025\336<\0176A\215\250\357\265\242G\374<\3249\000*\222\345_+d\306\023\340\001\200\3052*8h\021\010>\235z\033\355\222%Uh\027$u\324\034\273k\004\215\333\225\236*\210o\037\250\347-0g?\203q\205\027\013\217;@\344\020=\340\024\260gB\275\017\352%\353D\241\317(\226~\334\263\361\246\026EYU/\252\262v_Oz0\375\205\342\031.\017\240\034\326\360f15\214\222!\003N \033Kj\254v\266\217\030\330\306Y\365^*\375\323\312U\220f\230\373\002\372l\206\203\371\207\006U\322\024\241\364\256F$\231Z\3573\340Bf\365\023 \204@\216\331\362Yk\0033\006\026\321\210\030o\320\262](\337\267\354\341\267\212\2133\271\014\232e0\262'\314+0\277ns\240n\315UXGRQ\333P\360\251m\201\013\307QdG\224\264\032s\214_\355\374\305r\016x?\247\365\353\347\014\266\326\270VV\247\200nDx\321.\\\002\325.\241\240\325\302\027\313\234y\371\006\310\000\266\224\237U\253\001f\304\032\373I\357\252}\323_.)K\332\210\226\326G\365\242c\277\212\356~\017P\372\265U=li$\260\031v\001O\007\026P\351V\336\251,\032\325\336\303yp\204\337\300\351{\210\216\317\354\315S\227\351\354:_\276Ni\204&f\246\\t\\V\262Y\\=F\335'(\255g\264l\266\236\207\306\335V\225>jWqb\327\337=_u\237=L\324Bt\376\274\362\203\312\326B'\377\3329\\\003\233\022A^\177S\206\311p\373:>p\014=\201\371\3658ZvmM\177f\354V\220\307\336\236\377\326\306\223\300\234\230>m|_Y\253&\352\376\236\244}5z\237r/\030\212\233\352k`(\353\033!\312@\203\224ib\314#\200WB_\301\200\001}C/\004\035hm\210AE\215\271t\2716}\317\350\003\211\263lx\034,8\221U\313mQO\237\254;\266\336Kh\357\231DMUG$\246\325X\315#.;\350~\334E\304\032=S\212\177\237\370\352\324Y\260H\253`\177\337\"\252T\353o+g\210\035$\030\014\200\215K\252\254W""\303\210\304Z\261\200E\021\022\375xB\002\032R`@0\202Q\343\030\370\330\233\277\3005G\306\265Sz\270\263\211g\365\244G\240<!\005\036\026\002w\031C\374{]\267\350\372\357Q\315\272\033\301\264\326C\035\330\246M\2059j;A\312\373\360f\324\250\357*\254\023\347(\217\025\026\224\376gmWO\033\261\272\245^[`3\256\221\310\302\345\202e\325\001x\336\201\210\346\005\214A-\361@\n\177\003\376\371Dc\007D\260T\257\261#L\315+\304\271*\301\362)\372 \214\205'\220\235\224\267O@\244ct\2077J\334\335\014m2\330\335\267\264i\367\257Q\363_'\233\261\240\033\247\"\345x\315=\256\217\330>8a\\\271\206\270\330\304=\205\366?R\366b\206^\260\033M41\311\020\354%,I\305@jU\355\207\350\001\003\305\310%\272\023\360\023\232\020f\327\"`N|\373\234\2048\257\004\034?\001\201\361\371A\320\3115b\224\210\202\004Q\001\006\225K\020v\206\353\2441\245\022k\270\216\264C\372\014)\257\251\335>\005\361\004K\207B\352\002MG\352\026\325\306\020\037\252\250OIX\001\375\317A\373f\265^\335\342\323sj\242\236\226Y\317\333\263r\321\036=\251\210 \370o\264)\315\352\262,\346\231\326\342\366\331\0306\036\033ls\330\350\261\320\226\372\\\305;\201\024\315\351\227\215\331\212}.j\336. \343\tV!FC\252LCx\025\211\0012\257\301|b|7\016w\033\270L|\315\320\2046\004Z2\364m-rYy\250\235\006{\025'\301\354\327V\006\346\331n\004\003\313\343\021\374\007Wt'\022\013\337fK2@5\322\352\351\003q\350Sx\270CO\270\034)\277\206KZ\215\353\266\217\362x\022K\215\033\222\217\006$Y\014@?\331\001\370\375r\222\016\276\203X\300n4\2408\255\216\003M\207'\264A\235F\374f\030\202\032\010\220y\022I\r_s\"\345M#\331\336\236Z\030\272v\215&\241i\355{\235\251\314VO\231\311\345\006\333\354\334\tMK\032\324\206\204'^\374\374\200v\277$\211\3025\255\013\325\272\017cIt\034\373H}$_\022i\220\006\213\361\263*\241{\262(\0019\330)@\270\267\037s,\024\265\275\362\216\262\242v\3035\006P\312\250\307\212\251w\2658\365Dt\024\364\031W\354\250+\332\031}J\227\214\230q\2672]\275ZM\326\006\256\302\344\333z\027\254\036\214A\260 i?\200\251\274j$\215\255\312fu\305|\225D\031\275c\306\356\033#F\252\022\256\\\253""\236\254J\346\362JmhL\335\323J\340\026An\277\203@\246X\213\376\244\367\030g*\361J\242\026\275\252>\324\273\352#\343\3468&\306\343\223$\033J\324\306\343\372\000\244D\327*'*\231j\242v\377W\343\240\n\236\342\216\316\033\305\332\310\217\220\327\336\206\2501\\\033\271\241\355\351%#\201\354:\376\346\203\200\333\026l8k\276zg\276{\337D\207;`\235^\253\023`\004J\372<\\n\r0\214`pLL\337\036\370r\314\356\007\206\314!\314\255\337\272\234\006\262I\300\351\273\352\2646\014\346\307\235\261j\336[\004\304\207F\325u\240]\004h0u\2736\365\2631\007\024\212\271\215;\367\215\211J\334ry\177\237\203L\206\306P\003Z\304\374\361\027#]\231\250\022\343o\261\234\312a\t\275\226\023n\rha\253\200\002\246`Z\031V\022\236!\330\345!\220\010\314\357e\222\232\207k\343\023\265\361\037\300&\205A\023\234\206\225s\307\235t'l\205\337\243\276(\322\351\360\304\216\346\367\017\214\2701k>ZF\236\333U\001\013\337>*\247$\377\277M\263\030R\010P\272\250e\217PGs\207\324|\"\350#H@\177\231\004\276\"\270\006+\217\"\231f\027F\372`:\321o\333\001M\222\206\275\350+\301\002>\305\304\023yv\n\375}m\340\212\362\t\334U\030\235\307\032\246\317\270oQ\365y\000L\"V\301\346R.\255W\202\225\251\312N5I\263*Bz4`at\251\275\207\323\220\001Q\035\004\354\317\221\\'f\221\014u\372\374\2202o\016\377\014\231?\034\370\0016\375\000\304\375\201\306|\004\2553\304#\200k\302\314`\312\354\307\342Z\242n+\277e\021\340<s\020\205(I\375\026\257\354\230\243\267\365d\275\347\234y\356\n\2326@\372;\345\213\306\022\"\220,\250\356\341\225?\362\363d\242/\301qti\227\314[\263\225\347\250\266\256\247\362DMu\2327A\332eFo\021\215\014c\212\222%\006\224\004\247\2506S\352\201~\305(:\354v\214|\335v\032\365\236\213`\353F\225}\315\262\353\227I\316\275D\034\227m\024\355\320\355b\371\000I\3513\226`\242\207i\227\327=8\235\270!d=\276\300\320Id\347 \236\210\333e\023+7jr\223N\020\021s\334\007-0\222\364\364\031\030\303\244\023\243\003\373\317^\006\022q\352=\355\211>kt\033I\247\270\347.\242i\327\033\355\036\330\220\230\035b\235\240\333\266:\336qm\375\344\376#\220\372?\3207\214\200A\306""\332\373\265Vn\325\271\016\035\244\262\357E\303\301\270#\324\234\372\345\236\352\211\306\023G,\201\340\362:F\241\235\242\016\330!\363\372\375R2\250\304\232R\201\022\251\260\311\352m\032\352\265\010Up\243AR\206\035\364U\364<\262\323O\353f\365\036T\\V\371C{i\304\275\202\231h\2124n*\313\312g\022\025x\267\264n\371/D\365\210\003\300w\327[\0079n\311n\220\310\306}\375\255A\022D\354p\355E\270\014\366\037\303\3065j3\316\200\231\032&\026\261\227\244'X\266\267\234}\221\304\224\032\251fX\231(\326\262\355\206mT\337(q\032\245n\330\231\0005\331\366\211\2202\307HA\3543\270U\222\350\\\"\272q_K\326\032M\301EL\267\220\277$~mL\355\022\365\2261\037]H\312\320\255)\343y\371W\262z\331]\333^V;\276\230Gf\235\264\231\306%\031\020\3130q\311\264(s\266\237\250\036x*Oq\361\035\226 <Cd>\346\3111t\025\323X\224\205,\276\307\223\351\266\"\327\021i\362\377:\0325\005\370;\304?\267\026\013;\326\030\264\303\\w\272\207z\346\315\307\020N9q\316E\010\344f\215SXT\377W\"\366?K\261\213\340\324\213\220\350r\030X[\331i\313\376\2274\365'\345v%\3414\315\241\007\306Mc\025#\310\277\334T\002\374\317\030\365\007W\354(\007\353\037$\307w\n7\336>\273\\\347\"F\213\274S\345\317\352\325\206\324\314r2>\307\323y\272Fg\336U\217\237{\034\361\352~\034\353G8\302Fe\354\340\\+\245<\236{$\314\240e lB\0347A\262\356m\343\002\344\371'\350G\034\034\271\243\204\355\346]\340\337\034\204\313{Z\021+\341v\367/\352\005\325\336\310\2740\206\345\024\232>\237?<\200\230l\014\204\376\2061h>~k\276}\327\356\233\035~\270X\002;?\245\025\235\322VC\242\357|\300\033\007g\222\321fuj\317\315\320\217Z\322[i\247\330\336R\262\340\372\372\rOu\362\234\236\255\220\357\300\243\364\023\016\255\301\236;\\%Urtd\031P\271\236J\250\362\264\2326\227\327\315u\306d>\231\237\362f~\317\334\373\317\337_}\365G\327B\000\300B\340\031\202g\2015\004k\201u\004\353\201\017\201N\213\271\262rO]\000\025\tB\252zP\351\257vc\032\272j\256Bj\367\273\371;gr[\346V\326\314J\246t`\036|\201\315\037\005f\360\214\231\200u\376+\004\257\354\363? \370\020`\0200\201\024\202T`\033\301v@D \006v\021\354""\006\016\020\034\004\376D\360g\340I\020\300\223\340K\004/\203\253\010V\203k\010\326\202\353\010\326\203i\004\351\3406\202\355`\001A!(!\220\202\273\010v\203\217B\210`h\001\301B\3509\202\347\241\227\010^\206V\020\254\204>\"\370\030\342\020p\241O\010>\205r\010r\241\"\202bh\017\301^\350\013\202/\241G\335n\271\373G\374\330\240\217\031\227+\013\325x\335\337\363\377<\374\277\301\303\353\350\372\264]}\033\010\325U\367\367\204]\036\206;'\376}\214\026\335\003n\3427b}\327\330\256\366CfX\367wyN\030\004W\277\005\221\367\004\341Z\244\362\321\\Y3\327\322f\032\270U2K\373H\332\256E$\355b\340\005\202\027\201\245\177 \022XF\031\325$R\206[\253\314U/`\301\006l\037\010!\234\261inn\233\333\262)\177\206\215\377\323\225\300\375\023\201Y\004\263\201'\010\236\004^#xm\213\003\213\200\r\244\021\244\003[\010\266\0022\0029\360\031\301\347\300#\344\340\243\340\014\202\231\340\002\202\205\340\n\202\225\340{\004\357\203\014\002&\270\201`#\230A\220\t\346\020\344\2022\0029X\n\272\264\374\001m+\230\3163\225\351j\254\356\357\211\273\244\304\340c\032L1\3339y\3603BI\233\321d\375\216\321_\351\256\254TC\325\005s\345\275\371~\335=\376\006V4\365\005\343Ae\263J9\351\366\260\376\343\357\252S\370K\036\331\270W\231\255\2363\337\300F\240{@i\252\361\310Ps\237\352\236E\345\271\300\277\301v\332\030\253\364UR\325H\2251?\244\314\024\010\0130R0\205\366\274\264\004h\025\301j\340\035\202w6g\177G\360{ \203 \023\310!\310\331\212^BP\n\354#\330\267\025}\016\0315\027|\212\340i\360\005\202\027\301$\202d\360\003\202\017\301\024\202\024\350\373?&\346\025E6\257\336\326W\215K\225)s\341\203\371\001\310X4\213@\300\317\346gJ@\277\325\264\356\364\026\301\333@\001A\301\026\314\307\210\306\343\340<\202y[\024-\223\3646\3309\375\037j'!\010\236\321e\363\301s\024\023\372['P% ?\245\375\256\271K\311\337\201-\225\020H\266\365\374\202\340K\003\252\317\020<\013.#X\2661\266t\350#\202\217\235\330\322/\010\276\004\347\321\n\316\207\236!x\026ZB\260\024ZF\260\034b\0200\241\014\202Lh\033\301v(\217 \037\022\021\210\241?\021\374\031\232\353F\256w?E\360""\264\373\005\202\027\335I\004\311\356\267\010\336v3\010\230\356\337=\346v\n\177\014\003\032v\246:m.\257\324\375]q\037\333\325_Hm\367\2373\305xX=Y-\231\253`>\201+\240\016\242)J\235\243P\013a\314yM\3572CW\024\366\357\323_\235\n\227{\025\367s1\rs\311'\277\353\366\017\220\212dn\255\347\364\341\265r\227\031\036Q\037\333?\200Z$14\213\237\002g\314~\022\206:\325\207'$}\215\320\022\3255\374\"\205u\361\241(\244)\233\332Gc\312\3745i&A\252@\257\301@\203l\361\265\301\253j\\\235\207\255\007H\301\26564j\216\376j\310\225;\350]V\311\257\356H\025\336.\330\r`9\370\233\362U\372\031\263\326{\3560SN\230}7\010\245v\r\326(\372\220\364\314t\276\016~S\276\246ta\331tN\277\000\332\031\307__\221{\226\301{\325C\337)E3\372\223~\006\324v\033\313\366\241\013\020z\017\220_\007\001\311\377\203\237\336j=?\0015\343\217+\223X\033\r\001\361\216X8\r\0214~\244u\027\"+\256\353K\220\177\266Y\366P\355!\245\027w\331\r\255h\376\364\250r\256\312\266[wOyB\312\006\356:\254\032?7\316U\332-3/\214\250OH=\310]wK\217\233SO\320\320\257\265]yM\335\202\330\242\350Yy[O\232w\236W\227\210\2439\032\325\007\020\033\260\252w!\344\026Z\336X\252\266\245\314\317\230^\203`\271\313&\341\374/F\276\232 \313L\\\324\201\210\237\305J\230\365CD\353\313:\251|\023)#\233\324m\331\037V\207UWBj\336\357\362\375\220\004F\2247\230\252Z\303f\350[\363[\374\345\217\363\003\267\260\373\203\000R\235@}D\2559\241\261\330\274A\223\274\377\002f\370R\212";
    PyObject *data = __Pyx_DecompressString(cstring, 7462, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (20113 bytes) */
const char* const bytes = ")Cannot read reduction variable in loop bodyCython.Compiler.Cython.Compiler.ErrorsCython/Compiler/FlowControl.pyCython.Compiler.OptimizeCython.Compiler.VisitorException handling helper.\n\n    entry_point   ControlBlock Exception handling entry point\n    finally_enter ControlBlock Normal finally clause entry point\n    finally_exit  ControlBlock Normal finally clause exit point\n    Generic loops are not supportedGraphviz DOT renderer.Graphviz subgraph object.Initialised at declaration time, e.g. stack allocation.NoneNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.Unhandled assignment node %sUnused argument '%s'Unused argument value '%s'Unused entry '%s'Unused result in '%s']  \"];\n -> ;\n }\n.*+?}\n\"\\\"\n\n  [ add_noteblock%dcan not delete variable '%s' referenced in nested scopecontrol_flow.dot_annotate_defscontrol_flow.dot_outputdigraph %s {\ndisableenable(entry=gcisenabled [label=\"local variable '%s' might be referenced before assignmentlocal variable '%s' referenced before assignment (maybe initialized inside a closure)\\n node [shape=box];\n [reference  subgraph %s {\n(tree fragment)warn.maybe_uninitializedwarn.unusedwarn.unused_argwarn.unused_resultArgumentArgument.__init__AssignmentCollectorAssignmentCollector.__reduce_cython__AssignmentCollector.__setstate_cython__AssignmentCollector.visit_CascadedAssignmentNodeAssignmentCollector.visit_NodeAssignmentCollector.visit_SingleAssignmentNodeAssignmentListAssignmentList.__reduce_cython__AssignmentList.__setstate_cython__AsyncForStatNodeAsyncIteratorNodeBuiltinConstantFoldingControlBlockControlBlock.__reduce_cython__ControlBlock.__setstate_cython__ControlBlock.add_childControlBlock.detachControlBlock.emptyControlFlowControlFlowAnalysisControlFlowAnalysis.__reduce_cython__ControlFlowAnalysis.__setstate_cython__ControlFlowAnalysis._delete_privatesControlFlowAnalysis.find_in_stackCon""trolFlowAnalysis.mark_assignmentControlFlowAnalysis.mark_forloop_targetControlFlowAnalysis.mark_parallel_forloop_assignmentControlFlowAnalysis.mark_positionControlFlowAnalysis.visit_AmpersandNodeControlFlowAnalysis.visit_AssertStatNodeControlFlowAnalysis.visit_AssignmentNodeControlFlowAnalysis.visit_AsyncForStatNodeControlFlowAnalysis.visit_BoolBinopNodeControlFlowAnalysis.visit_BreakStatNodeControlFlowAnalysis.visit_CArgDeclNodeControlFlowAnalysis.visit_CClassDefNodeControlFlowAnalysis.visit_CTypeDefNodeControlFlowAnalysis.visit_CascadedAssignmentNodeControlFlowAnalysis.visit_ComprehensionNodeControlFlowAnalysis.visit_CondExprNodeControlFlowAnalysis.visit_ContinueStatNodeControlFlowAnalysis.visit_DefNodeControlFlowAnalysis.visit_DelStatNodeControlFlowAnalysis.visit_ForFromStatNodeControlFlowAnalysis.visit_ForInStatNodeControlFlowAnalysis.visit_FromImportStatNodeControlFlowAnalysis.visit_FuncDefNodeControlFlowAnalysis.visit_GeneratorBodyDefNodeControlFlowAnalysis.visit_IfStatNodeControlFlowAnalysis.visit_InPlaceAssignmentNodeControlFlowAnalysis.visit_LoopNodeControlFlowAnalysis.visit_ModuleNodeControlFlowAnalysis.visit_NameNodeControlFlowAnalysis.visit_NodeControlFlowAnalysis.visit_ParallelAssignmentNodeControlFlowAnalysis.visit_ParallelRangeNodeControlFlowAnalysis.visit_ParallelWithBlockNodeControlFlowAnalysis.visit_PyClassDefNodeControlFlowAnalysis.visit_RaiseStatNodeControlFlowAnalysis.visit_ReraiseStatNodeControlFlowAnalysis.visit_ReturnStatNodeControlFlowAnalysis.visit_ScopedExprNodeControlFlowAnalysis.visit_SingleAssignmentNodeControlFlowAnalysis.visit_SizeofVarNodeControlFlowAnalysis.visit_StatListNodeControlFlowAnalysis.visit_TryExceptStatNodeControlFlowAnalysis.visit_TryFinallyStatNodeControlFlowAnalysis.visit_TypeidNodeControlFlowAnalysis.visit_WhileStatNodeControlFlowAnalysis.visit_WithStatNodeControlFlowAnalysis.visit_WithTargetAssignmentStatNodeControlFlowStateControlFlowState.__init__ControlFlowState.oneControlFlow.__reduce_cython__ControlFlow.__setsta""te_cython__ControlFlow.initializeControlFlow.is_statically_assignedControlFlow.is_trackedControlFlow.map_oneControlFlow.mark_argumentControlFlow.mark_assignmentControlFlow.mark_deletionControlFlow.mark_positionControlFlow.mark_referenceControlFlow.newblockControlFlow.nextblockControlFlow.normalizeCythonTransformCython.Compiler.FlowControlErrorsExceptionDescrExceptionDescr.__init__ExitBlockExitBlock.__reduce_cython__ExitBlock.__setstate_cython__ExitBlock.emptyExprNodeExprNodesForInStatNodeGVGVContextGVContext.__init__GVContext.addGVContext.escapeGVContext.extract_sourcesGVContext.nodeidGVContext.renderGV.__init__GV.renderIntNodeInternalErrorIteratorNodeLoopDescrLoopDescr.__init__MessageCollectionMessageCollection.__reduce_cython__MessageCollection.__setstate_cython__MessageCollection.errorMessageCollection.reportMessageCollection.warningNameAssignmentNameAssignment.__reduce_cython__NameAssignment.__setstate_cython__NameAssignment.infer_typeNameAssignment.type_dependenciesNameDeletionNameDeletion.__init__NameDeletion.infer_typeNameReferenceNameReference.__init__NameReference.__repr__NodesOptimizeOptionsPY_SSIZE_T_MAXParallelRangeNodePyrexTypes__Pyx_PyDict_NextRefSimpleCallNodeStaticAssignmentStaticAssignment.__init__StaticAssignment.infer_typeStaticAssignment.type_dependenciesTreeVisitorTypedExprNodeTypedExprNode.__init__TypedExprNode.may_be_noneUninitializedUninitialized.__reduce_cython__Uninitialized.__setstate_cython__UnknownUnknown.__reduce_cython__Unknown.__setstate_cython__Visitor_addadd_childallow_nullannotate_defsappendargargsassigned_nodesassignmentsasyncio.coroutinesbasesbinop_nodebitblockblockidsblocksbodybody_blockbound1bound2c_py_ssize_t_typecan_coerce_to_pyobjectcf_assignmentscf_is_nullcf_maybe_nullcf_referencescf_statecf_usedchildchildren__class____class_getitem__class_resultclassobjclausecline_in_tracebackcollectorconditioncondition_blockcreate_binop_nodectxdecoratorsdefaultdefinition_delete_privatesdeletiondescrdetach__dict__dict_dictdict_typediscard_""_doc__doc_nodedot_outputeelse_clauseempty__enter__enter_callentriesentryentry_pointenumerateenverrorerror_on_uninitializedescapeexc_valueexcept_clausesexceptionexceptionsexclude__exit__exit_pointexpr_scopeextract_sourcesfalse_valfinally_clausefinally_enterfinally_except_clausefinally_exitfind_in_stackflowfpfrom_closure__func__functiongbodyget_lines__getstate__handleriif_clausesignore_nonexistingin_closurein_try_blockinfer_typeinferable_item_nodeinferred_type__init__initializeis_anonymousis_argis_arrayis_builtinis_builtin_typeis_complex_is_coroutineis_cpp_classis_cpp_optionalis_cython_lock_typeis_deletionis_erroris_generatoris_localis_nameis_pyclass_attris_pyobjectis_sequence_constructoris_singleis_specialis_starredis_statically_assignedis_struct_or_unionis_terminatoris_trackedis_typeis_unspecifiedis_variableistateitemitemsiteratoriterator_typellabellhslhs_listlineslist_typelocal_scopelookuplooploop_block__main__managermap_onemark_argumentmark_assignmentmark_deletionmark_forloop_targetmark_parallel_forloop_assignmentmark_positionmark_referencemaskmaxmay_be_none_may_be_nonemessagemetaclass__metaclass__minmkwmodule__module____mro_entries____name__name__new__newblocknext_blocknext_handlernextblocknextidnodenodeidnormalizenot_noneoneopenoperandoperand1operand2outer_exception_handlersparentparentspatternpidpoppospositions__prepare__private_nodepy_object_type__pyx_checksum__pyx_result__pyx_state__pyx_type__pyx_unpickle_AssignmentCollector__pyx_unpickle_AssignmentList__pyx_unpickle_ControlBlock__pyx_unpickle_ControlFlow__pyx_unpickle_ControlFlowAnalysis__pyx_unpickle_ExitBlock__pyx_unpickle_MessageCollection__pyx_unpickle_NameAssignment__pyx_unpickle_Uninitialized__pyx_unpickle_Unknown__pyx_vtable____qualname__rangerange_type__reduce____reduce_cython____reduce_ex__reductionreductionsremoverenderreplacereport__repr__reversedrhsrhs_scopescopescope_predefined_namesselfsequence__set_name__setdefault__setstate____setstate_cython__sourcessrcdescrstar_argstarstar_argstartstartswit""hstatstatestatsstepstopstripsubexprssupertargettesttexttrue_valtuple_typetypetype_dependenciesunspecified_typeunusedupdateuse_setstateusedvaluevaluesvisit_AmpersandNodevisit_AssertStatNodevisit_AssignmentNodevisit_AsyncForStatNodevisit_BoolBinopNodevisit_BreakStatNodevisit_CArgDeclNodevisit_CClassDefNodevisit_CTypeDefNodevisit_CascadedAssignmentNodevisit_ComprehensionNodevisit_CondExprNodevisit_ContinueStatNodevisit_DefNodevisit_DelStatNodevisit_ForFromStatNodevisit_ForInStatNodevisit_FromImportStatNodevisit_FuncDefNodevisit_GeneratorBodyDefNodevisit_IfStatNodevisit_InPlaceAssignmentNodevisit_LoopNodevisit_ModuleNodevisit_NameNodevisit_Nodevisit_ParallelAssignmentNodevisit_ParallelRangeNodevisit_ParallelWithBlockNodevisit_PyClassDefNodevisit_RaiseStatNodevisit_ReraiseStatNodevisit_ReturnStatNodevisit_ScopedExprNodevisit_SingleAssignmentNodevisit_SizeofVarNodevisit_StatListNodevisit_TryExceptStatNodevisit_TryFinallyStatNodevisit_TypeidNodevisit_WhileStatNodevisit_WithStatNodevisit_WithTargetAssignmentStatNodewwarningwith_nodewritexrange\200\001\330\0041\260\021\260&\270\001\200\001\330\004+\2501\250F\260!\200\001\330\004*\250!\2506\260\021\320\004'\320'7\260q\330\010\013\2104\210t\2205\230\001\330\014\r\330\010\013\2104\210u\220A\330\014\030\230\004\230E\240\033\250B\250a\330\014\020\220\005\220V\230:\240Q\240i\250q\330\014\020\220\005\220Z\230q\340\010\013\2104\210q\330\014\022\220$\220a\330\010\013\2103\210a\330\014\017\210s\220'\230\027\240\001\330\020\030\230\003\2301\340\020\030\230\004\230D\240\007\240q\250\003\2501\330\014\017\210v\220S\230\001\330\020\021\330\014\020\220\005\320\025%\240Q\240e\2505\3200B\300*\310C\310t\320ST\330\r\020\220\001\330\014\020\220\003\2207\230)\2401\240C\240q\330\020\023\2203\220a\340\024 \240\r\250Q\250g\260\\\300\034\310W\320TX\320X[\320[\\\330\025\031\230\023\230D\240\001\330\024 \240\001\340\024 \240\003\320#7\260q\270\001\330\020\024\320\024$\240A\240U\320*?\270q\340\014\020\220\007\220q\230\001\340\010\013\2104\210u\220A\330""\014\030\230\004\230E\240\033\250B\250a\330\014\020\220\005\220V\230:\240Q\240i\250q\330\014\020\220\005\220Z\230q\320\004$\320$8\270\001\330\010\014\210O\2301\330\010\014\320\014\035\230Q\330\010\014\320\014\034\230A\320\0049\270\021\330\010\013\2104\210w\220d\230$\230k\250\021\250!\330\014\031\230\036\240q\250\005\250U\260'\270\032\3001\330\014\020\220\006\220f\230G\2401\240A\330\014\020\220\006\220d\230!\2309\240A\330\014\020\220\010\230\004\230A\230Q\200\001\330\004,\250A\250V\2601\200A\340\010\013\2104\320\017\"\240!\2401\330\014\020\220\005\220^\2401\240A\200A\330\010\013\2104\210q\330\014\020\220\006\220g\230R\230t\2406\250\024\250Q\330\014\020\220\007\220t\2301\340\010\014\210G\2201\220D\230\001\330\010\013\2104\210q\330\014\020\220\006\220d\230$\230f\240D\250\001\330\010\017\210q\200A\340\010\013\2104\210q\330\014\020\220\006\220j\240\004\240A\240T\250\024\250R\250q\200A\330\010\013\2104\210s\220$\220a\330\014\023\2204\220q\330\010\014\210C\210x\220x\230q\240\004\240A\330\014\017\210r\220\023\220A\330\020\027\220q\330\010\017\210q\200A\330\010\013\2104\210t\2205\230\001\340\014\023\2201\330\010\017\210t\2205\230\006\230b\240\001\330\010\014\210N\230!\2301\330\010\014\210M\230\024\230[\250\004\250A\330\014\017\210y\230\001\330\020\024\220E\230\026\230z\250\021\250)\2601\330\020\023\2209\230A\330\024\035\230]\250*\260A\260T\270\021\330\020\021\340\014\020\220\005\220V\230:\240Q\240d\250!\330\010\014\210E\220\031\230!\330\010\017\210q\200A\330\010\013\2104\210u\220A\330\014\023\2201\330\010\020\220\003\2201\220E\230\021\330\010\017\210s\220!\2205\230\001\330\010\023\2205\230\001\230\021\330\010\013\2109\220G\2304\230q\330\014\020\220\010\230\001\230\034\240T\250\021\250(\260*\270A\330\010\020\220\004\220H\230A\230Q\330\010\017\210u\220E\230\021\230!\2301\230F\240#\240T\250\025\250e\2601\260E\270\021\270#\270R\270r\300\024\300Q\300a\200A\330\010\013\2104\210u\220A\330\014\020\220\010\230\004\230A\330\020\024\220G\2301\230A\330\020\023\2204\220t\2305\240\001""\330\024\030\320\030)\250\021\330\024\025\330\010\017\210q\200A\330\010\013\2104\210u\220A\330\014\024\220D\230\007\230s\240$\240d\250'\260\021\260$\260a\330\014\017\210q\330\020\024\220E\230\037\250\001\250\026\250q\340\020\023\2206\230\023\230D\240\014\250D\260\004\260D\270\001\330\024\031\230\021\230$\230a\330\032\033\340\010\017\210q\200A\330\010\013\2104\210u\220E\230\021\330\014\032\230!\340\014\032\230!\330\010\016\210m\2301\330\014\021\220\027\230\014\240M\260\024\260U\270!\330\010\r\210R\210y\230\001\230\025\230e\2401\200A\330\010\013\2104\210w\220d\230$\230k\250\021\250!\330\014\031\230\034\240Q\240f\250A\330\014\020\220\006\220f\230G\2401\240A\330\014\020\220\006\220d\230!\2309\240A\330\014\020\220\010\230\004\230A\230Q\200A\330\010\013\2104\210w\220d\230$\230k\250\021\250!\330\014\020\220\006\220f\230G\2401\240M\260\021\260&\270\001\360\014\000\r\021\220\010\230\004\230A\230Q\200A\330\010\013\2104\210w\220d\230$\230k\250\021\250!\330\014\031\230\030\240\021\240%\240u\250A\330\014\020\220\006\220f\230G\2401\240A\330\014\020\220\006\220d\230!\2309\240A\330\014\020\220\010\230\004\230A\230Q\200A\330\010\013\2104\210x\220q\340\014\020\320\020 \240\001\240\024\240Z\250q\330\010\014\210N\230!\2301\330\010\017\210q\200A\330\010\013\2104\210z\230\023\230A\330\014\020\220\017\230q\330\010\014\210H\220A\330\010\014\210I\220Q\330\010\014\210G\2204\220q\200A\330\010\013\2105\220\001\330\014\023\2201\330\010\020\220\005\220Z\230s\240%\320'8\270\003\2705\300\010\310\001\330\020\025\220^\2403\240e\250<\260q\330\020\025\220Q\200A\330\010\013\2106\220\027\230\004\230A\330\014\020\220\t\230\021\230)\240:\250R\250t\2601\330\014\020\220\013\2301\330\010\017\210t\2209\230A\230Q\200A\330\010\014\320\014\034\230A\230T\240\026\240t\250:\260Q\330\010\017\210q\200A\330\010\013\210>\230\023\230A\330\014\021\220\030\230\021\230!\330\014\020\320\020!\240\021\330\014\017\210t\2201\330\020\024\220N\240!\330\r\025\220S\230\001\330\014\021\220\030\230\021\230!\330\014\020\320\020!\240""\021\340\014\017\210s\220!\2207\230#\230Q\330\020\024\220M\240\021\340\010\r\210R\210y\230\001\330\014\r\210R\210t\2205\230\006\230c\240\021\240%\240w\250a\200A\330\010\030\230\004\230D\240\013\2501\250D\260\006\260a\330\010\014\210D\220\r\230Q\330\020\024\220M\320!8\270\001\270\024\270V\3001\330\014\023\220:\230Q\330\010\014\320\014\035\230Q\330\010\017\210q\200A\330\010\014\320\014\034\230D\240\001\330\014\030\230\006\320\0368\270\001\340\010\014\210N\230!\2301\340\010\014\320\014\035\230Q\230a\340\010\017\210q\200A\330\010\020\220\004\220D\230\007\230q\240\004\240A\330\010\013\2101\330\014\032\230$\230d\240!\330\014\020\220\005\220^\2401\330\020\026\220m\2401\240E\250\027\260\016\270a\330\010\017\210q\200A\330\010\020\220\004\220D\230\007\230t\2404\240t\2501\200A\330\010\014\210E\220\032\2304\230u\240M\260\021\330\021\026\220e\320\033/\250q\330\021\026\220e\230<\240q\330\021\026\220e\230:\240Q\330\021\026\220e\320\0330\260\001\330\022\027\220u\230N\250$\250d\260%\260q\340\014\023\2201\330\010\017\210q\200A\330\010\014\210E\220\032\230;\240f\250A\250T\260\021\330\014\017\210q\330\020\025\220Q\220e\2301\340\020\027\220q\230\005\230Y\240a\200A\340\010\014\210F\220'\230\022\2304\230x\240t\2501\330\010\014\210N\230!\2301\330\010\014\210F\220$\220a\330\010\017\210q\200A\330\010\014\210F\220*\230D\240\001\330\014\017\210u\220C\220q\330\020\024\320\024$\240A\240Q\330\010\014\210N\230!\2301\330\010\017\210q\200A\330\010\014\210G\2201\220D\230\001\330\010\014\320\014\034\230A\230T\240\026\240t\2501\330\010\017\210q\200A\330\010\014\210G\2201\220D\230\001\330\010\014\210G\2201\220D\230\001\330\010\014\210G\2201\220D\230\001\330\010\017\210q\200A\330\010\014\210G\2201\220D\230\001\330\010\014\210G\2204\220q\330\014\020\320\020 \240\001\240\025\240d\250!\330\010\017\210q\200\001\360\010\000\005\r\210A\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220q\330\004\007\200q\330\010\017\320\017(\250\004""\250A\250W\260K\270w\300a\340\010\017\320\017(\250\004\250A\250W\260K\270q\200\001\360\010\000\005\r\210A\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220q\330\004\007\200q\330\010\017\320\017.\250d\260!\2607\270+\300W\310A\340\010\017\320\017.\250d\260!\2607\270+\300Q\200A\330\010\014\210G\2204\220q\330\014\020\220\014\230G\2402\240U\250$\250a\200A\330\010\014\210G\2204\220q\330\014\017\210s\220!\330\020\030\230\003\2307\240#\240T\250\024\250W\260A\260S\270\001\330\020\023\2205\230\014\240C\240u\250A\330\024\031\230\021\230#\230Q\330\032\033\33079\270\025\270a\330\020\023\2204\220t\2301\330\024\030\230\007\230q\240\001\330\020\024\220E\230\036\240q\250\005\250Q\340\020\024\220G\2301\230A\330\010\017\210q\200A\330\010\014\210G\2204\220q\330\014\017\210s\220!\330\020\024\220N\240!\2401\330\010\014\210N\230!\2307\240!\330\010\014\210F\220'\230\022\2304\230v\240T\250\021\330\010\014\210G\2204\220q\330\010\014\210H\220K\230q\360\006\000\t\r\210I\220T\230\034\240X\250W\260A\330\014\017\210t\2205\230\013\2401\240A\330\020\024\220E\230\030\240\024\240Q\240a\340\010\014\210N\230!\2301\340\010\014\210E\220\032\2301\340\010\014\210G\2204\220q\330\014\020\220\007\220q\230\001\330\010\013\2104\210q\330\014\020\220\005\220^\2401\240D\250\001\330$1\260\021\260'\270\021\3302>\270a\330$(\250\t\260\021\330\010\013\2104\210q\330\014\020\220\005\220^\2401\240D\250\001\330$1\260\021\260'\270\021\3302>\270a\330$(\250\r\260Q\330\010\014\210G\2201\220D\230\001\340\010\013\2104\210q\330\014\020\220\007\220q\230\004\230F\240!\360\006\000\t\014\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240d\250%\250q\360\006\000\t\r\210E\220\032\2301\330\010\031\230\021\230$\230g\240T\250\021\330\010\014\210E\220\027\230\004\230A\230T\240\025\240a\340\010\013\2104\210x\220w\230a\330\014\020\220\007\220t\2301\230B\230a\230t\240<\250w\260d\270!\340\010\014\210F\220$\220h\230d\240&\250\004\250A\330\010\017\210q\200A\330\010""\014\210H\220A\330\010\014\210H\220A\200A\330\010\014\210H\220A\330\010\017\210t\320\023%\240Q\240a\200A\330\010\014\210I\220T\230\022\2305\240\006\240a\200A\330\010\014\210I\220T\230\022\2305\240\007\240q\200A\340\010\014\210I\220T\230\021\330\014\021\220\030\230\027\240\001\240\021\330\010\014\210J\220d\230!\330\014\022\220)\2307\240!\2401\330\010\014\210H\220F\230!\330\010\014\210I\220V\2301\200A\330\010\014\210I\220T\230\021\230!\330\010\r\210X\220T\230\021\230!\200A\330\010\014\210I\220W\230A\230Q\200A\340\010\014\210J\220a\360\010\000\t\024\2201\330\010\014\210I\220T\230\021\330\014\025\220^\2401\330\014\022\220(\230&\240\007\240q\330\014\020\220\007\220q\230\t\240\021\330\014\024\220A\340\010\014\210I\220T\230\021\330\014\020\220\010\230\005\230Q\330\020\023\220:\230Q\230f\240A\330\024\030\230\007\230q\330\024\035\230T\240\027\250\001\250\024\250Q\330\024\032\230&\240\007\240q\250\001\330\024\032\230)\2401\330\024\034\230A\340\010\014\210I\220T\230\021\330\014\020\220\007\220x\230u\240D\250\006\250a\330\020\031\230\024\230W\240A\240Q\330\020\023\2205\230\003\2301\330\024\031\230\032\2406\250\021\340\024\031\230\032\2404\240q\330\020\025\220[\240\006\240a\330\014\021\220\034\230U\240!\330\014\020\220\t\230\025\230a\330\020\025\220[\240\004\240G\2501\250F\260!\340\010\014\210J\220d\230'\240\027\250\001\330\014\020\220\014\230J\240f\250A\330\010\014\210L\230\014\240D\250\014\260A\200A\330\010\014\210L\230\001\330\010\014\210J\220a\330\010\014\210L\230\001\330\010\014\210K\220q\200A\330\010\014\210L\230\007\230r\240\024\240V\2504\250q\200A\330\010\014\210N\230!\2301\330\010\013\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240d\250%\250{\270\"\270B\270a\330\010\014\210E\220\031\230!\330\010\017\210q\200A\330\010\014\210N\230!\2301\330\010\014\210N\230!\2301\340\010#\2404\240q\250\004\250E\260\033\270D\300\001\330\010\014\210K\220q\330\014\017\210w\220a\330\020\024\220E\230\026\230z\250\021\250'\260\021\330\020\023\2207\230!\340\024!\240\024\240U\250!\330\024""\030\320\030(\250\001\330\030\033\230<\240q\330\034)\250\034\260Q\330\034\035\330\024\033\230=\250\n\260!\2601\330\020\021\340\014\017\210t\2205\230\001\330\020\024\220E\230\026\230z\250\021\250$\250e\2601\330\010\014\210E\220\031\230!\330\010\017\210q\200A\330\010\014\210N\230!\2301\330\010\014\210N\230!\2301\330\010\013\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240d\250%\250{\270\"\270B\270a\330\010\014\210E\220\031\230!\330\010\013\2104\210u\220A\330\014\020\320\020 \240\001\330\010\017\210q\200A\330\010\014\210N\230!\2301\330\010\014\210N\230!\2301\330\010\017\210q\200A\360\006\000\t\r\210N\230!\2301\330\010\025\220T\230\025\230i\240q\330\010\021\220\024\220U\230!\340\010\021\220\024\220U\230*\240A\240Q\330\010\014\210G\2201\220D\230\001\330\010\014\210E\220\032\2301\330\010\014\210G\2201\220D\230\001\330\010\013\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240a\330\010\016\210j\230\001\230\021\330\010\013\210:\220Q\330\014\020\220\005\220Y\230a\340\014\020\220\005\220Y\230a\330\010\017\210q\200A\330\010\014\210N\230!\2307\240(\250!\330\")\250\031\260!\330\010\014\210E\320\021!\240\021\240$\240i\250t\2601\330\"&\240d\250'\260\021\260$\260g\270Q\330\010\014\210F\220'\230\022\2304\230v\240T\250\021\330\010\014\210G\2204\220q\330\010\014\210E\220\032\2301\330\010\013\2104\210q\330\014\020\220\005\320\025%\240Q\240d\250+\260_\300D\310\t\320QR\330\010\014\210N\230!\2307\240!\330\010\014\210E\220\032\2301\330\010\014\210F\220$\220d\230&\240\004\240A\330\010\017\210q\200A\330\010\014\210N\230!\330\010\014\210N\230!\330\010\014\210N\230!\200A\330\010\014\210O\2301\230F\240&\250\001\200A\340\010\025\220Q\330\010\023\2204\220y\240\001\330\010\021\220\024\220Q\330\010\016\210d\220)\230<\240s\250$\250a\330\010\013\210:\220Q\220j\240\t\250\021\330\014\027\220x\230q\330\014\017\210x\220v\230S\240\005\240T\250\030\260\021\330\020\030\230\003\2307\240!\2408\2501\330\020\023\2204\220v\230S\240\005\240Q\330\024\027\220x\230v\240S\250\013\2604\260s\270!\2708\3007\310#""\310Q\330\030#\2408\2505\260\001\260\021\330\031!\240\026\240s\250,\260d\270#\270Q\270h\300g\310S\320PQ\330\030\033\2306\320!:\270$\270c\300\021\300&\310\007\310s\320RS\330\034'\240x\250u\260A\260Q\330\034\037\230x\240q\330 0\260\010\270\013\3001\300A\330 #\240=\260\001\340$(\320(8\270\001\330(.\250e\2601\260A\330(1\260\030\270\021\270&\300\006\300f\310A\330:?\270z\310\021\33026\260i\270q\330$-\250V\2605\270\001\270\021\330$/\250x\260u\270A\270Q\330\010\013\210:\220Q\220j\240\t\250\021\330\014\027\220x\230q\330\014\017\210x\220v\230S\240\005\240T\250\030\260\031\270$\270h\300f\310D\320PY\320YZ\330\020\030\230\003\2307\240!\2408\2501\330\020\023\2206\230\024\230U\240)\2504\250u\260F\270#\270W\300A\330\024!\240\021\330\024\030\230\007\230x\240u\250B\250a\330\030\034\320\034,\250A\250X\260_\300D\310\t\320QR\330\024\027\220s\230!\2308\2407\250\"\250A\330\030\034\320\034,\250A\250X\260T\3209I\310\021\330\034%\240[\260\001\260\024\260Q\33045\3304<\270E\300\021\300!\3304<\270E\300\021\300!\3306:\270)\3001\340\010\013\2104\210q\360\016\000\r\021\320\020 \240\001\240\030\250\024\320->\270d\300)\3101\200A\330\010\021\220\024\220Q\330\010\014\210G\2204\220u\230B\230a\330\014\020\320\020 \240\001\240\030\250\021\330\010\013\2103\210a\210t\2207\230\"\230A\330\014\020\320\020 \240\001\240\030\250\024\320-=\270Q\330\020\031\230\033\240A\240T\250\021\330()\330(,\250E\260\021\260!\330(,\250E\260\021\260!\330\010\013\2104\210t\2201\340\014\020\320\020 \240\001\240\021\200A\330\010\014\320\014%\240Q\330\010\014\210N\230!\2301\330\010\014\320\014%\240Q\330\010\014\320\014\034\230A\230T\240\026\240t\320+;\2701\270D\320@R\320RS\330\010\017\210q\200A\340\010\021\220\024\220Q\330\010\025\220Q\330\010\016\210a\330\014\023\2205\230\004\230A\330\014\023\2204\220q\230\001\330\014\020\220\t\230\024\230Q\330\020\023\2206\230\027\240\001\330\024\031\230\024\230Q\230a\340\010\033\2304\230x\240r\250\021\340\010\014\210I\220Q\330\014\021\220\027\230\001\340\010\017\210w\220a\220t\2301\360\006\000""\t\r\210I\220Q\330\014\017\210u\220F\230!\330\020\024\220J\230e\2401\330\024\030\230\t\240\025\240a\330\030\036\230j\250\001\250\021\330\020\025\220W\230A\330\020\033\2304\230q\240\001\330\010\014\210K\220q\200A\330\010\014\320\014\035\230T\240\024\240[\260\001\260\024\260[\300\003\3004\300v\310Q\330\010\017\210t\2201\200A\330\010\025\220T\230\021\360\010\000\t\014\2107\220!\2204\220y\240\001\330\014\020\220\016\230c\240\021\240!\340\014\020\320\020 \240\004\240A\330\020\034\230F\320\"<\270A\330\020\025\220\\\240\024\240\\\260\021\260,\270a\330\020\023\2201\330\024\030\230\013\2404\240q\250\014\260A\340\014\023\2204\320\027+\2501\250A\340\010\014\210N\230!\330\010\017\210q\200A\330\010\025\220T\320\031,\250A\250Q\330\010\014\210J\220i\230v\320%5\260Q\340\010\016\320\016\036\230a\330\010\014\320\014\037\230\177\250a\360\006\000\t\r\320\014\035\230Q\340\010\014\320\014%\240Q\330\010\014\210G\2204\220q\330\010\014\210H\220K\230q\330\010\014\210I\220Q\330\010\014\210O\230=\250\001\250\032\3203D\300L\320PQ\330\010\014\210N\230!\2301\340\010\031\230\021\230$\230g\240T\250\021\340\010\013\2101\330\014\034\230D\320 3\2601\260A\330\021\025\220Q\220l\240(\250!\330\020\024\220G\2307\240!\2404\240z\260\036\270q\330\010\017\210q\200A\340\010\025\220T\230\025\230i\240q\340\010\014\210E\220\031\230!\340\010\026\220d\230%\230y\250\001\330\010\014\210E\220\033\230G\2401\240N\260!\2601\330\010\014\210E\220\032\2301\360\006\000\t\r\210E\220\026\220z\240\021\240!\330\010\014\210E\220\032\2301\330\010\014\210E\320\021\"\240!\330\010\014\210G\2201\220D\230\001\330\010\014\210E\320\021\"\240!\330\010\014\210E\220\033\230D\240\001\360\006\000\t\014\2104\210u\220A\330\014\017\210t\2201\330\020\024\220E\230\032\2401\330\020\024\220G\2301\230D\240\001\330\014\017\210t\2205\230\001\330\020\024\220E\230\026\230z\250\021\250!\340\010\014\210J\220d\230!\330\014\020\220\005\220Y\230a\330\014\017\210v\220Q\330\020\024\220K\230v\240Q\330\024\030\230\007\230q\240\001\360\010\000\r\033\230$\230e\2409""\250H\260D\270\005\270Q\330\014\020\220\005\220Z\230q\330\014\017\210v\220Q\330\020\024\320\024$\240A\240V\2509\260F\270!\330\014\020\220\007\220q\230\006\230a\330\014\017\210t\2205\230\001\330\020\024\220E\230\026\230z\250\021\250!\340\010\013\2104\210u\220A\330\014\027\220z\240\021\240$\240e\250;\260b\270\002\270!\340\010\013\210:\220Q\330\014\020\220\005\220Y\230a\340\014\020\220\005\220Y\230a\330\010\017\210q\200A\330\010\025\220T\230\025\230i\240q\330\010\021\220\024\220U\230!\340\010\014\210J\220d\230!\330\014\025\220T\230\025\230j\250\001\250\021\330\014\020\220\007\220q\230\006\230a\330\014\020\220\005\220Z\230q\330\014\020\220\007\220q\230\006\230a\330\014\017\210t\2205\230\001\330\020\024\220E\230\026\230z\250\021\250!\340\010\013\2104\210q\330\014\020\220\005\220Z\230x\240q\330\014\020\220\007\220q\230\004\230A\330\014\017\210t\2205\230\001\330\020\024\220E\230\026\230z\250\021\250!\340\014\022\220*\230A\230Q\340\010\013\210:\220Q\330\014\020\220\005\220Y\230a\340\014\020\220\005\220Y\230a\330\010\017\210q\200A\330\010\025\220T\230\025\230j\250\001\360\006\000\t\027\220d\230%\230y\250\001\330\010\014\210E\220\031\230!\330\010\014\210G\2201\220D\230\001\340\010\013\2104\210u\220G\2304\230t\2405\250\001\330\014\020\220\005\220V\230:\240Q\240d\250%\250{\270\"\270B\270a\360\006\000\t\031\230\004\230E\240\031\250!\330\010\014\210E\220\031\230!\330\010\014\210G\2201\220D\230\001\330\010\027\220t\2305\240\001\340\010\020\220\016\230a\230}\250O\2701\330\010\014\210E\220\033\230G\2401\240A\330\010\013\2104\210u\220A\330\014\020\220\005\220V\2302\230R\230{\250'\260\021\260!\330\010\014\210E\220\031\230!\330\010\022\220*\230A\230Q\330\010\014\210E\220\032\2301\330\010\014\210E\320\021\"\240!\330\010\014\210G\2201\220D\230\001\330\010\014\210E\320\021\"\240!\330\010\014\210E\220\033\230D\240\001\330\010\013\2104\210u\220A\330\014\020\220\005\220V\2302\230R\230{\250$\250a\340\010\013\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240a\330\014\017\210q\330\020\024""\220E\230\031\240$\240e\250:\260X\270Q\340\020\024\220E\230\031\240!\330\010\017\210q\200A\330\010\021\220\021\330\010!\240\024\240W\250A\250Q\330\010\013\2107\220\"\220F\230!\330\014\017\210t\320\023*\250!\2501\330\020\023\2204\220q\320\030(\250\001\250\021\330\021\026\220a\330\020\023\2204\220q\230\001\340\020\023\2204\220q\230\001\360\006\000\t\r\210I\220V\2301\330\014\017\210w\220b\230\005\230Q\330\020\023\2204\220q\230\001\330\010\017\210q\200A\330\010\017\320\017!\240\024\240Z\250{\270$\270a\200A\330\010\032\230$\230e\240:\250Q\330\010\025\220T\230\025\230i\240q\340\010\014\210E\220\026\220w\230a\230y\250\001\250\034\260Q\330\010\013\2104\210q\330\014\020\220\007\220q\230\004\230A\340\010\014\210E\220\032\2301\330\010\014\210G\2201\220D\230\001\330\010\014\210E\220\026\220t\2301\340\010\013\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240a\330\014\020\220\005\220V\230:\240Q\240a\340\010\013\2104\210q\330\014\020\220\005\220Z\230x\240q\330\014\020\220\007\220q\230\004\230A\330\014\017\210t\2205\230\001\330\020\024\220E\230\026\230z\250\021\250!\340\014\033\230:\240Q\240a\340\010\013\210:\220Q\330\014\020\220\005\220Y\230a\340\014\020\220\005\220Y\230a\330\010\017\210q\200A\330\010\032\230$\230e\240:\250Q\330\010\025\220T\230\025\230i\240q\340\010\014\210E\220\026\220w\230a\230y\250\001\250\034\260Q\330\010\014\210G\2201\220D\230\001\340\010\014\210E\220\032\2301\340\010\013\210:\220Q\220f\230E\240\021\330\014\020\320\020$\240A\240Q\330\r\027\220q\230\006\230e\2401\340\014\020\320\020 \240\001\240\024\240Y\250d\260!\330\r\027\220q\230\006\230e\2401\330\014\020\320\0201\260\021\260!\340\014\023\2207\230$\230a\230q\360\010\000\t\r\210E\220\032\2301\330\010\014\210G\2201\220D\230\001\330\010\014\210E\220\026\220t\2301\360\006\000\t\014\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240a\340\010\013\2104\210q\330\014\020\220\005\220Z\230x\240q\330\014\020\220\007\220q\230\004\230A\330\014\017\210t\2205\230\001\330\020\024\220E\230\026\230z\250\021\250!\340""\014\033\230:\240Q\240a\340\010\013\210:\220Q\330\014\020\220\005\220Y\230a\340\014\020\220\005\220Y\230a\330\010\017\210q\200A\330\010\032\230$\230e\240:\250Q\330\010\025\220T\230\025\230i\240q\340\010\014\210E\220\026\220w\230a\230y\250\001\250\034\260Q\330\010\014\210G\2201\220D\230\001\330\010\014\210G\2201\220D\230\001\330\010\013\2104\210v\220W\230A\330\014\020\220\007\220q\230\004\230A\340\010\014\210E\220\032\2301\330\010\014\320\014\034\230A\230T\240\031\250$\250a\330\010\013\2104\210v\220W\230A\330\014\020\320\020 \240\001\240\024\240Y\250d\3202B\300!\330\020\031\230\033\240A\240T\250\026\250u\260D\270\t\300\024\300Q\340\010\014\210E\220\032\2301\330\010\014\210G\2201\220D\230\001\330\010\014\210E\220\026\220t\2301\340\010\013\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240a\340\010\013\2104\210q\330\014\020\220\005\220Z\230x\240q\330\014\020\220\007\220q\230\004\230A\330\014\017\210t\2205\230\001\330\020\024\220E\230\026\230z\250\021\250!\340\014\033\230:\240Q\240a\340\010\013\210:\220Q\330\014\020\220\005\220Y\230a\340\014\020\220\005\220Y\230a\330\010\017\210q\200A\330\010\026\220i\230q\240\006\240e\2505\260\001\330\010\014\210J\220a\200A\330\010\026\220i\230q\240\006\240e\2505\260\001\330\010\014\210O\2301\200A\330\010\016\210m\2301\230A\200A\330\010\016\210m\2301\320\034;\2702\270T\300\021\300!\200A\330\010\017\210q\200A\330\010\024\320\024'\240q\330\010\021\220\036\230q\240\001\330\010\014\210E\220\027\230\t\240\021\330\014\020\220\007\220q\230\001\330\010\014\210E\220\027\230\t\240\021\330\014\020\320\020 \240\001\240\025\240a\330\010\017\210q\200A\330\010\017\210s\220!\2204\220{\240#\240Q\330\010\014\210G\2201\220D\230\001\330\010\021\220\024\220U\230!\330\010\025\220T\230\025\230i\240q\330\010\014\210E\220\032\2301\330\010\014\210G\2201\220D\230\001\330\010\013\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240a\330\010\014\210E\220\032\2308\2401\330\010\014\210G\2201\220D\230\001\330\010\013\2104\210u\220A\330\014\020\220\005\220V\230:""\240Q\240a\340\010\013\210:\220Q\330\014\020\220\005\220Y\230a\340\014\020\220\005\220Y\230a\330\010\017\210q\200A\340\010\017\210s\220!\2204\220{\240#\240Q\340\010\025\220T\230\025\230i\240q\330\010\021\220\024\220U\230!\340\010\014\210G\2201\220D\230\001\340\010\014\210E\220\032\2301\330\010\014\210G\2201\220D\230\001\330\010\013\2104\210u\220A\330\014\020\220\005\220V\230:\240Q\240a\340\010\016\210j\230\001\230\021\340\010\013\210:\220Q\330\014\020\220\005\220Y\230a\340\014\020\220\005\220Y\230a\330\010\017\210q\200A\330\010\017\210t\2201\220A\200A\330\010\017\210t\2204\320\027)\250\021\250$\250k\270\023\270D\300\006\300a\200A\330\010\017\210t\2206\230\021\200A\330\010\017\210t\2208\2301\230E\240\026\240x\250q\260\006\260a\200A\330\010\017\210t\220>\240\023\240A\200A\330\010\017\210t\320\023'\240q\250\001\200A\360\006\000\t\020\210z\230\021\230'\240\031\250/\270\031\320BX\320XY\330\010\013\2104\210q\330\014\020\220\006\220g\230R\230t\2406\250\024\250Q\330\014\020\220\010\230\004\230N\250!\2504\250q\330\014\020\220\007\220t\2301\330\010\014\210N\230!\2301\330\010\013\2104\210q\330\014\020\220\006\220d\230(\240$\240f\250D\260\001\330\010\017\210q\320\004-\250Q\330\010\014\320\014\034\230D\240\001\330\014\017\210t\2208\2303\230l\250'\260\027\270\001\330\020\024\220E\230\036\240q\250\016\260l\300!\200\001\330\004%\240Q\240f\250A\200\001\360\010\000\005\016\210T\220\032\2304\230{\250$\250f\260D\270\010\300\004\300J\310d\320R[\320[_\320_j\320jn\320nx\320x|\360\000\000}\001G\002\360\000\000G\002K\002\360\000\000K\002W\002\360\000\000W\002[\002\360\000\000[\002\\\002\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\2309\240G\2505\260\003\2604\260z\300\027\310\005\310S\320PT\320TY\320Y`\320`e\320eh\320hl\320ls\320sz\320z\177\360\000\000@\002C\002\360\000\000C\002G\002\360\000\000G\002P\002\360\000\000P\002W\002\360\000\000W\002\\\002\360\000\000\\\002_\002\360\000\000_\002c\002\360\000\000c""\002k\002\360\000\000k\002r\002\360\000\000r\002w\002\360\000\000w\002z\002\360\000\000z\002~\002\360\000\000~\002H\003\360\000\000H\003O\003\360\000\000O\003T\003\360\000\000T\003W\003\360\000\000W\003[\003\360\000\000[\003d\003\360\000\000d\003k\003\360\000\000k\003p\003\360\000\000p\003s\003\360\000\000s\003w\003\360\000\000w\003@\004\360\000\000@\004G\004\360\000\000G\004L\004\360\000\000L\004O\004\360\000\000O\004S\004\360\000\000S\004^\004\360\000\000^\004e\004\360\000\000e\004j\004\360\000\000j\004m\004\360\000\000m\004q\004\360\000\000q\004x\004\360\000\000x\004\177\004\360\000\000\177\004@\005\330\004\007\200q\330\010\017\320\017-\250T\260\021\260'\270\033\300G\3101\340\010\017\320\017-\250T\260\021\260'\270\033\300A\200\001\360\010\000\005\016\210T\220\032\2304\230{\250$\250f\260D\270\010\300\004\300J\310d\320R[\320[_\320_j\320jn\320nx\320x|\360\000\000}\001G\002\360\000\000G\002K\002\360\000\000K\002W\002\360\000\000W\002[\002\360\000\000[\002\\\002\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\2309\240G\2505\260\003\2604\260z\300\027\310\005\310S\320PT\320TY\320Y`\320`e\320eh\320hl\320ls\320sz\320z\177\360\000\000@\002C\002\360\000\000C\002G\002\360\000\000G\002P\002\360\000\000P\002W\002\360\000\000W\002\\\002\360\000\000\\\002_\002\360\000\000_\002c\002\360\000\000c\002k\002\360\000\000k\002r\002\360\000\000r\002w\002\360\000\000w\002z\002\360\000\000z\002~\002\360\000\000~\002H\003\360\000\000H\003O\003\360\000\000O\003T\003\360\000\000T\003W\003\360\000\000W\003[\003\360\000\000[\003d\003\360\000\000d\003k\003\360\000\000k\003p\003\360\000\000p\003s\003\360\000\000s\003w\003\360\000\000w\003@\004\360\000\000@\004G\004\360\000\000G\004L\004\360\000\000L\004O\004\360\000\000O\004S\004\360\000\000S\004^\004\360\000\000^\004e\004\360\000\000e\004j\004\360\000\000j\004m\004\360\000\000m\004q\004\360\000\000q\004x\004\360\000\000x\004\177\004\360\000\000\177\004@\005\330\004""\007\200q\330\010\017\320\017*\250$\250a\250w\260k\300\027\310\001\340\010\017\320\017*\250$\250a\250w\260k\300\021\200\001\360\010\000\005\016\210T\220\021\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\230:\240W\250A\330\004\007\200q\330\010\017\320\0172\260$\260a\260w\270k\310\027\320PQ\340\010\017\320\0172\260$\260a\260w\270k\310\021\200\001\360\010\000\005\016\210T\220\031\230$\230h\240d\250)\2604\260z\300\024\300^\320SW\320Wd\320dh\320hu\320uy\360\000\000z\001I\002\360\000\000I\002M\002\360\000\000M\002N\002\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\2308\2407\250%\250s\260$\260g\270W\300E\310\023\310D\320PX\320X_\320_d\320dg\320gk\320kt\320t{\360\000\000|\001A\002\360\000\000A\002D\002\360\000\000D\002H\002\360\000\000H\002U\002\360\000\000U\002\\\002\360\000\000\\\002a\002\360\000\000a\002d\002\360\000\000d\002h\002\360\000\000h\002t\002\360\000\000t\002{\002\360\000\000{\002@\003\360\000\000@\003C\003\360\000\000C\003G\003\360\000\000G\003S\003\360\000\000S\003Z\003\360\000\000Z\003_\003\360\000\000_\003b\003\360\000\000b\003f\003\360\000\000f\003m\003\360\000\000m\003t\003\360\000\000t\003u\003\330\004\007\200q\330\010\017\320\017,\250D\260\001\260\027\270\013\3007\310!\340\010\017\320\017,\250D\260\001\260\027\270\013\3001\200\001\360\010\000\005\016\210T\220\026\220t\2307\240$\240a\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\2305\240\007\240u\250C\250t\2606\270\027\300\005\300S\310\004\310G\320SZ\320Z[\330\004\007\200q\330\010\017\320\017/\250t\2601\260G\270;\300g\310Q\340\010\017\320\017/\250t\2601\260G\270;\300a\200\001\360\010\000\005\016\210T\220\026\220t\2308\2404\320'7\260t\2709\300D\310\016\320VZ\320Z`\320`d\320dj\320jn\320nu\320uy\320y\177\360\000\000@\002D\002\360\000\000D\002E\002\330\004\014\210G""\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\2305\240\007\240u\250C\250t\2607\270'\300\025\300c\310\024\310_\320\\c\320ch\320hk\320ko\320ot\320t{\360\000\000|\001A\002\360\000\000A\002D\002\360\000\000D\002H\002\360\000\000H\002M\002\360\000\000M\002T\002\360\000\000T\002Y\002\360\000\000Y\002\\\002\360\000\000\\\002`\002\360\000\000`\002f\002\360\000\000f\002m\002\360\000\000m\002r\002\360\000\000r\002u\002\360\000\000u\002y\002\360\000\000y\002~\002\360\000\000~\002E\003\360\000\000E\003J\003\360\000\000J\003M\003\360\000\000M\003Q\003\360\000\000Q\003\\\003\360\000\000\\\003c\003\360\000\000c\003d\003\330\004\007\200q\330\010\017\320\017/\250t\2601\260G\270;\300g\310Q\340\010\017\320\017/\250t\2601\260G\270;\300a\200\001\360\010\000\005\016\210T\220\036\230t\320#5\260T\270\032\3004\320G\\\320\\`\320`q\320qu\320u{\320{\177\360\000\000@\002G\002\360\000\000G\002K\002\360\000\000K\002T\002\360\000\000T\002X\002\360\000\000X\002p\002\360\000\000p\002t\002\360\000\000t\002B\003\360\000\000B\003F\003\360\000\000F\003S\003\360\000\000S\003W\003\360\000\000W\003X\003\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\230=\250\007\250u\260C\260t\320;L\310G\320SX\320X[\320[_\320_h\320ho\320ot\320tw\320w{\360\000\000|\001P\002\360\000\000P\002W\002\360\000\000W\002\\\002\360\000\000\\\002_\002\360\000\000_\002c\002\360\000\000c\002s\002\360\000\000s\002z\002\360\000\000z\002\177\002\360\000\000\177\002B\003\360\000\000B\003F\003\360\000\000F\003K\003\360\000\000K\003R\003\360\000\000R\003W\003\360\000\000W\003Z\003\360\000\000Z\003^\003\360\000\000^\003d\003\360\000\000d\003k\003\360\000\000k\003p\003\360\000\000p\003s\003\360\000\000s\003w\003\360\000\000w\003\177\003\360\000\000\177\003F\004\360\000\000F\004K\004\360\000\000K\004N\004\360\000\000N\004R\004\360\000\000R\004_\004\360\000\000_\004f\004\360\000\000f\004k\004\360\000""\000k\004n\004\360\000\000n\004r\004\360\000\000r\004~\004\360\000\000~\004E\005\360\000\000E\005J\005\360\000\000J\005M\005\360\000\000M\005Q\005\360\000\000Q\005X\005\360\000\000X\005_\005\360\000\000_\005`\005\330\004\007\200q\330\010\017\320\0174\260D\270\001\270\027\300\013\3107\320RS\340\010\017\320\0174\260D\270\001\270\027\300\013\3101\200\001\360\010\000\005\016\210T\220\036\230t\240>\260\024\260Q\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\230=\250\007\250u\260C\260t\270=\310\007\310u\320TW\320W[\320[k\320kr\320rs\330\004\007\200q\330\010\017\320\0174\260D\270\001\270\027\300\013\3107\320RS\340\010\017\320\0174\260D\270\001\270\027\300\013\3101\200\001\330\004)\250\021\250&\260\001\320\004\036\230a\360\n\000\t\021\220\014\230A\330\010\014\210G\2204\220q\230\001\330\010\013\2101\330\014\022\220*\230A\230Q\330\010\017\210q\320\004\036\230a\330\010\n\210&\220\001\320\021$\240B\240d\250!\330\010\014\210I\220T\230\025\230a\330\014\024\220C\320\027'\240q\250\001\330\014\017\210q\330\020\024\220H\230E\240\021\330\024\027\220z\240\021\240&\250\001\330\030!\240\021\330\034 \240\006\240g\250^\2704\320?Q\320Q_\320_c\320cg\320gh\320hi\330\031#\2401\240F\250!\330\030\033\2304\230q\330\034%\320%?\270t\3006\310\027\320PT\320TX\320XY\320YZ\330\014\017\210t\2201\330\020\030\230\001\330\014\022\220#\220W\230A\230Q\330\014\016\210f\220A\320\025/\250u\260C\260w\270a\270q\330\010\014\210I\220T\230\025\230a\330\014\022\220#\220W\230A\230Q\330\014\020\220\t\230\025\230a\330\020\022\220&\230\001\320\031,\250E\260\023\260G\2701\270A\330\010\n\210&\220\001\220\021\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\220>\240\030\250\021\250!\330\004\007\200|\2207\230!\330\0100\260\001\3201B\300.\320PQ\330\004\013\2101\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\2207\230(\240!\2401\330\004\007\200|\2207\230!\330\010)\250\021\250*\260N\300!\330\004\013\2101\200""\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\220=\240\010\250\001\250\021\330\004\007\200|\2207\230!\330\010/\250q\3200@\300\016\310a\330\004\013\2101\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\2209\230H\240A\240Q\330\004\007\200|\2207\230!\330\010+\2501\250L\270\016\300a\330\004\013\2101\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\320\023$\240H\250A\250Q\330\004\007\200|\2207\230!\330\0103\2601\3204H\310\016\320VW\330\004\013\2101\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\320\023&\240h\250a\250q\330\004\007\200|\2207\230!\330\0105\260Q\3206L\310N\320Z[\330\004\013\2101\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\220;\230h\240a\240q\330\004\007\200|\2207\230!\330\010-\250Q\250n\270N\310!\330\004\013\2101\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\220<\230x\240q\250\001\330\004\007\200|\2207\230!\330\010.\250a\250\177\270n\310A\330\004\013\2101\320\004\037\230q\360\n\000\t\021\220\014\230A\330\010\014\210G\2204\220q\230\001\330\010\013\2101\330\014\022\220*\230A\230Q\330\r\021\220\021\330\014\020\220\006\220j\240\001\240\021\330\010\014\210I\220Q\330\010\017\210t\2201\320\004\037\230q\340\010\n\210&\220\001\320\021\"\240\"\240A\330\010\n\210&\220\001\220\021\330\010\014\210I\220T\230\021\330\014\021\220\027\230\001\230\024\230V\2401\330\010\n\210&\220\001\220\021\320\004\035\320\035/\250q\330\010\r\210R\210y\230\001\230\021\330\010\014\210H\220A\330\010\014\320\014\034\230A\200\001\330\004'\240q\250\006\250a\200\001\330\004/\250q\260\006\260a";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 532; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 61) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 532; i < 647; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 647; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 532;
      for (Py_ssize_t i=0; i<115; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,-1,1,2};
    int32_t const cint_constants_4[] = {9995728L,48084501L,105766659L,161667023L,211101602L,238750788L,243737303L,257740027L};
    for (int i = 0; i < 12; i++) {
      numbertab[i] = PyLong_FromLong((i < 4 ? cint_constants_1[i - 0] : cint_constants_4[i - 4]));
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<12; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 3;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 4;
    unsigned int flags : 10;
    unsigned int first_line : 11;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 22};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_type, __pyx_mstate->__pyx_n_u_may_be_none, __pyx_mstate->__pyx_n_u_pos};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_q_Ry_HA_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 27};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_may_be_none, __pyx_mstate->__pyx_kp_b_iso88591_A_t_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 72};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_empty, __pyx_mstate->__pyx_kp_b_iso88591_A_D_t4t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 75};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_detach, __pyx_mstate->__pyx_kp_b_iso88591_A_IT_Jd_7_1_HF_IV1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 84};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_block};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_add_child, __pyx_mstate->__pyx_kp_b_iso88591_A_IT_XT, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_4_fD_JdR___jjnnxx_G_G_K_K_W_W, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_6, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 92};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_empty, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_4_fD_JdR___jjnnxx_G_G_K_K_W_W_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_t7_a_G1F_a_vWE_Q_q_t5_uCt6_S, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_AV1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 126};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_parent};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_newblock, __pyx_mstate->__pyx_kp_b_iso88591_a_A_G4q_1_AQ_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 137};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_parent};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_nextblock, __pyx_mstate->__pyx_kp_b_iso88591_q_A_G4q_1_AQ_j_IQ_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 151};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_is_tracked, __pyx_mstate->__pyx_kp_b_iso88591_A_5_1_Zs_8_5_3e_q_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 158};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_is_statically_assigned, __pyx_mstate->__pyx_kp_b_iso88591_A_E_4uM_e_q_e_q_e_Q_e_0_uN_d_q_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 169};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_position, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_j_AT_Rq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 174};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_lhs, __pyx_mstate->__pyx_n_u_rhs, __pyx_mstate->__pyx_n_u_entry, __pyx_mstate->__pyx_n_u_rhs_scope};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_assignment, __pyx_mstate->__pyx_kp_b_iso88591_9_4wd_k_q_U_1_fG1A_d_9A_AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 181};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_lhs, __pyx_mstate->__pyx_n_u_rhs, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_argument, __pyx_mstate->__pyx_kp_b_iso88591_A_4wd_k_uA_fG1A_d_9A_AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 188};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_deletion, __pyx_mstate->__pyx_kp_b_iso88591_A_4wd_k_QfA_fG1A_d_9A_AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 195};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_reference, __pyx_mstate->__pyx_kp_b_iso88591_A_4wd_k_fG1M_AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 205};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_normalize, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_Q_a_5_A_4q_Q_6_Qa_4xr_IQ_wat, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 233};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_initialize, __pyx_mstate->__pyx_kp_b_iso88591_A_Ja_1_IT_1_q_q_A_IT_Q_QfA_q_T_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 271};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_istate, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_map_one, __pyx_mstate->__pyx_kp_b_iso88591_A_WAQ_7_F_t_1_4q_a_4q_4q_IV1_wb, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_hd_4z_SWWddhhuuy_z_I_I_M_M_N, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591__21, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 308};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_next_block, __pyx_mstate->__pyx_n_u_loop_block};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_N_N_N, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 322};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_entry_point, __pyx_mstate->__pyx_n_u_finally_enter, __pyx_mstate->__pyx_n_u_finally_exit};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_8_O1_Q_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 347};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_infer_type, __pyx_mstate->__pyx_kp_b_iso88591_A_T_4vQ_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 351};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_type_dependencies, __pyx_mstate->__pyx_kp_b_iso88591_A_t4_k_D_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_t84_7t9D_VZZ_ddjjnnuuyy_D_D_E, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_AV1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 363};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_entry, __pyx_mstate->__pyx_n_u_may_be_none, __pyx_mstate->__pyx_n_u_lhs};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_4uE_m1_M_U_Ry_e1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 372};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_infer_type, __pyx_mstate->__pyx_kp_b_iso88591_A_t6, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 375};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[34] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_type_dependencies, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[34])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 380};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_lhs, __pyx_mstate->__pyx_n_u_rhs, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[35] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_iq_e5_Ja, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[35])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 386};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_lhs, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[36] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_iq_e5_O1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[36])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 390};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_inferred_type};
    __pyx_mstate_global->__pyx_codeobj_tab[37] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_infer_type, __pyx_mstate->__pyx_kp_b_iso88591_A_D_1D_a_D_Q_M_8_V1_Q_Q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[37])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[38] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_A_G1F_a_vWE_Q_q_q_q_d_7_WA_d_7, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[38])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[39] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_1F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[39])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[40] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_A_G1F_a_vWE_Q_q_q_q_AWKwa_AWKq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[40])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[41] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_QfA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[41])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 408};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[42] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_4z_A_q_HA_IQ_G4q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[42])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 415};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[43] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_repr, __pyx_mstate->__pyx_kp_b_iso88591_A_Z_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[43])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 430};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_i};
    __pyx_mstate_global->__pyx_codeobj_tab[44] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_A_t1_N_S_s_7_Q_M_Ry_Rt5_c_wa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[44])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 446};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[45] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_one, __pyx_mstate->__pyx_kp_b_iso88591_A_t1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[45])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 453};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[46] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_L_Ja_L_Kq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[46])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 459};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_child};
    __pyx_mstate_global->__pyx_codeobj_tab[47] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_add, __pyx_mstate->__pyx_kp_b_iso88591_A_IWAQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[47])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 462};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_block};
    __pyx_mstate_global->__pyx_codeobj_tab[48] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_nodeid, __pyx_mstate->__pyx_kp_b_iso88591_A_6_A_Rt1_1_t9AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[48])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 468};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_block, __pyx_mstate->__pyx_n_u_start, __pyx_mstate->__pyx_n_u_stop, __pyx_mstate->__pyx_n_u_srcdescr, __pyx_mstate->__pyx_n_u_lines, __pyx_mstate->__pyx_n_u_l};
    __pyx_mstate_global->__pyx_codeobj_tab[49] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_extract_sources, __pyx_mstate->__pyx_kp_b_iso88591_A_4uA_1_1E_s_5_5_9G4q_T_A_HAQ_uE, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[49])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 479};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_fp, __pyx_mstate->__pyx_n_u_name_2, __pyx_mstate->__pyx_n_u_annotate_defs, __pyx_mstate->__pyx_n_u_child};
    __pyx_mstate_global->__pyx_codeobj_tab[50] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_render, __pyx_mstate->__pyx_kp_b_iso88591_q_A_IT_V1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[50])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 487};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[51] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_escape, __pyx_mstate->__pyx_kp_b_iso88591_A_t81E_xq_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[51])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 494};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name_2, __pyx_mstate->__pyx_n_u_flow};
    __pyx_mstate_global->__pyx_codeobj_tab[52] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_HA_HA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[52])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 9, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 498};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_fp, __pyx_mstate->__pyx_n_u_ctx, __pyx_mstate->__pyx_n_u_annotate_defs, __pyx_mstate->__pyx_n_u_block, __pyx_mstate->__pyx_n_u_label_2, __pyx_mstate->__pyx_n_u_stat, __pyx_mstate->__pyx_n_u_pid, __pyx_mstate->__pyx_n_u_child};
    __pyx_mstate_global->__pyx_codeobj_tab[53] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_render, __pyx_mstate->__pyx_kp_b_iso88591_a_Bd_IT_a_C_q_q_HE_z_g_4_QQ__cc, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[53])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 526};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_message};
    __pyx_mstate_global->__pyx_codeobj_tab[54] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_error, __pyx_mstate->__pyx_kp_b_iso88591_A_IT_5_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[54])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 529};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_message};
    __pyx_mstate_global->__pyx_codeobj_tab[55] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_warning, __pyx_mstate->__pyx_kp_b_iso88591_A_IT_5_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[55])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 532};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_is_error, __pyx_mstate->__pyx_n_u_message};
    __pyx_mstate_global->__pyx_codeobj_tab[56] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_report, __pyx_mstate->__pyx_kp_b_iso88591_A_E_fAT_q_Qe1_q_Ya, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[56])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[57] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_G1F_a_vWE_Q_q_t_WA_q_2_awk_PQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[57])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[58] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_q_a_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[58])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 685};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[59] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_Node, __pyx_mstate->__pyx_kp_b_iso88591_A_O1F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[59])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 688};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[60] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_SingleAssignmentNode, __pyx_mstate->__pyx_kp_b_iso88591_A_L_r_V4q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[60])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 691};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_lhs};
    __pyx_mstate_global->__pyx_codeobj_tab[61] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_CascadedAssignmentNode, __pyx_mstate->__pyx_kp_b_iso88591_A_G4q_G2U_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[61])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[62] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_t_Q_G1F_a_vWE_Q_q_t_uCt_uTWW, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[62])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[63] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[63])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 698};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_env, __pyx_mstate->__pyx_n_u_e, __pyx_mstate->__pyx_n_u_flow};
    __pyx_mstate_global->__pyx_codeobj_tab[64] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_find_in_stack, __pyx_mstate->__pyx_kp_b_iso88591_A_4s_a_4q_Cxxq_A_r_A_q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[64])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 706};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_dot_output, __pyx_mstate->__pyx_n_u_ConstantFolding, __pyx_mstate->__pyx_n_u_annotate_defs, __pyx_mstate->__pyx_n_u_fp};
    __pyx_mstate_global->__pyx_codeobj_tab[65] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ModuleNode, __pyx_mstate->__pyx_kp_b_iso88591_A_T_AQ_Jiv_5Q_a_a_Q_Q_G4q_HKq_IQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[65])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 731};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_arg, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[66] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_FuncDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_G4q_s_N_1_N_7_F_4vT_G4q_HKq_IT, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[66])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 781};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[67] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_DefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_HA_t_Qa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[67])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 785};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[68] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_GeneratorBodyDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[68])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 788};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[69] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_CTypeDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[69])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 791};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_lhs, __pyx_mstate->__pyx_n_u_rhs, __pyx_mstate->__pyx_n_u_rhs_scope};
    __pyx_mstate_global->__pyx_codeobj_tab[70] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_assignment, __pyx_mstate->__pyx_kp_b_iso88591_7q_4t5_4uA_E_Ba_V_Qiq_Zq_4q_a_3, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[70])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 827};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[71] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_position, __pyx_mstate->__pyx_kp_b_iso88591_A_4_1_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[71])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 832};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_name_2, __pyx_mstate->__pyx_n_u_target};
    __pyx_mstate_global->__pyx_codeobj_tab[72] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_FromImportStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_F_D_uCq_AQ_N_1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[72])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 839};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[73] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_AssignmentNode, __pyx_mstate->__pyx_kp_b_iso88591_A_m1_2T, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[73])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 842};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[74] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_SingleAssignmentNode, __pyx_mstate->__pyx_kp_b_iso88591_A_G1D_AT_t1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[74])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 847};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_lhs};
    __pyx_mstate_global->__pyx_codeobj_tab[75] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_CascadedAssignmentNode, __pyx_mstate->__pyx_kp_b_iso88591_A_G1D_G4q_d_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[75])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 853};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_collector, __pyx_mstate->__pyx_n_u_lhs, __pyx_mstate->__pyx_n_u_rhs};
    __pyx_mstate_global->__pyx_codeobj_tab[76] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ParallelAssignmentNode, __pyx_mstate->__pyx_kp_b_iso88591_A_q_q_E_q_E_a_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[76])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 862};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[77] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_InPlaceAssignmentNode, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_N_1_Q_AT_t_1D_RRS_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[77])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 869};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_arg, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[78] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_DelStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_G4q_s_7_T_WAS_5_CuA_Q_79_a_4t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[78])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 884};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_entry, __pyx_mstate->__pyx_n_u_may_be_none};
    __pyx_mstate_global->__pyx_codeobj_tab[79] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_CArgDeclNode, __pyx_mstate->__pyx_kp_b_iso88591_A_D_q_A_1_d_1_m1E_a_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[79])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 892};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_entry};
    __pyx_mstate_global->__pyx_codeobj_tab[80] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_NameNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4uA_D_s_d_a_q_E_q_6_D_D_D_a_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[80])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 904};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_stat};
    __pyx_mstate_global->__pyx_codeobj_tab[81] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_StatListNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4uA_A_G1A_4t5_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[81])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 913};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[82] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_Node, __pyx_mstate->__pyx_kp_b_iso88591_A_N_1_N_1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[82])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 918};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[83] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_SizeofVarNode, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[83])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 921};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[84] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_TypeidNode, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[84])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 924};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_next_block, __pyx_mstate->__pyx_n_u_parent, __pyx_mstate->__pyx_n_u_clause};
    __pyx_mstate_global->__pyx_codeobj_tab[85] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_IfStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_T_iq_U_Jd_T_j_q_a_Zq_q_a_t5_E, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[85])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 950};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_next_block, __pyx_mstate->__pyx_n_u_parent};
    __pyx_mstate_global->__pyx_codeobj_tab[86] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_AssertStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_N_1_T_iq_U_U_AQ_G1D_E_1_G1D_4u, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[86])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 970};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_condition_block, __pyx_mstate->__pyx_n_u_next_block};
    __pyx_mstate_global->__pyx_codeobj_tab[87] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_WhileStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_e_Q_T_iq_E_way_Q_4q_q_A_E_1_G1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[87])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 11, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1000};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_is_special, __pyx_mstate->__pyx_n_u_sequence, __pyx_mstate->__pyx_n_u_target, __pyx_mstate->__pyx_n_u_env, __pyx_mstate->__pyx_n_u_function, __pyx_mstate->__pyx_n_u_entry, __pyx_mstate->__pyx_n_u_iterator, __pyx_mstate->__pyx_n_u_iterator_type, __pyx_mstate->__pyx_n_u_arg};
    __pyx_mstate_global->__pyx_codeobj_tab[88] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_forloop_target, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_4y_Q_d_s_a_Qj_xq_xvS_T_7_81, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[88])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1052};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_target, __pyx_mstate->__pyx_n_u_arg};
    __pyx_mstate_global->__pyx_codeobj_tab[89] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_mark_parallel_forloop_assignment, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_G4uBa_3at7_A_Q_AT_E_E_4t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[89])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1066};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[90] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_AsyncForStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_t_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[90])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1069};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_condition_block, __pyx_mstate->__pyx_n_u_next_block};
    __pyx_mstate_global->__pyx_codeobj_tab[91] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ForInStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_e_Q_T_iq_E_way_Q_G1D_E_1_QfE_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[91])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1112};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_exclude, __pyx_mstate->__pyx_n_u_private_node};
    __pyx_mstate_global->__pyx_codeobj_tab[92] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_delete_privates, __pyx_mstate->__pyx_kp_b_iso88591_Q_D_t83l_E_q_l, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[92])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1117};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_reductions, __pyx_mstate->__pyx_n_u_private_node, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_reduction};
    __pyx_mstate_global->__pyx_codeobj_tab[93] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ParallelRangeNode, __pyx_mstate->__pyx_kp_b_iso88591_A_T_7_4y_c_A_F_A_a_1_4q_A_4_1A_N, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[93])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1136};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_private_node};
    __pyx_mstate_global->__pyx_codeobj_tab[94] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ParallelWithBlockNode, __pyx_mstate->__pyx_kp_b_iso88591_A_D_8_N_1_Qa_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[94])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1146};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_condition_block, __pyx_mstate->__pyx_n_u_next_block};
    __pyx_mstate_global->__pyx_codeobj_tab[95] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ForFromStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_e_Q_T_iq_E_way_Q_G1D_G1D_4vWA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[95])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1183};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[96] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_LoopNode, __pyx_mstate->__pyx_kp_b_iso88591_A_m1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[96])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1186};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[97] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_WithTargetAssignmentStatNo, __pyx_mstate->__pyx_kp_b_iso88591_A_AT_t_Q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[97])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1190};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[98] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_WithStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_G1D_G1D_G1D_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[98])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1196};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_next_block, __pyx_mstate->__pyx_n_u_entry_point, __pyx_mstate->__pyx_n_u_clause, __pyx_mstate->__pyx_n_u_pattern};
    __pyx_mstate_global->__pyx_codeobj_tab[99] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_TryExceptStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_T_iq_E_d_y_E_G1N_1_E_1_E_z_E_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[99])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1247};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_body_block, __pyx_mstate->__pyx_n_u_entry_point, __pyx_mstate->__pyx_n_u_finally_enter, __pyx_mstate->__pyx_n_u_finally_exit, __pyx_mstate->__pyx_n_u_descr};
    __pyx_mstate_global->__pyx_codeobj_tab[100] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_TryFinallyStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_T_j_d_y_E_G1D_4uG4t5_V_Qd_Ba_E, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[100])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1286};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[101] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_RaiseStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_N_1_N_1_4uA_V_Qd_Ba_E_4uA_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[101])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1296};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[102] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ReraiseStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_N_1_4uA_V_Qd_Ba_E_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[102])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1303};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_outer_exception_handlers, __pyx_mstate->__pyx_n_u_handler, __pyx_mstate->__pyx_n_u_exit_point, __pyx_mstate->__pyx_n_u_next_handler};
    __pyx_mstate_global->__pyx_codeobj_tab[103] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ReturnStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_N_1_N_1_4q_E_D_Kq_wa_E_z_7_U_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[103])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1326};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_loop, __pyx_mstate->__pyx_n_u_exception};
    __pyx_mstate_global->__pyx_codeobj_tab[104] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_BreakStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4t5_1_t5_b_N_1_M_A_y_E_z_1_9A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[104])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1343};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_loop, __pyx_mstate->__pyx_n_u_exception};
    __pyx_mstate_global->__pyx_codeobj_tab[105] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ContinueStatNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4t5_1_t5_b_N_1_M_A_y_E_z_1_9A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[105])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1360};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u__16};
    __pyx_mstate_global->__pyx_codeobj_tab[106] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ComprehensionNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_gRt6_Q_t1_G1D_4q_d_fD_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[106])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1370};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[107] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_ScopedExprNode, __pyx_mstate->__pyx_kp_b_iso88591_A_z_BXXY_4q_gRt6_Q_N_4q_t1_N_1_4, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[107])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1383};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u__16};
    __pyx_mstate_global->__pyx_codeobj_tab[108] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_PyClassDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_N_7_E_it1_d_gQ_F_4vT_G4q_E_1_4, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[108])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1398};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[109] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_CClassDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_F_4xt1_N_1_F_a_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[109])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1405};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[110] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_AmpersandNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4xq_Zq_N_1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[110])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1412};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_next_block, __pyx_mstate->__pyx_n_u_parent};
    __pyx_mstate_global->__pyx_codeobj_tab[111] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_BoolBinopNode, __pyx_mstate->__pyx_kp_b_iso88591_A_s_4_Q_T_iq_U_G1D_E_1_G1D_4uA_V, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[111])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1434};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_parent, __pyx_mstate->__pyx_n_u_next_block};
    __pyx_mstate_global->__pyx_codeobj_tab[112] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_FlowControl_py, __pyx_mstate->__pyx_n_u_visit_CondExprNode, __pyx_mstate->__pyx_kp_b_iso88591_A_s_4_Q_G1D_U_T_iq_E_1_G1D_4uA_V, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[112])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_3, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[113] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_t_5T_4G_qquu_G_G_K_K_T_T_X_X, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[113])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[114] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[114])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[115] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_ControlBlock, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_xq_7_a_nA_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[115])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[116] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_ExitBlock, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_9HAQ_7_1L_a_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[116])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[117] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_AssignmentList, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_7_0_1B_PQ_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[117])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[118] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_ControlFlow, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_haq_7_QnN_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[118])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[119] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_NameAssignment, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_7_0_1B_PQ_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[119])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[120] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_Uninitialized, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_7_q0_a_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[120])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[121] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_Unknown, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_7_1_7_N_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[121])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[122] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_MessageCollection, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_HAQ_7_314H_VW_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[122])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[123] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_AssignmentCollect, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_haq_7_5Q6LNZ_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[123])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[124] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_ControlFlowAnalys, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_haq_7_5Q6LNZ_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[124])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* RejectKeywords */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds) {
    PyObject *key = NULL;
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds))) {
        key = __Pyx_PySequence_ITEM(kwds, 0);
    } else {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *pos = NULL;
#else
        Py_ssize_t pos = 0;
#endif
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
        if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return;
#endif
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL);
#if CYTHON_AVOID_BORROWED_REFS
        Py_XDECREF(pos);
#endif
    }
    if (likely(key)) {
        PyErr_Format(PyExc_TypeError,
            "%s() got an unexpected keyword argument '%U'",
            function_name, key);
        Py_DECREF(key);
    }
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* IterFinish (used by set_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* set_iter */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    is_set = is_set || likely(PySet_CheckExact(iterable) || PyFrozenSet_CheckExact(iterable));
    *p_source_is_set = is_set;
    if (likely(is_set)) {
        *p_orig_length = PySet_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#else
    CYTHON_UNUSED_VAR(is_set);
    *p_source_is_set = 0;
#endif
    *p_orig_length = 0;
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set) {
    if (!CYTHON_COMPILING_IN_CPYTHON || PY_VERSION_HEX >= 0x030d0000 || unlikely(!source_is_set)) {
        *value = PyIter_Next(iter_obj);
        if (unlikely(!*value)) {
            return __Pyx_IterFinish();
        }
        CYTHON_UNUSED_VAR(orig_length);
        CYTHON_UNUSED_VAR(ppos);
        return 1;
    }
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    if (unlikely(PySet_GET_SIZE(iter_obj) != orig_length)) {
        PyErr_SetString(
            PyExc_RuntimeError,
            "set changed size during iteration");
        return -1;
    }
    {
        Py_hash_t hash;
        int ret = _PySet_NextEntry(iter_obj, ppos, value, &hash);
        assert (ret != -1);
        if (likely(ret)) {
            Py_INCREF(*value);
            return 1;
        }
    }
#endif
    return 0;
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyLong_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyLong_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* PyObjectVectorCallKwBuilder */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* PyObjectCallNoArg (used by pyfrozenset_new) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* pyfrozenset_new (used by PySetContains) */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
#if CYTHON_COMPILING_IN_LIMITED_API
            || __Pyx_get_runtime_version() >= 0x030A0000
#endif
            )
            return result;
        {
            Py_ssize_t size = __Pyx_PySet_GET_SIZE(result);
            if (likely(size > 0))
                return result;
#if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely(size < 0)) {
                Py_DECREF(result);
                return NULL;
            }
#endif
        }
        Py_DECREF(result);
#endif
    }
    return __Pyx_PyObject_CallNoArg((PyObject*) &PyFrozenSet_Type);
}

/* PySetContains */
static int __Pyx_PySet_ContainsUnhashable(PyObject *set, PyObject *key) {
    int result = -1;
    if (PySet_Check(key) && PyErr_ExceptionMatches(PyExc_TypeError)) {
        PyObject *tmpkey;
        PyErr_Clear();
        tmpkey = __Pyx_PyFrozenSet_New(key);
        if (tmpkey != NULL) {
            result = PySet_Contains(set, tmpkey);
            Py_DECREF(tmpkey);
        }
    }
    return result;
}
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq) {
    int result = PySet_Contains(set, key);
    if (unlikely(result < 0)) {
        result = __Pyx_PySet_ContainsUnhashable(set, key);
    }
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* py_set_discard_unhashable (used by py_set_remove) */
static int __Pyx_PySet_DiscardUnhashable(PyObject *set, PyObject *key) {
    PyObject *tmpkey;
    int rv;
    if (likely(!PySet_Check(key) || !PyErr_ExceptionMatches(PyExc_TypeError)))
        return -1;
    PyErr_Clear();
    tmpkey = __Pyx_PyFrozenSet_New(key);
    if (tmpkey == NULL)
        return -1;
    rv = PySet_Discard(set, tmpkey);
    Py_DECREF(tmpkey);
    return rv;
}

/* py_set_remove */
static int __Pyx_PySet_RemoveNotFound(PyObject *set, PyObject *key, int found) {
    if (unlikely(found < 0)) {
        found = __Pyx_PySet_DiscardUnhashable(set, key);
    }
    if (likely(found == 0)) {
        PyObject *tup;
        tup = PyTuple_Pack(1, key);
        if (!tup)
            return -1;
        PyErr_SetObject(PyExc_KeyError, tup);
        Py_DECREF(tup);
        return -1;
    }
    return found;
}
static CYTHON_INLINE int __Pyx_PySet_Remove(PyObject *set, PyObject *key) {
    int found = PySet_Discard(set, key);
    if (unlikely(found != 1)) {
        return __Pyx_PySet_RemoveNotFound(set, key, found);
    }
    return 0;
}

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_LshiftObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceLshift : PyNumber_Lshift)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
#if __clang__ || __GNUC__
__attribute__((no_sanitize("shift")))
#endif
static PyObject* __Pyx_Unpacked___Pyx_PyLong_LshiftObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
#if (defined(__cplusplus) && __cplusplus >= 202002L)\
        || (defined(__GNUC__) || (defined(__clang__))) &&\
            (defined(__arm__) || defined(__x86_64__) || defined(__i386__))\
        || (defined(_MSC_VER) &&\
            (defined(_M_ARM) || defined(_M_AMD64) || defined(_M_IX86)))
    const int negative_shift_works = 1;
#else
    const int negative_shift_works = 0;
#endif
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op1);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_lshift(op1, op2);
    }
    calculate_long:
        if ((!negative_shift_works) && unlikely(a < 0)) goto fallback;
        {
            long x;
            x = a << b;
            if (unlikely(!(b < (long) (sizeof(long)*8) && a == x >> b)) && a) {
                lla = a;
                goto calculate_long_long;
            }
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla << llb;
            if (unlikely(lla != llx >> llb)) goto fallback;
            return PyLong_FromLongLong(llx);
        }
    fallback:
        return __Pyx_Fallback___Pyx_PyLong_LshiftObjC(op1, op2, inplace);
    
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyLong_LshiftObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_LshiftObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    return __Pyx_Fallback___Pyx_PyLong_LshiftObjC(op1, op2, inplace);
}
#endif

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod0 (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* RaiseNeedMoreValuesToUnpack (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseNoneIterError (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
        PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple) {
    if (likely(is_tuple || PyTuple_Check(tuple))) {
        Py_ssize_t size;
        if (has_known_size) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        size = __Pyx_PyTuple_GET_SIZE(tuple);
        if (likely(size == 2)) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        if (size >= 0) {
            __Pyx_UnpackTupleError(tuple, 2);
        }
        return -1;
    } else {
        return __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple);
    }
}
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
    value1 = __Pyx_PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = __Pyx_PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#else
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
#if !CYTHON_AVOID_BORROWED_REFS
static CYTHON_INLINE int __Pyx_dict_iter_next_source_is_dict(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem) {
    PyObject *key, *value;
    if (unlikely(orig_length != PyDict_Size(iter_obj))) {
        PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
        return -1;
    }
    if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
        return 0;
    }
    if (pitem) {
        PyObject* tuple = PyTuple_New(2);
        if (unlikely(!tuple)) {
            return -1;
        }
        Py_INCREF(key);
        Py_INCREF(value);
        #if CYTHON_ASSUME_SAFE_MACROS
        PyTuple_SET_ITEM(tuple, 0, key);
        PyTuple_SET_ITEM(tuple, 1, value);
        #else
        if (unlikely(PyTuple_SetItem(tuple, 0, key) < 0)) {
            Py_DECREF(value);
            Py_DECREF(tuple);
            return -1;
        }
        if (unlikely(PyTuple_SetItem(tuple, 1, value) < 0)) {
            Py_DECREF(tuple);
            return -1;
        }
        #endif
        *pitem = tuple;
    } else {
        if (pkey) {
            Py_INCREF(key);
            *pkey = key;
        }
        if (pvalue) {
            Py_INCREF(value);
            *pvalue = value;
        }
    }
    return 1;
}
#endif
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_AVOID_BORROWED_REFS
    if (source_is_dict) {
        int result;
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_BEGIN_CRITICAL_SECTION(iter_obj);
#endif
        result = __Pyx_dict_iter_next_source_is_dict(iter_obj, orig_length, ppos, pkey, pvalue, pitem);
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_END_CRITICAL_SECTION();
#endif
        return result;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(tuple_size < 0)) return -1;
        #endif
        if (unlikely(pos >= tuple_size)) return 0;
        *ppos = pos + 1;
        #if CYTHON_ASSUME_SAFE_MACROS
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        #else
        next_item = PyTuple_GetItem(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
        #endif
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t list_size = __Pyx_PyList_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(list_size < 0)) return -1;
        #endif
        if (unlikely(pos >= list_size)) return 0;
        *ppos = pos + 1;
        next_item = __Pyx_PyList_GetItemRef(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* PyObjectCall2Args (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod1 (used by append) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_mstate_global->__pyx_n_u_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op2);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a + b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla + llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_AddObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) + (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_AddObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_AddObjC(op1, op2, inplace);
}
#endif

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return PyLong_FromLong(-intval);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a - b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla - llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_SubtractObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) - (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_SubtractObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_SubtractObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_SubtractObjC(op1, op2, inplace);
}
#endif

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* py_set_discard */
static CYTHON_INLINE int __Pyx_PySet_Discard(PyObject *set, PyObject *key) {
    int found = PySet_Discard(set, key);
    if (unlikely(found < 0)) {
        found = __Pyx_PySet_DiscardUnhashable(set, key);
    }
    return found;
}

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON
static int
__Pyx_unicode_modifiable(PyObject *unicode, int unsafe_shared)
{
    if (!__Pyx_IS_UNIQUELY_REFERENCED(unicode, unsafe_shared))
        return 0;
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030F0000
    if (PyUnstable_Unicode_GET_CACHED_HASH(unicode) != -1)
        return 0;
#endif
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left, unsafe_shared)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__17);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* pop */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (__Pyx_IS_TYPE(L, &PySet_Type)) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_mstate_global->__pyx_n_u_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* CallTypeTraverse */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    destructor tp_dealloc = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_dealloc, destructor) != current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_dealloc = __Pyx_PyType_GetSlot(type, tp_dealloc, destructor)) == current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type)
        tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    traverseproc tp_traverse = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc) != current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_traverse = __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc)) == current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_traverse)
        return tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    inquiry tp_clear = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_clear, inquiry) != current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_clear = __Pyx_PyType_GetSlot(type, tp_clear, inquiry)) == current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_clear)
        tp_clear(obj);
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i=0;
    Py_ssize_t size;
    void** base_vtables;
    __Pyx_TypeName tp_base_name = NULL;
    __Pyx_TypeName base_name = NULL;
    void* unknown = (void*)-1;
    PyObject* bases = __Pyx_PyType_GetSlot(type, tp_bases, PyObject*);
    int base_depth = 0;
    {
        PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        while (base) {
            base_depth += 1;
            base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
        }
    }
    base_vtables = (void**) PyMem_Malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
#if CYTHON_COMPILING_IN_LIMITED_API
    size = PyTuple_Size(bases);
    if (size < 0) goto other_failure;
#else
    size = PyTuple_GET_SIZE(bases);
#endif
    for (i = 1; i < size; i++) {
        PyObject *basei;
        void* base_vtable;
#if CYTHON_AVOID_BORROWED_REFS
        basei = PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#else
        basei = PyTuple_GET_ITEM(bases, i);
#endif
        base_vtable = __Pyx_GetVtable((PyTypeObject*)basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
            }
        }
    }
    PyErr_Clear();
    PyMem_Free(base_vtables);
    return 0;
bad:
    {
        PyTypeObject* basei = NULL;
        PyTypeObject* tp_base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        tp_base_name = __Pyx_PyType_GetFullyQualifiedName(tp_base);
#if CYTHON_AVOID_BORROWED_REFS
        basei = (PyTypeObject*)PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = (PyTypeObject*)PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#else
        basei = (PyTypeObject*)PyTuple_GET_ITEM(bases, i);
#endif
        base_name = __Pyx_PyType_GetFullyQualifiedName(basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
    }
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
really_bad: // bad has failed!
#endif
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
other_failure:
#endif
    PyMem_Free(base_vtables);
    return -1;
}

/* DelItemOnTypeDict (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_DelItem(tp_dict, k);
    if (likely(!result)) PyType_Modified(tp);
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_mstate_global->__pyx_n_u_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_mstate_global->__pyx_n_u_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython);
            if (likely(reduce_cython)) {
                ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_mstate_global->__pyx_n_u_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetFullyQualifiedName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_2_4
#define __PYX_HAVE_RT_ImportType_3_2_4
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size)
{
    PyObject *result = 0;
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API)
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !( defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API) )
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    if (size == 0) {
        return (PyTypeObject *)result;
    }
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_2_4 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_2_4 && (size_t)basicsize > size) {
        if (PyErr_WarnFormat(NULL, 0,
                "%.200s.%.200s size changed, may indicate binary incompatibility. "
                "Expected %zd from C header, got %zd from PyObject",
                module_name, class_name, size, basicsize) < 0) {
            goto bad;
        }
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base = NULL, *meth, *new_base, *result, *new_bases = NULL;
#if CYTHON_ASSUME_SAFE_SIZE
    size_bases = PyTuple_GET_SIZE(bases);
#else
    size_bases = PyTuple_Size(bases);
    if (size_bases < 0) return NULL;
#endif
    for (i = 0; i < size_bases; i++) {
#if CYTHON_AVOID_BORROWED_REFS
        Py_CLEAR(base);
#endif
#if CYTHON_ASSUME_SAFE_MACROS
        base = PyTuple_GET_ITEM(bases, i);
#else
        base = PyTuple_GetItem(bases, i);
        if (!base) goto error;
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(base);
#endif
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_mstate_global->__pyx_n_u_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                PyObject *base_from_list;
#if CYTHON_ASSUME_SAFE_MACROS
                base_from_list = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base_from_list);
                Py_INCREF(base_from_list);
#else
                base_from_list = PyTuple_GetItem(bases, j);
                if (!base_from_list) goto error;
                Py_INCREF(base_from_list);
                if (PyList_SetItem(new_bases, j, base_from_list) < 0) goto error;
#endif
            }
        }
#if CYTHON_ASSUME_SAFE_SIZE
        j = PyList_GET_SIZE(new_bases);
#else
        j = PyList_Size(new_bases);
        if (j < 0) goto error;
#endif
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return result;
error:
    Py_XDECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_SIZE
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
        metaclass = &PyType_Type;
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_mstate_global->__pyx_n_u_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_module_2, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_mstate_global->__pyx_n_u_metaclass_2);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
    Py_XDECREF(owned_metaclass);
    return result;
}

/* CyFunctionClassCell */
static int __Pyx_CyFunction_InitClassCell(PyObject *cyfunctions, PyObject *classobj) {
    Py_ssize_t i, count = __Pyx_PyList_GET_SIZE(cyfunctions);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(count < 0)) return -1;
    #endif
    for (i = 0; i < count; i++) {
        __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *)
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && !CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
            PyList_GET_ITEM(cyfunctions, i);
#else
            __Pyx_PySequence_ITEM(cyfunctions, i);
        if (unlikely(!m))
            return -1;
#endif
        __Pyx_CyFunction_SetClassObj(m, classobj);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && !CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
        Py_DECREF((PyObject*)m);
#endif
    }
    return 0;
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CheckUnpickleChecksum */
static void __Pyx_RaiseUnpickleChecksumError(long checksum, long checksum1, long checksum2, long checksum3, const char *members) {
    PyObject *pickle_module = PyImport_ImportModule("pickle");
    if (unlikely(!pickle_module)) return;
    PyObject *pickle_error = PyObject_GetAttrString(pickle_module, "PickleError");
    Py_DECREF(pickle_module);
    if (unlikely(!pickle_error)) return;
    if (checksum2 == checksum1) {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x) = (%s))",
            checksum, checksum1, members);
    } else if (checksum3 == checksum2) {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x, 0x%x) = (%s))",
            checksum, checksum1, checksum2, members);
    } else {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x, 0x%x, 0x%x) = (%s))",
            checksum, checksum1, checksum2, checksum3, members);
    }
    Py_DECREF(pickle_error);
}
static int __Pyx_CheckUnpickleChecksum(long checksum, long checksum1, long checksum2, long checksum3, const char *members) {
    int found = 0;
    found |= checksum1 == checksum;
    found |= checksum2 == checksum;
    found |= checksum3 == checksum;
    if (likely(found))
        return 0;
    __Pyx_RaiseUnpickleChecksumError(checksum, checksum1, checksum2, checksum3, members);
    return -1;
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* UpdateUnpickledDict */
static int __Pyx__UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index) {
    PyObject *state_dict = __Pyx_PySequence_ITEM(state, index);
    if (unlikely(!state_dict)) {
        return -1;
    }
    int non_empty = PyObject_IsTrue(state_dict);
    if (non_empty == 0) {
        Py_DECREF(state_dict);
        return 0;
    } else if (unlikely(non_empty == -1)) {
        return -1;
    }
    PyObject *dict;
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    dict = PyObject_GetAttrString(obj, "__dict__");
    #else
    dict = PyObject_GenericGetDict(obj, NULL);
    #endif
    if (unlikely(!dict)) {
        Py_DECREF(state_dict);
        return -1;
    }
    int result;
    if (likely(PyDict_CheckExact(dict))) {
        result = PyDict_Update(dict, state_dict);
    } else {
        PyObject *obj_result = __Pyx_PyObject_CallMethod1(dict, __pyx_mstate_global->__pyx_n_u_update, state_dict);
        if (likely(obj_result)) {
            Py_DECREF(obj_result);
            result = 0;
        } else {
            result = -1;
        }
    }
    Py_DECREF(state_dict);
    Py_DECREF(dict);
    return result;
}
static int __Pyx_UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index) {
    Py_ssize_t state_size = __Pyx_PyTuple_GET_SIZE(state);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(state_size == -1)) return -1;
    #endif
    if (state_size <= index) {
        return 0;
    }
    return __Pyx__UpdateUnpickledDict(obj, state, index);
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module_2);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__20);
    }
    goto done;
}
#endif

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
